@@ -1,17 +1,19 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a code metrics dialog.
 """
 
+from __future__ import unicode_literals
+
 import os
 import fnmatch
 
-from PyQt4.QtCore import pyqtSlot, Qt, QLocale, qVersion
-from PyQt4.QtGui import QDialog, QDialogButtonBox, QMenu, QHeaderView, \
+from PyQt5.QtCore import pyqtSlot, Qt, QLocale, qVersion
+from PyQt5.QtWidgets import QDialog, QDialogButtonBox, QMenu, QHeaderView, \
     QTreeWidgetItem, QApplication
 
 from .Ui_CodeMetricsDialog import Ui_CodeMetricsDialog
@@ -30,8 +32,9 @@ class CodeMetricsDialog(QDialog, Ui_CodeMetricsDialog):
         
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(CodeMetricsDialog, self).__init__(parent)
         self.setupUi(self)
+        self.setWindowFlags(Qt.Window)
         
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
@@ -46,9 +49,9 @@ class CodeMetricsDialog(QDialog, Ui_CodeMetricsDialog):
         self.cancelled = False
         
         self.__menu = QMenu(self)
-        self.__menu.addAction(self.trUtf8("Collapse all"),
+        self.__menu.addAction(self.tr("Collapse all"),
                               self.__resultCollapse)
-        self.__menu.addAction(self.trUtf8("Expand all"), self.__resultExpand)
+        self.__menu.addAction(self.tr("Expand all"), self.__resultExpand)
         self.resultList.setContextMenuPolicy(Qt.CustomContextMenu)
         self.resultList.customContextMenuRequested.connect(
             self.__showContextMenu)
@@ -185,19 +188,19 @@ class CodeMetricsDialog(QDialog, Ui_CodeMetricsDialog):
         # now do the summary stuff
         docstrings = total['lines'] - total['comments'] - \
             total['empty lines'] - total['non-commentary lines']
-        self.__createSummaryItem(self.trUtf8("files"),
+        self.__createSummaryItem(self.tr("files"),
                                  loc.toString(total['files']))
-        self.__createSummaryItem(self.trUtf8("lines"),
+        self.__createSummaryItem(self.tr("lines"),
                                  loc.toString(total['lines']))
-        self.__createSummaryItem(self.trUtf8("bytes"),
+        self.__createSummaryItem(self.tr("bytes"),
                                  loc.toString(total['bytes']))
-        self.__createSummaryItem(self.trUtf8("comments"),
+        self.__createSummaryItem(self.tr("comments"),
                                  loc.toString(total['comments']))
-        self.__createSummaryItem(self.trUtf8("empty lines"),
+        self.__createSummaryItem(self.tr("empty lines"),
                                  loc.toString(total['empty lines']))
-        self.__createSummaryItem(self.trUtf8("non-commentary lines"),
+        self.__createSummaryItem(self.tr("non-commentary lines"),
                                  loc.toString(total['non-commentary lines']))
-        self.__createSummaryItem(self.trUtf8("documentation lines"),
+        self.__createSummaryItem(self.tr("documentation lines"),
                                  loc.toString(docstrings))
         self.__resizeSummaryColumns()
         self.__finish()
@@ -215,7 +218,7 @@ class CodeMetricsDialog(QDialog, Ui_CodeMetricsDialog):
         v = []
         for key in ('start', 'end', 'lines', 'nloc', 'comments', 'empty'):
             if counters.get(key, 0):
-                v.append(counters[key])
+                v.append(loc.toString(counters[key]))
             else:
                 v.append('')
         return v
