@@ -1,16 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a Python code coverage dialog.
 """
 
+from __future__ import unicode_literals
+
 import os
 
-from PyQt4.QtCore import pyqtSlot, Qt
-from PyQt4.QtGui import QDialog, QDialogButtonBox, QMenu, QHeaderView, \
+from PyQt5.QtCore import pyqtSlot, Qt
+from PyQt5.QtWidgets import QDialog, QDialogButtonBox, QMenu, QHeaderView, \
     QTreeWidgetItem, QApplication
 
 from E5Gui import E5MessageBox
@@ -34,8 +36,9 @@ class PyCoverageDialog(QDialog, Ui_PyCoverageDialog):
         
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(PyCoverageDialog, self).__init__(parent)
         self.setupUi(self)
+        self.setWindowFlags(Qt.Window)
         
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
@@ -53,15 +56,15 @@ class PyCoverageDialog(QDialog, Ui_PyCoverageDialog):
         self.__menu = QMenu(self)
         self.__menu.addSeparator()
         self.openAct = self.__menu.addAction(
-            self.trUtf8("Open"), self.__openFile)
+            self.tr("Open"), self.__openFile)
         self.__menu.addSeparator()
         self.annotate = self.__menu.addAction(
-            self.trUtf8('Annotate'), self.__annotate)
-        self.__menu.addAction(self.trUtf8('Annotate all'), self.__annotateAll)
+            self.tr('Annotate'), self.__annotate)
+        self.__menu.addAction(self.tr('Annotate all'), self.__annotateAll)
         self.__menu.addAction(
-            self.trUtf8('Delete annotated files'), self.__deleteAnnotated)
+            self.tr('Delete annotated files'), self.__deleteAnnotated)
         self.__menu.addSeparator()
-        self.__menu.addAction(self.trUtf8('Erase Coverage Info'), self.__erase)
+        self.__menu.addAction(self.tr('Erase Coverage Info'), self.__erase)
         self.resultList.setContextMenuPolicy(Qt.CustomContextMenu)
         self.resultList.customContextMenuRequested.connect(
             self.__showContextMenu)
@@ -240,10 +243,10 @@ class PyCoverageDialog(QDialog, Ui_PyCoverageDialog):
         if total_exceptions:
             E5MessageBox.warning(
                 self,
-                self.trUtf8("Parse Error"),
-                self.trUtf8("""%n file(s) could not be parsed. Coverage"""
-                            """ info for these is not available.""", "",
-                            total_exceptions))
+                self.tr("Parse Error"),
+                self.tr("""%n file(s) could not be parsed. Coverage"""
+                        """ info for these is not available.""", "",
+                        total_exceptions))
         
         self.__finish()
         
@@ -343,9 +346,10 @@ class PyCoverageDialog(QDialog, Ui_PyCoverageDialog):
         
         # now process them
         progress = E5ProgressDialog(
-            self.trUtf8("Annotating files..."), self.trUtf8("Abort"),
-            0, len(files), self.trUtf8("%v/%m Files"), self)
+            self.tr("Annotating files..."), self.tr("Abort"),
+            0, len(files), self.tr("%v/%m Files"), self)
         progress.setMinimumDuration(0)
+        progress.setWindowTitle(self.tr("Coverage"))
         count = 0
         
         for file in files:
