@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -203,6 +203,7 @@ class DebugClientBase(object):
         
         # The context to run the debugged program in.
         self.debugMod = imp.new_module('__main__')
+        self.debugMod.__dict__['__builtins__'] = __builtins__
 
         # The list of complete lines to execute.
         self.buffer = ''
@@ -307,7 +308,7 @@ class DebugClientBase(object):
     
     def __dumpThreadList(self):
         """
-        Public method to send the list of threads.
+        Private method to send the list of threads.
         """
         threadList = []
         if self.threads and self.currentThread:
@@ -324,7 +325,10 @@ class DebugClientBase(object):
             d = {}
             d["id"] = -1
             d["name"] = "MainThread"
-            d["broken"] = self.isBroken()
+            if hasattr(self, "isBroken"):
+                d["broken"] = self.isBroken()
+            else:
+                d["broken"] = False
             threadList.append(d)
         
         self.write('%s%s\n' % (DebugProtocol.ResponseThreadList,
@@ -1284,9 +1288,11 @@ class DebugClientBase(object):
             frmnr -= 1
         
         if f is None:
-            return
-        
-        if scope:
+            if scope:
+                dict = self.debugMod.__dict__
+            else:
+                scope = -1
+        elif scope:
             dict = f.f_globals
         else:
             dict = f.f_locals
@@ -1327,9 +1333,11 @@ class DebugClientBase(object):
             frmnr -= 1
         
         if f is None:
-            return
-        
-        if scope:
+            if scope:
+                dict = self.debugMod.__dict__
+            else:
+                scope = -1
+        elif scope:
             dict = f.f_globals
         else:
             dict = f.f_locals
@@ -1420,7 +1428,8 @@ class DebugClientBase(object):
                             exec 'mdict = dict%s.__dict__' % access
                             ndict.update(mdict)     # __IGNORE_WARNING__
                             exec 'obj = dict%s' % access
-                            if "PyQt4." in str(type(obj)):
+                            if "PyQt4." in str(type(obj)) or \
+                                    "PyQt5." in str(type(obj)):
                                 qtVariable = True
                                 qvar = obj
                                 qvtype = ("%s" % type(qvar))[1:-1]\
@@ -1430,7 +1439,7 @@ class DebugClientBase(object):
                         try:
                             exec 'mcdict = dict%s.__class__.__dict__' % access
                             ndict.update(mcdict)     # __IGNORE_WARNING__
-                            if mdict and not "sipThis" in mdict.keys(): # __IGNORE_WARNING__
+                            if mdict and not "sipThis" in mdict.keys():  # __IGNORE_WARNING__
                                 del rvar[0:2]
                                 access = ""
                         except:
@@ -1446,7 +1455,8 @@ class DebugClientBase(object):
                             ndict.update(cdict)
                             exec 'obj = dict%s' % access
                             access = ""
-                            if "PyQt4." in str(type(obj)):
+                            if "PyQt4." in str(type(obj)) or \
+                                    "PyQt5." in str(type(obj)):
                                 qtVariable = True
                                 qvar = obj
                                 qvtype = ("%s" % type(qvar))[1:-1]\
@@ -1459,7 +1469,8 @@ class DebugClientBase(object):
                             ndict.update(dict[var[i]].__class__.__dict__)
                             del rvar[0]
                             obj = dict[var[i]]
-                            if "PyQt4." in str(type(obj)):
+                            if "PyQt4." in str(type(obj)) or \
+                                    "PyQt5." in str(type(obj)):
                                 qtVariable = True
                                 qvar = obj
                                 qvtype = ("%s" % type(qvar))[1:-1]\
@@ -1476,7 +1487,8 @@ class DebugClientBase(object):
                                     pass
                             ndict.update(cdict)
                             obj = dict[var[i]]
-                            if "PyQt4." in str(type(obj)):
+                            if "PyQt4." in str(type(obj)) or \
+                                    "PyQt5." in str(type(obj)):
                                 qtVariable = True
                                 qvar = obj
                                 qvtype = ("%s" % type(qvar))[1:-1]\
@@ -1488,7 +1500,7 @@ class DebugClientBase(object):
                 i += 1
             
             if qtVariable:
-                vlist = self.__formatQt4Variable(qvar, qvtype)
+                vlist = self.__formatQtVariable(qvar, qvtype)
             elif ("sipThis" in dict.keys() and len(dict) == 1) or \
                     (len(dict) == 0 and len(udict) > 0):
                 if access:
@@ -1499,8 +1511,8 @@ class DebugClientBase(object):
                 else:
                     qvar = udict[var[-1]]
                 qvtype = ("%s" % type(qvar))[1:-1].split()[1][1:-1]
-                if qvtype.startswith("PyQt4"):
-                    vlist = self.__formatQt4Variable(qvar, qvtype)
+                if qvtype.startswith(("PyQt4", "PyQt5")):
+                    vlist = self.__formatQtVariable(qvar, qvtype)
                 else:
                     vlist = []
             else:
@@ -1514,11 +1526,11 @@ class DebugClientBase(object):
                     else:
                         qvar = udict[var[-1]]
                     qvtype = ("%s" % type(qvar))[1:-1].split()[1][1:-1]
-                    if qvtype.startswith("PyQt4"):
+                    if qvtype.startswith(("PyQt4", "PyQt5")):
                         qtVariable = True
                 
                 if qtVariable:
-                    vlist = self.__formatQt4Variable(qvar, qvtype)
+                    vlist = self.__formatQtVariable(qvar, qvtype)
                 else:
                     # format the dictionary found
                     if dictkeys is None:
@@ -1551,7 +1563,7 @@ class DebugClientBase(object):
         self.write('%s%s\n' % (
             DebugProtocol.ResponseVariable, unicode(varlist)))
         
-    def __formatQt4Variable(self, value, vtype):
+    def __formatQtVariable(self, value, vtype):
         """
         Private method to produce a formated output of a simple Qt4/Qt5 type.
         
@@ -1601,12 +1613,12 @@ class DebugClientBase(object):
         elif qttype == 'QColor':
             varlist.append(("name", "str", "%s" % value.name()))
             r, g, b, a = value.getRgb()
-            varlist.append(("rgb", "int", "%d, %d, %d, %d" % (r, g, b, a)))
+            varlist.append(("rgba", "int", "%d, %d, %d, %d" % (r, g, b, a)))
             h, s, v, a = value.getHsv()
-            varlist.append(("hsv", "int", "%d, %d, %d, %d" % (h, s, v, a)))
+            varlist.append(("hsva", "int", "%d, %d, %d, %d" % (h, s, v, a)))
             c, m, y, k, a = value.getCmyk()
             varlist.append(
-                ("cmyk", "int", "%d, %d, %d, %d, %d" % (c, m, y, k, a)))
+                ("cmyka", "int", "%d, %d, %d, %d, %d" % (c, m, y, k, a)))
         elif qttype == 'QDate':
             varlist.append(("", "QDate", "%s" % value.toString()))
         elif qttype == 'QTime':
@@ -2075,7 +2087,7 @@ class DebugClientBase(object):
             except:
                 remoteAddress = None
             sys.argv = ['']
-            if not '' in sys.path:
+            if '' not in sys.path:
                 sys.path.insert(0, '')
             if port >= 0:
                 if not self.noencoding:
@@ -2112,7 +2124,7 @@ class DebugClientBase(object):
         
     def close(self, fd):
         """
-        Private method implementing a close method as a replacement for
+        Public method implementing a close method as a replacement for
         os.close().
         
         It prevents the debugger connections from being closed.
