@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -103,6 +103,8 @@ class DebugClientThreads(DebugClientBase.DebugClientBase, AsyncIO):
                     sys.setprofile(newThread.profile)
             else:
                 ident = _original_start_thread(newThread.bootstrap, ())
+                if self.mainThread is not None:
+                    self.tracePython = self.mainThread.tracePython
             newThread.set_ident(ident)
             self.threads[newThread.get_ident()] = newThread
         finally:
@@ -147,7 +149,7 @@ class DebugClientThreads(DebugClientBase.DebugClientBase, AsyncIO):
         
     def setCurrentThread(self, id):
         """
-        Private method to set the current thread.
+        Public method to set the current thread.
 
         @param id the id the current thread should be set to.
         """
@@ -177,7 +179,7 @@ class DebugClientThreads(DebugClientBase.DebugClientBase, AsyncIO):
 
     def set_quit(self):
         """
-        Private method to do a 'set quit' on all threads.
+        Public method to do a 'set quit' on all threads.
         """
         try:
             locked = self.lockClient(0)
