@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -190,7 +190,7 @@ class DebugBase(bdb.Bdb):
     
     def trace_dispatch(self, frame, event, arg):
         """
-        Reimplemented from bdb.py to do some special things.
+        Public method reimplemented from bdb.py to do some special things.
         
         This specialty is to check the connection to the debug server
         for new events (i.e. new breakpoints) while we are going through
@@ -229,7 +229,7 @@ class DebugBase(bdb.Bdb):
 
     def dispatch_line(self, frame):
         """
-        Reimplemented from bdb.py to do some special things.
+        Public method reimplemented from bdb.py to do some special things.
         
         This speciality is to check the connection to the debug server
         for new events (i.e. new breakpoints) while we are going through
@@ -247,7 +247,7 @@ class DebugBase(bdb.Bdb):
 
     def dispatch_return(self, frame, arg):
         """
-        Reimplemented from bdb.py to handle passive mode cleanly.
+        Public method reimplemented from bdb.py to handle passive mode cleanly.
         
         @param frame The current stack frame.
         @param arg The arguments
@@ -262,7 +262,7 @@ class DebugBase(bdb.Bdb):
 
     def dispatch_exception(self, frame, arg):
         """
-        Reimplemented from bdb.py to always call user_exception.
+        Public method reimplemented from bdb.py to always call user_exception.
         
         @param frame The current stack frame.
         @param arg The arguments
@@ -277,7 +277,7 @@ class DebugBase(bdb.Bdb):
 
     def set_trace(self, frame=None):
         """
-        Overridden method of bdb.py to do some special setup.
+        Public method reimplemented from bdb.py to do some special setup.
         
         @param frame frame to start debugging from
         """
@@ -286,7 +286,8 @@ class DebugBase(bdb.Bdb):
     
     def set_continue(self, special):
         """
-        Reimplemented from bdb.py to always get informed of exceptions.
+        Public method reimplemented from bdb.py to always get informed of
+        exceptions.
         
         @param special flag indicating a special continue operation
         """
@@ -458,7 +459,8 @@ class DebugBase(bdb.Bdb):
     
     def break_here(self, frame):
         """
-        Reimplemented from bdb.py to fix the filename from the frame.
+        Public method reimplemented from bdb.py to fix the filename from the
+        frame.
         
         See fix_frame_filename for more info.
         
@@ -498,7 +500,7 @@ class DebugBase(bdb.Bdb):
 
     def break_anywhere(self, frame):
         """
-        Reimplemented from bdb.py to do some special things.
+        Public method reimplemented from bdb.py to do some special things.
         
         These speciality is to fix the filename from the frame
         (see fix_frame_filename for more info).
@@ -512,10 +514,10 @@ class DebugBase(bdb.Bdb):
 
     def get_break(self, filename, lineno):
         """
-        Reimplemented from bdb.py to get the first breakpoint of a particular
-        line.
+        Public method reimplemented from bdb.py to get the first breakpoint of
+        a particular line.
         
-        Because eric5 supports only one breakpoint per line, this overwritten
+        Because eric6 supports only one breakpoint per line, this overwritten
         method will return this one and only breakpoint.
         
         @param filename the filename of the bp to retrieve (string)
@@ -558,9 +560,12 @@ class DebugBase(bdb.Bdb):
                 
                 if ffunc and not ffunc.startswith("<"):
                     argInfo = inspect.getargvalues(fr)
-                    fargs = inspect.formatargvalues(
-                        argInfo.args, argInfo.varargs,
-                        argInfo.keywords, argInfo.locals)
+                    try:
+                        fargs = inspect.formatargvalues(
+                            argInfo.args, argInfo.varargs,
+                            argInfo.keywords, argInfo.locals)
+                    except Exception:
+                        fargs = ""
                 else:
                     fargs = ""
                 
@@ -575,7 +580,8 @@ class DebugBase(bdb.Bdb):
     
     def user_line(self, frame):
         """
-        Reimplemented to handle the program about to execute a particular line.
+        Public method reimplemented to handle the program about to execute a
+        particular line.
         
         @param frame the frame object
         """
@@ -616,9 +622,12 @@ class DebugBase(bdb.Bdb):
                 
                 if ffunc and not ffunc.startswith("<"):
                     argInfo = inspect.getargvalues(fr)
-                    fargs = inspect.formatargvalues(
-                        argInfo.args, argInfo.varargs,
-                        argInfo.keywords, argInfo.locals)
+                    try:
+                        fargs = inspect.formatargvalues(
+                            argInfo.args, argInfo.varargs,
+                            argInfo.keywords, argInfo.locals)
+                    except Exception:
+                        fargs = ""
                 else:
                     fargs = ""
                 
@@ -636,13 +645,18 @@ class DebugBase(bdb.Bdb):
 
     def user_exception(self, frame, excinfo, unhandled=False):
         """
-        Reimplemented to report an exception to the debug server.
+        Public method reimplemented to report an exception to the debug server.
         
         @param frame the frame object
         @param excinfo information about the exception
         @param unhandled flag indicating an uncaught exception
         """
         exctype, excval, exctb = excinfo
+        
+        if exctype in [GeneratorExit, StopIteration]:
+            # ignore these
+            return
+        
         if exctype in [SystemExit, bdb.BdbQuit]:
             atexit._run_exitfuncs()
             if excval is None:
@@ -715,9 +729,12 @@ class DebugBase(bdb.Bdb):
                 
                 if ffunc and not ffunc.startswith("<"):
                     argInfo = inspect.getargvalues(fr)
-                    fargs = inspect.formatargvalues(
-                        argInfo.args, argInfo.varargs,
-                        argInfo.keywords, argInfo.locals)
+                    try:
+                        fargs = inspect.formatargvalues(
+                            argInfo.args, argInfo.varargs,
+                            argInfo.keywords, argInfo.locals)
+                    except Exception:
+                        fargs = ""
                 else:
                     fargs = ""
                 
@@ -758,7 +775,8 @@ class DebugBase(bdb.Bdb):
 
     def user_return(self, frame, retval):
         """
-        Reimplemented to report program termination to the debug server.
+        Public method reimplemented to report program termination to the debug
+        server.
         
         @param frame the frame object
         @param retval the return value of the program
@@ -774,7 +792,7 @@ class DebugBase(bdb.Bdb):
 
     def stop_here(self, frame):
         """
-        Reimplemented to filter out debugger files.
+        Public method reimplemented to filter out debugger files.
         
         Tracing is turned off for files that are part of the
         debugger that are called from the application being debugged.
@@ -835,7 +853,7 @@ class DebugBase(bdb.Bdb):
     
     def getEvent(self):
         """
-        Public method to return the last debugger event.
+        Protected method to return the last debugger event.
         
         @return last debugger event (string)
         """
