@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -177,6 +177,7 @@ class DebugClientBase(object):
         
         # The context to run the debugged program in.
         self.debugMod = imp.new_module('__main__')
+        self.debugMod.__dict__['__builtins__'] = __builtins__
 
         # The list of complete lines to execute.
         self.buffer = ''
@@ -276,7 +277,7 @@ class DebugClientBase(object):
 
     def __dumpThreadList(self):
         """
-        Public method to send the list of threads.
+        Private method to send the list of threads.
         """
         threadList = []
         if self.threads and self.currentThread:
@@ -293,7 +294,10 @@ class DebugClientBase(object):
             d = {}
             d["id"] = -1
             d["name"] = "MainThread"
-            d["broken"] = self.isBroken()
+            if hasattr(self, "isBroken"):
+                d["broken"] = self.isBroken()
+            else:
+                d["broken"] = False
             threadList.append(d)
         
         self.write("{0}{1!r}\n".format(DebugProtocol.ResponseThreadList,
@@ -1295,9 +1299,11 @@ class DebugClientBase(object):
             frmnr -= 1
         
         if f is None:
-            return
-        
-        if scope:
+            if scope:
+                dict = self.debugMod.__dict__
+            else:
+                scope = -1
+        elif scope:
             dict = f.f_globals
         else:
             dict = f.f_locals
@@ -1338,9 +1344,11 @@ class DebugClientBase(object):
             frmnr -= 1
         
         if f is None:
-            return
-        
-        if scope:
+            if scope:
+                dict = self.debugMod.__dict__
+            else:
+                scope = -1
+        elif scope:
             dict = f.f_globals
         else:
             dict = f.f_locals
@@ -1439,7 +1447,8 @@ class DebugClientBase(object):
                                  .format(access), globals(), loc)
                             mdict = loc["mdict"]
                             obj = loc["obj"]
-                            if "PyQt4." in str(type(obj)):
+                            if "PyQt4." in str(type(obj)) or \
+                                    "PyQt5." in str(type(obj)):
                                 qtVariable = True
                                 qvar = obj
                                 qvtype = str(type(qvar))[1:-1].split()[1][1:-1]
@@ -1451,7 +1460,7 @@ class DebugClientBase(object):
                             exec('mcdict = dict{0!s}.__class__.__dict__'
                                  .format(access), globals(), loc)
                             ndict.update(loc["mcdict"])
-                            if mdict and not "sipThis" in mdict.keys():
+                            if mdict and "sipThis" not in mdict.keys():
                                 del rvar[0:2]
                                 access = ""
                         except:
@@ -1472,7 +1481,8 @@ class DebugClientBase(object):
                                  globals(), loc)
                             obj = loc["obj"]
                             access = ""
-                            if "PyQt4." in str(type(obj)):
+                            if "PyQt4." in str(type(obj)) or \
+                                    "PyQt5." in str(type(obj)):
                                 qtVariable = True
                                 qvar = obj
                                 qvtype = str(type(qvar))[1:-1].split()[1][1:-1]
@@ -1484,7 +1494,8 @@ class DebugClientBase(object):
                             ndict.update(dict[var[i]].__class__.__dict__)
                             del rvar[0]
                             obj = dict[var[i]]
-                            if "PyQt4." in str(type(obj)):
+                            if "PyQt4." in str(type(obj)) or \
+                                    "PyQt5." in str(type(obj)):
                                 qtVariable = True
                                 qvar = obj
                                 qvtype = str(type(qvar))[1:-1].split()[1][1:-1]
@@ -1504,7 +1515,8 @@ class DebugClientBase(object):
                                     pass
                             ndict.update(loc["cdict"])
                             obj = dict[var[i]]
-                            if "PyQt4." in str(type(obj)):
+                            if "PyQt4." in str(type(obj)) or \
+                                    "PyQt5." in str(type(obj)):
                                 qtVariable = True
                                 qvar = obj
                                 qvtype = str(type(qvar))[1:-1].split()[1][1:-1]
@@ -1515,7 +1527,7 @@ class DebugClientBase(object):
                 i += 1
             
             if qtVariable:
-                vlist = self.__formatQt4Variable(qvar, qvtype)
+                vlist = self.__formatQtVariable(qvar, qvtype)
             elif ("sipThis" in dict.keys() and len(dict) == 1) or \
                     (len(dict) == 0 and len(udict) > 0):
                 if access:
@@ -1532,8 +1544,8 @@ class DebugClientBase(object):
                 else:
                     qvar = udict[var[-1]]
                 qvtype = str(type(qvar))[1:-1].split()[1][1:-1]
-                if qvtype.startswith("PyQt4"):
-                    vlist = self.__formatQt4Variable(qvar, qvtype)
+                if qvtype.startswith(("PyQt4", "PyQt5")):
+                    vlist = self.__formatQtVariable(qvar, qvtype)
                 else:
                     vlist = []
             else:
@@ -1553,11 +1565,11 @@ class DebugClientBase(object):
                     else:
                         qvar = udict[var[-1]]
                     qvtype = str(type(qvar))[1:-1].split()[1][1:-1]
-                    if qvtype.startswith("PyQt4"):
+                    if qvtype.startswith(("PyQt4", "PyQt5")):
                         qtVariable = True
                 
                 if qtVariable:
-                    vlist = self.__formatQt4Variable(qvar, qvtype)
+                    vlist = self.__formatQtVariable(qvar, qvtype)
                 else:
                     # format the dictionary found
                     if dictkeys is None:
@@ -1596,7 +1608,7 @@ class DebugClientBase(object):
         self.write('{0}{1}\n'.format(
             DebugProtocol.ResponseVariable, str(varlist)))
         
-    def __formatQt4Variable(self, value, vtype):
+    def __formatQtVariable(self, value, vtype):
         """
         Private method to produce a formatted output of a simple Qt4/Qt5 type.
         
@@ -1646,15 +1658,15 @@ class DebugClientBase(object):
             varlist.append(("name", "str", "{0}".format(value.name())))
             r, g, b, a = value.getRgb()
             varlist.append(
-                ("rgb", "int",
+                ("rgba", "int",
                  "{0:d}, {1:d}, {2:d}, {3:d}".format(r, g, b, a)))
             h, s, v, a = value.getHsv()
             varlist.append(
-                ("hsv", "int",
+                ("hsva", "int",
                  "{0:d}, {1:d}, {2:d}, {3:d}".format(h, s, v, a)))
             c, m, y, k, a = value.getCmyk()
             varlist.append(
-                ("cmyk", "int",
+                ("cmyka", "int",
                  "{0:d}, {1:d}, {2:d}, {3:d}, {4:d}".format(c, m, y, k, a)))
         elif qttype == 'QDate':
             varlist.append(("", "QDate", "{0}".format(value.toString())))
@@ -2135,7 +2147,7 @@ class DebugClientBase(object):
             except:
                 remoteAddress = None
             sys.argv = ['']
-            if not '' in sys.path:
+            if '' not in sys.path:
                 sys.path.insert(0, '')
             if port >= 0:
                 if not self.noencoding:
@@ -2172,7 +2184,7 @@ class DebugClientBase(object):
         
     def close(self, fd):
         """
-        Private method implementing a close method as a replacement for
+        Public method implementing a close method as a replacement for
         os.close().
         
         It prevents the debugger connections from being closed.
