@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -46,6 +46,7 @@ class DebugThread(DebugBase):
         
         self.__ident = None  # id of this thread.
         self.__name = ""
+        self.tracePython = False
     
     def set_ident(self, id):
         """
@@ -73,7 +74,7 @@ class DebugThread(DebugBase):
     
     def traceThread(self):
         """
-        Private method to setup tracing for this thread.
+        Public method to setup tracing for this thread.
         """
         self.set_trace()
         if not self._mainThread:
@@ -81,7 +82,7 @@ class DebugThread(DebugBase):
     
     def bootstrap(self):
         """
-        Private method to bootstrap the thread.
+        Public method to bootstrap the thread.
         
         It wraps the call to the user function to enable tracing
         before hand.
@@ -101,7 +102,7 @@ class DebugThread(DebugBase):
     
     def trace_dispatch(self, frame, event, arg):
         """
-        Private method wrapping the trace_dispatch of bdb.py.
+        Public method wrapping the trace_dispatch of bdb.py.
         
         It wraps the call to dispatch tracing into
         bdb to make sure we have locked the client to prevent multiple
