@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Breakpoint model.
 """
 
-from PyQt4.QtCore import pyqtSignal, Qt, QAbstractItemModel, QModelIndex
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSignal, Qt, QAbstractItemModel, QModelIndex
 
 
 class BreakPointModel(QAbstractItemModel):
@@ -22,16 +24,16 @@ class BreakPointModel(QAbstractItemModel):
         
         @param parent reference to the parent widget (QObject)
         """
-        super().__init__(parent)
+        super(BreakPointModel, self).__init__(parent)
         
         self.breakpoints = []
         self.header = [
-            self.trUtf8("Filename"),
-            self.trUtf8("Line"),
-            self.trUtf8('Condition'),
-            self.trUtf8('Temporary'),
-            self.trUtf8('Enabled'),
-            self.trUtf8('Ignore Count'),
+            self.tr("Filename"),
+            self.tr("Line"),
+            self.tr('Condition'),
+            self.tr('Temporary'),
+            self.tr('Enabled'),
+            self.tr('Ignore Count'),
         ]
         self.alignments = [Qt.Alignment(Qt.AlignLeft),
                            Qt.Alignment(Qt.AlignRight),
