@@ -1,15 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Breakpoint viewer widget.
 """
 
-from PyQt4.QtCore import pyqtSignal, Qt, qVersion
-from PyQt4.QtGui import QTreeView, QAbstractItemView, QSortFilterProxyModel, \
-    QHeaderView, QItemSelectionModel, QMenu, QDialog
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSignal, Qt, qVersion, QItemSelectionModel, \
+    QSortFilterProxyModel
+from PyQt5.QtWidgets import QTreeView, QAbstractItemView, QHeaderView, QMenu, \
+    QDialog
 
 from E5Gui.E5Application import e5App
 
@@ -31,7 +34,7 @@ class BreakPointViewer(QTreeView):
         
         @param parent the parent (QWidget)
         """
-        super().__init__(parent)
+        super(BreakPointViewer, self).__init__(parent)
         self.setObjectName("BreakPointViewer")
         
         self.__model = None
@@ -42,7 +45,7 @@ class BreakPointViewer(QTreeView):
         self.setSelectionMode(QAbstractItemView.ExtendedSelection)
         self.setSelectionBehavior(QAbstractItemView.SelectRows)
         
-        self.setWindowTitle(self.trUtf8("Breakpoints"))
+        self.setWindowTitle(self.tr("Breakpoints"))
         
         self.setContextMenuPolicy(Qt.CustomContextMenu)
         self.customContextMenuRequested.connect(self.__showContextMenu)
@@ -65,7 +68,7 @@ class BreakPointViewer(QTreeView):
         self.sortingModel = QSortFilterProxyModel()
         self.sortingModel.setDynamicSortFilter(True)
         self.sortingModel.setSourceModel(self.__model)
-        super().setModel(self.sortingModel)
+        super(BreakPointViewer, self).setModel(self.sortingModel)
         
         header = self.header()
         header.setSortIndicator(0, Qt.AscendingOrder)
@@ -142,58 +145,58 @@ class BreakPointViewer(QTreeView):
         Private method to generate the popup menus.
         """
         self.menu = QMenu()
-        self.menu.addAction(self.trUtf8("Add"), self.__addBreak)
-        self.menu.addAction(self.trUtf8("Edit..."), self.__editBreak)
+        self.menu.addAction(self.tr("Add"), self.__addBreak)
+        self.menu.addAction(self.tr("Edit..."), self.__editBreak)
         self.menu.addSeparator()
-        self.menu.addAction(self.trUtf8("Enable"), self.__enableBreak)
-        self.menu.addAction(self.trUtf8("Enable all"), self.__enableAllBreaks)
+        self.menu.addAction(self.tr("Enable"), self.__enableBreak)
+        self.menu.addAction(self.tr("Enable all"), self.__enableAllBreaks)
         self.menu.addSeparator()
-        self.menu.addAction(self.trUtf8("Disable"), self.__disableBreak)
-        self.menu.addAction(self.trUtf8("Disable all"),
+        self.menu.addAction(self.tr("Disable"), self.__disableBreak)
+        self.menu.addAction(self.tr("Disable all"),
                             self.__disableAllBreaks)
         self.menu.addSeparator()
-        self.menu.addAction(self.trUtf8("Delete"), self.__deleteBreak)
-        self.menu.addAction(self.trUtf8("Delete all"), self.__deleteAllBreaks)
+        self.menu.addAction(self.tr("Delete"), self.__deleteBreak)
+        self.menu.addAction(self.tr("Delete all"), self.__deleteAllBreaks)
         self.menu.addSeparator()
-        self.menu.addAction(self.trUtf8("Goto"), self.__showSource)
+        self.menu.addAction(self.tr("Goto"), self.__showSource)
         self.menu.addSeparator()
-        self.menu.addAction(self.trUtf8("Configure..."), self.__configure)
+        self.menu.addAction(self.tr("Configure..."), self.__configure)
 
         self.backMenuActions = {}
         self.backMenu = QMenu()
-        self.backMenu.addAction(self.trUtf8("Add"), self.__addBreak)
+        self.backMenu.addAction(self.tr("Add"), self.__addBreak)
         self.backMenuActions["EnableAll"] = \
-            self.backMenu.addAction(self.trUtf8("Enable all"),
+            self.backMenu.addAction(self.tr("Enable all"),
                                     self.__enableAllBreaks)
         self.backMenuActions["DisableAll"] = \
-            self.backMenu.addAction(self.trUtf8("Disable all"),
+            self.backMenu.addAction(self.tr("Disable all"),
                                     self.__disableAllBreaks)
         self.backMenuActions["DeleteAll"] = \
-            self.backMenu.addAction(self.trUtf8("Delete all"),
+            self.backMenu.addAction(self.tr("Delete all"),
                                     self.__deleteAllBreaks)
         self.backMenu.aboutToShow.connect(self.__showBackMenu)
         self.backMenu.addSeparator()
-        self.backMenu.addAction(self.trUtf8("Configure..."), self.__configure)
+        self.backMenu.addAction(self.tr("Configure..."), self.__configure)
 
         self.multiMenu = QMenu()
-        self.multiMenu.addAction(self.trUtf8("Add"), self.__addBreak)
+        self.multiMenu.addAction(self.tr("Add"), self.__addBreak)
         self.multiMenu.addSeparator()
-        self.multiMenu.addAction(self.trUtf8("Enable selected"),
+        self.multiMenu.addAction(self.tr("Enable selected"),
                                  self.__enableSelectedBreaks)
-        self.multiMenu.addAction(self.trUtf8("Enable all"),
+        self.multiMenu.addAction(self.tr("Enable all"),
                                  self.__enableAllBreaks)
         self.multiMenu.addSeparator()
-        self.multiMenu.addAction(self.trUtf8("Disable selected"),
+        self.multiMenu.addAction(self.tr("Disable selected"),
                                  self.__disableSelectedBreaks)
-        self.multiMenu.addAction(self.trUtf8("Disable all"),
+        self.multiMenu.addAction(self.tr("Disable all"),
                                  self.__disableAllBreaks)
         self.multiMenu.addSeparator()
-        self.multiMenu.addAction(self.trUtf8("Delete selected"),
+        self.multiMenu.addAction(self.tr("Delete selected"),
                                  self.__deleteSelectedBreaks)
-        self.multiMenu.addAction(self.trUtf8("Delete all"),
+        self.multiMenu.addAction(self.tr("Delete all"),
                                  self.__deleteAllBreaks)
         self.multiMenu.addSeparator()
-        self.multiMenu.addAction(self.trUtf8("Configure..."), self.__configure)
+        self.multiMenu.addAction(self.tr("Configure..."), self.__configure)
     
     def __showContextMenu(self, coord):
         """
