@@ -1,16 +1,22 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the debug server.
 """
 
+from __future__ import unicode_literals
+try:
+    str = unicode
+except NameError:
+    pass
+
 import os
 
-from PyQt4.QtCore import pyqtSignal, QModelIndex
-from PyQt4.QtNetwork import QTcpServer, QHostAddress, QHostInfo, \
+from PyQt5.QtCore import pyqtSignal, QModelIndex
+from PyQt5.QtNetwork import QTcpServer, QHostAddress, QHostInfo, \
     QNetworkInterface
 
 from E5Gui.E5Application import e5App
@@ -84,6 +90,8 @@ class DebugServer(QTcpServer):
         connected in passive debug mode
     @signal clientGone(bool) emitted if the client went away (planned or
         unplanned)
+    @signal clientInterpreterChanged(str) emitted to signal a change of the
+        client interpreter
     @signal utPrepared(nrTests, exc_type, exc_value) emitted after the client
         has loaded a unittest suite
     @signal utFinished() emitted after the client signalled the end of the
@@ -104,6 +112,8 @@ class DebugServer(QTcpServer):
     @signal callTraceInfo emitted after the client reported the call trace
         data (isCall, fromFile, fromLine, fromFunction, toFile, toLine,
         toFunction)
+    @signal appendStdout(msg) emitted when a passive debug connection is
+        established or lost
     """
     clientClearBreak = pyqtSignal(str, int)
     clientClearWatch = pyqtSignal(str)
@@ -128,6 +138,7 @@ class DebugServer(QTcpServer):
     clientBanner = pyqtSignal(str, str, str)
     clientCapabilities = pyqtSignal(int, str)
     clientCompletionList = pyqtSignal(list, str)
+    clientInterpreterChanged = pyqtSignal(str)
     utPrepared = pyqtSignal(int, str, str)
     utStartTest = pyqtSignal(str, str)
     utStopTest = pyqtSignal()
@@ -139,20 +150,21 @@ class DebugServer(QTcpServer):
     utFinished = pyqtSignal()
     passiveDebugStarted = pyqtSignal(str, bool)
     callTraceInfo = pyqtSignal(bool, str, str, str, str, str, str)
+    appendStdout = pyqtSignal(str)
     
     def __init__(self):
         """
         Constructor
         """
-        super().__init__()
+        super(DebugServer, self).__init__()
         
         # create our models
         self.breakpointModel = BreakPointModel(self)
         self.watchpointModel = WatchPointModel(self)
         self.watchSpecialCreated = \
-            self.trUtf8("created", "must be same as in EditWatchpointDialog")
+            self.tr("created", "must be same as in EditWatchpointDialog")
         self.watchSpecialChanged = \
-            self.trUtf8("changed", "must be same as in EditWatchpointDialog")
+            self.tr("changed", "must be same as in EditWatchpointDialog")
         
         self.networkInterface = Preferences.getDebugger("NetworkInterface")
         if self.networkInterface == "all":
@@ -179,14 +191,30 @@ class DebugServer(QTcpServer):
         self.debugging = False
         self.running = False
         self.clientProcess = None
+        self.clientInterpreter = ""
         self.clientType = \
-            Preferences.Prefs.settings.value('DebugClient/Type', 'Python3')
+            Preferences.Prefs.settings.value('DebugClient/Type')
+        if self.clientType is None:
+            import sys
+            if sys.version_info[0] == 2:
+                self.clientType = 'Python2'
+            else:
+                self.clientType = 'Python3'
+        # Change clientType if dependent interpreter not exist anymore
+        # (maybe deinstalled,...)
+        elif self.clientType == 'Python2' and Preferences.getDebugger(
+                "PythonInterpreter") == '':
+            self.clientType = 'Python3'
+        elif self.clientType == 'Python3' and Preferences.getDebugger(
+                "Python3Interpreter") == '':
+            self.clientType = 'Python2'
+        
         self.lastClientType = ''
         self.__autoClearShell = False
         
         self.clientClearBreak.connect(self.__clientClearBreakPoint)
         self.clientClearWatch.connect(self.__clientClearWatchPoint)
-        self.newConnection[()].connect(self.__newConnection)
+        self.newConnection.connect(self.__newConnection)
         
         self.breakpointModel.rowsAboutToBeRemoved.connect(
             self.__deleteBreakPoints)
@@ -387,15 +415,15 @@ class DebugServer(QTcpServer):
             if forProject:
                 project = e5App().getObject("Project")
                 if not project.isDebugPropertiesLoaded():
-                    self.clientProcess, isNetworked = \
+                    self.clientProcess, isNetworked, clientInterpreter = \
                         self.debuggerInterface.startRemote(self.serverPort(),
                                                            runInConsole)
                 else:
-                    self.clientProcess, isNetworked = \
+                    self.clientProcess, isNetworked, clientInterpreter = \
                         self.debuggerInterface.startRemoteForProject(
                             self.serverPort(), runInConsole)
             else:
-                self.clientProcess, isNetworked = \
+                self.clientProcess, isNetworked, clientInterpreter = \
                     self.debuggerInterface.startRemote(
                         self.serverPort(), runInConsole)
             
@@ -405,19 +433,25 @@ class DebugServer(QTcpServer):
                 self.clientProcess.readyReadStandardOutput.connect(
                     self.__clientProcessOutput)
                 
-                if not isNetworked:
-                    # the client is connected through stdin and stdout
-                    # Perform actions necessary, if client type has changed
-                    if self.lastClientType != self.clientType:
-                        self.lastClientType = self.clientType
-                        self.remoteBanner()
-                    elif self.__autoClearShell:
-                        self.__autoClearShell = False
-                        self.remoteBanner()
-                    
-                    self.debuggerInterface.flush()
+                # Perform actions necessary, if client type has changed
+                if self.lastClientType != self.clientType:
+                    self.lastClientType = self.clientType
+                    self.remoteBanner()
+                elif self.__autoClearShell:
+                    self.__autoClearShell = False
+                    self.remoteBanner()
+                self.remoteClientVariables(0, [], 0)
+                self.remoteClientVariables(1, [], 0)
+            else:
+                if clType and self.lastClientType:
+                    self.__setClientType(self.lastClientType)
         else:
             self.__createDebuggerInterface("None")
+            clientInterpreter = ""
+        
+        if clientInterpreter != self.clientInterpreter:
+            self.clientInterpreter = clientInterpreter
+            self.clientInterpreterChanged.emit(clientInterpreter)
 
     def __clientProcessOutput(self):
         """
@@ -624,6 +658,14 @@ class DebugServer(QTcpServer):
         except KeyError:
             return 0    # no capabilities
         
+    def getClientInterpreter(self):
+        """
+        Public method to get the interpreter of the debug client.
+        
+        @return interpreter of the debug client (string)
+        """
+        return self.clientInterpreter
+        
     def __newConnection(self):
         """
         Private slot to handle a new connection.
@@ -634,8 +676,8 @@ class DebugServer(QTcpServer):
             # the peer is not allowed to connect
             res = E5MessageBox.yesNo(
                 None,
-                self.trUtf8("Connection from illegal host"),
-                self.trUtf8(
+                self.tr("Connection from illegal host"),
+                self.tr(
                     """<p>A connection was attempted by the illegal host"""
                     """ <b>{0}</b>. Accept this connection?</p>""")
                 .format(peerAddress),
@@ -1234,7 +1276,7 @@ class DebugServer(QTcpServer):
             self.startClient(False)
         if self.passive:
             self.__createDebuggerInterface("None")
-            self.signalClientOutput(self.trUtf8('\nNot connected\n'))
+            self.signalClientOutput(self.tr('\nNot connected\n'))
             self.signalClientStatement(False)
         self.running = False
         
@@ -1414,7 +1456,7 @@ class DebugServer(QTcpServer):
         @param fn filename of the debugged script (string)
         @param exc flag to enable exception reporting of the IDE (boolean)
         """
-        print(self.trUtf8("Passive debug connection received"))
+        self.appendStdout.emit(self.tr("Passive debug connection received\n"))
         self.passiveClientExited = False
         self.debugging = True
         self.running = True
@@ -1428,7 +1470,7 @@ class DebugServer(QTcpServer):
         """
         self.passiveClientExited = True
         self.shutdownServer()
-        print(self.trUtf8("Passive debug connection closed"))
+        self.appendStdout.emit(self.tr("Passive debug connection closed\n"))
         
     def __restoreBreakpoints(self):
         """
