@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dummy debugger interface for the debug server.
 """
 
-from PyQt4.QtCore import QObject
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import QObject
 
 
 ClientDefaultCapabilities = 0
@@ -36,7 +38,7 @@ class DebuggerInterfaceNone(QObject):
         @param debugServer reference to the debug server (DebugServer)
         @param passive flag indicating passive connection mode (boolean)
         """
-        super().__init__()
+        super(DebuggerInterfaceNone, self).__init__()
         
         self.debugServer = debugServer
         self.passive = passive
@@ -53,10 +55,11 @@ class DebuggerInterfaceNone(QObject):
         @param port portnumber the debug server is listening on (integer)
         @param runInConsole flag indicating to start the debugger in a
             console window (boolean)
-        @return client process object (QProcess) and a flag to indicate
-            a network connection (boolean)
+        @return client process object (QProcess), a flag to indicate
+            a network connection (boolean) and the name of the interpreter
+            in case of a local execution (string)
         """
-        return None, True
+        return None, True, ""
 
     def startRemoteForProject(self, port, runInConsole):
         """
@@ -65,10 +68,11 @@ class DebuggerInterfaceNone(QObject):
         @param port portnumber the debug server is listening on (integer)
         @param runInConsole flag indicating to start the debugger in a
             console window (boolean)
-        @return client process object (QProcess) and a flag to indicate
-            a network connection (boolean)
+        @return client process object (QProcess), a flag to indicate
+            a network connection (boolean) and the name of the interpreter
+            in case of a local execution (string)
         """
-        return None, True
+        return None, True, ""
 
     def getClientCapabilities(self):
         """
