@@ -1,18 +1,21 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Python debugger interface for the debug server.
 """
 
+from __future__ import unicode_literals
+
 import sys
 import os
 import re
 
-from PyQt4.QtCore import QObject, QTextCodec, QProcess, QTimer
-from PyQt4.QtGui import QInputDialog
+from PyQt5.QtCore import QObject, QTextCodec, QProcess, QProcessEnvironment, \
+    QTimer
+from PyQt5.QtWidgets import QInputDialog
 
 from E5Gui.E5Application import e5App
 from E5Gui import E5MessageBox
@@ -23,7 +26,7 @@ from . import DebugClientCapabilities
 import Preferences
 import Utilities
 
-from eric5config import getConfig
+from eric6config import getConfig
 
 
 ClientDefaultCapabilities = DebugClientCapabilities.HasAll
@@ -60,7 +63,7 @@ class DebuggerInterfacePython(QObject):
         @param debugServer reference to the debug server (DebugServer)
         @param passive flag indicating passive connection mode (boolean)
         """
-        super().__init__()
+        super(DebuggerInterfacePython, self).__init__()
         
         self.__isNetworked = True
         self.__autoContinue = False
@@ -71,9 +74,13 @@ class DebuggerInterfacePython(QObject):
         
         self.qsock = None
         self.queue = []
+        
         # set default values for capabilities of clients
         self.clientCapabilities = ClientDefaultCapabilities
         
+        # set translation function
+        self.translate = self.__identityTranslation
+        
         self.codec = QTextCodec.codecForName(
             Preferences.getSystem("StringEncoding"))
         
@@ -130,10 +137,10 @@ class DebuggerInterfacePython(QObject):
         """
         proc = QProcess()
         if environment is not None:
-            env = []
+            env = QProcessEnvironment()
             for key, value in list(environment.items()):
-                env.append("{0}={1}".format(key, value))
-            proc.setEnvironment(env)
+                env.insert(key, value)
+            proc.setProcessEnvironment(env)
         args = []
         for arg in arguments:
             args.append(arg)
@@ -150,17 +157,18 @@ class DebuggerInterfacePython(QObject):
         @param port portnumber the debug server is listening on (integer)
         @param runInConsole flag indicating to start the debugger in a
             console window (boolean)
-        @return client process object (QProcess) and a flag to indicate
-            a network connection (boolean)
+        @return client process object (QProcess), a flag to indicate
+            a network connection (boolean) and the name of the interpreter
+            in case of a local execution (string)
         """
         interpreter = Preferences.getDebugger("PythonInterpreter")
         if interpreter == "":
             E5MessageBox.critical(
                 None,
-                self.trUtf8("Start Debugger"),
-                self.trUtf8(
+                self.tr("Start Debugger"),
+                self.tr(
                     """<p>No Python2 interpreter configured.</p>"""))
-            return None, False
+            return None, False, ""
         
         debugClientType = Preferences.getDebugger("DebugClientType")
         if debugClientType == "standard":
@@ -197,8 +205,8 @@ class DebuggerInterfacePython(QObject):
                 if process is None:
                     E5MessageBox.critical(
                         None,
-                        self.trUtf8("Start Debugger"),
-                        self.trUtf8(
+                        self.tr("Start Debugger"),
+                        self.tr(
                             """<p>The debugger backend could not be"""
                             """ started.</p>"""))
                 
@@ -211,7 +219,7 @@ class DebuggerInterfacePython(QObject):
                     self.translate = self.__remoteTranslation
                 else:
                     self.translate = self.__identityTranslation
-                return process, self.__isNetworked
+                return process, self.__isNetworked, ""
         
         # set translation function
         self.translate = self.__identityTranslation
@@ -244,11 +252,11 @@ class DebuggerInterfacePython(QObject):
                 if process is None:
                     E5MessageBox.critical(
                         None,
-                        self.trUtf8("Start Debugger"),
-                        self.trUtf8(
+                        self.tr("Start Debugger"),
+                        self.tr(
                             """<p>The debugger backend could not be"""
                             """ started.</p>"""))
-                return process, self.__isNetworked
+                return process, self.__isNetworked, interpreter
         
         process = self.__startProcess(
             interpreter,
@@ -257,10 +265,10 @@ class DebuggerInterfacePython(QObject):
         if process is None:
             E5MessageBox.critical(
                 None,
-                self.trUtf8("Start Debugger"),
-                self.trUtf8(
+                self.tr("Start Debugger"),
+                self.tr(
                     """<p>The debugger backend could not be started.</p>"""))
-        return process, self.__isNetworked
+        return process, self.__isNetworked, interpreter
 
     def startRemoteForProject(self, port, runInConsole):
         """
@@ -269,12 +277,13 @@ class DebuggerInterfacePython(QObject):
         @param port portnumber the debug server is listening on (integer)
         @param runInConsole flag indicating to start the debugger in a
             console window (boolean)
-        @return client process object (QProcess) and a flag to indicate
-            a network connection (boolean)
+        @return client process object (QProcess), a flag to indicate
+            a network connection (boolean) and the name of the interpreter
+            in case of a local execution (string)
         """
         project = e5App().getObject("Project")
         if not project.isDebugPropertiesLoaded():
-            return None, self.__isNetworked
+            return None, self.__isNetworked, ""
         
         # start debugger with project specific settings
         interpreter = project.getDebugProperty("INTERPRETER")
@@ -299,8 +308,8 @@ class DebuggerInterfacePython(QObject):
                 if process is None:
                     E5MessageBox.critical(
                         None,
-                        self.trUtf8("Start Debugger"),
-                        self.trUtf8(
+                        self.tr("Start Debugger"),
+                        self.tr(
                             """<p>The debugger backend could not be"""
                             """ started.</p>"""))
                 # set translation function
@@ -312,7 +321,7 @@ class DebuggerInterfacePython(QObject):
                     self.translate = self.__remoteTranslation
                 else:
                     self.translate = self.__identityTranslation
-                return process, self.__isNetworked
+                return process, self.__isNetworked, ""
         
         # set translation function
         self.translate = self.__identityTranslation
@@ -346,11 +355,11 @@ class DebuggerInterfacePython(QObject):
                 if process is None:
                     E5MessageBox.critical(
                         None,
-                        self.trUtf8("Start Debugger"),
-                        self.trUtf8(
+                        self.tr("Start Debugger"),
+                        self.tr(
                             """<p>The debugger backend could not be"""
                             """ started.</p>"""))
-                return process, self.__isNetworked
+                return process, self.__isNetworked, interpreter
         
         process = self.__startProcess(
             interpreter,
@@ -359,10 +368,10 @@ class DebuggerInterfacePython(QObject):
         if process is None:
             E5MessageBox.critical(
                 None,
-                self.trUtf8("Start Debugger"),
-                self.trUtf8(
+                self.tr("Start Debugger"),
+                self.tr(
                     """<p>The debugger backend could not be started.</p>"""))
-        return process, self.__isNetworked
+        return process, self.__isNetworked, interpreter
 
     def getClientCapabilities(self):
         """
@@ -384,8 +393,8 @@ class DebuggerInterfacePython(QObject):
         if self.qsock is not None:
             return False
         
-        sock.disconnected[()].connect(self.debugServer.startClient)
-        sock.readyRead[()].connect(self.__parseClientLine)
+        sock.disconnected.connect(self.debugServer.startClient)
+        sock.readyRead.connect(self.__parseClientLine)
         
         self.qsock = sock
         
@@ -415,7 +424,7 @@ class DebuggerInterfacePython(QObject):
         
         # do not want any slots called during shutdown
         self.qsock.disconnected.disconnect(self.debugServer.startClient)
-        self.qsock.readyRead[()].disconnect(self.__parseClientLine)
+        self.qsock.readyRead.disconnect(self.__parseClientLine)
         
         # close down socket, and shut down client as well.
         self.__sendCommand('{0}\n'.format(DebugProtocol.RequestShutdown))
@@ -798,12 +807,12 @@ class DebuggerInterfacePython(QObject):
         """
         Private method to ask the user which branch of a fork to follow.
         """
-        selections = [self.trUtf8("Parent Process"),
-                      self.trUtf8("Child process")]
+        selections = [self.tr("Parent Process"),
+                      self.tr("Child process")]
         res, ok = QInputDialog.getItem(
             None,
-            self.trUtf8("Client forking"),
-            self.trUtf8("Select the fork branch to follow."),
+            self.tr("Client forking"),
+            self.tr("Select the fork branch to follow."),
             selections,
             0, False)
         if not ok or res == selections[0]:
