@@ -1,17 +1,20 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Python3 debugger interface for the debug server.
 """
 
+from __future__ import unicode_literals
+
 import sys
 import os
 
-from PyQt4.QtCore import QObject, QTextCodec, QProcess, QTimer
-from PyQt4.QtGui import QInputDialog
+from PyQt5.QtCore import QObject, QTextCodec, QProcess, QProcessEnvironment, \
+    QTimer
+from PyQt5.QtWidgets import QInputDialog
 
 from E5Gui.E5Application import e5App
 from E5Gui import E5MessageBox
@@ -22,7 +25,7 @@ from . import DebugClientCapabilities
 import Preferences
 import Utilities
 
-from eric5config import getConfig
+from eric6config import getConfig
 
 
 ClientDefaultCapabilities = DebugClientCapabilities.HasAll
@@ -59,7 +62,7 @@ class DebuggerInterfacePython3(QObject):
         @param debugServer reference to the debug server (DebugServer)
         @param passive flag indicating passive connection mode (boolean)
         """
-        super().__init__()
+        super(DebuggerInterfacePython3, self).__init__()
         
         self.__isNetworked = True
         self.__autoContinue = False
@@ -70,9 +73,13 @@ class DebuggerInterfacePython3(QObject):
         
         self.qsock = None
         self.queue = []
+        
         # set default values for capabilities of clients
         self.clientCapabilities = ClientDefaultCapabilities
         
+        # set translation function
+        self.translate = self.__identityTranslation
+        
         self.codec = QTextCodec.codecForName(
             str(Preferences.getSystem("StringEncoding")))
         
@@ -127,10 +134,10 @@ class DebuggerInterfacePython3(QObject):
         """
         proc = QProcess()
         if environment is not None:
-            env = []
+            env = QProcessEnvironment()
             for key, value in list(environment.items()):
-                env.append("{0}={1}".format(key, value))
-            proc.setEnvironment(env)
+                env.insert(key, value)
+            proc.setProcessEnvironment(env)
         args = []
         for arg in arguments:
             args.append(arg)
@@ -147,15 +154,18 @@ class DebuggerInterfacePython3(QObject):
         @param port portnumber the debug server is listening on (integer)
         @param runInConsole flag indicating to start the debugger in a
             console window (boolean)
-        @return client process object (QProcess) and a flag to indicate
-            a network connection (boolean)
+        @return client process object (QProcess), a flag to indicate
+            a network connection (boolean) and the name of the interpreter
+            in case of a local execution (string)
         """
-        if Preferences.getDebugger("CustomPython3Interpreter"):
-            interpreter = Preferences.getDebugger("Python3Interpreter")
-            if interpreter == "":
-                interpreter = sys.executable
-        else:
-            interpreter = sys.executable
+        interpreter = Preferences.getDebugger("Python3Interpreter")
+        if interpreter == "":
+            E5MessageBox.critical(
+                None,
+                self.tr("Start Debugger"),
+                self.tr(
+                    """<p>No Python3 interpreter configured.</p>"""))
+            return None, False, ""
         
         debugClientType = Preferences.getDebugger("DebugClientType3")
         if debugClientType == "standard":
@@ -192,8 +202,8 @@ class DebuggerInterfacePython3(QObject):
                 if process is None:
                     E5MessageBox.critical(
                         None,
-                        self.trUtf8("Start Debugger"),
-                        self.trUtf8(
+                        self.tr("Start Debugger"),
+                        self.tr(
                             """<p>The debugger backend could not be"""
                             """ started.</p>"""))
                 
@@ -206,7 +216,7 @@ class DebuggerInterfacePython3(QObject):
                     self.translate = self.__remoteTranslation
                 else:
                     self.translate = self.__identityTranslation
-                return process, self.__isNetworked
+                return process, self.__isNetworked, ""
         
         # set translation function
         self.translate = self.__identityTranslation
@@ -239,11 +249,11 @@ class DebuggerInterfacePython3(QObject):
                 if process is None:
                     E5MessageBox.critical(
                         None,
-                        self.trUtf8("Start Debugger"),
-                        self.trUtf8(
+                        self.tr("Start Debugger"),
+                        self.tr(
                             """<p>The debugger backend could not be"""
                             """ started.</p>"""))
-                return process, self.__isNetworked
+                return process, self.__isNetworked, interpreter
         
         process = self.__startProcess(
             interpreter,
@@ -252,10 +262,10 @@ class DebuggerInterfacePython3(QObject):
         if process is None:
             E5MessageBox.critical(
                 None,
-                self.trUtf8("Start Debugger"),
-                self.trUtf8(
+                self.tr("Start Debugger"),
+                self.tr(
                     """<p>The debugger backend could not be started.</p>"""))
-        return process, self.__isNetworked
+        return process, self.__isNetworked, interpreter
 
     def startRemoteForProject(self, port, runInConsole):
         """
@@ -264,12 +274,13 @@ class DebuggerInterfacePython3(QObject):
         @param port portnumber the debug server is listening on (integer)
         @param runInConsole flag indicating to start the debugger in a
             console window (boolean)
-        @return client process object (QProcess) and a flag to indicate
-            a network connection (boolean)
+        @return client process object (QProcess), a flag to indicate
+            a network connection (boolean) and the name of the interpreter
+            in case of a local execution (string)
         """
         project = e5App().getObject("Project")
         if not project.isDebugPropertiesLoaded():
-            return None, self.__isNetworked
+            return None, self.__isNetworked, ""
         
         # start debugger with project specific settings
         interpreter = project.getDebugProperty("INTERPRETER")
@@ -294,8 +305,8 @@ class DebuggerInterfacePython3(QObject):
                 if process is None:
                     E5MessageBox.critical(
                         None,
-                        self.trUtf8("Start Debugger"),
-                        self.trUtf8(
+                        self.tr("Start Debugger"),
+                        self.tr(
                             """<p>The debugger backend could not be"""
                             """ started.</p>"""))
                 # set translation function
@@ -307,7 +318,7 @@ class DebuggerInterfacePython3(QObject):
                     self.translate = self.__remoteTranslation
                 else:
                     self.translate = self.__identityTranslation
-                return process, self.__isNetworked
+                return process, self.__isNetworked, ""
         
         # set translation function
         self.translate = self.__identityTranslation
@@ -341,11 +352,11 @@ class DebuggerInterfacePython3(QObject):
                 if process is None:
                     E5MessageBox.critical(
                         None,
-                        self.trUtf8("Start Debugger"),
-                        self.trUtf8(
+                        self.tr("Start Debugger"),
+                        self.tr(
                             """<p>The debugger backend could not be"""
                             """ started.</p>"""))
-                return process, self.__isNetworked
+                return process, self.__isNetworked, interpreter
         
         process = self.__startProcess(
             interpreter,
@@ -354,10 +365,10 @@ class DebuggerInterfacePython3(QObject):
         if process is None:
             E5MessageBox.critical(
                 None,
-                self.trUtf8("Start Debugger"),
-                self.trUtf8(
+                self.tr("Start Debugger"),
+                self.tr(
                     """<p>The debugger backend could not be started.</p>"""))
-        return process, self.__isNetworked
+        return process, self.__isNetworked, interpreter
 
     def getClientCapabilities(self):
         """
@@ -379,8 +390,8 @@ class DebuggerInterfacePython3(QObject):
         if self.qsock is not None:
             return False
         
-        sock.disconnected[()].connect(self.debugServer.startClient)
-        sock.readyRead[()].connect(self.__parseClientLine)
+        sock.disconnected.connect(self.debugServer.startClient)
+        sock.readyRead.connect(self.__parseClientLine)
         
         self.qsock = sock
         
@@ -410,7 +421,7 @@ class DebuggerInterfacePython3(QObject):
         
         # do not want any slots called during shutdown
         self.qsock.disconnected.disconnect(self.debugServer.startClient)
-        self.qsock.readyRead[()].disconnect(self.__parseClientLine)
+        self.qsock.readyRead.disconnect(self.__parseClientLine)
         
         # close down socket, and shut down client as well.
         self.__sendCommand('{0}\n'.format(DebugProtocol.RequestShutdown))
@@ -793,12 +804,12 @@ class DebuggerInterfacePython3(QObject):
         """
         Private method to ask the user which branch of a fork to follow.
         """
-        selections = [self.trUtf8("Parent Process"),
-                      self.trUtf8("Child process")]
+        selections = [self.tr("Parent Process"),
+                      self.tr("Child process")]
         res, ok = QInputDialog.getItem(
             None,
-            self.trUtf8("Client forking"),
-            self.trUtf8("Select the fork branch to follow."),
+            self.tr("Client forking"),
+            self.tr("Select the fork branch to follow."),
             selections,
             0, False)
         if not ok or res == selections[0]:
