@@ -1,15 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Ruby debugger interface for the debug server.
 """
 
+from __future__ import unicode_literals
+
 import os
 
-from PyQt4.QtCore import QObject, QTextCodec, QProcess, QTimer
+from PyQt5.QtCore import QObject, QTextCodec, QProcess, QProcessEnvironment, \
+    QTimer
 
 from E5Gui.E5Application import e5App
 from E5Gui import E5MessageBox
@@ -20,7 +23,7 @@ from . import DebugClientCapabilities
 import Preferences
 import Utilities
 
-from eric5config import getConfig
+from eric6config import getConfig
 
 
 ClientDefaultCapabilities = \
@@ -56,7 +59,7 @@ class DebuggerInterfaceRuby(QObject):
         @param debugServer reference to the debug server (DebugServer)
         @param passive flag indicating passive connection mode (boolean)
         """
-        super().__init__()
+        super(DebuggerInterfaceRuby, self).__init__()
         
         self.__isNetworked = True
         self.__autoContinue = not passive
@@ -67,9 +70,13 @@ class DebuggerInterfaceRuby(QObject):
         
         self.qsock = None
         self.queue = []
+        
         # set default values for capabilities of clients
         self.clientCapabilities = ClientDefaultCapabilities
         
+        # set translation function
+        self.translate = self.__identityTranslation
+        
         self.codec = QTextCodec.codecForName(
             str(Preferences.getSystem("StringEncoding")))
         
@@ -121,10 +128,10 @@ class DebuggerInterfaceRuby(QObject):
         """
         proc = QProcess()
         if environment is not None:
-            env = []
+            env = QProcessEnvironment()
             for key, value in list(environment.items()):
-                env.append("{0}={1}".format(key, value))
-            proc.setEnvironment(env)
+                env.insert(key, value)
+            proc.setProcessEnvironment(env)
         args = []
         for arg in arguments:
             args.append(arg)
@@ -141,8 +148,9 @@ class DebuggerInterfaceRuby(QObject):
         @param port portnumber the debug server is listening on (integer)
         @param runInConsole flag indicating to start the debugger in a
             console window (boolean)
-        @return client process object (QProcess) and a flag to indicate
-            a network connection (boolean)
+        @return client process object (QProcess), a flag to indicate
+            a network connection (boolean) and the name of the interpreter
+            in case of a local execution (string)
         """
         interpreter = Preferences.getDebugger("RubyInterpreter")
         if interpreter == "":
@@ -150,7 +158,8 @@ class DebuggerInterfaceRuby(QObject):
                 None,
                 self.tr("Start Debugger"),
                 self.tr("""<p>No Ruby interpreter configured.</p>"""))
-            return None, False
+            return None, False, ""
+        
         debugClient = os.path.join(
             getConfig('ericDir'), "DebugClients", "Ruby", "DebugClient.rb")
         
@@ -171,8 +180,8 @@ class DebuggerInterfaceRuby(QObject):
                 if process is None:
                     E5MessageBox.critical(
                         None,
-                        self.trUtf8("Start Debugger"),
-                        self.trUtf8(
+                        self.tr("Start Debugger"),
+                        self.tr(
                             """<p>The debugger backend could not be"""
                             """ started.</p>"""))
                 
@@ -185,7 +194,7 @@ class DebuggerInterfaceRuby(QObject):
                     self.translate = self.__remoteTranslation
                 else:
                     self.translate = self.__identityTranslation
-                return process, self.__isNetworked
+                return process, self.__isNetworked, ""
         
         # set translation function
         self.translate = self.__identityTranslation
@@ -218,11 +227,11 @@ class DebuggerInterfaceRuby(QObject):
                 if process is None:
                     E5MessageBox.critical(
                         None,
-                        self.trUtf8("Start Debugger"),
-                        self.trUtf8(
+                        self.tr("Start Debugger"),
+                        self.tr(
                             """<p>The debugger backend could not be"""
                             """ started.</p>"""))
-                return process, self.__isNetworked
+                return process, self.__isNetworked, interpreter
         
         process = self.__startProcess(
             interpreter,
@@ -231,10 +240,10 @@ class DebuggerInterfaceRuby(QObject):
         if process is None:
             E5MessageBox.critical(
                 None,
-                self.trUtf8("Start Debugger"),
-                self.trUtf8(
+                self.tr("Start Debugger"),
+                self.tr(
                     """<p>The debugger backend could not be started.</p>"""))
-        return process, self.__isNetworked
+        return process, self.__isNetworked, interpreter
 
     def startRemoteForProject(self, port, runInConsole):
         """
@@ -243,12 +252,13 @@ class DebuggerInterfaceRuby(QObject):
         @param port portnumber the debug server is listening on (integer)
         @param runInConsole flag indicating to start the debugger in a
             console window (boolean)
-        @return pid of the client process (integer) and a flag to indicate
-            a network connection (boolean)
+        @return client process object (QProcess), a flag to indicate
+            a network connection (boolean) and the name of the interpreter
+            in case of a local execution (string)
         """
         project = e5App().getObject("Project")
         if not project.isDebugPropertiesLoaded():
-            return None, self.__isNetworked
+            return None, self.__isNetworked, ""
         
         # start debugger with project specific settings
         interpreter = project.getDebugProperty("INTERPRETER")
@@ -271,8 +281,8 @@ class DebuggerInterfaceRuby(QObject):
                 if process is None:
                     E5MessageBox.critical(
                         None,
-                        self.trUtf8("Start Debugger"),
-                        self.trUtf8(
+                        self.tr("Start Debugger"),
+                        self.tr(
                             """<p>The debugger backend could not be"""
                             """ started.</p>"""))
                 # set translation function
@@ -284,7 +294,7 @@ class DebuggerInterfaceRuby(QObject):
                     self.translate = self.__remoteTranslation
                 else:
                     self.translate = self.__identityTranslation
-                return process, self.__isNetworked
+                return process, self.__isNetworked, ""
         
         # set translation function
         self.translate = self.__identityTranslation
@@ -318,11 +328,11 @@ class DebuggerInterfaceRuby(QObject):
                 if process is None:
                     E5MessageBox.critical(
                         None,
-                        self.trUtf8("Start Debugger"),
-                        self.trUtf8(
+                        self.tr("Start Debugger"),
+                        self.tr(
                             """<p>The debugger backend could not be"""
                             """ started.</p>"""))
-                return process, self.__isNetworked
+                return process, self.__isNetworked, interpreter
         
         process = self.__startProcess(
             interpreter,
@@ -331,10 +341,10 @@ class DebuggerInterfaceRuby(QObject):
         if process is None:
             E5MessageBox.critical(
                 None,
-                self.trUtf8("Start Debugger"),
-                self.trUtf8(
+                self.tr("Start Debugger"),
+                self.tr(
                     """<p>The debugger backend could not be started.</p>"""))
-        return process, self.__isNetworked
+        return process, self.__isNetworked, interpreter
 
     def getClientCapabilities(self):
         """
@@ -356,8 +366,8 @@ class DebuggerInterfaceRuby(QObject):
         if self.qsock is not None:
             return False
         
-        sock.disconnected[()].connect(self.debugServer.startClient)
-        sock.readyRead[()].connect(self.__parseClientLine)
+        sock.disconnected.connect(self.debugServer.startClient)
+        sock.readyRead.connect(self.__parseClientLine)
         
         self.qsock = sock
         
@@ -387,7 +397,7 @@ class DebuggerInterfaceRuby(QObject):
         
         # do not want any slots called during shutdown
         self.qsock.disconnected.disconnect(self.debugServer.startClient)
-        self.qsock.readyRead[()].disconnect(self.__parseClientLine)
+        self.qsock.readyRead.disconnect(self.__parseClientLine)
         
         # close down socket, and shut down client as well.
         self.__sendCommand('{0}\n'.format(DebugProtocol.RequestShutdown))
