@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to edit watch expression properties.
 """
 
-from PyQt4.QtGui import QDialog, QDialogButtonBox
+from __future__ import unicode_literals
+
+from PyQt5.QtWidgets import QDialog, QDialogButtonBox
 
 from .Ui_EditWatchpointDialog import Ui_EditWatchpointDialog
 
@@ -27,7 +29,7 @@ class EditWatchpointDialog(QDialog, Ui_EditWatchpointDialog):
         @param name the widget name of this dialog
         @param modal flag indicating a modal dialog
         """
-        super().__init__(parent)
+        super(EditWatchpointDialog, self).__init__(parent)
         self.setupUi(self)
         if name:
             self.setObjectName(name)
@@ -65,6 +67,9 @@ class EditWatchpointDialog(QDialog, Ui_EditWatchpointDialog):
         else:
             self.specialEdit.setFocus()
         
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
+        
     def __textChanged(self, txt):
         """
         Private slot to handle the text changed signal of the condition line
