@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the exceptions filter dialog.
 """
 
-from PyQt4.QtCore import pyqtSlot
-from PyQt4.QtGui import QDialog, QDialogButtonBox
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSlot
+from PyQt5.QtWidgets import QDialog, QDialogButtonBox
 
 from .Ui_ExceptionsFilterDialog import Ui_ExceptionsFilterDialog
 
@@ -25,16 +27,16 @@ class ExceptionsFilterDialog(QDialog, Ui_ExceptionsFilterDialog):
         @param ignore flag indicating the ignore exceptions mode (boolean)
         @param parent the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(ExceptionsFilterDialog, self).__init__(parent)
         self.setupUi(self)
         self.setModal(True)
         
         self.exceptionList.addItems(excList)
         
         if ignore:
-            self.setWindowTitle(self.trUtf8("Ignored Exceptions"))
+            self.setWindowTitle(self.tr("Ignored Exceptions"))
             self.exceptionList.setToolTip(
-                self.trUtf8("List of ignored exceptions"))
+                self.tr("List of ignored exceptions"))
         
         self.okButton = self.buttonBox.button(QDialogButtonBox.Ok)
     
