@@ -1,20 +1,23 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Start Program dialog.
 """
 
-from PyQt4.QtCore import pyqtSlot
-from PyQt4.QtGui import QDialog, QDialogButtonBox
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSlot
+from PyQt5.QtWidgets import QDialog, QDialogButtonBox
 
 from E5Gui.E5Completers import E5DirCompleter
 from E5Gui import E5FileDialog
 
 import Utilities
 import Preferences
+import UI.PixmapCache
 
 
 class StartDialog(QDialog):
@@ -58,7 +61,7 @@ class StartDialog(QDialog):
         @keyparam forkChild flag indicating to debug the child after forking
             (boolean)
         """
-        super().__init__(parent)
+        super(StartDialog, self).__init__(parent)
         self.setModal(True)
         
         self.type = type
@@ -75,9 +78,10 @@ class StartDialog(QDialog):
             from .Ui_StartProfileDialog import Ui_StartProfileDialog
             self.ui = Ui_StartProfileDialog()
         self.ui.setupUi(self)
+        self.ui.dirButton.setIcon(UI.PixmapCache.getIcon("open.png"))
         
         self.clearButton = self.ui.buttonBox.addButton(
-            self.trUtf8("Clear Histories"), QDialogButtonBox.ActionRole)
+            self.tr("Clear Histories"), QDialogButtonBox.ActionRole)
         
         self.workdirCompleter = E5DirCompleter(self.ui.workdirCombo)
         
@@ -114,6 +118,9 @@ class StartDialog(QDialog):
         
         self.__clearHistoryLists = False
         
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
+        
     @pyqtSlot()
     def on_dirButton_clicked(self):
         """
@@ -122,7 +129,7 @@ class StartDialog(QDialog):
         cwd = self.ui.workdirCombo.currentText()
         d = E5FileDialog.getExistingDirectory(
             self,
-            self.trUtf8("Working directory"),
+            self.tr("Working directory"),
             cwd,
             E5FileDialog.Options(E5FileDialog.ShowDirsOnly))
             
