@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the variable detail dialog.
 """
 
-from PyQt4.QtGui import QDialog
+from __future__ import unicode_literals
+
+from PyQt5.QtWidgets import QDialog
 
 from .Ui_VariableDetailDialog import Ui_VariableDetailDialog
 
@@ -28,7 +30,7 @@ class VariableDetailDialog(QDialog, Ui_VariableDetailDialog):
         @param vtype the variables type (string)
         @param value the variables value (string)
         """
-        super().__init__()
+        super(VariableDetailDialog, self).__init__()
         self.setupUi(self)
         
         # set the different fields
