@@ -1,16 +1,22 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the variables viewer widget.
 """
 
-from PyQt4.QtCore import Qt, QRegExp, qVersion
-from PyQt4.QtGui import QTreeWidget, QTreeWidgetItem, QApplication, \
-    QAbstractItemView, QMenu
-from PyQt4.QtGui import QTextDocument   # __IGNORE_WARNING__
+from __future__ import unicode_literals
+try:
+    str = unicode
+except NameError:
+    pass
+
+from PyQt5.QtCore import Qt, QRegExp, qVersion, QCoreApplication
+from PyQt5.QtWidgets import QTreeWidget, QTreeWidgetItem, QAbstractItemView, \
+    QMenu
+from PyQt5.QtGui import QTextDocument   # __IGNORE_WARNING__
 
 from E5Gui.E5Application import e5App
 
@@ -28,7 +34,7 @@ class VariableItem(QTreeWidgetItem):
     """
     def __init__(self, parent, dvar, dvalue, dtype):
         """
-        Constructor.
+        Constructor
         
         @param parent reference to the parent item
         @param dvar variable name (string)
@@ -37,8 +43,8 @@ class VariableItem(QTreeWidgetItem):
         """
         self.__value = dvalue
         if len(dvalue) > 2048:     # 1024 * 2
-            dvalue = QApplication.translate("VariableItem",
-                                            "<double click to show value>")
+            dvalue = QCoreApplication.translate(
+                "VariableItem", "<double click to show value>")
             self.__tooltip = dvalue
         else:
             if Qt.mightBeRichText(dvalue):
@@ -60,7 +66,7 @@ class VariableItem(QTreeWidgetItem):
                 if index < len(lines) - 1:
                     dvalue += "<...>"
         
-        super().__init__(parent, [dvar, dvalue, dtype])
+        super(VariableItem, self).__init__(parent, [dvar, dvalue, dtype])
         
         self.populated = True
         
@@ -85,7 +91,7 @@ class VariableItem(QTreeWidgetItem):
         """
         if column == 1 and role == Qt.ToolTipRole:
             return self.__tooltip
-        return super().data(column, role)
+        return super(VariableItem, self).data(column, role)
         
     def attachDummy(self):
         """
@@ -111,7 +117,7 @@ class VariableItem(QTreeWidgetItem):
         
     def __lt__(self, other):
         """
-        Public method to check, if the item is less than the other one.
+        Special method to check, if the item is less than the other one.
         
         @param other reference to item to compare against (QTreeWidgetItem)
         @return true, if this item is less than other (boolean)
@@ -281,12 +287,13 @@ class VariablesViewer(QTreeWidget):
         @param parent the parent (QWidget)
         @param scope flag indicating global (1) or local (0) variables
         """
-        super().__init__(parent)
+        super(VariablesViewer, self).__init__(parent)
         
         self.indicators = {'list': '[]', 'tuple': '()', 'dict': '{}',
                            # Python types
-                           'Array': '[]', 'Hash': '{}'}
+                           'Array': '[]', 'Hash': '{}'
                            # Ruby types
+                           }
         
         self.rx_class = QRegExp('<.*(instance|object) at 0x.*>')
         self.rx_class2 = QRegExp('class .*')
@@ -310,23 +317,23 @@ class VariablesViewer(QTreeWidget):
         
         self.scope = scope
         if scope:
-            self.setWindowTitle(self.trUtf8("Global Variables"))
+            self.setWindowTitle(self.tr("Global Variables"))
             self.setHeaderLabels([
-                self.trUtf8("Globals"),
-                self.trUtf8("Value"),
-                self.trUtf8("Type")])
-            self.setWhatsThis(self.trUtf8(
+                self.tr("Globals"),
+                self.tr("Value"),
+                self.tr("Type")])
+            self.setWhatsThis(self.tr(
                 """<b>The Global Variables Viewer Window</b>"""
                 """<p>This window displays the global variables"""
                 """ of the debugged program.</p>"""
             ))
         else:
-            self.setWindowTitle(self.trUtf8("Local Variables"))
+            self.setWindowTitle(self.tr("Local Variables"))
             self.setHeaderLabels([
-                self.trUtf8("Locals"),
-                self.trUtf8("Value"),
-                self.trUtf8("Type")])
-            self.setWhatsThis(self.trUtf8(
+                self.tr("Locals"),
+                self.tr("Value"),
+                self.tr("Type")])
+            self.setWhatsThis(self.tr(
                 """<b>The Local Variables Viewer Window</b>"""
                 """<p>This window displays the local variables"""
                 """ of the debugged program.</p>"""
@@ -356,12 +363,12 @@ class VariablesViewer(QTreeWidget):
         Private method to generate the popup menus.
         """
         self.menu = QMenu()
-        self.menu.addAction(self.trUtf8("Show Details..."), self.__showDetails)
+        self.menu.addAction(self.tr("Show Details..."), self.__showDetails)
         self.menu.addSeparator()
-        self.menu.addAction(self.trUtf8("Configure..."), self.__configure)
+        self.menu.addAction(self.tr("Configure..."), self.__configure)
         
         self.backMenu = QMenu()
-        self.backMenu.addAction(self.trUtf8("Configure..."), self.__configure)
+        self.backMenu.addAction(self.tr("Configure..."), self.__configure)
         
     def __showContextMenu(self, coord):
         """
@@ -444,7 +451,7 @@ class VariablesViewer(QTreeWidget):
                 citm = self.__findItem(self.curpathlist, 0)
                 if citm:
                     self.setCurrentItem(citm)
-                    self.setItemSelected(citm, True)
+                    citm.setSelected(True)
                     self.scrollToItem(citm, QAbstractItemView.PositionAtTop)
                     self.current = None
             
@@ -495,7 +502,7 @@ class VariablesViewer(QTreeWidget):
             citm = self.__findItem(self.curpathlist, 0)
             if citm:
                 self.setCurrentItem(citm)
-                self.setItemSelected(citm, True)
+                citm.setSelected(True)
                 if self.__scrollToItem:
                     self.scrollToItem(self.__scrollToItem,
                                       QAbstractItemView.PositionAtTop)
@@ -570,7 +577,7 @@ class VariablesViewer(QTreeWidget):
         
         if vtype in ['list', 'Array', 'tuple', 'dict', 'Hash']:
             itm = self.__generateItem(parent, dvar,
-                                      self.trUtf8("{0} items").format(value),
+                                      self.tr("{0} items").format(value),
                                       dvtype, True)
         elif vtype in ['unicode', 'str']:
             if self.rx_nonprintable.indexIn(value) != -1:
@@ -597,10 +604,10 @@ class VariablesViewer(QTreeWidget):
         """
         try:
             i = ConfigVarTypeStrings.index(vtype)
-            dvtype = self.trUtf8(ConfigVarTypeDispStrings[i])
+            dvtype = self.tr(ConfigVarTypeDispStrings[i])
         except ValueError:
             if vtype == 'classobj':
-                dvtype = self.trUtf8(ConfigVarTypeDispStrings[
+                dvtype = self.tr(ConfigVarTypeDispStrings[
                     ConfigVarTypeStrings.index('instance')])
             else:
                 dvtype = vtype
@@ -710,7 +717,7 @@ class VariablesViewer(QTreeWidget):
             parentItem.expand()
             self.__resort()
         except AttributeError:
-            super().expandItem(parentItem)
+            super(VariablesViewer, self).expandItem(parentItem)
 
     def collapseItem(self, parentItem):
         """
@@ -725,7 +732,7 @@ class VariablesViewer(QTreeWidget):
         try:
             parentItem.collapse()
         except AttributeError:
-            super().collapseItem(parentItem)
+            super(VariablesViewer, self).collapseItem(parentItem)
 
     def __resort(self):
         """
