@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Watch expression model.
 """
 
-from PyQt4.QtCore import pyqtSignal, Qt, QAbstractItemModel, QModelIndex
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSignal, Qt, QAbstractItemModel, QModelIndex
 
 
 class WatchPointModel(QAbstractItemModel):
@@ -22,15 +24,15 @@ class WatchPointModel(QAbstractItemModel):
         
         @param parent reference to the parent widget (QObject)
         """
-        super().__init__(parent)
+        super(WatchPointModel, self).__init__(parent)
         
         self.watchpoints = []
         self.header = [
-            self.trUtf8("Condition"),
-            self.trUtf8("Special"),
-            self.trUtf8('Temporary'),
-            self.trUtf8('Enabled'),
-            self.trUtf8('Ignore Count'),
+            self.tr("Condition"),
+            self.tr("Special"),
+            self.tr('Temporary'),
+            self.tr('Enabled'),
+            self.tr('Ignore Count'),
         ]
         self.alignments = [Qt.Alignment(Qt.AlignLeft),
                            Qt.Alignment(Qt.AlignLeft),
