@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -11,6 +11,8 @@ Python file. The appearance is determined by several templates defined within
 this module.
 """
 
+from __future__ import unicode_literals
+
 import sys
 import re
 
@@ -274,6 +276,8 @@ class ModuleDocument(object):
                        'FunctionList': functionList,
                        })
         except TagError as e:
+            sys.stderr.write(
+                "Error processing {0}.\n".format(self.module.file))
             sys.stderr.write(
                 "Error in tags of description of module {0}.\n".format(
                     self.module.name))
@@ -424,6 +428,8 @@ class ModuleDocument(object):
                         classMethBodies + methBodies + staticMethBodies,
                        })
             except TagError as e:
+                sys.stderr.write(
+                    "Error processing {0}.\n".format(self.module.file))
                 sys.stderr.write(
                     "Error in tags of description of class {0}.\n".format(
                         className))
@@ -506,6 +512,8 @@ class ModuleDocument(object):
                         ', '.join(obj.methods['__init__'].parameters[1:]),
                        })
             except TagError as e:
+                sys.stderr.write(
+                    "Error processing {0}.\n".format(self.module.file))
                 sys.stderr.write(
                     "Error in tags of description of method {0}.{1}.\n".format(
                         className, '__init__'))
@@ -532,6 +540,8 @@ class ModuleDocument(object):
                        'Params': ', '.join(obj.methods[method].parameters[1:]),
                        })
             except TagError as e:
+                sys.stderr.write(
+                    "Error processing {0}.\n".format(self.module.file))
                 sys.stderr.write(
                     "Error in tags of description of method {0}.{1}.\n".format(
                         className, method))
@@ -578,6 +588,8 @@ class ModuleDocument(object):
                        'FunctionsDetails': methBodies,
                        })
             except TagError as e:
+                sys.stderr.write(
+                    "Error processing {0}.\n".format(self.module.file))
                 sys.stderr.write(
                     "Error in tags of description of Ruby module {0}.\n"
                     .format(rbModuleName))
@@ -621,6 +633,8 @@ class ModuleDocument(object):
                        'MethodDetails': methBodies,
                        })
             except TagError as e:
+                sys.stderr.write(
+                    "Error processing {0}.\n".format(self.module.file))
                 sys.stderr.write(
                     "Error in tags of description of class {0}.\n".format(
                         className))
@@ -682,6 +696,8 @@ class ModuleDocument(object):
                         ', '.join(self.module.functions[funcName].parameters),
                        })
             except TagError as e:
+                sys.stderr.write(
+                    "Error processing {0}.\n".format(self.module.file))
                 sys.stderr.write(
                     "Error in tags of description of function {0}.\n".format(
                         funcName))
