@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a clickable label.
 """
 
-from PyQt4.QtCore import pyqtSignal, Qt, QPoint
-from PyQt4.QtGui import QLabel
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSignal, Qt, QPoint
+from PyQt5.QtWidgets import QLabel
 
 
 class E5ClickableLabel(QLabel):
@@ -16,9 +18,9 @@ class E5ClickableLabel(QLabel):
     Class implementing a clickable label.
     
     @signal clicked(QPoint) emitted upon a click on the label
-            with the left buton
+        with the left button
     @signal middleClicked(QPoint) emitted upon a click on the label
-            with the middle buton or CTRL and left button
+        with the middle button or CTRL and left button
     """
     clicked = pyqtSignal(QPoint)
     middleClicked = pyqtSignal(QPoint)
@@ -29,7 +31,7 @@ class E5ClickableLabel(QLabel):
         
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(E5ClickableLabel, self).__init__(parent)
     
     def mouseReleaseEvent(self, evt):
         """
@@ -46,4 +48,4 @@ class E5ClickableLabel(QLabel):
                 self.rect().contains(evt.pos()):
             self.middleClicked.emit(evt.globalPos())
         else:
-            super().mouseReleaseEvent(evt)
+            super(E5ClickableLabel, self).mouseReleaseEvent(evt)
