@@ -1,15 +1,17 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a sidebar class.
 """
 
-from PyQt4.QtCore import QEvent, QSize, Qt, QByteArray, QDataStream, \
-    QIODevice, QTimer
-from PyQt4.QtGui import QTabBar, QWidget, QStackedWidget, QBoxLayout, \
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import QEvent, QSize, Qt, QByteArray, QDataStream, \
+    QIODevice, QTimer, qVersion
+from PyQt5.QtWidgets import QTabBar, QWidget, QStackedWidget, QBoxLayout, \
     QToolButton, QSizePolicy
 
 from E5Gui.E5Application import e5App
@@ -39,7 +41,7 @@ class E5SideBar(QWidget):
             (integer)
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(E5SideBar, self).__init__(parent)
         
         self.__tabBar = QTabBar()
         self.__tabBar.setDrawBase(True)
@@ -54,7 +56,7 @@ class E5SideBar(QWidget):
             UI.PixmapCache.getIcon("autoHideOff.png"))
         self.__autoHideButton.setChecked(True)
         self.__autoHideButton.setToolTip(
-            self.trUtf8("Deselect to activate automatic collapsing"))
+            self.tr("Deselect to activate automatic collapsing"))
         self.barLayout = QBoxLayout(QBoxLayout.LeftToRight)
         self.barLayout.setContentsMargins(0, 0, 0, 0)
         self.layout = QBoxLayout(QBoxLayout.TopToBottom)
@@ -230,7 +232,7 @@ class E5SideBar(QWidget):
     
     def eventFilter(self, obj, evt):
         """
-        Protected method to handle some events for the tabbar.
+        Public method to handle some events for the tabbar.
         
         @param obj reference to the object (QObject)
         @param evt reference to the event object (QEvent)
@@ -251,9 +253,12 @@ class E5SideBar(QWidget):
                     return True
                 elif self.isMinimized():
                     self.expand()
-            elif evt.type() == QEvent.Wheel and \
-                    not self.__stackedWidget.isHidden():
-                if evt.delta() > 0:
+            elif evt.type() == QEvent.Wheel:
+                if qVersion() >= "5.0.0":
+                    delta = evt.angleDelta().y()
+                else:
+                    delta = evt.delta()
+                if delta > 0:
                     self.prevTab()
                 else:
                     self.nextTab()
@@ -603,7 +608,7 @@ class E5SideBar(QWidget):
         stream.readUInt16()  # version
         minimized = stream.readBool()
         
-        if minimized:
+        if minimized and not self.__minimized:
             self.shrink()
         
         stream >> self.__bigSize
