@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a toolbar manager class.
 """
 
-from PyQt4.QtCore import QObject, QByteArray, QDataStream, QIODevice
-from PyQt4.QtGui import QToolBar
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import QObject, QByteArray, QDataStream, QIODevice
+from PyQt5.QtWidgets import QToolBar
 
 import Utilities
 
@@ -28,35 +30,35 @@ class E5ToolBarManager(QObject):
         @param ui reference to the user interface object (UI.UserInterface)
         @param parent reference to the parent object (QObject)
         """
-        super().__init__(parent)
+        super(E5ToolBarManager, self).__init__(parent)
         
         self.__mainWindow = None
         self.__ui = ui
         
         self.__toolBars = {}
-            # maps toolbar IDs to actions
+        # maps toolbar IDs to actions
         self.__toolBarsWithSeparators = {}
-            # maps toolbar IDs to actions incl. separators
+        # maps toolbar IDs to actions incl. separators
         self.__defaultToolBars = {}
-            # maps default toolbar IDs to actions
+        # maps default toolbar IDs to actions
         self.__customToolBars = []
-            # list of custom toolbars
+        # list of custom toolbars
         self.__allToolBars = {}
-            # maps toolbar IDs to toolbars
+        # maps toolbar IDs to toolbars
         
         self.__categoryToActions = {}
-            # maps categories to actions
+        # maps categories to actions
         self.__actionToCategory = {}
-            # maps action IDs to categories
+        # maps action IDs to categories
         self.__allActions = {}
-            # maps action IDs to actions
+        # maps action IDs to actions
         self.__actionToToolBars = {}
-            # maps action IDs to toolbars
+        # maps action IDs to toolbars
         
         self.__widgetActions = {}
-            # maps widget action IDs to toolbars
+        # maps widget action IDs to toolbars
         self.__allWidgetActions = {}
-            # maps widget action IDs to widget actions
+        # maps widget action IDs to widget actions
     
     ######################################################
     ## Private methods
@@ -468,18 +470,18 @@ class E5ToolBarManager(QObject):
         for tbID in self.__defaultToolBars:
             tb = self.__allToolBars[tbID]
             if tb.objectName():
-                stream.writeString(tb.objectName().encode())
+                stream.writeString(tb.objectName().encode("utf-8"))
             else:
-                stream.writeString(tb.windowTitle().encode())
+                stream.writeString(tb.windowTitle().encode("utf-8"))
             stream.writeUInt16(len(self.__toolBars[tbID]))
             for action in self.__toolBars[tbID]:
                 if action is not None:
                     if action.objectName():
-                        stream.writeString(action.objectName().encode())
+                        stream.writeString(action.objectName().encode("utf-8"))
                     else:
-                        stream.writeString(action.text().encode())
+                        stream.writeString(action.text().encode("utf-8"))
                 else:
-                    stream.writeString("".encode())
+                    stream.writeString("".encode("utf-8"))
         
         # save the custom toolbars
         stream.writeUInt16(E5ToolBarManager.CustomToolBarMarker)
@@ -487,17 +489,18 @@ class E5ToolBarManager(QObject):
         for tbID in self.__toolBars:
             if tbID not in self.__defaultToolBars:
                 tb = self.__allToolBars[tbID]
-                stream.writeString(tb.objectName().encode())
-                stream.writeString(tb.windowTitle().encode())
+                stream.writeString(tb.objectName().encode("utf-8"))
+                stream.writeString(tb.windowTitle().encode("utf-8"))
                 stream.writeUInt16(len(self.__toolBars[tbID]))
                 for action in self.__toolBars[tbID]:
                     if action is not None:
                         if action.objectName():
-                            stream.writeString(action.objectName().encode())
+                            stream.writeString(action.objectName()
+                                               .encode("utf-8"))
                         else:
-                            stream.writeString(action.text().encode())
+                            stream.writeString(action.text().encode("utf-8"))
                     else:
-                        stream.writeString("".encode())
+                        stream.writeString("".encode("utf-8"))
         
         return data
     
