@@ -1,17 +1,22 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog showing a UML like class diagram of a package.
 """
 
+from __future__ import unicode_literals
+
 import glob
 import os.path
-import itertools
+try:  # Py3
+    from itertools import zip_longest
+except ImportError:
+    from itertools import izip_longest as zip_longest    # __IGNORE_WARNING__
 
-from PyQt4.QtGui import QApplication, QGraphicsTextItem
+from PyQt5.QtWidgets import QApplication, QGraphicsTextItem
 
 from E5Gui.E5ProgressDialog import E5ProgressDialog
 
@@ -36,7 +41,7 @@ class PackageDiagramBuilder(UMLDiagramBuilder):
         @keyparam noAttrs flag indicating, that no attributes should be shown
             (boolean)
         """
-        super().__init__(dialog, view, project)
+        super(PackageDiagramBuilder, self).__init__(dialog, view, project)
         self.setObjectName("PackageDiagram")
         
         self.package = Utilities.normabspath(package)
@@ -48,10 +53,10 @@ class PackageDiagramBuilder(UMLDiagramBuilder):
         """
         pname = self.project.getProjectName()
         if pname:
-            name = self.trUtf8("Package Diagram {0}: {1}").format(
+            name = self.tr("Package Diagram {0}: {1}").format(
                 pname, self.project.getRelativePath(self.package))
         else:
-            name = self.trUtf8("Package Diagram: {0}").format(self.package)
+            name = self.tr("Package Diagram: {0}").format(self.package)
         self.umlView.setDiagramName(name)
     
     def __getCurrentShape(self, name):
@@ -88,8 +93,9 @@ class PackageDiagramBuilder(UMLDiagramBuilder):
                 Utilities.normjoinpath(self.package, ext)))
         tot = len(modules)
         progress = E5ProgressDialog(
-            self.trUtf8("Parsing modules..."),
-            None, 0, tot, self.trUtf8("%v/%m Modules"), self.parent())
+            self.tr("Parsing modules..."),
+            None, 0, tot, self.tr("%v/%m Modules"), self.parent())
+        progress.setWindowTitle(self.tr("Package Diagram"))
         try:
             prog = 0
             progress.show()
@@ -147,8 +153,9 @@ class PackageDiagramBuilder(UMLDiagramBuilder):
             for subpackage in subpackagesList:
                 tot += len(glob.glob(Utilities.normjoinpath(subpackage, ext)))
         progress = E5ProgressDialog(
-            self.trUtf8("Parsing modules..."),
-            None, 0, tot, self.trUtf8("%v/%m Modules"), self.parent())
+            self.tr("Parsing modules..."),
+            None, 0, tot, self.tr("%v/%m Modules"), self.parent())
+        progress.setWindowTitle(self.tr("Package Diagram"))
         try:
             prog = 0
             progress.show()
@@ -195,17 +202,19 @@ class PackageDiagramBuilder(UMLDiagramBuilder):
         
         initlist = glob.glob(os.path.join(self.package, '__init__.*'))
         if len(initlist) == 0:
-            ct = QGraphicsTextItem(None, self.scene)
+            ct = QGraphicsTextItem(None)
+            self.scene.addItem(ct)
             ct.setHtml(
-                self.trUtf8("The directory <b>'{0}'</b> is not a package.")
+                self.tr("The directory <b>'{0}'</b> is not a package.")
                     .format(self.package))
             return
         
         modules = self.__buildModulesDict()
         if not modules:
-            ct = QGraphicsTextItem(None, self.scene)
+            ct = QGraphicsTextItem(None)
+            self.scene.addItem(ct)
             ct.setHtml(
-                self.trUtf8(
+                self.tr(
                     "The package <b>'{0}'</b> does not contain any modules.")
                 .format(self.package))
             return
@@ -219,9 +228,10 @@ class PackageDiagramBuilder(UMLDiagramBuilder):
                 classesFound = True
                 self.__addLocalClass(cls, module.classes[cls], 0, 0)
         if not classesFound:
-            ct = QGraphicsTextItem(None, self.scene)
+            ct = QGraphicsTextItem(None)
+            self.scene.addItem(ct)
             ct.setHtml(
-                self.trUtf8(
+                self.tr(
                     "The package <b>'{0}'</b> does not contain any classes.")
                 .format(self.package))
             return
@@ -349,7 +359,7 @@ class PackageDiagramBuilder(UMLDiagramBuilder):
         # generations across height
         y = 10.0
         for currentWidth, currentHeight, generation in \
-                itertools.zip_longest(widths, heights, generations):
+                zip_longest(widths, heights, generations):
             x = 10.0
             # whiteSpace is the space between any two elements
             whiteSpace = (width - currentWidth - 20) / \
