@@ -1,16 +1,19 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog showing a pixmap.
 """
 
-from PyQt4.QtCore import Qt, QSize, QEvent
-from PyQt4.QtGui import QLabel, QPalette, QSizePolicy, QScrollArea, QAction, \
-    QMenu, QToolBar, QImage, QPixmap, QPrinter, QPrintDialog, QPainter, \
-    QFont, QColor
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import Qt, QSize, QEvent, qVersion
+from PyQt5.QtGui import QPalette, QImage, QPixmap, QPainter, QFont, QColor
+from PyQt5.QtWidgets import QLabel, QSizePolicy, QScrollArea, QAction, QMenu, \
+    QToolBar
+from PyQt5.QtPrintSupport import QPrinter, QPrintDialog
 
 from E5Gui import E5MessageBox
 from E5Gui.E5MainWindow import E5MainWindow
@@ -42,12 +45,12 @@ class PixmapDiagram(E5MainWindow):
         @param parent parent widget of the view (QWidget)
         @param name name of the view widget (string)
         """
-        super().__init__(parent)
+        super(PixmapDiagram, self).__init__(parent)
         if name:
             self.setObjectName(name)
         else:
             self.setObjectName("PixmapDiagram")
-        self.setWindowTitle(self.trUtf8("Pixmap-Viewer"))
+        self.setWindowTitle(self.tr("Pixmap-Viewer"))
         
         self.pixmapLabel = QLabel()
         self.pixmapLabel.setObjectName("pixmapLabel")
@@ -90,18 +93,18 @@ class PixmapDiagram(E5MainWindow):
         """
         self.closeAct = \
             QAction(UI.PixmapCache.getIcon("close.png"),
-                    self.trUtf8("Close"), self)
-        self.closeAct.triggered[()].connect(self.close)
+                    self.tr("Close"), self)
+        self.closeAct.triggered.connect(self.close)
         
         self.printAct = \
             QAction(UI.PixmapCache.getIcon("print.png"),
-                    self.trUtf8("Print"), self)
-        self.printAct.triggered[()].connect(self.__printDiagram)
+                    self.tr("Print"), self)
+        self.printAct.triggered.connect(self.__printDiagram)
         
         self.printPreviewAct = \
             QAction(UI.PixmapCache.getIcon("printPreview.png"),
-                    self.trUtf8("Print Preview"), self)
-        self.printPreviewAct.triggered[()].connect(self.__printPreviewDiagram)
+                    self.tr("Print Preview"), self)
+        self.printPreviewAct.triggered.connect(self.__printPreviewDiagram)
         
     def __initContextMenu(self):
         """
@@ -128,11 +131,11 @@ class PixmapDiagram(E5MainWindow):
         """
         Private method to populate the toolbars with our actions.
         """
-        self.windowToolBar = QToolBar(self.trUtf8("Window"), self)
+        self.windowToolBar = QToolBar(self.tr("Window"), self)
         self.windowToolBar.setIconSize(UI.Config.ToolBarIconSize)
         self.windowToolBar.addAction(self.closeAct)
         
-        self.graphicsToolBar = QToolBar(self.trUtf8("Graphics"), self)
+        self.graphicsToolBar = QToolBar(self.tr("Graphics"), self)
         self.graphicsToolBar.setIconSize(UI.Config.ToolBarIconSize)
         self.graphicsToolBar.addAction(self.printPreviewAct)
         self.graphicsToolBar.addAction(self.printAct)
@@ -151,8 +154,8 @@ class PixmapDiagram(E5MainWindow):
         if image.isNull():
             E5MessageBox.warning(
                 self,
-                self.trUtf8("Pixmap-Viewer"),
-                self.trUtf8(
+                self.tr("Pixmap-Viewer"),
+                self.tr(
                     """<p>The file <b>{0}</b> cannot be displayed."""
                     """ The format is not supported.</p>""").format(filename))
             return False
@@ -163,7 +166,7 @@ class PixmapDiagram(E5MainWindow):
         
     def getDiagramName(self):
         """
-        Method to retrieve a name for the diagram.
+        Public method to retrieve a name for the diagram.
         
         @return name for the diagram
         """
@@ -171,7 +174,7 @@ class PixmapDiagram(E5MainWindow):
         
     def getStatus(self):
         """
-        Method to retrieve the status of the canvas.
+        Public method to retrieve the status of the canvas.
         
         @return flag indicating a successful pixmap loading (boolean)
         """
@@ -184,18 +187,22 @@ class PixmapDiagram(E5MainWindow):
         @param evt reference to the wheel event (QWheelEvent)
         """
         if evt.modifiers() & Qt.ControlModifier:
-            if evt.delta() < 0:
+            if qVersion() >= "5.0.0":
+                delta = evt.angleDelta().y()
+            else:
+                delta = evt.delta()
+            if delta < 0:
                 self.__zoomOut()
             else:
                 self.__zoomIn()
             evt.accept()
             return
         
-        super().wheelEvent(evt)
+        super(PixmapDiagram, self).wheelEvent(evt)
     
     def event(self, evt):
         """
-        Protected method handling events.
+        Public method handling events.
         
         @param evt reference to the event (QEvent)
         @return flag indicating, if the event was handled (boolean)
@@ -204,7 +211,7 @@ class PixmapDiagram(E5MainWindow):
             self.gestureEvent(evt)
             return True
         
-        return super().event(evt)
+        return super(PixmapDiagram, self).event(evt)
     
     def gestureEvent(self, evt):
         """
@@ -251,7 +258,7 @@ class PixmapDiagram(E5MainWindow):
     
     def __doZoom(self, value):
         """
-        Public method to set the zoom value in percent.
+        Private method to set the zoom value in percent.
         
         @param value zoom value in percent (integer)
         """
@@ -292,7 +299,7 @@ class PixmapDiagram(E5MainWindow):
         
     def __zoom(self):
         """
-        Public method to get the current zoom factor in percent.
+        Private method to get the current zoom factor in percent.
         
         @return current zoom factor in percent (integer)
         """
@@ -323,7 +330,7 @@ class PixmapDiagram(E5MainWindow):
         """
         Private slot called to show a print preview of the diagram.
         """
-        from PyQt4.QtGui import QPrintPreviewDialog
+        from PyQt5.QtPrintSupport import QPrintPreviewDialog
         
         printer = QPrinter(mode=QPrinter.ScreenResolution)
         printer.setFullPage(True)
@@ -377,7 +384,7 @@ class PixmapDiagram(E5MainWindow):
             int(printer.resolution() / 2.54)
 
         # write a foot note
-        s = self.trUtf8("Diagram: {0}").format(self.getDiagramName())
+        s = self.tr("Diagram: {0}").format(self.getDiagramName())
         tc = QColor(50, 50, 50)
         painter.setPen(tc)
         painter.drawRect(marginX, marginY, width, height)
