@@ -1,16 +1,19 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog showing a SVG graphic.
 """
 
-from PyQt4.QtCore import Qt, QSize, QEvent
-from PyQt4.QtGui import QPalette, QSizePolicy, QScrollArea, QAction, QMenu, \
-    QToolBar, QPrinter, QPrintDialog, QPainter, QFont, QColor
-from PyQt4.QtSvg import QSvgWidget
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import Qt, QSize, QEvent, qVersion
+from PyQt5.QtGui import QPalette, QPainter, QFont, QColor
+from PyQt5.QtWidgets import QSizePolicy, QScrollArea, QAction, QMenu, QToolBar
+from PyQt5.QtPrintSupport import QPrinter, QPrintDialog
+from PyQt5.QtSvg import QSvgWidget
 
 from E5Gui.E5MainWindow import E5MainWindow
 from E5Gui.E5ZoomWidget import E5ZoomWidget
@@ -41,12 +44,12 @@ class SvgDiagram(E5MainWindow):
         @param parent parent widget of the view (QWidget)
         @param name name of the view widget (string)
         """
-        super().__init__(parent)
+        super(SvgDiagram, self).__init__(parent)
         if name:
             self.setObjectName(name)
         else:
             self.setObjectName("SvgDiagram")
-        self.setWindowTitle(self.trUtf8("SVG-Viewer"))
+        self.setWindowTitle(self.tr("SVG-Viewer"))
         
         self.svgWidget = QSvgWidget()
         self.svgWidget.setObjectName("svgWidget")
@@ -89,18 +92,18 @@ class SvgDiagram(E5MainWindow):
         """
         self.closeAct = \
             QAction(UI.PixmapCache.getIcon("close.png"),
-                    self.trUtf8("Close"), self)
-        self.closeAct.triggered[()].connect(self.close)
+                    self.tr("Close"), self)
+        self.closeAct.triggered.connect(self.close)
         
         self.printAct = \
             QAction(UI.PixmapCache.getIcon("print.png"),
-                    self.trUtf8("Print"), self)
-        self.printAct.triggered[()].connect(self.__printDiagram)
+                    self.tr("Print"), self)
+        self.printAct.triggered.connect(self.__printDiagram)
         
         self.printPreviewAct = \
             QAction(UI.PixmapCache.getIcon("printPreview.png"),
-                    self.trUtf8("Print Preview"), self)
-        self.printPreviewAct.triggered[()].connect(self.__printPreviewDiagram)
+                    self.tr("Print Preview"), self)
+        self.printPreviewAct.triggered.connect(self.__printPreviewDiagram)
         
     def __initContextMenu(self):
         """
@@ -127,11 +130,11 @@ class SvgDiagram(E5MainWindow):
         """
         Private method to populate the toolbars with our actions.
         """
-        self.windowToolBar = QToolBar(self.trUtf8("Window"), self)
+        self.windowToolBar = QToolBar(self.tr("Window"), self)
         self.windowToolBar.setIconSize(UI.Config.ToolBarIconSize)
         self.windowToolBar.addAction(self.closeAct)
         
-        self.graphicsToolBar = QToolBar(self.trUtf8("Graphics"), self)
+        self.graphicsToolBar = QToolBar(self.tr("Graphics"), self)
         self.graphicsToolBar.setIconSize(UI.Config.ToolBarIconSize)
         self.graphicsToolBar.addAction(self.printPreviewAct)
         self.graphicsToolBar.addAction(self.printAct)
@@ -141,7 +144,7 @@ class SvgDiagram(E5MainWindow):
         
     def getDiagramName(self):
         """
-        Method to retrieve a name for the diagram.
+        Public method to retrieve a name for the diagram.
         
         @return name for the diagram
         """
@@ -154,18 +157,22 @@ class SvgDiagram(E5MainWindow):
         @param evt reference to the wheel event (QWheelEvent)
         """
         if evt.modifiers() & Qt.ControlModifier:
-            if evt.delta() < 0:
+            if qVersion() >= "5.0.0":
+                delta = evt.angleDelta().y()
+            else:
+                delta = evt.delta()
+            if delta < 0:
                 self.__zoomOut()
             else:
                 self.__zoomIn()
             evt.accept()
             return
         
-        super().wheelEvent(evt)
+        super(SvgDiagram, self).wheelEvent(evt)
     
     def event(self, evt):
         """
-        Protected method handling events.
+        Public method handling events.
         
         @param evt reference to the event (QEvent)
         @return flag indicating, if the event was handled (boolean)
@@ -174,7 +181,7 @@ class SvgDiagram(E5MainWindow):
             self.gestureEvent(evt)
             return True
         
-        return super().event(evt)
+        return super(SvgDiagram, self).event(evt)
     
     def gestureEvent(self, evt):
         """
@@ -222,7 +229,7 @@ class SvgDiagram(E5MainWindow):
     
     def __doZoom(self, value):
         """
-        Public method to set the zoom value in percent.
+        Private method to set the zoom value in percent.
         
         @param value zoom value in percent (integer)
         """
@@ -260,7 +267,7 @@ class SvgDiagram(E5MainWindow):
         
     def __zoom(self):
         """
-        Public method to get the current zoom factor in percent.
+        Private method to get the current zoom factor in percent.
         
         @return current zoom factor in percent (integer)
         """
@@ -293,7 +300,7 @@ class SvgDiagram(E5MainWindow):
         """
         Private slot called to show a print preview of the diagram.
         """
-        from PyQt4.QtGui import QPrintPreviewDialog
+        from PyQt5.QtPrintSupport import QPrintPreviewDialog
         
         printer = QPrinter(mode=QPrinter.ScreenResolution)
         printer.setFullPage(True)
@@ -349,7 +356,7 @@ class SvgDiagram(E5MainWindow):
             int(printer.resolution() / 2.54)
 
         # write a foot note
-        s = self.trUtf8("Diagram: {0}").format(self.getDiagramName())
+        s = self.tr("Diagram: {0}").format(self.getDiagramName())
         tc = QColor(50, 50, 50)
         painter.setPen(tc)
         painter.drawRect(marginX, marginY, width, height)
