@@ -1,16 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a subclass of E5GraphicsView for our diagrams.
 """
 
-from PyQt4.QtCore import pyqtSignal, Qt, QSignalMapper, QFileInfo, QEvent, \
-    QRectF
-from PyQt4.QtGui import QGraphicsView, QAction, QToolBar, QDialog, QPrinter, \
-    QPrintDialog
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSignal, Qt, QSignalMapper, QFileInfo, QEvent, \
+    QRectF, qVersion
+from PyQt5.QtWidgets import QGraphicsView, QAction, QToolBar, QDialog
+from PyQt5.QtPrintSupport import QPrinter, QPrintDialog
 
 from E5Graphics.E5GraphicsView import E5GraphicsView
 
@@ -76,87 +78,87 @@ class UMLGraphicsView(E5GraphicsView):
         
         self.deleteShapeAct = \
             QAction(UI.PixmapCache.getIcon("deleteShape.png"),
-                    self.trUtf8("Delete shapes"), self)
-        self.deleteShapeAct.triggered[()].connect(self.__deleteShape)
+                    self.tr("Delete shapes"), self)
+        self.deleteShapeAct.triggered.connect(self.__deleteShape)
         
         self.incWidthAct = \
             QAction(UI.PixmapCache.getIcon("sceneWidthInc.png"),
-                    self.trUtf8("Increase width by {0} points").format(
+                    self.tr("Increase width by {0} points").format(
                         self.deltaSize),
                     self)
-        self.incWidthAct.triggered[()].connect(self.__incWidth)
+        self.incWidthAct.triggered.connect(self.__incWidth)
         
         self.incHeightAct = \
             QAction(UI.PixmapCache.getIcon("sceneHeightInc.png"),
-                    self.trUtf8("Increase height by {0} points").format(
+                    self.tr("Increase height by {0} points").format(
                         self.deltaSize),
                     self)
-        self.incHeightAct.triggered[()].connect(self.__incHeight)
+        self.incHeightAct.triggered.connect(self.__incHeight)
         
         self.decWidthAct = \
             QAction(UI.PixmapCache.getIcon("sceneWidthDec.png"),
-                    self.trUtf8("Decrease width by {0} points").format(
+                    self.tr("Decrease width by {0} points").format(
                         self.deltaSize),
                     self)
-        self.decWidthAct.triggered[()].connect(self.__decWidth)
+        self.decWidthAct.triggered.connect(self.__decWidth)
         
         self.decHeightAct = \
             QAction(UI.PixmapCache.getIcon("sceneHeightDec.png"),
-                    self.trUtf8("Decrease height by {0} points").format(
+                    self.tr("Decrease height by {0} points").format(
                         self.deltaSize),
                     self)
-        self.decHeightAct.triggered[()].connect(self.__decHeight)
+        self.decHeightAct.triggered.connect(self.__decHeight)
         
         self.setSizeAct = \
             QAction(UI.PixmapCache.getIcon("sceneSize.png"),
-                    self.trUtf8("Set size"), self)
-        self.setSizeAct.triggered[()].connect(self.__setSize)
+                    self.tr("Set size"), self)
+        self.setSizeAct.triggered.connect(self.__setSize)
         
         self.rescanAct = \
             QAction(UI.PixmapCache.getIcon("rescan.png"),
-                    self.trUtf8("Re-Scan"), self)
-        self.rescanAct.triggered[()].connect(self.__rescan)
+                    self.tr("Re-Scan"), self)
+        self.rescanAct.triggered.connect(self.__rescan)
         
         self.relayoutAct = \
             QAction(UI.PixmapCache.getIcon("relayout.png"),
-                    self.trUtf8("Re-Layout"), self)
-        self.relayoutAct.triggered[()].connect(self.__relayout)
+                    self.tr("Re-Layout"), self)
+        self.relayoutAct.triggered.connect(self.__relayout)
         
         self.alignLeftAct = \
             QAction(UI.PixmapCache.getIcon("shapesAlignLeft.png"),
-                    self.trUtf8("Align Left"), self)
+                    self.tr("Align Left"), self)
         self.alignMapper.setMapping(self.alignLeftAct, Qt.AlignLeft)
-        self.alignLeftAct.triggered[()].connect(self.alignMapper.map)
+        self.alignLeftAct.triggered.connect(self.alignMapper.map)
         
         self.alignHCenterAct = \
             QAction(UI.PixmapCache.getIcon("shapesAlignHCenter.png"),
-                    self.trUtf8("Align Center Horizontal"), self)
+                    self.tr("Align Center Horizontal"), self)
         self.alignMapper.setMapping(self.alignHCenterAct, Qt.AlignHCenter)
-        self.alignHCenterAct.triggered[()].connect(self.alignMapper.map)
+        self.alignHCenterAct.triggered.connect(self.alignMapper.map)
         
         self.alignRightAct = \
             QAction(UI.PixmapCache.getIcon("shapesAlignRight.png"),
-                    self.trUtf8("Align Right"), self)
+                    self.tr("Align Right"), self)
         self.alignMapper.setMapping(self.alignRightAct, Qt.AlignRight)
-        self.alignRightAct.triggered[()].connect(self.alignMapper.map)
+        self.alignRightAct.triggered.connect(self.alignMapper.map)
         
         self.alignTopAct = \
             QAction(UI.PixmapCache.getIcon("shapesAlignTop.png"),
-                    self.trUtf8("Align Top"), self)
+                    self.tr("Align Top"), self)
         self.alignMapper.setMapping(self.alignTopAct, Qt.AlignTop)
-        self.alignTopAct.triggered[()].connect(self.alignMapper.map)
+        self.alignTopAct.triggered.connect(self.alignMapper.map)
         
         self.alignVCenterAct = \
             QAction(UI.PixmapCache.getIcon("shapesAlignVCenter.png"),
-                    self.trUtf8("Align Center Vertical"), self)
+                    self.tr("Align Center Vertical"), self)
         self.alignMapper.setMapping(self.alignVCenterAct, Qt.AlignVCenter)
-        self.alignVCenterAct.triggered[()].connect(self.alignMapper.map)
+        self.alignVCenterAct.triggered.connect(self.alignMapper.map)
         
         self.alignBottomAct = \
             QAction(UI.PixmapCache.getIcon("shapesAlignBottom.png"),
-                    self.trUtf8("Align Bottom"), self)
+                    self.tr("Align Bottom"), self)
         self.alignMapper.setMapping(self.alignBottomAct, Qt.AlignBottom)
-        self.alignBottomAct.triggered[()].connect(self.alignMapper.map)
+        self.alignBottomAct.triggered.connect(self.alignMapper.map)
         
     def __checkSizeActions(self):
         """
@@ -204,7 +206,7 @@ class UMLGraphicsView(E5GraphicsView):
         
         @return the populated toolBar (QToolBar)
         """
-        toolBar = QToolBar(self.trUtf8("Graphics"), self)
+        toolBar = QToolBar(self.tr("Graphics"), self)
         toolBar.setIconSize(UI.Config.ToolBarIconSize)
         toolBar.addAction(self.deleteShapeAct)
         toolBar.addSeparator()
@@ -319,7 +321,7 @@ class UMLGraphicsView(E5GraphicsView):
         @param limit flag indicating to limit the scene to the
             initial size (boolean)
         """
-        super().autoAdjustSceneSize(limit=limit)
+        super(UMLGraphicsView, self).autoAdjustSceneSize(limit=limit)
         self.__checkSizeActions()
         
     def saveImage(self):
@@ -328,10 +330,10 @@ class UMLGraphicsView(E5GraphicsView):
         """
         fname, selectedFilter = E5FileDialog.getSaveFileNameAndFilter(
             self,
-            self.trUtf8("Save Diagram"),
+            self.tr("Save Diagram"),
             "",
-            self.trUtf8("Portable Network Graphics (*.png);;"
-                        "Scalable Vector Graphics (*.svg)"),
+            self.tr("Portable Network Graphics (*.png);;"
+                    "Scalable Vector Graphics (*.svg)"),
             "",
             E5FileDialog.Options(E5FileDialog.DontConfirmOverwrite))
         if fname:
@@ -343,20 +345,20 @@ class UMLGraphicsView(E5GraphicsView):
             if QFileInfo(fname).exists():
                 res = E5MessageBox.yesNo(
                     self,
-                    self.trUtf8("Save Diagram"),
-                    self.trUtf8("<p>The file <b>{0}</b> already exists."
-                                " Overwrite it?</p>").format(fname),
+                    self.tr("Save Diagram"),
+                    self.tr("<p>The file <b>{0}</b> already exists."
+                            " Overwrite it?</p>").format(fname),
                     icon=E5MessageBox.Warning)
                 if not res:
                     return
             
-            success = super().saveImage(
+            success = super(UMLGraphicsView, self).saveImage(
                 fname, QFileInfo(fname).suffix().upper())
             if not success:
                 E5MessageBox.critical(
                     self,
-                    self.trUtf8("Save Diagram"),
-                    self.trUtf8(
+                    self.tr("Save Diagram"),
+                    self.tr(
                         """<p>The file <b>{0}</b> could not be saved.</p>""")
                     .format(fname))
         
@@ -422,13 +424,14 @@ class UMLGraphicsView(E5GraphicsView):
         
         printDialog = QPrintDialog(printer, self)
         if printDialog.exec_():
-            super().printDiagram(printer, self.diagramName)
+            super(UMLGraphicsView, self).printDiagram(
+                printer, self.diagramName)
         
     def printPreviewDiagram(self):
         """
         Public slot called to show a print preview of the diagram.
         """
-        from PyQt4.QtGui import QPrintPreviewDialog
+        from PyQt5.QtPrintSupport import QPrintPreviewDialog
         
         printer = QPrinter(mode=QPrinter.ScreenResolution)
         printer.setFullPage(True)
@@ -461,7 +464,7 @@ class UMLGraphicsView(E5GraphicsView):
         
         @param printer reference to the printer object (QPrinter)
         """
-        super().printDiagram(printer, self.diagramName)
+        super(UMLGraphicsView, self).printDiagram(printer, self.diagramName)
         
     def setDiagramName(self, name):
         """
@@ -589,7 +592,7 @@ class UMLGraphicsView(E5GraphicsView):
                 evt.accept()
                 return
         
-        super().keyPressEvent(evt)
+        super(UMLGraphicsView, self).keyPressEvent(evt)
     
     def wheelEvent(self, evt):
         """
@@ -598,18 +601,22 @@ class UMLGraphicsView(E5GraphicsView):
         @param evt reference to the wheel event (QWheelEvent)
         """
         if evt.modifiers() & Qt.ControlModifier:
-            if evt.delta() < 0:
+            if qVersion() >= "5.0.0":
+                delta = evt.angleDelta().y()
+            else:
+                delta = evt.delta()
+            if delta < 0:
                 self.zoomOut()
             else:
                 self.zoomIn()
             evt.accept()
             return
         
-        super().wheelEvent(evt)
+        super(UMLGraphicsView, self).wheelEvent(evt)
     
     def event(self, evt):
         """
-        Protected method handling events.
+        Public method handling events.
         
         @param evt reference to the event (QEvent)
         @return flag indicating, if the event was handled (boolean)
@@ -618,7 +625,7 @@ class UMLGraphicsView(E5GraphicsView):
             self.gestureEvent(evt)
             return True
         
-        return super().event(evt)
+        return super(UMLGraphicsView, self).event(evt)
     
     def gestureEvent(self, evt):
         """
