@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to set the scene sizes.
 """
 
-from PyQt4.QtGui import QDialog
+from __future__ import unicode_literals
+
+from PyQt5.QtWidgets import QDialog
 
 from .Ui_UMLSceneSizeDialog import Ui_UMLSceneSizeDialog
 
@@ -27,7 +29,7 @@ class UMLSceneSizeDialog(QDialog, Ui_UMLSceneSizeDialog):
         @param parent parent widget of this dialog (QWidget)
         @param name name of this widget (string)
         """
-        super().__init__(parent)
+        super(UMLSceneSizeDialog, self).__init__(parent)
         if name:
             self.setObjectName(name)
         self.setupUi(self)
@@ -39,9 +41,12 @@ class UMLSceneSizeDialog(QDialog, Ui_UMLSceneSizeDialog):
         self.widthSpinBox.selectAll()
         self.widthSpinBox.setFocus()
         
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
+        
     def getData(self):
         """
-        Method to retrieve the entered data.
+        Public method to retrieve the entered data.
         
         @return tuple giving the selected width and height
             (integer, integer)
