@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a QNetworkReply subclass reporting a blocked request.
 """
 
-from PyQt4.QtCore import QTimer
-from PyQt4.QtNetwork import QNetworkReply, QNetworkAccessManager
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import QTimer
+from PyQt5.QtNetwork import QNetworkReply, QNetworkAccessManager
 
 
 class AdBlockBlockedNetworkReply(QNetworkReply):
@@ -25,7 +27,7 @@ class AdBlockBlockedNetworkReply(QNetworkReply):
         @param rule matching rule (AdBlockRule)
         @param parent reference to the parent object (QObject)
         """
-        super().__init__(parent)
+        super(AdBlockBlockedNetworkReply, self).__init__(parent)
         self.setOperation(QNetworkAccessManager.GetOperation)
         self.setRequest(request)
         self.setUrl(request.url())
@@ -45,7 +47,7 @@ class AdBlockBlockedNetworkReply(QNetworkReply):
     
     def readData(self, maxlen):
         """
-        Protected method to retrieve data from the reply object.
+        Public method to retrieve data from the reply object.
         
         @param maxlen maximum number of bytes to read (integer)
         @return string containing the data (string)
