@@ -1,20 +1,23 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the AdBlock subscription class.
 """
 
+from __future__ import unicode_literals
+
 import os
 import re
 import hashlib
 import base64
 
-from PyQt4.QtCore import pyqtSignal, Qt, QObject, QByteArray, QDateTime, \
-    QUrl, QCryptographicHash, QFile, QIODevice, QTextStream, QDate, QTime
-from PyQt4.QtNetwork import QNetworkReply
+from PyQt5.QtCore import pyqtSignal, Qt, QObject, QByteArray, QDateTime, \
+    QUrl, QCryptographicHash, QFile, QIODevice, QTextStream, QDate, QTime, \
+    qVersion
+from PyQt5.QtNetwork import QNetworkReply
 
 from E5Gui import E5MessageBox
 
@@ -43,7 +46,7 @@ class AdBlockSubscription(QObject):
         @param parent reference to the parent object (QObject)
         @param default flag indicating a default subscription (boolean)
         """
-        super().__init__(parent)
+        super(AdBlockSubscription, self).__init__(parent)
         
         self.__custom = custom
         self.__url = url.toEncoded()
@@ -110,27 +113,54 @@ class AdBlockSubscription(QObject):
         if url.path() != "subscribe":
             return
         
-        self.__title = \
-            QUrl.fromPercentEncoding(url.encodedQueryItemValue("title"))
-        self.__enabled = QUrl.fromPercentEncoding(
-            url.encodedQueryItemValue("enabled")) != "false"
-        self.__location = QByteArray(QUrl.fromPercentEncoding(
-            url.encodedQueryItemValue("location")))
-        
-        # Check for required subscription
-        self.__requiresLocation = QUrl.fromPercentEncoding(
-            url.encodedQueryItemValue("requiresLocation"))
-        self.__requiresTitle = QUrl.fromPercentEncoding(
-            url.encodedQueryItemValue("requiresTitle"))
-        if self.__requiresLocation and self.__requiresTitle:
-            import Helpviewer.HelpWindow
-            Helpviewer.HelpWindow.HelpWindow.adBlockManager()\
-                .loadRequiredSubscription(self.__requiresLocation,
-                                          self.__requiresTitle)
-        
-        lastUpdateByteArray = url.encodedQueryItemValue("lastUpdate")
-        lastUpdateString = QUrl.fromPercentEncoding(lastUpdateByteArray)
-        self.__lastUpdate = QDateTime.fromString(lastUpdateString, Qt.ISODate)
+        if qVersion() >= "5.0.0":
+            from PyQt5.QtCore import QUrlQuery
+            urlQuery = QUrlQuery(url)
+            self.__title = QUrl.fromPercentEncoding(
+                QByteArray(urlQuery.queryItemValue("title").encode()))
+            self.__enabled = urlQuery.queryItemValue("enabled") != "false"
+            self.__location = QByteArray(QUrl.fromPercentEncoding(
+                QByteArray(urlQuery.queryItemValue("location").encode()))
+                .encode("utf-8"))
+            
+            # Check for required subscription
+            self.__requiresLocation = QUrl.fromPercentEncoding(
+                QByteArray(urlQuery.queryItemValue(
+                "requiresLocation").encode()))
+            self.__requiresTitle = QUrl.fromPercentEncoding(
+                QByteArray(urlQuery.queryItemValue("requiresTitle").encode()))
+            if self.__requiresLocation and self.__requiresTitle:
+                import Helpviewer.HelpWindow
+                Helpviewer.HelpWindow.HelpWindow.adBlockManager()\
+                    .loadRequiredSubscription(self.__requiresLocation,
+                                              self.__requiresTitle)
+            
+            lastUpdateString = urlQuery.queryItemValue("lastUpdate")
+            self.__lastUpdate = QDateTime.fromString(lastUpdateString,
+                                                     Qt.ISODate)
+        else:
+            self.__title = \
+                QUrl.fromPercentEncoding(url.encodedQueryItemValue(b"title"))
+            self.__enabled = QUrl.fromPercentEncoding(
+                url.encodedQueryItemValue(b"enabled")) != "false"
+            self.__location = QByteArray(QUrl.fromPercentEncoding(
+                url.encodedQueryItemValue(b"location")).encode("utf-8"))
+            
+            # Check for required subscription
+            self.__requiresLocation = QUrl.fromPercentEncoding(
+                url.encodedQueryItemValue(b"requiresLocation"))
+            self.__requiresTitle = QUrl.fromPercentEncoding(
+                url.encodedQueryItemValue(b"requiresTitle"))
+            if self.__requiresLocation and self.__requiresTitle:
+                import Helpviewer.HelpWindow
+                Helpviewer.HelpWindow.HelpWindow.adBlockManager()\
+                    .loadRequiredSubscription(self.__requiresLocation,
+                                              self.__requiresTitle)
+            
+            lastUpdateByteArray = url.encodedQueryItemValue(b"lastUpdate")
+            lastUpdateString = QUrl.fromPercentEncoding(lastUpdateByteArray)
+            self.__lastUpdate = QDateTime.fromString(lastUpdateString,
+                                                     Qt.ISODate)
         
         self.__loadRules()
     
@@ -155,7 +185,13 @@ class AdBlockSubscription(QObject):
         if self.__lastUpdate.isValid():
             queryItems.append(("lastUpdate",
                                self.__lastUpdate.toString(Qt.ISODate)))
-        url.setQueryItems(queryItems)
+        if qVersion() >= "5.0.0":
+            from PyQt5.QtCore import QUrlQuery
+            query = QUrlQuery()
+            query.setQueryItems(queryItems)
+            url.setQuery(query)
+        else:
+            url.setQueryItems(queryItems)
         return url
     
     def isEnabled(self):
@@ -267,8 +303,8 @@ class AdBlockSubscription(QObject):
             if not f.open(QIODevice.ReadOnly):
                 E5MessageBox.warning(
                     None,
-                    self.trUtf8("Load subscription rules"),
-                    self.trUtf8(
+                    self.tr("Load subscription rules"),
+                    self.tr(
                         """Unable to open adblock file '{0}' for reading.""")
                     .format(fileName))
             else:
@@ -277,9 +313,9 @@ class AdBlockSubscription(QObject):
                 if not header.startswith("[Adblock"):
                     E5MessageBox.warning(
                         None,
-                        self.trUtf8("Load subscription rules"),
-                        self.trUtf8("""AdBlock file '{0}' does not start"""
-                                    """ with [Adblock.""")
+                        self.tr("Load subscription rules"),
+                        self.tr("""AdBlock file '{0}' does not start"""
+                                """ with [Adblock.""")
                         .format(fileName))
                     f.close()
                     f.remove()
@@ -358,7 +394,7 @@ class AdBlockSubscription(QObject):
         self.__downloading = FollowRedirectReply(
             self.location(),
             Helpviewer.HelpWindow.HelpWindow.networkAccessManager())
-        self.__downloading.finished[()].connect(self.__rulesDownloaded)
+        self.__downloading.finished.connect(self.__rulesDownloaded)
     
     def __rulesDownloaded(self):
         """
@@ -375,8 +411,8 @@ class AdBlockSubscription(QObject):
                 # don't show error if we try to load the default
                 E5MessageBox.warning(
                     None,
-                    self.trUtf8("Downloading subscription rules"),
-                    self.trUtf8(
+                    self.tr("Downloading subscription rules"),
+                    self.tr(
                         """<p>Subscription rules could not be"""
                         """ downloaded.</p><p>Error: {0}</p>""")
                     .format(reply.errorString()))
@@ -388,8 +424,8 @@ class AdBlockSubscription(QObject):
         if response.isEmpty():
             E5MessageBox.warning(
                 None,
-                self.trUtf8("Downloading subscription rules"),
-                self.trUtf8("""Got empty subscription rules."""))
+                self.tr("Downloading subscription rules"),
+                self.tr("""Got empty subscription rules."""))
             return
         
         fileName = self.rulesFileName()
@@ -398,8 +434,8 @@ class AdBlockSubscription(QObject):
         if not f.open(QIODevice.ReadWrite):
             E5MessageBox.warning(
                 None,
-                self.trUtf8("Downloading subscription rules"),
-                self.trUtf8(
+                self.tr("Downloading subscription rules"),
+                self.tr(
                     """Unable to open adblock file '{0}' for writing.""")
                 .file(fileName))
             return
@@ -411,6 +447,7 @@ class AdBlockSubscription(QObject):
         else:
             QFile.remove(fileName)
         self.__downloading = None
+        reply.deleteLater()
     
     def __validateCheckSum(self, fileName):
         """
@@ -450,8 +487,8 @@ class AdBlockSubscription(QObject):
         else:
             res = E5MessageBox.yesNo(
                 None,
-                self.trUtf8("Downloading subscription rules"),
-                self.trUtf8(
+                self.tr("Downloading subscription rules"),
+                self.tr(
                     """<p>AdBlock subscription <b>{0}</b> has a wrong"""
                     """ checksum.<br/>"""
                     """Found: {1}<br/>"""
@@ -473,8 +510,8 @@ class AdBlockSubscription(QObject):
         if not f.open(QIODevice.ReadWrite | QIODevice.Truncate):
             E5MessageBox.warning(
                 None,
-                self.trUtf8("Saving subscription rules"),
-                self.trUtf8(
+                self.tr("Saving subscription rules"),
+                self.tr(
                     """Unable to open adblock file '{0}' for writing.""")
                 .format(fileName))
             return
