@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to add a bookmark or a bookmark folder.
 """
 
-from PyQt4.QtCore import QModelIndex
-from PyQt4.QtGui import QSortFilterProxyModel, QDialog, QTreeView
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import QModelIndex, QSortFilterProxyModel
+from PyQt5.QtWidgets import QDialog, QTreeView
 
 from .Ui_AddBookmarkDialog import Ui_AddBookmarkDialog
 
@@ -23,7 +25,7 @@ class AddBookmarkProxyModel(QSortFilterProxyModel):
         
         @param parent reference to the parent object (QObject)
         """
-        super().__init__(parent)
+        super(AddBookmarkProxyModel, self).__init__(parent)
     
     def columnCount(self, parent):
         """
@@ -36,7 +38,7 @@ class AddBookmarkProxyModel(QSortFilterProxyModel):
     
     def filterAcceptsRow(self, sourceRow, sourceParent):
         """
-        Protected method to determine, if the row is acceptable.
+        Public method to determine, if the row is acceptable.
         
         @param sourceRow row number in the source model (integer)
         @param sourceParent index of the source item (QModelIndex)
@@ -47,7 +49,7 @@ class AddBookmarkProxyModel(QSortFilterProxyModel):
     
     def filterAcceptsColumn(self, sourceColumn, sourceParent):
         """
-        Protected method to determine, if the column is acceptable.
+        Public method to determine, if the column is acceptable.
         
         @param sourceColumn column number in the source model (integer)
         @param sourceParent index of the source item (QModelIndex)
@@ -78,7 +80,7 @@ class AddBookmarkDialog(QDialog, Ui_AddBookmarkDialog):
         @param bookmarksManager reference to the bookmarks manager
             object (BookmarksManager)
         """
-        super().__init__(parent)
+        super(AddBookmarkDialog, self).__init__(parent)
         self.setupUi(self)
         
         self.__bookmarksManager = bookmarksManager
@@ -107,8 +109,8 @@ class AddBookmarkDialog(QDialog, Ui_AddBookmarkDialog):
         self.locationCombo.setModel(self.__proxyModel)
         self.locationCombo.setView(self.__treeView)
         
-        self.addressEdit.setInactiveText(self.trUtf8("Url"))
-        self.nameEdit.setInactiveText(self.trUtf8("Title"))
+        self.addressEdit.setInactiveText(self.tr("Url"))
+        self.nameEdit.setInactiveText(self.tr("Title"))
         
         self.resize(self.sizeHint())
     
@@ -190,10 +192,10 @@ class AddBookmarkDialog(QDialog, Ui_AddBookmarkDialog):
         self.__addFolder = folder
         
         if folder:
-            self.setWindowTitle(self.trUtf8("Add Folder"))
+            self.setWindowTitle(self.tr("Add Folder"))
             self.addressEdit.setVisible(False)
         else:
-            self.setWindowTitle(self.trUtf8("Add Bookmark"))
+            self.setWindowTitle(self.tr("Add Bookmark"))
             self.addressEdit.setVisible(True)
         
         self.resize(self.sizeHint())
@@ -220,7 +222,7 @@ class AddBookmarkDialog(QDialog, Ui_AddBookmarkDialog):
         """
         if (not self.__addFolder and not self.addressEdit.text()) or \
            not self.nameEdit.text():
-            super().accept()
+            super(AddBookmarkDialog, self).accept()
             return
         
         from .BookmarkNode import BookmarkNode
@@ -243,4 +245,4 @@ class AddBookmarkDialog(QDialog, Ui_AddBookmarkDialog):
         self.__bookmarksManager.addBookmark(parent, bookmark)
         self.__addedNode = bookmark
         
-        super().accept()
+        super(AddBookmarkDialog, self).accept()
