@@ -1,14 +1,17 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to manage bookmarks.
 """
 
-from PyQt4.QtCore import pyqtSignal, Qt, QUrl, QModelIndex
-from PyQt4.QtGui import QDialog, QFontMetrics, QMenu, QCursor, QApplication
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSignal, Qt, QUrl, QModelIndex
+from PyQt5.QtGui import QFontMetrics, QCursor
+from PyQt5.QtWidgets import QDialog, QMenu, QApplication
 
 from E5Gui.E5TreeSortFilterProxyModel import E5TreeSortFilterProxyModel
 
@@ -33,8 +36,9 @@ class BookmarksDialog(QDialog, Ui_BookmarksDialog):
         @param manager reference to the bookmarks manager object
             (BookmarksManager)
         """
-        super().__init__(parent)
+        super(BookmarksDialog, self).__init__(parent)
         self.setupUi(self)
+        self.setWindowFlags(Qt.Window)
         
         self.__bookmarksManager = manager
         if self.__bookmarksManager is None:
@@ -62,9 +66,9 @@ class BookmarksDialog(QDialog, Ui_BookmarksDialog):
         self.bookmarksTree.customContextMenuRequested.connect(
             self.__customContextMenuRequested)
         
-        self.removeButton.clicked[()].connect(
+        self.removeButton.clicked.connect(
             self.bookmarksTree.removeSelected)
-        self.addFolderButton.clicked[()].connect(self.__newFolder)
+        self.addFolderButton.clicked.connect(self.__newFolder)
         
         self.__expandNodes(self.__bookmarksManager.bookmarks())
     
@@ -78,10 +82,10 @@ class BookmarksDialog(QDialog, Ui_BookmarksDialog):
     
     def reject(self):
         """
-        Protected method called when the dialog is rejected.
+        Public method called when the dialog is rejected.
         """
         self.__shutdown()
-        super().reject()
+        super(BookmarksDialog, self).reject()
     
     def __shutdown(self):
         """
@@ -140,20 +144,20 @@ class BookmarksDialog(QDialog, Ui_BookmarksDialog):
         node = self.__bookmarksModel.node(sourceIndex)
         if idx.isValid() and node.type() != BookmarkNode.Folder:
             menu.addAction(
-                self.trUtf8("&Open"), self.__openBookmarkInCurrentTab)
+                self.tr("&Open"), self.__openBookmarkInCurrentTab)
             menu.addAction(
-                self.trUtf8("Open in New &Tab"), self.__openBookmarkInNewTab)
+                self.tr("Open in New &Tab"), self.__openBookmarkInNewTab)
             menu.addSeparator()
-        act = menu.addAction(self.trUtf8("Edit &Name"), self.__editName)
+        act = menu.addAction(self.tr("Edit &Name"), self.__editName)
         act.setEnabled(idx.flags() & Qt.ItemIsEditable)
         if idx.isValid() and node.type() != BookmarkNode.Folder:
-            menu.addAction(self.trUtf8("Edit &Address"), self.__editAddress)
+            menu.addAction(self.tr("Edit &Address"), self.__editAddress)
         menu.addSeparator()
         act = menu.addAction(
-            self.trUtf8("&Delete"), self.bookmarksTree.removeSelected)
+            self.tr("&Delete"), self.bookmarksTree.removeSelected)
         act.setEnabled(idx.flags() & Qt.ItemIsDragEnabled)
         menu.addSeparator()
-        act = menu.addAction(self.trUtf8("&Properties..."), self.__edit)
+        act = menu.addAction(self.tr("&Properties..."), self.__edit)
         act.setEnabled(idx.flags() & Qt.ItemIsEditable)
         menu.exec_(QCursor.pos())
     
@@ -258,5 +262,5 @@ class BookmarksDialog(QDialog, Ui_BookmarksDialog):
         idx = self.__proxyModel.mapToSource(idx)
         parent = self.__bookmarksModel.node(idx)
         node = BookmarkNode(BookmarkNode.Folder)
-        node.title = self.trUtf8("New Folder")
+        node.title = self.tr("New Folder")
         self.__bookmarksManager.addBookmark(parent, node, row)
