@@ -1,17 +1,20 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the bookmarks manager.
 """
 
+from __future__ import unicode_literals
+
 import os
 
-from PyQt4.QtCore import pyqtSignal, Qt, QT_TRANSLATE_NOOP, QObject, QFile, \
-    QIODevice, QXmlStreamReader, QDate, QDateTime, QFileInfo, QUrl
-from PyQt4.QtGui import QUndoStack, QUndoCommand, QApplication, QDialog
+from PyQt5.QtCore import pyqtSignal, Qt, QT_TRANSLATE_NOOP, QObject, QFile, \
+    QIODevice, QXmlStreamReader, QDate, QDateTime, QFileInfo, QUrl, \
+    QCoreApplication
+from PyQt5.QtWidgets import QUndoStack, QUndoCommand, QDialog
 
 from E5Gui import E5MessageBox, E5FileDialog
 
@@ -54,7 +57,7 @@ class BookmarksManager(QObject):
         
         @param parent reference to the parent object (QObject)
         """
-        super().__init__(parent)
+        super(BookmarksManager, self).__init__(parent)
         
         self.__saveTimer = AutoSaver(self, self.save)
         self.entryAdded.connect(self.__saveTimer.changeOccurred)
@@ -77,7 +80,7 @@ class BookmarksManager(QObject):
     @classmethod
     def getFileName(cls):
         """
-        Public method to get the file name of the bookmark file.
+        Class method to get the file name of the bookmark file.
         
         @return name of the bookmark file (string)
         """
@@ -136,8 +139,8 @@ class BookmarksManager(QObject):
         if reader.error() != QXmlStreamReader.NoError:
             E5MessageBox.warning(
                 None,
-                self.trUtf8("Loading Bookmarks"),
-                self.trUtf8(
+                self.tr("Loading Bookmarks"),
+                self.tr(
                     """Error when loading bookmarks on line {0},"""
                     """ column {1}:\n {2}""")
                 .format(reader.lineNumber(),
@@ -149,16 +152,16 @@ class BookmarksManager(QObject):
                 len(self.__bookmarkRootNode.children()) - 1, -1, -1):
             node = self.__bookmarkRootNode.children()[index]
             if node.type() == BookmarkNode.Folder:
-                if (node.title == self.trUtf8("Toolbar Bookmarks") or
+                if (node.title == self.tr("Toolbar Bookmarks") or
                     node.title == BOOKMARKBAR) and \
                    self.__toolbar is None:
-                    node.title = self.trUtf8(BOOKMARKBAR)
+                    node.title = self.tr(BOOKMARKBAR)
                     self.__toolbar = node
                 
-                if (node.title == self.trUtf8("Menu") or
+                if (node.title == self.tr("Menu") or
                     node.title == BOOKMARKMENU) and \
                    self.__menu is None:
-                    node.title = self.trUtf8(BOOKMARKMENU)
+                    node.title = self.tr(BOOKMARKMENU)
                     self.__menu = node
             else:
                 others.append(node)
@@ -170,14 +173,14 @@ class BookmarksManager(QObject):
         if self.__toolbar is None:
             self.__toolbar = BookmarkNode(BookmarkNode.Folder,
                                           self.__bookmarkRootNode)
-            self.__toolbar.title = self.trUtf8(BOOKMARKBAR)
+            self.__toolbar.title = self.tr(BOOKMARKBAR)
         else:
             self.__bookmarkRootNode.add(self.__toolbar)
         
         if self.__menu is None:
             self.__menu = BookmarkNode(BookmarkNode.Folder,
                                        self.__bookmarkRootNode)
-            self.__menu.title = self.trUtf8(BOOKMARKMENU)
+            self.__menu.title = self.tr(BOOKMARKMENU)
         else:
             self.__bookmarkRootNode.add(self.__menu)
         
@@ -203,13 +206,13 @@ class BookmarksManager(QObject):
         if not writer.write(bookmarkFile, self.__bookmarkRootNode):
             E5MessageBox.warning(
                 None,
-                self.trUtf8("Saving Bookmarks"),
-                self.trUtf8("""Error saving bookmarks to <b>{0}</b>.""")
+                self.tr("Saving Bookmarks"),
+                self.tr("""Error saving bookmarks to <b>{0}</b>.""")
                 .format(bookmarkFile))
         
         # restore localized titles
-        self.__menu.title = self.trUtf8(BOOKMARKMENU)
-        self.__toolbar.title = self.trUtf8(BOOKMARKBAR)
+        self.__menu.title = self.tr(BOOKMARKMENU)
+        self.__toolbar.title = self.tr(BOOKMARKBAR)
         
         self.bookmarksSaved.emit()
     
@@ -224,7 +227,7 @@ class BookmarksManager(QObject):
         if not self.__loaded:
             return
         
-        self.setTimestamp(node,  BookmarkNode.TsAdded,
+        self.setTimestamp(node, BookmarkNode.TsAdded,
                           QDateTime.currentDateTime())
         
         command = InsertBookmarksCommand(self, parent, node, row)
@@ -365,11 +368,11 @@ class BookmarksManager(QObject):
         """
         fileName, selectedFilter = E5FileDialog.getSaveFileNameAndFilter(
             None,
-            self.trUtf8("Export Bookmarks"),
-            "eric5_bookmarks.xbel",
-            self.trUtf8("XBEL bookmarks (*.xbel);;"
-                        "XBEL bookmarks (*.xml);;"
-                        "HTML Bookmarks (*.html)"))
+            self.tr("Export Bookmarks"),
+            "eric6_bookmarks.xbel",
+            self.tr("XBEL bookmarks (*.xbel);;"
+                    "XBEL bookmarks (*.xml);;"
+                    "HTML Bookmarks (*.html)"))
         if not fileName:
             return
         
@@ -389,8 +392,8 @@ class BookmarksManager(QObject):
         if not writer.write(fileName, self.__bookmarkRootNode):
             E5MessageBox.critical(
                 None,
-                self.trUtf8("Exporting Bookmarks"),
-                self.trUtf8("""Error exporting bookmarks to <b>{0}</b>.""")
+                self.tr("Exporting Bookmarks"),
+                self.tr("""Error exporting bookmarks to <b>{0}</b>.""")
                 .format(fileName))
     
     def __convertFromOldBookmarks(self):
@@ -403,7 +406,7 @@ class BookmarksManager(QObject):
         if bmNames is not None and bmFiles is not None:
             if len(bmNames) == len(bmFiles):
                 convertedRootNode = BookmarkNode(BookmarkNode.Folder)
-                convertedRootNode.title = self.trUtf8("Converted {0}")\
+                convertedRootNode.title = self.tr("Converted {0}")\
                     .format(QDate.currentDate().toString(
                         Qt.SystemLocaleShortDate))
                 for i in range(len(bmNames)):
@@ -528,8 +531,8 @@ class RemoveBookmarksCommand(QUndoCommand):
         @param parent reference to the parent node (BookmarkNode)
         @param row row number of bookmark (integer)
         """
-        super().__init__(
-            QApplication.translate("BookmarksManager", "Remove Bookmark"))
+        super(RemoveBookmarksCommand, self).__init__(
+            QCoreApplication.translate("BookmarksManager", "Remove Bookmark"))
         
         self._row = row
         self._bookmarksManager = bookmarksManager
@@ -570,7 +573,7 @@ class InsertBookmarksCommand(RemoveBookmarksCommand):
         @param row row number of bookmark (integer)
         """
         RemoveBookmarksCommand.__init__(self, bookmarksManager, parent, row)
-        self.setText(QApplication.translate(
+        self.setText(QCoreApplication.translate(
             "BookmarksManager", "Insert Bookmark"))
         self._node = node
     
@@ -602,7 +605,7 @@ class ChangeBookmarkCommand(QUndoCommand):
         @param title flag indicating a change of the title (True) or
             the URL (False) (boolean)
         """
-        super().__init__()
+        super(ChangeBookmarkCommand, self).__init__()
         
         self._bookmarksManager = bookmarksManager
         self._title = title
@@ -611,11 +614,11 @@ class ChangeBookmarkCommand(QUndoCommand):
         
         if self._title:
             self._oldValue = self._node.title
-            self.setText(QApplication.translate(
+            self.setText(QCoreApplication.translate(
                 "BookmarksManager", "Name Change"))
         else:
             self._oldValue = self._node.url
-            self.setText(QApplication.translate(
+            self.setText(QCoreApplication.translate(
                 "BookmarksManager", "Address Change"))
     
     def undo(self):
