@@ -1,14 +1,17 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the bookmarks menu.
 """
 
-from PyQt4.QtCore import pyqtSignal, Qt, QUrl
-from PyQt4.QtGui import QMenu, QCursor
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSignal, Qt, QUrl
+from PyQt5.QtGui import QCursor
+from PyQt5.QtWidgets import QMenu
 
 from E5Gui.E5ModelMenu import E5ModelMenu
 
@@ -92,8 +95,8 @@ class BookmarksMenu(E5ModelMenu):
             return
         
         self.addSeparator()
-        act = self.addAction(self.trUtf8("Open all in Tabs"))
-        act.triggered[()].connect(self.openAll)
+        act = self.addAction(self.tr("Open all in Tabs"))
+        act.triggered.connect(self.openAll)
     
     def openAll(self):
         """
@@ -137,21 +140,21 @@ class BookmarksMenu(E5ModelMenu):
             v = act.data()
             
             menuAction = menu.addAction(
-                self.trUtf8("&Open"), self.__openBookmark)
+                self.tr("&Open"), self.__openBookmark)
             menuAction.setData(v)
             menuAction = menu.addAction(
-                self.trUtf8("Open in New &Tab\tCtrl+LMB"),
+                self.tr("Open in New &Tab\tCtrl+LMB"),
                 self.__openBookmarkInNewTab)
             menuAction.setData(v)
             menu.addSeparator()
             
             menuAction = menu.addAction(
-                self.trUtf8("&Remove"), self.__removeBookmark)
+                self.tr("&Remove"), self.__removeBookmark)
             menuAction.setData(v)
             menu.addSeparator()
             
             menuAction = menu.addAction(
-                self.trUtf8("&Properties..."), self.__edit)
+                self.tr("&Properties..."), self.__edit)
             menuAction.setData(v)
             
             execAct = menu.exec_(QCursor.pos())
@@ -274,15 +277,15 @@ class BookmarksMenuBarMenu(BookmarksMenu):
             return
         
         self.addSeparator()
-        act = self.addAction(self.trUtf8("Default Home Page"))
+        act = self.addAction(self.tr("Default Home Page"))
         act.setData("eric:home")
-        act.triggered[()].connect(self.__defaultBookmarkTriggered)
-        act = self.addAction(self.trUtf8("Speed Dial"))
+        act.triggered.connect(self.__defaultBookmarkTriggered)
+        act = self.addAction(self.tr("Speed Dial"))
         act.setData("eric:speeddial")
-        act.triggered[()].connect(self.__defaultBookmarkTriggered)
+        act.triggered.connect(self.__defaultBookmarkTriggered)
         self.addSeparator()
-        act = self.addAction(self.trUtf8("Open all in Tabs"))
-        act.triggered[()].connect(self.openAll)
+        act = self.addAction(self.tr("Open all in Tabs"))
+        act.triggered.connect(self.openAll)
     
     def setInitialActions(self, actions):
         """
