@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the bookmark model class.
 """
 
-from PyQt4.QtCore import Qt, QAbstractItemModel, QModelIndex, QUrl, \
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import Qt, QAbstractItemModel, QModelIndex, QUrl, \
     QByteArray, QDataStream, QIODevice, QBuffer, QMimeData
 
 import UI.PixmapCache
@@ -32,7 +34,7 @@ class BookmarksModel(QAbstractItemModel):
             (BookmarksManager)
         @param parent reference to the parent object (QObject)
         """
-        super().__init__(parent)
+        super(BookmarksModel, self).__init__(parent)
         
         self.__endMacro = False
         self.__bookmarksManager = manager
@@ -42,8 +44,8 @@ class BookmarksModel(QAbstractItemModel):
         manager.entryChanged.connect(self.entryChanged)
         
         self.__headers = [
-            self.trUtf8("Title"),
-            self.trUtf8("Address"),
+            self.tr("Title"),
+            self.tr("Address"),
         ]
     
     def bookmarksManager(self):
