@@ -1,15 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a tool bar showing bookmarks.
 """
 
-from PyQt4.QtCore import pyqtSignal, Qt, QUrl
-from PyQt4.QtGui import QMenu, QApplication, QCursor
-from PyQt4.QtWebKit import QWebPage
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSignal, Qt, QUrl, QCoreApplication
+from PyQt5.QtGui import QCursor
+from PyQt5.QtWidgets import QMenu
+from PyQt5.QtWebKitWidgets import QWebPage
 
 from E5Gui.E5ModelToolBar import E5ModelToolBar
 
@@ -37,7 +40,7 @@ class BookmarksToolBar(E5ModelToolBar):
         @param parent reference to the parent widget (QWidget)
         """
         E5ModelToolBar.__init__(
-            self, QApplication.translate("BookmarksToolBar", "Bookmarks"),
+            self, QCoreApplication.translate("BookmarksToolBar", "Bookmarks"),
             parent)
         
         self.__mw = mainWindow
@@ -85,26 +88,26 @@ class BookmarksToolBar(E5ModelToolBar):
             
             if act.menu() is None:
                 menuAction = menu.addAction(
-                    self.trUtf8("&Open"), self.__openBookmark)
+                    self.tr("&Open"), self.__openBookmark)
                 menuAction.setData(v)
                 menuAction = menu.addAction(
-                    self.trUtf8("Open in New &Tab\tCtrl+LMB"),
+                    self.tr("Open in New &Tab\tCtrl+LMB"),
                     self.__openBookmarkInNewTab)
                 menuAction.setData(v)
                 menu.addSeparator()
             
             menuAction = menu.addAction(
-                self.trUtf8("&Remove"), self.__removeBookmark)
+                self.tr("&Remove"), self.__removeBookmark)
             menuAction.setData(v)
             menu.addSeparator()
             
             menuAction = menu.addAction(
-                self.trUtf8("&Properties..."), self.__edit)
+                self.tr("&Properties..."), self.__edit)
             menuAction.setData(v)
             menu.addSeparator()
         
-        menu.addAction(self.trUtf8("Add &Bookmark..."), self.__newBookmark)
-        menu.addAction(self.trUtf8("Add &Folder..."), self.__newFolder)
+        menu.addAction(self.tr("Add &Bookmark..."), self.__newBookmark)
+        menu.addAction(self.tr("Add &Folder..."), self.__newFolder)
         
         menu.exec_(QCursor.pos())
     
