@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a class to read XBEL bookmark files.
 """
 
-from PyQt4.QtCore import QXmlStreamReader, QXmlStreamEntityResolver, \
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import QXmlStreamReader, QXmlStreamEntityResolver, \
     QIODevice, QFile, QCoreApplication, QXmlStreamNamespaceDeclaration, \
     QDateTime, Qt
 
@@ -38,7 +40,7 @@ class XbelReader(QXmlStreamReader):
         """
         Constructor
         """
-        super().__init__()
+        super(XbelReader, self).__init__()
         
         self.__resolver = XmlEntityResolver()
         self.setEntityResolver(self.__resolver)
