@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a class to write XBEL bookmark files.
 """
 
-from PyQt4.QtCore import QXmlStreamWriter, QIODevice, QFile, Qt
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import QXmlStreamWriter, QIODevice, QFile, Qt
 
 from .BookmarkNode import BookmarkNode
 
@@ -20,7 +22,7 @@ class XbelWriter(QXmlStreamWriter):
         """
         Constructor
         """
-        super().__init__()
+        super(XbelWriter, self).__init__()
         
         self.setAutoFormatting(True)
     
