@@ -1,18 +1,20 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a QNetworkCookieJar subclass with various accept policies.
 """
 
+from __future__ import unicode_literals
+
 import os
 
-from PyQt4.QtCore import pyqtSignal, QByteArray, QDataStream, QIODevice, \
+from PyQt5.QtCore import pyqtSignal, QByteArray, QDataStream, QIODevice, \
     QSettings, QDateTime
-from PyQt4.QtNetwork import QNetworkCookieJar, QNetworkCookie
-from PyQt4.QtWebKit import QWebSettings
+from PyQt5.QtNetwork import QNetworkCookieJar, QNetworkCookie
+from PyQt5.QtWebKit import QWebSettings
 
 from Utilities.AutoSaver import AutoSaver
 import Utilities
@@ -48,7 +50,7 @@ class CookieJar(QNetworkCookieJar):
         
         @param parent reference to the parent object (QObject)
         """
-        super().__init__(parent)
+        super(CookieJar, self).__init__(parent)
         
         self.__loaded = False
         self.__acceptCookies = self.AcceptOnlyFromSitesNavigatedTo
@@ -259,7 +261,7 @@ class CookieJar(QNetworkCookieJar):
             for cookie in cookieList:
                 lst = []
                 if not (self.__filterTrackingCookies and
-                        cookie.name().startsWith("__utm")):
+                        cookie.name().startsWith(b"__utm")):
                     if eAllowSession:
                         cookie.setExpirationDate(QDateTime())
                     if self.__keepCookies == self.KeepUntilTimeLimit and \
@@ -317,7 +319,7 @@ class CookieJar(QNetworkCookieJar):
     
     def keepPolicy(self):
         """
-        Private method to get the keep policy.
+        Public method to get the keep policy.
         
         @return keep policy
         """
