@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the cookie model.
 """
 
-from PyQt4.QtCore import Qt, QAbstractTableModel, QSize, QModelIndex
-from PyQt4.QtGui import QFont, QFontMetrics
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import Qt, QAbstractTableModel, QSize, QModelIndex
+from PyQt5.QtGui import QFont, QFontMetrics
 
 
 class CookieModel(QAbstractTableModel):
@@ -22,15 +24,15 @@ class CookieModel(QAbstractTableModel):
         @param cookieJar reference to the cookie jar (CookieJar)
         @param parent reference to the parent object (QObject)
         """
-        super().__init__(parent)
+        super(CookieModel, self).__init__(parent)
         
         self.__headers = [
-            self.trUtf8("Website"),
-            self.trUtf8("Name"),
-            self.trUtf8("Path"),
-            self.trUtf8("Secure"),
-            self.trUtf8("Expires"),
-            self.trUtf8("Contents"),
+            self.tr("Website"),
+            self.tr("Name"),
+            self.tr("Path"),
+            self.tr("Secure"),
+            self.tr("Expires"),
+            self.tr("Contents"),
         ]
         self.__cookieJar = cookieJar
         self.__cookieJar.cookiesChanged.connect(self.__cookiesChanged)
@@ -146,4 +148,5 @@ class CookieModel(QAbstractTableModel):
         """
         Private slot handling changes of the cookies list in the cookie jar.
         """
-        self.reset()
+        self.beginResetModel()
+        self.endResetModel()
