@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the cookies configuration dialog.
 """
 
-from PyQt4.QtCore import pyqtSlot
-from PyQt4.QtGui import QDialog
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSlot
+from PyQt5.QtWidgets import QDialog
 
 from .CookieJar import CookieJar
 
@@ -25,7 +27,7 @@ class CookiesConfigurationDialog(QDialog, Ui_CookiesConfigurationDialog):
         
         @param parent reference to the parent object (QWidget)
         """
-        super().__init__(parent)
+        super(CookiesConfigurationDialog, self).__init__(parent)
         self.setupUi(self)
         
         self.__mw = parent
@@ -49,6 +51,9 @@ class CookiesConfigurationDialog(QDialog, Ui_CookiesConfigurationDialog):
         
         self.filterTrackingCookiesCheckbox.setChecked(
             jar.filterTrackingCookies())
+        
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
     
     def accept(self):
         """
@@ -76,7 +81,7 @@ class CookiesConfigurationDialog(QDialog, Ui_CookiesConfigurationDialog):
         jar.setFilterTrackingCookies(
             self.filterTrackingCookiesCheckbox.isChecked())
         
-        super().accept()
+        super(CookiesConfigurationDialog, self).accept()
     
     @pyqtSlot()
     def on_exceptionsButton_clicked(self):
