@@ -1,15 +1,17 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog for the configuration of cookie exceptions.
 """
 
-from PyQt4.QtCore import pyqtSlot
-from PyQt4.QtGui import QDialog, QSortFilterProxyModel, QCompleter, QFont, \
-    QFontMetrics
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSlot, QSortFilterProxyModel
+from PyQt5.QtGui import QFont, QFontMetrics
+from PyQt5.QtWidgets import QDialog, QCompleter
 
 from .CookieExceptionsModel import CookieExceptionsModel
 from .CookieModel import CookieModel
@@ -28,14 +30,14 @@ class CookiesExceptionsDialog(QDialog, Ui_CookiesExceptionsDialog):
         @param cookieJar reference to the cookie jar (CookieJar)
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(CookiesExceptionsDialog, self).__init__(parent)
         self.setupUi(self)
         
         self.__cookieJar = cookieJar
         
-        self.removeButton.clicked[()].connect(
+        self.removeButton.clicked.connect(
             self.exceptionsTable.removeSelected)
-        self.removeAllButton.clicked[()].connect(
+        self.removeAllButton.clicked.connect(
             self.exceptionsTable.removeAll)
         
         self.exceptionsTable.verticalHeader().hide()
@@ -61,7 +63,7 @@ class CookiesExceptionsDialog(QDialog, Ui_CookiesExceptionsDialog):
             if section == 0:
                 header = fm.width("averagebiglonghost.averagedomain.info")
             elif section == 1:
-                header = fm.width(self.trUtf8("Allow For Session"))
+                header = fm.width(self.tr("Allow For Session"))
             buffer = fm.width("mm")
             header += buffer
             self.exceptionsTable.horizontalHeader()\
