@@ -1,16 +1,23 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a widget controlling a download.
 """
 
-from PyQt4.QtCore import pyqtSlot, pyqtSignal, Qt, QTime, QFile, QFileInfo, \
-    QUrl, QIODevice, QCryptographicHash
-from PyQt4.QtGui import QWidget, QPalette, QStyle, QDesktopServices, QDialog
-from PyQt4.QtNetwork import QNetworkRequest, QNetworkReply
+from __future__ import unicode_literals
+try:
+    str = unicode
+except NameError:
+    pass
+
+from PyQt5.QtCore import pyqtSlot, pyqtSignal, Qt, QTime, QFile, QFileInfo, \
+    QUrl, QIODevice, QCryptographicHash, PYQT_VERSION_STR
+from PyQt5.QtGui import QPalette, QDesktopServices
+from PyQt5.QtWidgets import QWidget, QStyle, QDialog
+from PyQt5.QtNetwork import QNetworkRequest, QNetworkReply
 
 from E5Gui import E5FileDialog
 
@@ -52,7 +59,7 @@ class DownloadItem(QWidget, Ui_DownloadItem):
         @keyparam parent reference to the parent widget (QWidget)
         @keyparam mainWindow reference to the main window (HelpWindow)
         """
-        super().__init__(parent)
+        super(DownloadItem, self).__init__(parent)
         self.setupUi(self)
         
         p = self.infoLabel.palette()
@@ -134,11 +141,11 @@ class DownloadItem(QWidget, Ui_DownloadItem):
         self.__url = self.__reply.url()
         self.__reply.setParent(self)
         self.__reply.setReadBufferSize(16 * 1024 * 1024)
-        self.__reply.readyRead[()].connect(self.__readyRead)
+        self.__reply.readyRead.connect(self.__readyRead)
         self.__reply.error.connect(self.__networkError)
         self.__reply.downloadProgress.connect(self.__downloadProgress)
         self.__reply.metaDataChanged.connect(self.__metaDataChanged)
-        self.__reply.finished[()].connect(self.__finished)
+        self.__reply.finished.connect(self.__finished)
         
         # reset info
         self.infoLabel.clear()
@@ -185,33 +192,40 @@ class DownloadItem(QWidget, Ui_DownloadItem):
                 self.__reply.close()
                 self.on_stopButton_clicked()
                 self.filenameLabel.setText(
-                    self.trUtf8("Download canceled: {0}").format(
-                        QFileInfo(defaultFileName).fileName()))
-                self.__canceledFileSelect = True
-                return
-            
-            if dlg.getAction() == "scan":
-                self.__mainWindow.requestVirusTotalScan(url)
-                
-                self.progressBar.setVisible(False)
-                self.__reply.close()
-                self.on_stopButton_clicked()
-                self.filenameLabel.setText(
-                    self.trUtf8("VirusTotal scan scheduled: {0}").format(
+                    self.tr("Download canceled: {0}").format(
                         QFileInfo(defaultFileName).fileName()))
                 self.__canceledFileSelect = True
                 return
             
+##            if dlg.getAction() == "scan":
+##                self.__mainWindow.requestVirusTotalScan(url)
+##                
+##                self.progressBar.setVisible(False)
+##                self.__reply.close()
+##                self.on_stopButton_clicked()
+##                self.filenameLabel.setText(
+##                    self.tr("VirusTotal scan scheduled: {0}").format(
+##                        QFileInfo(defaultFileName).fileName()))
+##                self.__canceledFileSelect = True
+##                return
+##            
             self.__autoOpen = dlg.getAction() == "open"
-            fileName = QDesktopServices.storageLocation(
-                QDesktopServices.TempLocation) + \
-                '/' + QFileInfo(fileName).completeBaseName()
+            if PYQT_VERSION_STR >= "5.0.0":
+                from PyQt5.QtCore import QStandardPaths
+                tempLocation = QStandardPaths.storageLocation(
+                    QStandardPaths.TempLocation)
+            else:
+                from PyQt5.QtGui import QDesktopServices
+                tempLocation = QDesktopServices.storageLocation(
+                    QDesktopServices.TempLocation)
+            fileName = tempLocation + '/' + \
+                QFileInfo(fileName).completeBaseName()
         
         if ask and not self.__autoOpen and self.__requestFilename:
             self.__gettingFileName = True
             fileName = E5FileDialog.getSaveFileName(
                 None,
-                self.trUtf8("Save File"),
+                self.tr("Save File"),
                 defaultFileName,
                 "")
             self.__gettingFileName = False
@@ -220,7 +234,7 @@ class DownloadItem(QWidget, Ui_DownloadItem):
                 self.__reply.close()
                 self.on_stopButton_clicked()
                 self.filenameLabel.setText(
-                    self.trUtf8("Download canceled: {0}")
+                    self.tr("Download canceled: {0}")
                         .format(QFileInfo(defaultFileName).fileName()))
                 self.__canceledFileSelect = True
                 return
@@ -239,7 +253,7 @@ class DownloadItem(QWidget, Ui_DownloadItem):
             if not saveDirPath.mkpath(saveDirPath.absolutePath()):
                 self.progressBar.setVisible(False)
                 self.on_stopButton_clicked()
-                self.infoLabel.setText(self.trUtf8(
+                self.infoLabel.setText(self.tr(
                     "Download directory ({0}) couldn't be created.")
                     .format(saveDirPath.absolutePath()))
                 return
@@ -348,10 +362,10 @@ class DownloadItem(QWidget, Ui_DownloadItem):
         @param checked flag indicating the state of the button (boolean)
         """
         if checked:
-            self.__reply.readyRead[()].disconnect(self.__readyRead)
+            self.__reply.readyRead.disconnect(self.__readyRead)
             self.__reply.setReadBufferSize(16 * 1024)
         else:
-            self.__reply.readyRead[()].connect(self.__readyRead)
+            self.__reply.readyRead.connect(self.__readyRead)
             self.__reply.setReadBufferSize(16 * 1024 * 1024)
             self.__readyRead()
     
@@ -417,7 +431,7 @@ class DownloadItem(QWidget, Ui_DownloadItem):
                 self.__getFileName()
             if not self.__output.open(QIODevice.WriteOnly):
                 self.infoLabel.setText(
-                    self.trUtf8("Error opening save file: {0}")
+                    self.tr("Error opening save file: {0}")
                     .format(self.__output.errorString()))
                 self.on_stopButton_clicked()
                 self.statusChanged.emit()
@@ -429,8 +443,9 @@ class DownloadItem(QWidget, Ui_DownloadItem):
         self.__md5Hash.addData(buffer)
         bytesWritten = self.__output.write(buffer)
         if bytesWritten == -1:
-            self.infoLabel.setText(self.trUtf8("Error saving: {0}")
-                .format(self.__output.errorString()))
+            self.infoLabel.setText(
+                self.tr("Error saving: {0}")
+                    .format(self.__output.errorString()))
             self.on_stopButton_clicked()
         else:
             self.__startedSaving = True
@@ -441,8 +456,9 @@ class DownloadItem(QWidget, Ui_DownloadItem):
         """
         Private slot to handle a network error.
         """
-        self.infoLabel.setText(self.trUtf8("Network Error: {0}")
-            .format(self.__reply.errorString()))
+        self.infoLabel.setText(
+            self.tr("Network Error: {0}")
+                .format(self.__reply.errorString()))
         self.tryAgainButton.setEnabled(True)
         self.tryAgainButton.setVisible(True)
         self.downloadFinished.emit()
@@ -552,16 +568,16 @@ class DownloadItem(QWidget, Ui_DownloadItem):
             if bytesTotal > 0:
                 remaining = timeString(timeRemaining)
             
-            info = self.trUtf8("{0} of {1} ({2}/sec)\n{3}")\
+            info = self.tr("{0} of {1} ({2}/sec)\n{3}")\
                 .format(
                     dataString(self.__bytesReceived),
-                    bytesTotal == -1 and self.trUtf8("?")
+                    bytesTotal == -1 and self.tr("?")
                     or dataString(bytesTotal),
                     dataString(int(speed)),
                     remaining)
         else:
             if self.__bytesReceived == bytesTotal or bytesTotal == -1:
-                info = self.trUtf8("{0} downloaded\nSHA1: {1}\nMD5: {2}")\
+                info = self.tr("{0} downloaded\nSHA1: {1}\nMD5: {2}")\
                     .format(dataString(self.__output.size()),
                             str(self.__sha1Hash.result().toHex(),
                                 encoding="ascii"),
@@ -569,7 +585,7 @@ class DownloadItem(QWidget, Ui_DownloadItem):
                                 encoding="ascii")
                             )
             else:
-                info = self.trUtf8("{0} of {1} - Stopped")\
+                info = self.tr("{0} of {1} - Stopped")\
                     .format(dataString(self.__bytesReceived),
                             dataString(bytesTotal))
         self.infoLabel.setText(info)
