@@ -1,14 +1,17 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a window for showing the QtHelp index.
 """
 
-from PyQt4.QtCore import pyqtSignal, Qt, QUrl, QEvent
-from PyQt4.QtGui import QWidget, QVBoxLayout, QLabel, QLineEdit, QMenu, QDialog
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSignal, Qt, QUrl, QEvent
+from PyQt5.QtWidgets import QWidget, QVBoxLayout, QLabel, QLineEdit, QMenu, \
+    QDialog
 
 
 class HelpIndexWidget(QWidget):
@@ -32,7 +35,7 @@ class HelpIndexWidget(QWidget):
         @param mainWindow reference to the main window object (QMainWindow)
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(HelpIndexWidget, self).__init__(parent)
         
         self.__engine = engine
         self.__mw = mainWindow
@@ -41,7 +44,7 @@ class HelpIndexWidget(QWidget):
         self.__index = None
         
         self.__layout = QVBoxLayout(self)
-        label = QLabel(self.trUtf8("&Look for:"))
+        label = QLabel(self.tr("&Look for:"))
         self.__layout.addWidget(label)
         
         self.__searchEdit = QLineEdit()
@@ -140,8 +143,8 @@ class HelpIndexWidget(QWidget):
             idx = self.__index.indexAt(event.pos())
             if idx.isValid():
                 menu = QMenu()
-                curTab = menu.addAction(self.trUtf8("Open Link"))
-                newTab = menu.addAction(self.trUtf8("Open Link in New Tab"))
+                curTab = menu.addAction(self.tr("Open Link"))
+                newTab = menu.addAction(self.tr("Open Link in New Tab"))
                 menu.move(self.__index.mapToGlobal(event.pos()))
                 
                 act = menu.exec_()
