@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to configure the preferred languages.
 """
 
-from PyQt4.QtCore import pyqtSlot, QByteArray, QLocale
-from PyQt4.QtGui import QDialog, QStringListModel
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSlot, QByteArray, QLocale, QStringListModel
+from PyQt5.QtWidgets import QDialog
 
 from .Ui_HelpLanguagesDialog import Ui_HelpLanguagesDialog
 
@@ -25,7 +27,7 @@ class HelpLanguagesDialog(QDialog, Ui_HelpLanguagesDialog):
         
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(HelpLanguagesDialog, self).__init__(parent)
         self.setupUi(self)
         
         self.__model = QStringListModel()
@@ -114,13 +116,13 @@ class HelpLanguagesDialog(QDialog, Ui_HelpLanguagesDialog):
             Preferences.Prefs.settings.remove("Help/AcceptLanguages")
         else:
             Preferences.Prefs.settings.setValue("Help/AcceptLanguages", result)
-        super().accept()
+        super(HelpLanguagesDialog, self).accept()
     
     @classmethod
     def httpString(cls, languages):
         """
-        Class method to convert a list of acceptable languages into a byte
-        array.
+        Class method to convert a list of acceptable languages into a
+        byte array.
        
         The byte array can be sent along with the Accept-Language http header
         (see RFC 2616).
@@ -141,7 +143,7 @@ class HelpLanguagesDialog(QDialog, Ui_HelpLanguagesDialog):
             if qvalue > 0.1:
                 qvalue -= 0.1
         
-        return QByteArray(", ".join(processed))
+        return QByteArray(", ".join(processed).encode("utf-8"))
     
     @classmethod
     def defaultAcceptLanguages(cls):
@@ -159,13 +161,15 @@ class HelpLanguagesDialog(QDialog, Ui_HelpLanguagesDialog):
     @classmethod
     def expand(cls, language):
         """
-        Class method to expand a language enum to a readable languages list.
+        Class method to expand a language enum to a readable languages
+        list.
         
         @param language language number (QLocale.Language)
         @return list of expanded language names (list of strings)
         """
         allLanguages = []
-        countries = QLocale.countriesForLanguage(language)
+        countries = [l.country() for l in QLocale.matchingLocales(
+            language, QLocale.AnyScript, QLocale.AnyCountry)]
         languageString = "{0} [{1}]"\
             .format(QLocale.languageToString(language),
                     QLocale(language).name().split('_')[0])
