@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a window for showing the QtHelp TOC.
 """
 
-from PyQt4.QtCore import pyqtSignal, Qt, QEvent, QUrl
-from PyQt4.QtGui import QWidget, QVBoxLayout, QMenu
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSignal, Qt, QEvent, QUrl
+from PyQt5.QtWidgets import QWidget, QVBoxLayout, QMenu
 
 
 class HelpTocWidget(QWidget):
@@ -29,7 +31,7 @@ class HelpTocWidget(QWidget):
         @param mainWindow reference to the main window object (QMainWindow)
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(HelpTocWidget, self).__init__(parent)
         
         self.__engine = engine
         self.__mw = mainWindow
@@ -145,8 +147,8 @@ class HelpTocWidget(QWidget):
             return
         
         menu = QMenu()
-        curTab = menu.addAction(self.trUtf8("Open Link"))
-        newTab = menu.addAction(self.trUtf8("Open Link in New Tab"))
+        curTab = menu.addAction(self.tr("Open Link"))
+        newTab = menu.addAction(self.tr("Open Link in New Tab"))
         menu.move(self.__tocWidget.mapToGlobal(pos))
         
         model = self.__tocWidget.model()
