@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to select a help topic to display.
 """
 
-from PyQt4.QtGui import QDialog
-from PyQt4.QtCore import QUrl
+from __future__ import unicode_literals
+
+from PyQt5.QtWidgets import QDialog
+from PyQt5.QtCore import QUrl
 
 from .Ui_HelpTopicDialog import Ui_HelpTopicDialog
 
@@ -26,11 +28,11 @@ class HelpTopicDialog(QDialog, Ui_HelpTopicDialog):
         @param links dictionary with help topic as key (string) and
             URL as value (QUrl)
         """
-        super().__init__(parent)
+        super(HelpTopicDialog, self).__init__(parent)
         self.setupUi(self)
         
-        self.label.setText(self.trUtf8("Choose a &topic for <b>{0}</b>:")
-            .format(keyword))
+        self.label.setText(self.tr("Choose a &topic for <b>{0}</b>:")
+                           .format(keyword))
         
         self.__links = links
         for topic in sorted(self.__links):
