@@ -1,14 +1,17 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to manage history.
 """
 
-from PyQt4.QtCore import pyqtSignal, Qt, QUrl
-from PyQt4.QtGui import QDialog, QFontMetrics, QMenu, QCursor, QApplication
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSignal, Qt, QUrl
+from PyQt5.QtGui import QFontMetrics, QCursor
+from PyQt5.QtWidgets import QDialog, QMenu, QApplication
 
 from E5Gui.E5TreeSortFilterProxyModel import E5TreeSortFilterProxyModel
 
@@ -34,8 +37,9 @@ class HistoryDialog(QDialog, Ui_HistoryDialog):
         @param parent reference to the parent widget (QWidget
         @param manager reference to the history manager object (HistoryManager)
         """
-        super().__init__(parent)
+        super(HistoryDialog, self).__init__(parent)
         self.setupUi(self)
+        self.setWindowFlags(Qt.Window)
         
         self.__historyManager = manager
         if self.__historyManager is None:
@@ -62,8 +66,8 @@ class HistoryDialog(QDialog, Ui_HistoryDialog):
         
         self.searchEdit.textChanged.connect(
             self.__proxyModel.setFilterFixedString)
-        self.removeButton.clicked[()].connect(self.historyTree.removeSelected)
-        self.removeAllButton.clicked[()].connect(self.__historyManager.clear)
+        self.removeButton.clicked.connect(self.historyTree.removeSelected)
+        self.removeAllButton.clicked.connect(self.__historyManager.clear)
         
         self.__proxyModel.modelReset.connect(self.__modelReset)
     
@@ -84,12 +88,12 @@ class HistoryDialog(QDialog, Ui_HistoryDialog):
         idx = idx.sibling(idx.row(), 0)
         if idx.isValid() and not self.historyTree.model().hasChildren(idx):
             menu.addAction(
-                self.trUtf8("&Open"), self.__openHistoryInCurrentTab)
+                self.tr("&Open"), self.__openHistoryInCurrentTab)
             menu.addAction(
-                self.trUtf8("Open in New &Tab"), self.__openHistoryInNewTab)
+                self.tr("Open in New &Tab"), self.__openHistoryInNewTab)
             menu.addSeparator()
-            menu.addAction(self.trUtf8("&Copy"), self.__copyHistory)
-        menu.addAction(self.trUtf8("&Remove"), self.historyTree.removeSelected)
+            menu.addAction(self.tr("&Copy"), self.__copyHistory)
+        menu.addAction(self.tr("&Remove"), self.historyTree.removeSelected)
         menu.exec_(QCursor.pos())
     
     def __activated(self, idx):
