@@ -1,14 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the history filter model.
 """
 
-from PyQt4.QtCore import Qt, QDateTime, QModelIndex
-from PyQt4.QtGui import QAbstractProxyModel
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import Qt, QDateTime, QModelIndex, QAbstractProxyModel
 
 from .HistoryModel import HistoryModel
 
@@ -66,7 +67,7 @@ class HistoryFilterModel(QAbstractProxyModel):
         @param sourceModel reference to the source model (QAbstractItemModel)
         @param parent reference to the parent object (QObject)
         """
-        super().__init__(parent)
+        super(HistoryFilterModel, self).__init__(parent)
         
         self.__loaded = False
         self.__filteredRows = []
@@ -124,7 +125,7 @@ class HistoryFilterModel(QAbstractProxyModel):
                 self.__sourceRowsInserted)
             self.sourceModel().rowsRemoved.disconnect(self.__sourceRowsRemoved)
         
-        super().setSourceModel(sourceModel)
+        super(HistoryFilterModel, self).setSourceModel(sourceModel)
         
         if self.sourceModel() is not None:
             self.__loaded = False
@@ -164,8 +165,9 @@ class HistoryFilterModel(QAbstractProxyModel):
         """
         Private slot to handle a reset of the source model.
         """
+        self.beginResetModel()
         self.__loaded = False
-        self.reset()
+        self.endResetModel()
     
     def rowCount(self, parent=QModelIndex()):
         """
@@ -344,7 +346,8 @@ class HistoryFilterModel(QAbstractProxyModel):
         self.sourceModel().rowsRemoved.connect(self.__sourceRowsRemoved)
         self.__loaded = False
         if oldCount - count != self.rowCount():
-            self.reset()
+            self.beginResetModel()
+            self.endResetModel()
         return True
     
     def __frequencyScore(self, sourceIndex):
