@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the history model.
 """
 
-from PyQt4.QtCore import Qt, QAbstractTableModel, QModelIndex, QUrl
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import Qt, QAbstractTableModel, QModelIndex, QUrl
 
 import Helpviewer.HelpWindow
 
@@ -31,13 +33,13 @@ class HistoryModel(QAbstractTableModel):
             (HistoryManager)
         @param parent reference to the parent object (QObject)
         """
-        super().__init__(parent)
+        super(HistoryModel, self).__init__(parent)
         
         self.__historyManager = historyManager
         
         self.__headers = [
-            self.trUtf8("Title"),
-            self.trUtf8("Address"),
+            self.tr("Title"),
+            self.tr("Address"),
         ]
         
         self.__historyManager.historyReset.connect(self.historyReset)
@@ -49,7 +51,8 @@ class HistoryModel(QAbstractTableModel):
         """
         Public slot to reset the model.
         """
-        self.reset()
+        self.beginResetModel()
+        self.endResetModel()
     
     def entryAdded(self):
         """
