@@ -1,12 +1,14 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a scheme access handler for about schemes.
 """
 
+from __future__ import unicode_literals
+
 from .SchemeAccessHandler import SchemeAccessHandler
 
 
@@ -16,7 +18,7 @@ class AboutAccessHandler(SchemeAccessHandler):
     """
     def createRequest(self, op, request, outgoingData=None):
         """
-        Protected method to create a request.
+        Public method to create a request.
         
         @param op the operation to be performed
             (QNetworkAccessManager.Operation)
