@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,8 +8,10 @@ Module implementing a network reply class for an empty reply
 (i.e. request was handle other way).
 """
 
-from PyQt4.QtCore import QTimer
-from PyQt4.QtNetwork import QNetworkReply, QNetworkAccessManager
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import QTimer
+from PyQt5.QtNetwork import QNetworkReply, QNetworkAccessManager
 
 
 class EmptyNetworkReply(QNetworkReply):
@@ -22,10 +24,10 @@ class EmptyNetworkReply(QNetworkReply):
         
         @param parent reference to the parent object (QObject)
         """
-        super().__init__(parent)
+        super(EmptyNetworkReply, self).__init__(parent)
         
         self.setOperation(QNetworkAccessManager.GetOperation)
-        self.setError(QNetworkReply.OperationCanceledError, "eric5:No Error")
+        self.setError(QNetworkReply.OperationCanceledError, "eric6:No Error")
         
         QTimer.singleShot(0, lambda: self.finished.emit())
     
@@ -38,7 +40,7 @@ class EmptyNetworkReply(QNetworkReply):
     
     def readData(self, maxlen):
         """
-        Protected method to retrieve data from the reply object.
+        Public method to retrieve data from the reply object.
         
         @param maxlen maximum number of bytes to read (integer)
         @return string containing the data (bytes)
