@@ -1,15 +1,17 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a network access manager proxy for web pages.
 """
 
-from PyQt4.QtNetwork import QNetworkAccessManager, QNetworkRequest
+from __future__ import unicode_literals
+
+from PyQt5.QtNetwork import QNetworkAccessManager, QNetworkRequest
 try:
-    from PyQt4.QtNetwork import QSslError   # __IGNORE_EXCEPTION__ __IGNORE_WARNING__
+    from PyQt5.QtNetwork import QSslError   # __IGNORE_EXCEPTION__ __IGNORE_WARNING__
     SSL_AVAILABLE = True
 except ImportError:
     SSL_AVAILABLE = False
@@ -27,7 +29,7 @@ class NetworkAccessManagerProxy(QNetworkAccessManager):
         
         @param parent reference to the parent object (QObject)
         """
-        super().__init__(parent)
+        super(NetworkAccessManagerProxy, self).__init__(parent)
         self.__webPage = None
     
     def setWebPage(self, page):
@@ -63,7 +65,7 @@ class NetworkAccessManagerProxy(QNetworkAccessManager):
     
     def createRequest(self, op, request, outgoingData=None):
         """
-        Protected method to create a request.
+        Public method to create a request.
         
         @param op the operation to be performed
             (QNetworkAccessManager.Operation)
