@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a network reply object for special data.
 """
 
-from PyQt4.QtCore import QTimer, QIODevice, QByteArray
-from PyQt4.QtNetwork import QNetworkReply, QNetworkRequest
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import QTimer, QIODevice, QByteArray
+from PyQt5.QtNetwork import QNetworkReply, QNetworkRequest
 
 
 class NetworkReply(QNetworkReply):
@@ -24,7 +26,7 @@ class NetworkReply(QNetworkReply):
         @param mimeType for the reply (string)
         @param parent reference to the parent object (QObject)
         """
-        super().__init__(parent)
+        super(NetworkReply, self).__init__(parent)
         
         self.__data = fileData
         
@@ -57,7 +59,7 @@ class NetworkReply(QNetworkReply):
     
     def readData(self, maxlen):
         """
-        Protected method to retrieve data from the reply object.
+        Public method to retrieve data from the reply object.
         
         @param maxlen maximum number of bytes to read (integer)
         @return string containing the data (bytes)
