@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the base class for specific scheme access handlers.
 """
 
-from PyQt4.QtCore import QObject
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import QObject
 
 
 class SchemeAccessHandler(QObject):
@@ -20,11 +22,11 @@ class SchemeAccessHandler(QObject):
         
         @param parent reference to the parent object (QObject)
         """
-        super().__init__(parent)
+        super(SchemeAccessHandler, self).__init__(parent)
     
     def createRequest(self, op, request, outgoingData=None):
         """
-        Protected method to create a request.
+        Public method to create a request.
         
         @param op the operation to be performed
             (QNetworkAccessManager.Operation)
