@@ -1,19 +1,22 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the open search engine.
 """
 
+from __future__ import unicode_literals
+
 import re
 import json
 
-from PyQt4.QtCore import pyqtSignal, pyqtSlot, QLocale, QUrl, QByteArray, \
-    QBuffer, QIODevice, QObject
-from PyQt4.QtGui import QImage
-from PyQt4.QtNetwork import QNetworkRequest, QNetworkAccessManager
+from PyQt5.QtCore import pyqtSignal, pyqtSlot, QLocale, QUrl, QByteArray, \
+    QBuffer, QIODevice, QObject, qVersion
+from PyQt5.QtGui import QImage
+from PyQt5.QtNetwork import QNetworkRequest, QNetworkAccessManager, \
+    QNetworkReply
 
 from UI.Info import Program
 
@@ -38,7 +41,7 @@ class OpenSearchEngine(QObject):
         
         @param parent reference to the parent object (QObject)
         """
-        super().__init__(parent)
+        super(OpenSearchEngine, self).__init__(parent)
         
         self.__suggestionsReply = None
         self.__networkAccessManager = None
@@ -148,12 +151,23 @@ class OpenSearchEngine(QObject):
             return QUrl()
         
         ret = QUrl.fromEncoded(
-            self.parseTemplate(searchTerm, self._searchUrlTemplate))
+            self.parseTemplate(searchTerm, self._searchUrlTemplate)
+            .encode("utf-8"))
         
         if self.__searchMethod != "post":
-            for parameter in self._searchParameters:
-                ret.addQueryItem(parameter[0],
-                                 self.parseTemplate(searchTerm, parameter[1]))
+            if qVersion() >= "5.0.0":
+                from PyQt5.QtCore import QUrlQuery
+                urlQuery = QUrlQuery(ret)
+                for parameter in self._searchParameters:
+                    urlQuery.addQueryItem(
+                        parameter[0],
+                        self.parseTemplate(searchTerm, parameter[1]))
+                ret.setQuery(urlQuery)
+            else:
+                for parameter in self._searchParameters:
+                    ret.addQueryItem(
+                        parameter[0],
+                        self.parseTemplate(searchTerm, parameter[1]))
         
         return ret
     
@@ -193,12 +207,22 @@ class OpenSearchEngine(QObject):
             return QUrl()
         
         ret = QUrl.fromEncoded(QByteArray(self.parseTemplate(
-            searchTerm, self._suggestionsUrlTemplate)))
+            searchTerm, self._suggestionsUrlTemplate).encode("utf-8")))
         
         if self.__searchMethod != "post":
-            for parameter in self._suggestionsParameters:
-                ret.addQueryItem(parameter[0],
-                                 self.parseTemplate(searchTerm, parameter[1]))
+            if qVersion() >= "5.0.0":
+                from PyQt5.QtCore import QUrlQuery
+                urlQuery = QUrlQuery(ret)
+                for parameter in self._suggestionsParameters:
+                    urlQuery.addQueryItem(
+                        parameter[0],
+                        self.parseTemplate(searchTerm, parameter[1]))
+                ret.setQuery(urlQuery)
+            else:
+                for parameter in self._suggestionsParameters:
+                    ret.addQueryItem(
+                        parameter[0],
+                        self.parseTemplate(searchTerm, parameter[1]))
         
         return ret
     
@@ -314,8 +338,8 @@ class OpenSearchEngine(QObject):
             return
         
         reply = self.__networkAccessManager.get(
-            QNetworkRequest(QUrl.fromEncoded(self._imageUrl)))
-        reply.finished[()].connect(self.__imageObtained)
+            QNetworkRequest(QUrl.fromEncoded(self._imageUrl.encode("utf-8"))))
+        reply.finished.connect(self.__imageObtained)
         self.__replies.append(reply)
     
     def __imageObtained(self):
@@ -336,7 +360,7 @@ class OpenSearchEngine(QObject):
         if response.isEmpty():
             return
         
-        if response.startsWith("<html>") or response.startsWith("HTML"):
+        if response.startsWith(b"<html>") or response.startsWith(b"HTML"):
             self.__iconMoved = True
             self.__image = QImage()
         else:
@@ -380,7 +404,7 @@ class OpenSearchEngine(QObject):
     
     def __eq__(self, other):
         """
-        Public method implementing the == operator.
+        Special method implementing the == operator.
         
         @param other reference to an open search engine (OpenSearchEngine)
         @return flag indicating equality (boolean)
@@ -398,7 +422,7 @@ class OpenSearchEngine(QObject):
     
     def __lt__(self, other):
         """
-        Public method implementing the < operator.
+        Special method implementing the < operator.
         
         @param other reference to an open search engine (OpenSearchEngine)
         @return flag indicating less than (boolean)
@@ -439,34 +463,36 @@ class OpenSearchEngine(QObject):
             data = "&".join(parameters)
             self.__suggestionsReply = self.networkAccessManager().post(
                 QNetworkRequest(self.suggestionsUrl(searchTerm)), data)
-        self.__suggestionsReply.finished[()].connect(
+        self.__suggestionsReply.finished.connect(
             self.__suggestionsObtained)
     
     def __suggestionsObtained(self):
         """
         Private slot to receive the suggestions.
         """
-        buffer = bytes(self.__suggestionsReply.readAll())
-        response = Utilities.decodeBytes(buffer)
-        response = response.strip()
-        
-        self.__suggestionsReply.close()
-        self.__suggestionsReply = None
-        
-        if len(response) == 0:
-            return
-        
-        try:
-            result = json.loads(response)
-        except ValueError:
-            return
-        
-        try:
-            suggestions = result[1]
-        except IndexError:
-            return
-        
-        self.suggestions.emit(suggestions)
+        if self.__suggestionsReply.error() == QNetworkReply.NoError:
+            buffer = bytes(self.__suggestionsReply.readAll())
+            response = Utilities.decodeBytes(buffer)
+            response = response.strip()
+            
+            self.__suggestionsReply.close()
+            self.__suggestionsReply.deleteLater()
+            self.__suggestionsReply = None
+            
+            if len(response) == 0:
+                return
+            
+            try:
+                result = json.loads(response)
+            except ValueError:
+                return
+            
+            try:
+                suggestions = result[1]
+            except IndexError:
+                return
+            
+            self.suggestions.emit(suggestions)
     
     def networkAccessManager(self):
         """
