@@ -1,14 +1,17 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a QAction subclass for open search.
 """
 
-from PyQt4.QtCore import QUrl
-from PyQt4.QtGui import QPixmap, QIcon, QAction
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import QUrl
+from PyQt5.QtGui import QPixmap, QIcon
+from PyQt5.QtWidgets import QAction
 
 
 class OpenSearchEngineAction(QAction):
@@ -23,7 +26,7 @@ class OpenSearchEngineAction(QAction):
             (OpenSearchEngine)
         @param parent reference to the parent object (QObject)
         """
-        super().__init__(parent)
+        super(OpenSearchEngineAction, self).__init__(parent)
         
         self.__engine = engine
         if self.__engine.networkAccessManager() is None:
