@@ -1,16 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a model for search engines.
 """
 
+from __future__ import unicode_literals
+
 import re
 
-from PyQt4.QtCore import Qt, QUrl, QAbstractTableModel, QModelIndex
-from PyQt4.QtGui import QPixmap, QIcon
+from PyQt5.QtCore import Qt, QUrl, QAbstractTableModel, QModelIndex
+from PyQt5.QtGui import QPixmap, QIcon
 
 
 class OpenSearchEngineModel(QAbstractTableModel):
@@ -25,14 +27,14 @@ class OpenSearchEngineModel(QAbstractTableModel):
             (OpenSearchManager)
         @param parent reference to the parent object (QObject)
         """
-        super().__init__(parent)
+        super(OpenSearchEngineModel, self).__init__(parent)
         
         self.__manager = manager
         manager.changed.connect(self.__enginesChanged)
         
         self.__headers = [
-            self.trUtf8("Name"),
-            self.trUtf8("Keywords"),
+            self.tr("Name"),
+            self.tr("Keywords"),
         ]
     
     def removeRows(self, row, count, parent=QModelIndex()):
@@ -130,11 +132,11 @@ class OpenSearchEngineModel(QAbstractTableModel):
                 return icon
                 
             elif role == Qt.ToolTipRole:
-                description = self.trUtf8("<strong>Description:</strong> {0}")\
+                description = self.tr("<strong>Description:</strong> {0}")\
                     .format(engine.description())
                 if engine.providesSuggestions():
                     description += "<br/>"
-                    description += self.trUtf8(
+                    description += self.tr(
                         "<strong>Provides contextual suggestions</strong>")
                 
                 return description
@@ -142,7 +144,7 @@ class OpenSearchEngineModel(QAbstractTableModel):
             if role in [Qt.EditRole, Qt.DisplayRole]:
                 return ",".join(self.__manager.keywordsForEngine(engine))
             elif role == Qt.ToolTipRole:
-                return self.trUtf8(
+                return self.tr(
                     "Comma-separated list of keywords that may"
                     " be entered in the location bar followed by search terms"
                     " to search with this engine")
@@ -195,4 +197,5 @@ class OpenSearchEngineModel(QAbstractTableModel):
         """
         Private slot handling a change of the registered engines.
         """
-        super().reset()
+        self.beginResetModel()
+        self.endResetModel()
