@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a writer for open search engine descriptions.
 """
 
-from PyQt4.QtCore import QXmlStreamWriter, QIODevice
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import QXmlStreamWriter, QIODevice
 
 
 class OpenSearchWriter(QXmlStreamWriter):
@@ -18,7 +20,7 @@ class OpenSearchWriter(QXmlStreamWriter):
         """
         Constructor
         """
-        super().__init__()
+        super(OpenSearchWriter, self).__init__()
         
         self.setAutoFormatting(True)
     
