@@ -1,19 +1,22 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the password manager.
 """
 
+from __future__ import unicode_literals
+
 import os
 
-from PyQt4.QtCore import pyqtSignal, QObject, QByteArray, QUrl, \
-    QCoreApplication, QXmlStreamReader
-from PyQt4.QtGui import QApplication
-from PyQt4.QtNetwork import QNetworkRequest
-from PyQt4.QtWebKit import QWebSettings, QWebPage
+from PyQt5.QtCore import pyqtSignal, QObject, QByteArray, QUrl, \
+    QCoreApplication, QXmlStreamReader, qVersion
+from PyQt5.QtWidgets import QApplication
+from PyQt5.QtNetwork import QNetworkRequest
+from PyQt5.QtWebKit import QWebSettings
+from PyQt5.QtWebKitWidgets import QWebPage
 
 from E5Gui import E5MessageBox
 from E5Gui.E5ProgressDialog import E5ProgressDialog
@@ -44,7 +47,7 @@ class PasswordManager(QObject):
         
         @param parent reference to the parent object (QObject)
         """
-        super().__init__(parent)
+        super(PasswordManager, self).__init__(parent)
         
         self.__logins = {}
         self.__loginForms = {}
@@ -114,11 +117,14 @@ class PasswordManager(QObject):
         @param realm realm to get the credentials for (string)
         @return key string (string)
         """
+        authority = url.authority()
+        if authority.startswith("@"):
+            authority = authority[1:]
         if realm:
             key = "{0}://{1} ({2})".format(
-                url.scheme(), url.authority(), realm)
+                url.scheme(), authority, realm)
         else:
-            key = "{0}://{1}".format(url.scheme(), url.authority())
+            key = "{0}://{1}".format(url.scheme(), authority)
         return key
     
     def getFileName(self):
@@ -143,8 +149,8 @@ class PasswordManager(QObject):
                 loginFile, self.__logins, self.__loginForms, self.__never):
             E5MessageBox.critical(
                 None,
-                self.trUtf8("Saving login data"),
-                self.trUtf8(
+                self.tr("Saving login data"),
+                self.tr(
                     """<p>Login data could not be saved to <b>{0}</b></p>"""
                 ).format(loginFile))
         else:
@@ -165,9 +171,9 @@ class PasswordManager(QObject):
             if reader.error() != QXmlStreamReader.NoError:
                 E5MessageBox.warning(
                     None,
-                    self.trUtf8("Loading login data"),
-                    self.trUtf8("""Error when loading login data on"""
-                                """ line {0}, column {1}:\n{2}""")
+                    self.tr("Loading login data"),
+                    self.tr("""Error when loading login data on"""
+                            """ line {0}, column {1}:\n{2}""")
                     .format(reader.lineNumber(),
                             reader.columnNumber(),
                             reader.errorString()))
@@ -191,16 +197,16 @@ class PasswordManager(QObject):
             except IOError as err:
                 E5MessageBox.critical(
                     None,
-                    self.trUtf8("Loading login data"),
-                    self.trUtf8("""<p>Login data could not be loaded """
-                                """from <b>{0}</b></p>"""
-                                """<p>Reason: {1}</p>""")
+                    self.tr("Loading login data"),
+                    self.tr("""<p>Login data could not be loaded """
+                            """from <b>{0}</b></p>"""
+                            """<p>Reason: {1}</p>""")
                     .format(loginFile, str(err)))
                 return
             
             data = []
-            section = 0     # 0 = login data, 1 = forms data,
-                            # 2 = never store info
+            section = 0
+            # 0 = login data, 1 = forms data, 2 = never store info
             for line in lines.splitlines():
                 if line == self.FORMS:
                     section = 1
@@ -216,8 +222,8 @@ class PasswordManager(QObject):
                         if len(data) != 3:
                             E5MessageBox.critical(
                                 None,
-                                self.trUtf8("Loading login data"),
-                                self.trUtf8(
+                                self.tr("Loading login data"),
+                                self.tr(
                                     """<p>Login data could not be loaded """
                                     """from <b>{0}</b></p>"""
                                     """<p>Reason: Wrong input format</p>""")
@@ -337,7 +343,7 @@ class PasswordManager(QObject):
             self.__load()
         
         # determine the url
-        refererHeader = request.rawHeader("Referer")
+        refererHeader = request.rawHeader(b"Referer")
         if refererHeader.isEmpty():
             return
         url = QUrl.fromEncoded(refererHeader)
@@ -360,10 +366,10 @@ class PasswordManager(QObject):
             return
         
         # determine the requests content type
-        contentTypeHeader = request.rawHeader("Content-Type")
+        contentTypeHeader = request.rawHeader(b"Content-Type")
         if contentTypeHeader.isEmpty():
             return
-        multipart = contentTypeHeader.startsWith("multipart/form-data")
+        multipart = contentTypeHeader.startsWith(b"multipart/form-data")
         if multipart:
             boundary = contentTypeHeader.split(" ")[1].split("=")[1]
         else:
@@ -384,18 +390,18 @@ class PasswordManager(QObject):
         if key not in self.__loginForms:
             mb = E5MessageBox.E5MessageBox(
                 E5MessageBox.Question,
-                self.trUtf8("Save password"),
-                self.trUtf8(
+                self.tr("Save password"),
+                self.tr(
                     """<b>Would you like to save this password?</b><br/>"""
                     """To review passwords you have saved and remove them, """
                     """use the password management dialog of the Settings"""
                     """ menu."""),
                 modal=True)
             neverButton = mb.addButton(
-                self.trUtf8("Never for this site"),
+                self.tr("Never for this site"),
                 E5MessageBox.DestructiveRole)
             noButton = mb.addButton(
-                self.trUtf8("Not now"), E5MessageBox.RejectRole)
+                self.tr("Not now"), E5MessageBox.RejectRole)
             mb.addButton(E5MessageBox.Yes)
             mb.exec_()
             if mb.clickedButton() == neverButton:
@@ -431,9 +437,18 @@ class PasswordManager(QObject):
         @return stripped URL (QUrl)
         """
         cleanUrl = QUrl(url)
-        cleanUrl.setQueryItems([])
-        cleanUrl.setFragment("")
+        if qVersion() >= "5.0.0":
+            cleanUrl.setQuery("")
+        else:
+            cleanUrl.setQueryItems([])
         cleanUrl.setUserInfo("")
+        
+        authority = cleanUrl.authority()
+        if authority.startswith("@"):
+            authority = authority[1:]
+        cleanUrl = QUrl("{0}://{1}{2}".format(
+            cleanUrl.scheme(), authority, cleanUrl.path()))
+        cleanUrl.setFragment("")
         return cleanUrl
     
     def __findForm(self, webPage, data, boundary=None):
@@ -451,9 +466,17 @@ class PasswordManager(QObject):
         if boundary is not None:
             args = self.__extractMultipartQueryItems(data, boundary)
         else:
-            argsUrl = QUrl.fromEncoded(
-                QByteArray("foo://bar.com/?" + data.replace(b"+", b"%20")))
-            encodedArgs = argsUrl.queryItems()
+            if qVersion() >= "5.0.0":
+                from PyQt5.QtCore import QUrlQuery
+                argsUrl = QUrl.fromEncoded(
+                    QByteArray(b"foo://bar.com/?" + QUrl.fromPercentEncoding(
+                        data.replace(b"+", b"%20")).encode("utf-8")))
+                encodedArgs = QUrlQuery(argsUrl).queryItems()
+            else:
+                argsUrl = QUrl.fromEncoded(
+                    QByteArray(b"foo://bar.com/?" + data.replace(b"+", b"%20"))
+                )
+                encodedArgs = argsUrl.queryItems()
             args = set()
             for arg in encodedArgs:
                 key = arg[0]
@@ -604,10 +627,11 @@ class PasswordManager(QObject):
             self.__load()
         
         progress = E5ProgressDialog(
-            self.trUtf8("Re-encoding saved passwords..."),
-            None, 0, len(self.__logins), self.trUtf8("%v/%m Passwords"),
+            self.tr("Re-encoding saved passwords..."),
+            None, 0, len(self.__logins), self.tr("%v/%m Passwords"),
             QApplication.activeModalWidget())
         progress.setMinimumDuration(0)
+        progress.setWindowTitle(self.tr("Passwords"))
         count = 0
         
         for key in self.__logins:
