@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a model for password management.
 """
 
-from PyQt4.QtCore import Qt, QModelIndex, QAbstractTableModel
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import Qt, QModelIndex, QAbstractTableModel
 
 
 class PasswordModel(QAbstractTableModel):
@@ -21,15 +23,15 @@ class PasswordModel(QAbstractTableModel):
         @param manager reference to the password manager (PasswordManager)
         @param parent reference to the parent object (QObject)
         """
-        super().__init__(parent)
+        super(PasswordModel, self).__init__(parent)
         
         self.__manager = manager
         manager.changed.connect(self.__passwordsChanged)
         
         self.__headers = [
-            self.trUtf8("Website"),
-            self.trUtf8("Username"),
-            self.trUtf8("Password")
+            self.tr("Website"),
+            self.tr("Username"),
+            self.tr("Password")
         ]
         
         self.__showPasswords = False
@@ -41,7 +43,8 @@ class PasswordModel(QAbstractTableModel):
         @param on flag indicating if passwords shall be shown (boolean)
         """
         self.__showPasswords = on
-        self.reset()
+        self.beginResetModel()
+        self.endResetModel()
     
     def showPasswords(self):
         """
@@ -55,7 +58,8 @@ class PasswordModel(QAbstractTableModel):
         """
         Private slot handling a change of the registered passwords.
         """
-        self.reset()
+        self.beginResetModel()
+        self.endResetModel()
     
     def removeRows(self, row, count, parent=QModelIndex()):
         """
