@@ -1,14 +1,17 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to show all saved logins.
 """
 
-from PyQt4.QtCore import pyqtSlot
-from PyQt4.QtGui import QDialog, QFont, QFontMetrics, QSortFilterProxyModel
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSlot, QSortFilterProxyModel
+from PyQt5.QtGui import QFont, QFontMetrics
+from PyQt5.QtWidgets import QDialog
 
 from E5Gui import E5MessageBox
 
@@ -25,16 +28,16 @@ class PasswordsDialog(QDialog, Ui_PasswordsDialog):
         
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(PasswordsDialog, self).__init__(parent)
         self.setupUi(self)
         
-        self.__showPasswordsText = self.trUtf8("Show Passwords")
-        self.__hidePasswordsText = self.trUtf8("Hide Passwords")
+        self.__showPasswordsText = self.tr("Show Passwords")
+        self.__hidePasswordsText = self.tr("Hide Passwords")
         self.passwordsButton.setText(self.__showPasswordsText)
         
-        self.removeButton.clicked[()].connect(
+        self.removeButton.clicked.connect(
             self.passwordsTable.removeSelected)
-        self.removeAllButton.clicked[()].connect(self.passwordsTable.removeAll)
+        self.removeAllButton.clicked.connect(self.passwordsTable.removeAll)
         
         import Helpviewer.HelpWindow
         from .PasswordModel import PasswordModel
@@ -86,8 +89,8 @@ class PasswordsDialog(QDialog, Ui_PasswordsDialog):
         else:
             res = E5MessageBox.yesNo(
                 self,
-                self.trUtf8("Saved Passwords"),
-                self.trUtf8("""Do you really want to show passwords?"""))
+                self.tr("Saved Passwords"),
+                self.tr("""Do you really want to show passwords?"""))
             if res:
                 self.__passwordModel.setShowPasswords(True)
                 self.passwordsButton.setText(self.__hidePasswordsText)
