@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,6 +8,9 @@ Module implementing a structure to hold the data for a speed dial page.
 """
 
 
+from __future__ import unicode_literals
+
+
 class Page(object):
     """
     Class to hold the data for a speed dial page.
@@ -26,7 +29,7 @@ class Page(object):
     
     def __eq__(self, other):
         """
-        Public method implementing the equality operator.
+        Special method implementing the equality operator.
         
         @param other reference to the other page object (Page)
         @return flag indicating equality (boolean)
