@@ -1,16 +1,19 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a palette widget for the icon editor.
 """
 
-from PyQt4.QtCore import pyqtSignal, Qt
-from PyQt4.QtGui import QWidget, QColor, QPainter, QBoxLayout, QLabel, \
-    QFrame, QPushButton, QSpinBox, QGroupBox, QVBoxLayout, QRadioButton, \
-    QSpacerItem, QSizePolicy, QPixmap, QColorDialog
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSignal, Qt
+from PyQt5.QtGui import QColor, QPainter, QPixmap
+from PyQt5.QtWidgets import QWidget, QBoxLayout, QLabel, QFrame, QPushButton, \
+    QSpinBox, QGroupBox, QVBoxLayout, QRadioButton, QSpacerItem, QSizePolicy, \
+    QColorDialog
 
 
 class IconEditorPalette(QWidget):
@@ -30,7 +33,7 @@ class IconEditorPalette(QWidget):
         
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(IconEditorPalette, self).__init__(parent)
         
         if self.layoutDirection == Qt.Horizontal:
             direction = QBoxLayout.LeftToRight
@@ -43,7 +46,7 @@ class IconEditorPalette(QWidget):
         self.__preview.setFrameStyle(QFrame.Panel | QFrame.Sunken)
         self.__preview.setFixedHeight(64)
         self.__preview.setAlignment(Qt.AlignHCenter | Qt.AlignVCenter)
-        self.__preview.setWhatsThis(self.trUtf8(
+        self.__preview.setWhatsThis(self.tr(
             """<b>Preview</b>"""
             """<p>This is a 1:1 preview of the current icon.</p>"""
         ))
@@ -53,7 +56,7 @@ class IconEditorPalette(QWidget):
         self.__color.setFrameStyle(QFrame.Panel | QFrame.Sunken)
         self.__color.setFixedHeight(24)
         self.__color.setAlignment(Qt.AlignHCenter | Qt.AlignVCenter)
-        self.__color.setWhatsThis(self.trUtf8(
+        self.__color.setWhatsThis(self.tr(
             """<b>Current Color</b>"""
             """<p>This is the currently selected color used for drawing.</p>"""
         ))
@@ -61,25 +64,25 @@ class IconEditorPalette(QWidget):
         
         self.__colorTxt = QLabel(self)
         self.__colorTxt.setAlignment(Qt.AlignHCenter | Qt.AlignVCenter)
-        self.__colorTxt.setWhatsThis(self.trUtf8(
+        self.__colorTxt.setWhatsThis(self.tr(
             """<b>Current Color Value</b>"""
             """<p>This is the currently selected color value used for"""
             """ drawing.</p>"""
         ))
         self.__layout.addWidget(self.__colorTxt)
         
-        self.__colorButton = QPushButton(self.trUtf8("Select Color"), self)
-        self.__colorButton.setWhatsThis(self.trUtf8(
+        self.__colorButton = QPushButton(self.tr("Select Color"), self)
+        self.__colorButton.setWhatsThis(self.tr(
             """<b>Select Color</b>"""
             """<p>Select the current drawing color via a color selection"""
             """ dialog.</p>"""
         ))
-        self.__colorButton.clicked[()].connect(self.__selectColor)
+        self.__colorButton.clicked.connect(self.__selectColor)
         self.__layout.addWidget(self.__colorButton)
         
         self.__colorAlpha = QSpinBox(self)
         self.__colorAlpha.setRange(0, 255)
-        self.__colorAlpha.setWhatsThis(self.trUtf8(
+        self.__colorAlpha.setWhatsThis(self.tr(
             """<b>Select alpha channel value</b>"""
             """<p>Select the value for the alpha channel of the current"""
             """ color.</p>"""
@@ -87,20 +90,20 @@ class IconEditorPalette(QWidget):
         self.__layout.addWidget(self.__colorAlpha)
         self.__colorAlpha.valueChanged[int].connect(self.__alphaChanged)
         
-        self.__compositingGroup = QGroupBox(self.trUtf8("Compositing"), self)
+        self.__compositingGroup = QGroupBox(self.tr("Compositing"), self)
         self.__compositingGroupLayout = QVBoxLayout(self.__compositingGroup)
         self.__compositingGroup.setLayout(self.__compositingGroupLayout)
-        self.__sourceButton = QRadioButton(self.trUtf8("Replace"),
+        self.__sourceButton = QRadioButton(self.tr("Replace"),
                                            self.__compositingGroup)
-        self.__sourceButton.setWhatsThis(self.trUtf8(
+        self.__sourceButton.setWhatsThis(self.tr(
             """<b>Replace</b>"""
             """<p>Replace the existing pixel with a new color.</p>"""
         ))
         self.__sourceButton.clicked[bool].connect(self.__compositingChanged)
         self.__compositingGroupLayout.addWidget(self.__sourceButton)
-        self.__sourceOverButton = QRadioButton(self.trUtf8("Blend"),
+        self.__sourceOverButton = QRadioButton(self.tr("Blend"),
                                                self.__compositingGroup)
-        self.__sourceOverButton.setWhatsThis(self.trUtf8(
+        self.__sourceOverButton.setWhatsThis(self.tr(
             """<b>Blend</b>"""
             """<p>Blend the new color over the existing pixel.</p>"""
         ))
