@@ -4,7 +4,9 @@
 Module implementing a dialog to enter the icon size.
 """
 
-from PyQt4.QtGui import QDialog
+from __future__ import unicode_literals
+
+from PyQt5.QtWidgets import QDialog
 
 from .Ui_IconSizeDialog import Ui_IconSizeDialog
 
@@ -21,13 +23,16 @@ class IconSizeDialog(QDialog, Ui_IconSizeDialog):
         @param height height to be set (integer)
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(IconSizeDialog, self).__init__(parent)
         self.setupUi(self)
         
         self.widthSpin.setValue(width)
         self.heightSpin.setValue(height)
         
         self.widthSpin.selectAll()
+        
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
     
     def getData(self):
         """
