@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the multi project properties dialog.
 """
 
-from PyQt4.QtGui import QDialog
+from __future__ import unicode_literals
+
+from PyQt5.QtWidgets import QDialog
 
 from .Ui_PropertiesDialog import Ui_PropertiesDialog
 
@@ -24,7 +26,7 @@ class PropertiesDialog(QDialog, Ui_PropertiesDialog):
         @param new flag indicating the generation of a new multi project
         @param parent parent widget of this dialog (QWidget)
         """
-        super().__init__(parent)
+        super(PropertiesDialog, self).__init__(parent)
         self.setupUi(self)
         
         self.multiProject = multiProject
