@@ -1,16 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the identities management dialog.
 """
 
+from __future__ import unicode_literals
+
 import copy
 
-from PyQt4.QtCore import pyqtSlot, Qt, QEvent
-from PyQt4.QtGui import QDialog, QInputDialog, QLineEdit, QItemSelectionModel
+from PyQt5.QtCore import pyqtSlot, Qt, QEvent, QItemSelectionModel
+from PyQt5.QtWidgets import QDialog, QInputDialog, QLineEdit
 
 from E5Gui import E5MessageBox
 
@@ -35,7 +37,7 @@ class IrcIdentitiesEditDialog(QDialog, Ui_IrcIdentitiesEditDialog):
         @param identityName name of the identity to be selected (string)
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(IrcIdentitiesEditDialog, self).__init__(parent)
         self.setupUi(self)
         
         self.addButton.setIcon(UI.PixmapCache.getIcon("plus.png"))
@@ -82,7 +84,7 @@ class IrcIdentitiesEditDialog(QDialog, Ui_IrcIdentitiesEditDialog):
                 self.on_nicknameAddButton_clicked()
                 return True
         
-        return super().eventFilter(obj, evt)
+        return super(IrcIdentitiesEditDialog, self).eventFilter(obj, evt)
 
     def __updateIdentitiesButtons(self):
         """
@@ -168,8 +170,8 @@ class IrcIdentitiesEditDialog(QDialog, Ui_IrcIdentitiesEditDialog):
         if self.nicknamesList.count() == 0:
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Edit Identity"),
-                self.trUtf8(
+                self.tr("Edit Identity"),
+                self.tr(
                     """The identity must contain at least one nick name."""))
             block = self.identitiesCombo.blockSignals(True)
             identity = self.__currentIdentity.getName()
@@ -185,8 +187,8 @@ class IrcIdentitiesEditDialog(QDialog, Ui_IrcIdentitiesEditDialog):
         if not self.realnameEdit.text():
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Edit Identity"),
-                self.trUtf8("""The identity must have a real name."""))
+                self.tr("Edit Identity"),
+                self.tr("""The identity must have a real name."""))
             block = self.identitiesCombo.blockSignals(True)
             identity = self.__currentIdentity.getName()
             if identity == IrcIdentity.DefaultIdentityName:
@@ -207,8 +209,8 @@ class IrcIdentitiesEditDialog(QDialog, Ui_IrcIdentitiesEditDialog):
         """
         name, ok = QInputDialog.getText(
             self,
-            self.trUtf8("Add Identity"),
-            self.trUtf8("Identity Name:"),
+            self.tr("Add Identity"),
+            self.tr("Identity Name:"),
             QLineEdit.Normal)
         
         if ok:
@@ -216,8 +218,8 @@ class IrcIdentitiesEditDialog(QDialog, Ui_IrcIdentitiesEditDialog):
                 if name in self.__identities:
                     E5MessageBox.critical(
                         self,
-                        self.trUtf8("Add Identity"),
-                        self.trUtf8(
+                        self.tr("Add Identity"),
+                        self.tr(
                             """An identity named <b>{0}</b> already exists."""
                             """ You must provide a different name.""").format(
                             name))
@@ -233,8 +235,8 @@ class IrcIdentitiesEditDialog(QDialog, Ui_IrcIdentitiesEditDialog):
             else:
                 E5MessageBox.critical(
                     self,
-                    self.trUtf8("Add Identity"),
-                    self.trUtf8("""The identity has to have a name."""))
+                    self.tr("Add Identity"),
+                    self.tr("""The identity has to have a name."""))
                 self.on_addButton_clicked()
     
     @pyqtSlot()
@@ -245,8 +247,8 @@ class IrcIdentitiesEditDialog(QDialog, Ui_IrcIdentitiesEditDialog):
         currentIdentity = self.identitiesCombo.currentText()
         name, ok = QInputDialog.getText(
             self,
-            self.trUtf8("Copy Identity"),
-            self.trUtf8("Identity Name:"),
+            self.tr("Copy Identity"),
+            self.tr("Identity Name:"),
             QLineEdit.Normal,
             currentIdentity)
         
@@ -255,8 +257,8 @@ class IrcIdentitiesEditDialog(QDialog, Ui_IrcIdentitiesEditDialog):
                 if name in self.__identities:
                     E5MessageBox.critical(
                         self,
-                        self.trUtf8("Copy Identity"),
-                        self.trUtf8(
+                        self.tr("Copy Identity"),
+                        self.tr(
                             """An identity named <b>{0}</b> already exists."""
                             """ You must provide a different name.""").format(
                             name))
@@ -271,8 +273,8 @@ class IrcIdentitiesEditDialog(QDialog, Ui_IrcIdentitiesEditDialog):
             else:
                 E5MessageBox.critical(
                     self,
-                    self.trUtf8("Copy Identity"),
-                    self.trUtf8("""The identity has to have a name."""))
+                    self.tr("Copy Identity"),
+                    self.tr("""The identity has to have a name."""))
                 self.on_copyButton_clicked()
     
     @pyqtSlot()
@@ -283,8 +285,8 @@ class IrcIdentitiesEditDialog(QDialog, Ui_IrcIdentitiesEditDialog):
         currentIdentity = self.identitiesCombo.currentText()
         name, ok = QInputDialog.getText(
             self,
-            self.trUtf8("Rename Identity"),
-            self.trUtf8("Identity Name:"),
+            self.tr("Rename Identity"),
+            self.tr("Identity Name:"),
             QLineEdit.Normal,
             currentIdentity)
         
@@ -293,8 +295,8 @@ class IrcIdentitiesEditDialog(QDialog, Ui_IrcIdentitiesEditDialog):
                 if name in self.__identities:
                     E5MessageBox.critical(
                         self,
-                        self.trUtf8("Rename Identity"),
-                        self.trUtf8(
+                        self.tr("Rename Identity"),
+                        self.tr(
                             """An identity named <b>{0}</b> already exists."""
                             """ You must provide a different name.""").format(
                             name))
@@ -308,8 +310,8 @@ class IrcIdentitiesEditDialog(QDialog, Ui_IrcIdentitiesEditDialog):
             else:
                 E5MessageBox.critical(
                     self,
-                    self.trUtf8("Copy Identity"),
-                    self.trUtf8("""The identity has to have a name."""))
+                    self.tr("Copy Identity"),
+                    self.tr("""The identity has to have a name."""))
                 self.on_renameButton_clicked()
     
     @pyqtSlot()
@@ -330,17 +332,17 @@ class IrcIdentitiesEditDialog(QDialog, Ui_IrcIdentitiesEditDialog):
                 break
         
         if inUse:
-            msg = self.trUtf8(
+            msg = self.tr(
                 """This identity is in use. If you remove it, the network"""
                 """ settings using it will fall back to the default"""
                 """ identity. Should it be deleted anyway?""")
         else:
-            msg = self.trUtf8(
+            msg = self.tr(
                 """Do you really want to delete all information for"""
                 """ this identity?""")
         res = E5MessageBox.yesNo(
             self,
-            self.trUtf8("Delete Identity"),
+            self.tr("Delete Identity"),
             msg,
             icon=E5MessageBox.Warning)
         if res:
@@ -461,4 +463,4 @@ class IrcIdentitiesEditDialog(QDialog, Ui_IrcIdentitiesEditDialog):
         self.__refreshCurrentIdentity()
         self.__manager.setIdentities(self.__identities)
         
-        super().accept()
+        super(IrcIdentitiesEditDialog, self).accept()
