@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 
@@ -8,8 +8,10 @@
 Module implementing the Plugin Details Dialog.
 """
 
-from PyQt4.QtGui import QDialog
-from PyQt4.QtCore import pyqtSlot
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSlot, Qt
+from PyQt5.QtWidgets import QDialog
 
 from .Ui_PluginDetailsDialog import Ui_PluginDetailsDialog
 
@@ -25,8 +27,9 @@ class PluginDetailsDialog(QDialog, Ui_PluginDetailsDialog):
         @param details dictionary containing the info to be displayed
         @param parent parent of this dialog (QWidget)
         """
-        super().__init__(parent)
+        super(PluginDetailsDialog, self).__init__(parent)
         self.setupUi(self)
+        self.setWindowFlags(Qt.Window)
         
         self.__autoactivate = details["autoactivate"]
         self.__active = details["active"]
