@@ -1,22 +1,27 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Plugin installation dialog.
 """
 
+from __future__ import unicode_literals
+
 import os
 import sys
 import shutil
 import zipfile
 import compileall
-import urllib.parse
 import glob
+try:  # Py3
+    import urllib.parse as parse
+except (ImportError):
+    import urlparse as parse    # __IGNORE_WARNING__
 
-from PyQt4.QtCore import pyqtSlot, Qt, QDir, QFileInfo
-from PyQt4.QtGui import QWidget, QDialogButtonBox, QAbstractButton, \
+from PyQt5.QtCore import pyqtSlot, Qt, QDir, QFileInfo
+from PyQt5.QtWidgets import QWidget, QDialogButtonBox, QAbstractButton, \
     QApplication, QDialog, QVBoxLayout
 
 from E5Gui import E5FileDialog
@@ -43,7 +48,7 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
             installation (list of strings)
         @param parent parent of this dialog (QWidget)
         """
-        super().__init__(parent)
+        super(PluginInstallWidget, self).__init__(parent)
         self.setupUi(self)
         
         if pluginManager is None:
@@ -56,11 +61,11 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
             self.__external = False
         
         self.__backButton = self.buttonBox.addButton(
-            self.trUtf8("< Back"), QDialogButtonBox.ActionRole)
+            self.tr("< Back"), QDialogButtonBox.ActionRole)
         self.__nextButton = self.buttonBox.addButton(
-            self.trUtf8("Next >"), QDialogButtonBox.ActionRole)
+            self.tr("Next >"), QDialogButtonBox.ActionRole)
         self.__finishButton = self.buttonBox.addButton(
-            self.trUtf8("Install"), QDialogButtonBox.ActionRole)
+            self.tr("Install"), QDialogButtonBox.ActionRole)
         
         self.__closeButton = self.buttonBox.button(QDialogButtonBox.Close)
         self.__cancelButton = self.buttonBox.button(QDialogButtonBox.Cancel)
@@ -68,13 +73,13 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
         userDir = self.__pluginManager.getPluginDir("user")
         if userDir is not None:
             self.destinationCombo.addItem(
-                self.trUtf8("User plugins directory"),
+                self.tr("User plugins directory"),
                 userDir)
         
         globalDir = self.__pluginManager.getPluginDir("global")
         if globalDir is not None and os.access(globalDir, os.W_OK):
             self.destinationCombo.addItem(
-                self.trUtf8("Global plugins directory"),
+                self.tr("Global plugins directory"),
                 globalDir)
         
         self.__installedDirs = []
@@ -137,7 +142,7 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
             self.__closeButton.hide()
             self.__cancelButton.show()
             
-            msg = self.trUtf8(
+            msg = self.tr(
                 "Plugin ZIP-Archives:\n{0}\n\nDestination:\n{1} ({2})")\
                 .format("\n".join(self.__createArchivesList()),
                         self.destinationCombo.currentText(),
@@ -154,9 +159,9 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
         dn = Preferences.getPluginManager("DownloadPath")
         archives = E5FileDialog.getOpenFileNames(
             self,
-            self.trUtf8("Select plugin ZIP-archives"),
+            self.tr("Select plugin ZIP-archives"),
             dn,
-            self.trUtf8("Plugin archive (*.zip)"))
+            self.tr("Plugin archive (*.zip)"))
         
         if archives:
             matchflags = Qt.MatchFixedString
@@ -219,21 +224,21 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
         self.summaryEdit.clear()
         for archive in self.__createArchivesList():
             self.summaryEdit.append(
-                self.trUtf8("Installing {0} ...").format(archive))
+                self.tr("Installing {0} ...").format(archive))
             ok, msg, restart = self.__installPlugin(archive)
             res = res and ok
             if ok:
-                self.summaryEdit.append(self.trUtf8("  ok"))
+                self.summaryEdit.append(self.tr("  ok"))
             else:
                 self.summaryEdit.append(msg)
             if restart:
                 self.__restartNeeded = True
         self.summaryEdit.append("\n")
         if res:
-            self.summaryEdit.append(self.trUtf8(
+            self.summaryEdit.append(self.tr(
                 """The plugins were installed successfully."""))
         else:
-            self.summaryEdit.append(self.trUtf8(
+            self.summaryEdit.append(self.tr(
                 """Some plugins could not be installed."""))
         
         return res
@@ -255,14 +260,14 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
             self.destinationCombo.currentIndex())
         
         # check if archive is a local url
-        url = urllib.parse.urlparse(archive)
+        url = parse.urlparse(archive)
         if url[0].lower() == 'file':
             archive = url[2]
 
         # check, if the archive exists
         if not os.path.exists(archive):
             return False, \
-                self.trUtf8(
+                self.tr(
                     """<p>The archive file <b>{0}</b> does not exist. """
                     """Aborting...</p>""").format(archive), \
                 False
@@ -270,7 +275,7 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
         # check, if the archive is a valid zip file
         if not zipfile.is_zipfile(archive):
             return False, \
-                self.trUtf8(
+                self.tr(
                     """<p>The file <b>{0}</b> is not a valid plugin """
                     """ZIP-archive. Aborting...</p>""").format(archive), \
                 False
@@ -278,7 +283,7 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
         # check, if the destination is writeable
         if not os.access(destination, os.W_OK):
             return False, \
-                self.trUtf8(
+                self.tr(
                     """<p>The destination directory <b>{0}</b> is not """
                     """writeable. Aborting...</p>""").format(destination), \
                 False
@@ -297,7 +302,7 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
         
         if not pluginFound:
             return False, \
-                self.trUtf8(
+                self.tr(
                     """<p>The file <b>{0}</b> is not a valid plugin """
                     """ZIP-archive. Aborting...</p>""").format(archive), \
                 False
@@ -342,7 +347,7 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
         
         if not packageName:
             return False, \
-                self.trUtf8(
+                self.tr(
                     """<p>The plugin module <b>{0}</b> does not contain """
                     """a 'packageName' attribute. Aborting...</p>""")\
                 .format(pluginFileName), \
@@ -350,7 +355,7 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
         
         if pyqtApi < 2:
             return False, \
-                self.trUtf8(
+                self.tr(
                     """<p>The plugin module <b>{0}</b> does not conform"""
                     """ with the PyQt v2 API. Aborting...</p>""")\
                 .format(pluginFileName), \
@@ -361,8 +366,8 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
            packageName != "None" and \
            os.path.exists(os.path.join(destination, packageName)):
             return False, \
-                self.trUtf8("""<p>The plugin package <b>{0}</b> exists. """
-                            """Aborting...</p>""")\
+                self.tr("""<p>The plugin package <b>{0}</b> exists. """
+                        """Aborting...</p>""")\
                     .format(os.path.join(destination, packageName)), \
                 False
         
@@ -370,8 +375,8 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
            packageName != "None" and \
            not os.path.exists(os.path.join(destination, packageName)):
             return False, \
-                self.trUtf8("""<p>The plugin module <b>{0}</b> exists. """
-                            """Aborting...</p>""")\
+                self.tr("""<p>The plugin module <b>{0}</b> exists. """
+                        """Aborting...</p>""")\
                     .format(os.path.join(destination, pluginFileName)), \
                 False
         
@@ -437,26 +442,26 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
         except os.error as why:
             self.__rollback()
             return False, \
-                self.trUtf8(
+                self.tr(
                     "Error installing plugin. Reason: {0}").format(str(why)), \
                 False
         except IOError as why:
             self.__rollback()
             return False, \
-                self.trUtf8(
+                self.tr(
                     "Error installing plugin. Reason: {0}").format(str(why)), \
                 False
         except OSError as why:
             self.__rollback()
             return False, \
-                self.trUtf8(
+                self.tr(
                     "Error installing plugin. Reason: {0}").format(str(why)), \
                 False
         except:
-            print("Unspecific exception installing plugin.", file=sys.stderr)
+            sys.stderr.write("Unspecific exception installing plugin.\n")
             self.__rollback()
             return False, \
-                self.trUtf8("Unspecific exception installing plugin."), \
+                self.tr("Unspecific exception installing plugin."), \
                 False
         
         # now compile the plugins
@@ -567,7 +572,7 @@ class PluginInstallDialog(QDialog):
             installation (list of strings)
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(PluginInstallDialog, self).__init__(parent)
         self.setSizeGripEnabled(True)
         
         self.__layout = QVBoxLayout(self)
@@ -580,8 +585,8 @@ class PluginInstallDialog(QDialog):
         self.resize(size)
         self.setWindowTitle(self.cw.windowTitle())
         
-        self.cw.buttonBox.accepted[()].connect(self.accept)
-        self.cw.buttonBox.rejected[()].connect(self.reject)
+        self.cw.buttonBox.accepted.connect(self.accept)
+        self.cw.buttonBox.rejected.connect(self.reject)
     
     def restartNeeded(self):
         """
@@ -604,7 +609,7 @@ class PluginInstallWindow(E5MainWindow):
             installation (list of strings)
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(PluginInstallWindow, self).__init__(parent)
         self.cw = PluginInstallWidget(None, pluginFileNames, self)
         size = self.cw.size()
         self.setCentralWidget(self.cw)
@@ -614,5 +619,5 @@ class PluginInstallWindow(E5MainWindow):
         self.setStyle(Preferences.getUI("Style"),
                       Preferences.getUI("StyleSheet"))
         
-        self.cw.buttonBox.accepted[()].connect(self.close)
-        self.cw.buttonBox.rejected[()].connect(self.close)
+        self.cw.buttonBox.accepted.connect(self.close)
+        self.cw.buttonBox.rejected.connect(self.close)
