@@ -1,21 +1,23 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Plugin Manager.
 """
 
+from __future__ import unicode_literals, print_function
+
 import os
 import sys
 import imp
 import zipfile
 
-from PyQt4.QtCore import pyqtSignal, QObject, QDate, QFile, QFileInfo, QUrl, \
+from PyQt5.QtCore import pyqtSignal, QObject, QDate, QFile, QFileInfo, QUrl, \
     QIODevice
-from PyQt4.QtGui import QPixmap
-from PyQt4.QtNetwork import QNetworkAccessManager, QNetworkRequest, \
+from PyQt5.QtGui import QPixmap
+from PyQt5.QtNetwork import QNetworkAccessManager, QNetworkRequest, \
     QNetworkReply
 
 from E5Gui import E5MessageBox
@@ -29,14 +31,14 @@ except ImportError:
 
 from .PluginExceptions import PluginPathError, PluginModulesError, \
     PluginLoadError, PluginActivationError, PluginModuleFormatError, \
-    PluginClassFormatError
+    PluginClassFormatError, PluginPy2IncompatibleError
 
 import UI.PixmapCache
 
 import Utilities
 import Preferences
 
-from eric5config import getConfig
+from eric6config import getConfig
 
 
 class PluginManager(QObject):
@@ -46,13 +48,13 @@ class PluginManager(QObject):
     @signal shutdown() emitted at shutdown of the IDE
     @signal pluginAboutToBeActivated(modulName, pluginObject) emitted just
         before a plugin is activated
-    @signal pluginActivated(modulName, pluginObject) emitted just after
+    @signal pluginActivated(moduleName, pluginObject) emitted just after
         a plugin was activated
     @signal allPlugginsActivated() emitted at startup after all plugins have
         been activated
-    @signal pluginAboutToBeDeactivated(modulName, pluginObject) emitted just
+    @signal pluginAboutToBeDeactivated(moduleName, pluginObject) emitted just
         before a plugin is deactivated
-    @signal pluginDeactivated(modulName, pluginObject) emitted just after
+    @signal pluginDeactivated(moduleName, pluginObject) emitted just after
         a plugin was deactivated
     """
     shutdown = pyqtSignal()
@@ -67,10 +69,10 @@ class PluginManager(QObject):
         Constructor
         
         The Plugin Manager deals with three different plugin directories.
-        The first is the one, that is part of eric5 (eric5/Plugins). The
-        second one is the global plugin directory called 'eric5plugins',
+        The first is the one, that is part of eric6 (eric6/Plugins). The
+        second one is the global plugin directory called 'eric6plugins',
         which is located inside the site-packages directory. The last one
-        is the user plugin directory located inside the .eric5 directory
+        is the user plugin directory located inside the .eric6 directory
         of the users home directory.
         
         @param parent reference to the parent object (QObject)
@@ -80,7 +82,7 @@ class PluginManager(QObject):
             development (string)
         @exception PluginPathError raised to indicate an invalid plug-in path
         """
-        super().__init__(parent)
+        super(PluginManager, self).__init__(parent)
         
         self.__ui = parent
         self.__develPluginFile = develPlugin
@@ -89,12 +91,12 @@ class PluginManager(QObject):
         self.__inactivePluginsKey = "PluginManager/InactivePlugins"
         
         self.pluginDirs = {
-            "eric5": os.path.join(getConfig('ericDir'), "Plugins"),
+            "eric6": os.path.join(getConfig('ericDir'), "Plugins"),
             "global": os.path.join(Utilities.getPythonModulesDirectory(),
-                                   "eric5plugins"),
-            "user": os.path.join(Utilities.getConfigDir(), "eric5plugins"),
+                                   "eric6plugins"),
+            "user": os.path.join(Utilities.getConfigDir(), "eric6plugins"),
         }
-        self.__priorityOrder = ["eric5", "global", "user"]
+        self.__priorityOrder = ["eric6", "global", "user"]
         
         self.__defaultDownloadDir = os.path.join(
             Utilities.getConfigDir(), "Downloads")
@@ -184,7 +186,7 @@ class PluginManager(QObject):
                 except IOError:
                     return (
                         False,
-                        self.trUtf8("Could not create a package for {0}.")
+                        self.tr("Could not create a package for {0}.")
                             .format(self.__develPluginFile))
         
         if Preferences.getPluginManager("ActivateExternal"):
@@ -216,12 +218,12 @@ class PluginManager(QObject):
             del self.pluginDirs["user"]
             del self.pluginDirs["global"]
         
-        if not os.path.exists(self.pluginDirs["eric5"]):
+        if not os.path.exists(self.pluginDirs["eric6"]):
             return (
                 False,
-                self.trUtf8(
+                self.tr(
                     "The internal plugin directory <b>{0}</b>"
-                    " does not exits.").format(self.pluginDirs["eric5"]))
+                    " does not exits.").format(self.pluginDirs["eric6"]))
         
         return (True, "")
     
@@ -236,7 +238,7 @@ class PluginManager(QObject):
             return False
         
         self.__foundCoreModules = self.getPluginModules(
-            self.pluginDirs["eric5"])
+            self.pluginDirs["eric6"])
         if "global" in self.pluginDirs:
             self.__foundGlobalModules = \
                 self.getPluginModules(self.pluginDirs["global"])
@@ -281,7 +283,7 @@ class PluginManager(QObject):
         
         if self.__develPluginFile:
             path = Utilities.splitPath(self.__develPluginFile)[0]
-            if not path in sys.path:
+            if path not in sys.path:
                 sys.path.insert(2, path)
             UI.PixmapCache.addSearchPath(path)
     
@@ -301,7 +303,7 @@ class PluginManager(QObject):
             if pluginName not in self.__foundGlobalModules and \
                pluginName not in self.__foundUserModules and \
                pluginName != develPluginName:
-                self.loadPlugin(pluginName, self.pluginDirs["eric5"])
+                self.loadPlugin(pluginName, self.pluginDirs["eric6"])
         
         for pluginName in self.__foundGlobalModules:
             # user plugins have priority
@@ -336,35 +338,53 @@ class PluginManager(QObject):
             fname = "{0}.py".format(os.path.join(directory, name))
             module = imp.load_source(name, fname)
             if not hasattr(module, "autoactivate"):
-                module.error = self.trUtf8(
+                module.error = self.tr(
                     "Module is missing the 'autoactivate' attribute.")
                 self.__failedModules[name] = module
                 raise PluginLoadError(name)
+            if sys.version_info[0] < 3:
+                if not hasattr(module, "python2Compatible"):
+                    module.error = self.tr(
+                        "Module is missing the Python2 compatibility flag."
+                        " Please update.")
+                    compatible = False
+                elif not getattr(module, "python2Compatible"):
+                    module.error = self.tr(
+                        "Module is not Python2 compatible.")
+                    compatible = False
+                else:
+                    compatible = True
+                if not compatible:
+                    self.__failedModules[name] = module
+                    raise PluginPy2IncompatibleError(name)
             if getattr(module, "autoactivate"):
                 self.__inactiveModules[name] = module
             else:
                 if not hasattr(module, "pluginType") or \
                    not hasattr(module, "pluginTypename"):
                     module.error = \
-                        self.trUtf8("Module is missing the 'pluginType' "
-                                    "and/or 'pluginTypename' attributes.")
+                        self.tr("Module is missing the 'pluginType' "
+                                "and/or 'pluginTypename' attributes.")
                     self.__failedModules[name] = module
                     raise PluginLoadError(name)
                 else:
                     self.__onDemandInactiveModules[name] = module
-            module.eric5PluginModuleName = name
-            module.eric5PluginModuleFilename = fname
+            module.eric6PluginModuleName = name
+            module.eric6PluginModuleFilename = fname
             self.__modulesCount += 1
             if reload_:
                 imp.reload(module)
         except PluginLoadError:
-            print("Error loading plugin module:", name)
+            print("Error loading plug-in module:", name)
+        except PluginPy2IncompatibleError:
+            print("Error loading plug-in module:", name)
+            print("The plug-in is not Python2 compatible.")
         except Exception as err:
             module = imp.new_module(name)
-            module.error = self.trUtf8(
+            module.error = self.tr(
                 "Module failed to load. Error: {0}").format(str(err))
             self.__failedModules[name] = module
-            print("Error loading plugin module:", name)
+            print("Error loading plug-in module:", name)
             print(str(err))
     
     def unloadPlugin(self, name):
@@ -449,16 +469,16 @@ class PluginManager(QObject):
                 return
             
             if not self.__canActivatePlugin(module):
-                raise PluginActivationError(module.eric5PluginModuleName)
+                raise PluginActivationError(module.eric6PluginModuleName)
             version = getattr(module, "version")
             className = getattr(module, "className")
             pluginClass = getattr(module, className)
             pluginObject = None
             if name not in self.__onDemandInactivePlugins:
                 pluginObject = pluginClass(self.__ui)
-                pluginObject.eric5PluginModule = module
-                pluginObject.eric5PluginName = className
-                pluginObject.eric5PluginVersion = version
+                pluginObject.eric6PluginModule = module
+                pluginObject.eric6PluginName = className
+                pluginObject.eric6PluginVersion = version
                 self.__onDemandInactivePlugins[name] = pluginObject
         except PluginActivationError:
             return
@@ -501,7 +521,7 @@ class PluginManager(QObject):
                 return None
             
             if not self.__canActivatePlugin(module):
-                raise PluginActivationError(module.eric5PluginModuleName)
+                raise PluginActivationError(module.eric6PluginModuleName)
             version = getattr(module, "version")
             className = getattr(module, "className")
             pluginClass = getattr(module, className)
@@ -516,7 +536,7 @@ class PluginManager(QObject):
             try:
                 obj, ok = pluginObject.activate()
             except TypeError:
-                module.error = self.trUtf8(
+                module.error = self.tr(
                     "Incompatible plugin activation method.")
                 obj = None
                 ok = True
@@ -528,9 +548,9 @@ class PluginManager(QObject):
                 return None
             
             self.pluginActivated.emit(name, pluginObject)
-            pluginObject.eric5PluginModule = module
-            pluginObject.eric5PluginName = className
-            pluginObject.eric5PluginVersion = version
+            pluginObject.eric6PluginModule = module
+            pluginObject.eric6PluginName = className
+            pluginObject.eric6PluginVersion = version
             
             if onDemand:
                 self.__onDemandInactiveModules.pop(name)
@@ -567,26 +587,26 @@ class PluginManager(QObject):
         try:
             if not hasattr(module, "version"):
                 raise PluginModuleFormatError(
-                    module.eric5PluginModuleName, "version")
+                    module.eric6PluginModuleName, "version")
             if not hasattr(module, "className"):
                 raise PluginModuleFormatError(
-                    module.eric5PluginModuleName, "className")
+                    module.eric6PluginModuleName, "className")
             className = getattr(module, "className")
             if not hasattr(module, className):
                 raise PluginModuleFormatError(
-                    module.eric5PluginModuleName, className)
+                    module.eric6PluginModuleName, className)
             pluginClass = getattr(module, className)
             if not hasattr(pluginClass, "__init__"):
                 raise PluginClassFormatError(
-                    module.eric5PluginModuleName,
+                    module.eric6PluginModuleName,
                     className, "__init__")
             if not hasattr(pluginClass, "activate"):
                 raise PluginClassFormatError(
-                    module.eric5PluginModuleName,
+                    module.eric6PluginModuleName,
                     className, "activate")
             if not hasattr(pluginClass, "deactivate"):
                 raise PluginClassFormatError(
-                    module.eric5PluginModuleName,
+                    module.eric6PluginModuleName,
                     className, "deactivate")
             return True
         except PluginModuleFormatError as e:
@@ -757,7 +777,7 @@ class PluginManager(QObject):
         
         details["moduleName"] = name
         details["moduleFileName"] = getattr(
-            module, "eric5PluginModuleFilename", "")
+            module, "eric6PluginModuleFilename", "")
         details["pluginName"] = getattr(module, "name", "")
         details["version"] = getattr(module, "version", "")
         details["author"] = getattr(module, "author", "")
@@ -1026,8 +1046,8 @@ class PluginManager(QObject):
                     except (OSError, IOError) as err:
                         E5MessageBox.critical(
                             self.__ui,
-                            self.trUtf8("Plugin Manager Error"),
-                            self.trUtf8(
+                            self.tr("Plugin Manager Error"),
+                            self.tr(
                                 """<p>The plugin download directory"""
                                 """ <b>{0}</b> could not be created. Please"""
                                 """ configure it via the configuration"""
@@ -1065,18 +1085,20 @@ class PluginManager(QObject):
                 elif period == 2 and lastModifiedDate.daysTo(now) < 7:
                     # weekly
                     return
-                elif period == 3 and lastModifiedDate.month() == now.month():
+                elif period == 3 and \
+                    (lastModifiedDate.daysTo(now) <
+                     lastModifiedDate.daysInMonth()):
                     # monthly
                     return
         
         self.__updateAvailable = False
         
         request = QNetworkRequest(
-            QUrl(Preferences.getUI("PluginRepositoryUrl5")))
+            QUrl(Preferences.getUI("PluginRepositoryUrl6")))
         request.setAttribute(QNetworkRequest.CacheLoadControlAttribute,
                              QNetworkRequest.AlwaysNetwork)
         reply = self.__networkManager.get(request)
-        reply.finished[()].connect(self.__downloadRepositoryFileDone)
+        reply.finished.connect(self.__downloadRepositoryFileDone)
         self.__replies.append(reply)
     
     def __downloadRepositoryFileDone(self):
@@ -1089,11 +1111,11 @@ class PluginManager(QObject):
         if reply.error() != QNetworkReply.NoError:
             E5MessageBox.warning(
                 None,
-                self.trUtf8("Error downloading file"),
-                self.trUtf8(
+                self.tr("Error downloading file"),
+                self.tr(
                     """<p>Could not download the requested file"""
                     """ from {0}.</p><p>Error: {1}</p>"""
-                ).format(Preferences.getUI("PluginRepositoryUrl5"),
+                ).format(Preferences.getUI("PluginRepositoryUrl6"),
                          reply.errorString())
             )
             return
@@ -1110,13 +1132,13 @@ class PluginManager(QObject):
             f = QFile(self.pluginRepositoryFile)
             if f.open(QIODevice.ReadOnly):
                 # save current URL
-                url = Preferences.getUI("PluginRepositoryUrl5")
+                url = Preferences.getUI("PluginRepositoryUrl6")
                 
                 # read the repository file
                 from E5XML.PluginRepositoryReader import PluginRepositoryReader
                 reader = PluginRepositoryReader(f, self.checkPluginEntry)
                 reader.readXML()
-                if url != Preferences.getUI("PluginRepositoryUrl5"):
+                if url != Preferences.getUI("PluginRepositoryUrl6"):
                     # redo if it is a redirect
                     self.checkPluginUpdatesAvailable()
                     return
@@ -1124,10 +1146,10 @@ class PluginManager(QObject):
                 if self.__updateAvailable:
                     res = E5MessageBox.information(
                         None,
-                        self.trUtf8("New plugin versions available"),
-                        self.trUtf8("<p>There are new plug-ins or plug-in"
-                                    " updates available. Use the plug-in"
-                                    " repository dialog to get them.</p>"),
+                        self.tr("New plugin versions available"),
+                        self.tr("<p>There are new plug-ins or plug-in"
+                                " updates available. Use the plug-in"
+                                " repository dialog to get them.</p>"),
                         E5MessageBox.StandardButtons(
                             E5MessageBox.Ignore |
                             E5MessageBox.Open),
@@ -1149,11 +1171,15 @@ class PluginManager(QObject):
         @param filename data for the filename field (string)
         @param status status of the plugin (string [stable, unstable, unknown])
         """
+        # ignore hidden plug-ins
+        pluginName = os.path.splitext(url.rsplit("/", 1)[1])[0]
+        if pluginName in Preferences.getPluginManager("HiddenPlugins"):
+            return
+        
         archive = os.path.join(Preferences.getPluginManager("DownloadPath"),
                                filename)
         
         # Check against installed/loaded plug-ins
-        pluginName = os.path.splitext(url.rsplit("/", 1)[1])[0]
         pluginDetails = self.getPluginDetails(pluginName)
         if pluginDetails is None:
             if not Preferences.getPluginManager("CheckInstalledOnly"):
