@@ -1,20 +1,22 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog for plugin deinstallation.
 """
 
+from __future__ import unicode_literals
+
 import sys
 import os
 import imp
 import shutil
 import glob
 
-from PyQt4.QtCore import pyqtSlot, pyqtSignal
-from PyQt4.QtGui import QWidget, QDialog, QDialogButtonBox, QVBoxLayout
+from PyQt5.QtCore import pyqtSlot, pyqtSignal
+from PyQt5.QtWidgets import QWidget, QDialog, QDialogButtonBox, QVBoxLayout
 
 from E5Gui import E5MessageBox
 from E5Gui.E5MainWindow import E5MainWindow
@@ -39,7 +41,7 @@ class PluginUninstallWidget(QWidget, Ui_PluginUninstallDialog):
         @param pluginManager reference to the plugin manager object
         @param parent parent of this dialog (QWidget)
         """
-        super().__init__(parent)
+        super(PluginUninstallWidget, self).__init__(parent)
         self.setupUi(self)
         
         if pluginManager is None:
@@ -52,14 +54,17 @@ class PluginUninstallWidget(QWidget, Ui_PluginUninstallDialog):
             self.__external = False
         
         self.pluginDirectoryCombo.addItem(
-            self.trUtf8("User plugins directory"),
+            self.tr("User plugins directory"),
             self.__pluginManager.getPluginDir("user"))
         
         globalDir = self.__pluginManager.getPluginDir("global")
         if globalDir is not None and os.access(globalDir, os.W_OK):
             self.pluginDirectoryCombo.addItem(
-                self.trUtf8("Global plugins directory"),
+                self.tr("Global plugins directory"),
                 globalDir)
+        
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
     
     @pyqtSlot(int)
     def on_pluginDirectoryCombo_currentIndexChanged(self, index):
@@ -102,20 +107,20 @@ class PluginUninstallWidget(QWidget, Ui_PluginUninstallDialog):
         if not self.__pluginManager.unloadPlugin(pluginName):
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Plugin Uninstallation"),
-                self.trUtf8(
+                self.tr("Plugin Uninstallation"),
+                self.tr(
                     """<p>The plugin <b>{0}</b> could not be unloaded."""
                     """ Aborting...</p>""").format(pluginName))
             return False
         
-        if not pluginDirectory in sys.path:
+        if pluginDirectory not in sys.path:
             sys.path.insert(2, pluginDirectory)
         module = imp.load_source(pluginName, pluginFile)
         if not hasattr(module, "packageName"):
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Plugin Uninstallation"),
-                self.trUtf8(
+                self.tr("Plugin Uninstallation"),
+                self.tr(
                     """<p>The plugin <b>{0}</b> has no 'packageName'"""
                     """ attribute. Aborting...</p>""").format(pluginName))
             return False
@@ -167,8 +172,8 @@ class PluginUninstallWidget(QWidget, Ui_PluginUninstallDialog):
         except OSError as err:
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Plugin Uninstallation"),
-                self.trUtf8(
+                self.tr("Plugin Uninstallation"),
+                self.tr(
                     """<p>The plugin package <b>{0}</b> could not be"""
                     """ removed. Aborting...</p>"""
                     """<p>Reason: {1}</p>""").format(packageDir, str(err)))
@@ -179,8 +184,8 @@ class PluginUninstallWidget(QWidget, Ui_PluginUninstallDialog):
             if ui.notificationsEnabled():
                 ui.showNotification(
                     UI.PixmapCache.getPixmap("plugin48.png"),
-                    self.trUtf8("Plugin Uninstallation"),
-                    self.trUtf8(
+                    self.tr("Plugin Uninstallation"),
+                    self.tr(
                         """<p>The plugin <b>{0}</b> was uninstalled"""
                         """ successfully from {1}.</p>""")
                     .format(pluginName, pluginDirectory))
@@ -188,8 +193,8 @@ class PluginUninstallWidget(QWidget, Ui_PluginUninstallDialog):
         
         E5MessageBox.information(
             self,
-            self.trUtf8("Plugin Uninstallation"),
-            self.trUtf8(
+            self.tr("Plugin Uninstallation"),
+            self.tr(
                 """<p>The plugin <b>{0}</b> was uninstalled successfully"""
                 """ from {1}.</p>""")
             .format(pluginName, pluginDirectory))
@@ -207,7 +212,7 @@ class PluginUninstallDialog(QDialog):
         @param pluginManager reference to the plugin manager object
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(PluginUninstallDialog, self).__init__(parent)
         self.setSizeGripEnabled(True)
         
         self.__layout = QVBoxLayout(self)
@@ -220,8 +225,8 @@ class PluginUninstallDialog(QDialog):
         self.resize(size)
         self.setWindowTitle(self.cw.windowTitle())
         
-        self.cw.buttonBox.accepted[()].connect(self.accept)
-        self.cw.buttonBox.rejected[()].connect(self.reject)
+        self.cw.buttonBox.accepted.connect(self.accept)
+        self.cw.buttonBox.rejected.connect(self.reject)
 
 
 class PluginUninstallWindow(E5MainWindow):
@@ -234,7 +239,7 @@ class PluginUninstallWindow(E5MainWindow):
         
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(PluginUninstallWindow, self).__init__(parent)
         self.cw = PluginUninstallWidget(None, self)
         size = self.cw.size()
         self.setCentralWidget(self.cw)
@@ -244,5 +249,5 @@ class PluginUninstallWindow(E5MainWindow):
         self.setStyle(Preferences.getUI("Style"),
                       Preferences.getUI("StyleSheet"))
         
-        self.cw.buttonBox.accepted[()].connect(self.close)
-        self.cw.buttonBox.rejected[()].connect(self.close)
+        self.cw.buttonBox.accepted.connect(self.close)
+        self.cw.buttonBox.rejected.connect(self.close)
