@@ -1,13 +1,16 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing an 'About Eric' dialog.
 """
 
-from PyQt4.QtGui import QApplication, QDialog
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import QCoreApplication
+from PyQt5.QtWidgets import QDialog
 
 from .Ui_AboutDialog import Ui_AboutDialog
 
@@ -19,7 +22,7 @@ import UI.Info
 
 titleText = "<b>{0} - {1}</b>".format(UI.Info.Program, UI.Info.Version)
 
-aboutText = QApplication.translate(
+aboutText = QCoreApplication.translate(
     "AboutDialog",
     """<p>{0} is an Integrated Development Environment for the Python"""
     """ programming language. It is written using the PyQt Python bindings"""
@@ -91,7 +94,7 @@ Ralf Ahlbrink
 Stefan Jaensch
 Martin v. Löwis
 Thorsten Kohnhorst
-for providing patches to improve eric3, eric4 and eric5.
+for providing patches to improve eric3, eric4, eric5 and eric6.
 
 And all the people who reported bugs and made suggestions."""
 
@@ -739,7 +742,7 @@ class AboutDialog(QDialog, Ui_AboutDialog):
         
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(AboutDialog, self).__init__(parent)
         self.setupUi(self)
         
         self.ericLabel.setText(titleText)
