@@ -1,18 +1,21 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2011 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to show the results of the code style check.
 """
 
+from __future__ import unicode_literals
+
 import os
 import fnmatch
 
-from PyQt4.QtCore import pyqtSlot, Qt
-from PyQt4.QtGui import QDialog, QTreeWidgetItem, QAbstractButton, \
-    QDialogButtonBox, QApplication, QHeaderView, QIcon
+from PyQt5.QtCore import pyqtSlot, Qt
+from PyQt5.QtGui import QIcon
+from PyQt5.QtWidgets import QDialog, QTreeWidgetItem, QAbstractButton, \
+    QDialogButtonBox, QApplication, QHeaderView
 
 from E5Gui.E5Application import e5App
 
@@ -23,50 +26,6 @@ import Preferences
 import Utilities
 
 from . import pep8
-from .NamingStyleChecker import NamingStyleChecker
-
-# register the name checker
-pep8.register_check(NamingStyleChecker, NamingStyleChecker.Codes)
-
-from .DocStyleChecker import DocStyleChecker
-
-
-class CodeStyleCheckerReport(pep8.BaseReport):
-    """
-    Class implementing a special report to be used with our dialog.
-    """
-    def __init__(self, options):
-        """
-        Constructor
-        
-        @param options options for the report (optparse.Values)
-        """
-        super().__init__(options)
-        
-        self.__repeat = options.repeat
-        self.errors = []
-    
-    def error_args(self, line_number, offset, code, check, *args):
-        """
-        Public method to collect the error messages.
-        
-        @param line_number line number of the issue (integer)
-        @param offset position within line of the issue (integer)
-        @param code message code (string)
-        @param check reference to the checker function (function)
-        @param args arguments for the message (list)
-        @return error code (string)
-        """
-        code = super().error_args(line_number, offset, code, check, *args)
-        if code and (self.counters[code] == 1 or self.__repeat):
-            if code in NamingStyleChecker.Codes:
-                text = NamingStyleChecker.getMessage(code, *args)
-            else:
-                text = pep8.getMessage(code, *args)
-            self.errors.append(
-                (self.filename, line_number, offset, text)
-            )
-        return code
 
 
 class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
@@ -79,28 +38,41 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
     messageRole = Qt.UserRole + 4
     fixableRole = Qt.UserRole + 5
     codeRole = Qt.UserRole + 6
+    ignoredRole = Qt.UserRole + 7
     
-    def __init__(self, parent=None):
+    def __init__(self, styleCheckService, parent=None):
         """
         Constructor
         
+        @param styleCheckService reference to the service
+            (CodeStyleCheckService)
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(CodeStyleCheckerDialog, self).__init__(parent)
         self.setupUi(self)
+        self.setWindowFlags(Qt.Window)
         
-        self.docTypeComboBox.addItem(self.trUtf8("PEP-257"), "pep257")
-        self.docTypeComboBox.addItem(self.trUtf8("Eric"), "eric")
+        self.excludeMessagesSelectButton.setIcon(
+            UI.PixmapCache.getIcon("select.png"))
+        self.includeMessagesSelectButton.setIcon(
+            UI.PixmapCache.getIcon("select.png"))
+        self.fixIssuesSelectButton.setIcon(
+            UI.PixmapCache.getIcon("select.png"))
+        self.noFixIssuesSelectButton.setIcon(
+            UI.PixmapCache.getIcon("select.png"))
+        
+        self.docTypeComboBox.addItem(self.tr("PEP-257"), "pep257")
+        self.docTypeComboBox.addItem(self.tr("Eric"), "eric")
         
         self.statisticsButton = self.buttonBox.addButton(
-            self.trUtf8("Statistics..."), QDialogButtonBox.ActionRole)
+            self.tr("Statistics..."), QDialogButtonBox.ActionRole)
         self.statisticsButton.setToolTip(
-            self.trUtf8("Press to show some statistics for the last run"))
+            self.tr("Press to show some statistics for the last run"))
         self.statisticsButton.setEnabled(False)
         self.showButton = self.buttonBox.addButton(
-            self.trUtf8("Show"), QDialogButtonBox.ActionRole)
+            self.tr("Show"), QDialogButtonBox.ActionRole)
         self.showButton.setToolTip(
-            self.trUtf8("Press to show all files containing an issue"))
+            self.tr("Press to show all files containing an issue"))
         self.showButton.setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
@@ -112,6 +84,10 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         self.checkProgressLabel.setVisible(False)
         self.checkProgressLabel.setMaximumWidth(600)
         
+        self.styleCheckService = styleCheckService
+        self.styleCheckService.styleChecked.connect(self.__processResult)
+        self.filename = None
+        
         self.noResults = True
         self.cancelled = False
         self.__lastFileItem = None
@@ -121,6 +97,7 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         self.__forProject = False
         self.__data = {}
         self.__statistics = {}
+        self.__onlyFixes = {}
         
         self.on_loadDefaultButton_clicked()
     
@@ -132,7 +109,8 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
                                   self.resultList.header().sortIndicatorOrder()
                                   )
     
-    def __createResultItem(self, file, line, pos, message, fixed, autofixing):
+    def __createResultItem(self, file, line, pos, message, fixed, autofixing,
+                           ignored):
         """
         Private method to create an entry in the result list.
         
@@ -143,6 +121,7 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         @param fixed flag indicating a fixed issue (boolean)
         @param autofixing flag indicating, that we are fixing issues
             automatically (boolean)
+        @param ignored flag indicating an ignored issue (boolean)
         @return reference to the created item (QTreeWidgetItem)
         """
         from .CodeStyleFixer import FixableCodeStyleIssues
@@ -159,7 +138,7 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         itm = QTreeWidgetItem(
             self.__lastFileItem,
             ["{0:6}".format(line), code, message])
-        if code.startswith("W"):
+        if code.startswith(("W", "-")):
             itm.setIcon(1, UI.PixmapCache.getIcon("warning.png"))
         elif code.startswith("N"):
             itm.setIcon(1, UI.PixmapCache.getIcon("namingError.png"))
@@ -186,6 +165,13 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         itm.setData(0, self.messageRole, message)
         itm.setData(0, self.fixableRole, fixable)
         itm.setData(0, self.codeRole, code)
+        itm.setData(0, self.ignoredRole, ignored)
+        
+        if ignored:
+            font = itm.font(0)
+            font.setItalic(True)
+            for col in range(itm.columnCount()):
+                itm.setFont(col, font)
         
         return itm
     
@@ -199,7 +185,7 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         @param fixed flag indicating a fixed issue (boolean)
         """
         if fixed:
-            message = itm.data(0, self.messageRole) + text
+            code, message = text.split(None, 1)
             itm.setText(2, message)
             itm.setIcon(0, UI.PixmapCache.getIcon("issueFixed.png"))
             
@@ -208,16 +194,17 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             itm.setIcon(0, QIcon())
         itm.setData(0, self.fixableRole, False)
     
-    def __updateStatistics(self, statistics, fixer):
+    def __updateStatistics(self, statistics, fixer, ignoredErrors):
         """
         Private method to update the collected statistics.
         
         @param statistics dictionary of statistical data with
             message code as key and message count as value
         @param fixer reference to the code style fixer (CodeStyleFixer)
+        @param ignoredErrors number of ignored errors (integer)
         """
         self.__statistics["_FilesCount"] += 1
-        stats = {v: k for v, k in statistics.items() if v[0].isupper()}
+        stats = [k for k in statistics.keys() if k[0].isupper()]
         if stats:
             self.__statistics["_FilesIssues"] += 1
             for key in statistics:
@@ -225,8 +212,8 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
                     self.__statistics[key] += statistics[key]
                 else:
                     self.__statistics[key] = statistics[key]
-        if fixer:
-            self.__statistics["_IssuesFixed"] += fixer.fixed
+        self.__statistics["_IssuesFixed"] += fixer
+        self.__statistics["_IgnoredErrors"] += ignoredErrors
     
     def __updateFixerStatistics(self, fixer):
         """
@@ -234,7 +221,7 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         
         @param fixer reference to the code style fixer (CodeStyleFixer)
         """
-        self.__statistics["_IssuesFixed"] += fixer.fixed
+        self.__statistics["_IssuesFixed"] += fixer
     
     def __resetStatistics(self):
         """
@@ -244,6 +231,7 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         self.__statistics["_FilesCount"] = 0
         self.__statistics["_FilesIssues"] = 0
         self.__statistics["_IssuesFixed"] = 0
+        self.__statistics["_IgnoredErrors"] = 0
     
     def prepare(self, fileList, project):
         """
@@ -280,6 +268,8 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             self.__data["NoFixCodes"] = "E501"
         if "DocstringType" not in self.__data:
             self.__data["DocstringType"] = "pep257"
+        if "ShowIgnored" not in self.__data:
+            self.__data["ShowIgnored"] = False
         
         self.excludeFilesEdit.setText(self.__data["ExcludeFiles"])
         self.excludeMessagesEdit.setText(self.__data["ExcludeMessages"])
@@ -288,6 +278,7 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         self.fixIssuesEdit.setText(self.__data["FixCodes"])
         self.noFixIssuesEdit.setText(self.__data["NoFixCodes"])
         self.fixIssuesCheckBox.setChecked(self.__data["FixIssues"])
+        self.ignoredCheckBox.setChecked(self.__data["ShowIgnored"])
         self.lineLengthSpinBox.setValue(self.__data["MaxLineLength"])
         self.hangClosingCheckBox.setChecked(self.__data["HangClosing"])
         self.docTypeComboBox.setCurrentIndex(
@@ -324,44 +315,34 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             self.__fileOrFileList = fn
         
         if isinstance(fn, list):
-            files = fn[:]
+            self.files = fn[:]
         elif os.path.isdir(fn):
-            files = []
-            for ext in Preferences.getPython("Python3Extensions"):
-                files.extend(
-                    Utilities.direntries(fn, 1, '*{0}'.format(ext), 0))
-            for ext in Preferences.getPython("PythonExtensions"):
-                files.extend(
-                    Utilities.direntries(fn, 1, '*{0}'.format(ext), 0))
+            self.files = []
+            extensions = set(Preferences.getPython("PythonExtensions") +
+                             Preferences.getPython("Python3Extensions"))
+            for ext in extensions:
+                self.files.extend(Utilities.direntries(
+                    fn, True, '*{0}'.format(ext), 0))
         else:
-            files = [fn]
-        
+            self.files = [fn]
+
         # filter the list depending on the filter string
-        if files:
+        if self.files:
             filterString = self.excludeFilesEdit.text()
             filterList = [f.strip() for f in filterString.split(",")
                           if f.strip()]
             for filter in filterList:
-                files = \
-                    [f for f in files
+                self.files = \
+                    [f for f in self.files
                      if not fnmatch.fnmatch(f, filter.strip())]
-        
+
         self.__resetStatistics()
-        self.__clearErrors(files)
+        self.__clearErrors(self.files)
         
-        py3files = [f for f in files
-                    if f.endswith(
-                        tuple(Preferences.getPython("Python3Extensions")))]
-        py2files = [f for f in files
-                    if f.endswith(
-                        tuple(Preferences.getPython("PythonExtensions")))]
-        
-        if len(py3files) + len(py2files) > 0:
-            self.checkProgress.setMaximum(len(py3files) + len(py2files))
-            self.checkProgressLabel.setVisible(
-                len(py3files) + len(py2files) > 1)
-            self.checkProgress.setVisible(
-                len(py3files) + len(py2files) > 1)
+        if len(self.files) > 0:
+            self.checkProgress.setMaximum(len(self.files))
+            self.checkProgressLabel.setVisible(len(self.files) > 1)
+            self.checkProgress.setVisible(len(self.files) > 1)
             QApplication.processEvents()
             
             # extract the configuration values
@@ -371,162 +352,141 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             fixCodes = self.fixIssuesEdit.text()
             noFixCodes = self.noFixIssuesEdit.text()
             fixIssues = self.fixIssuesCheckBox.isChecked() and repeatMessages
+            self.showIgnored = self.ignoredCheckBox.isChecked() and \
+                repeatMessages
             maxLineLength = self.lineLengthSpinBox.value()
             hangClosing = self.hangClosingCheckBox.isChecked()
             docType = self.docTypeComboBox.itemData(
                 self.docTypeComboBox.currentIndex())
             
-            try:
-                # disable updates of the list for speed
-                self.resultList.setUpdatesEnabled(False)
-                self.resultList.setSortingEnabled(False)
-                
-                # now go through all the files
-                progress = 0
-                for file in sorted(py3files + py2files):
-                    self.checkProgress.setValue(progress)
-                    self.checkProgressLabel.setPath(file)
-                    QApplication.processEvents()
-                    
-                    if self.cancelled:
-                        self.__resort()
-                        return
-                    
-                    self.__lastFileItem = None
-                    
-                    try:
-                        source, encoding = Utilities.readEncodedFile(file)
-                        source = source.splitlines(True)
-                    except (UnicodeError, IOError) as msg:
-                        self.noResults = False
-                        self.__createResultItem(
-                            file, "1", "1",
-                            self.trUtf8("Error: {0}").format(str(msg))
-                            .rstrip()[1:-1], False, False)
-                        progress += 1
-                        continue
-                    
-                    stats = {}
-                    flags = Utilities.extractFlags(source)
-                    ext = os.path.splitext(file)[1]
-                    if fixIssues:
-                        from .CodeStyleFixer import CodeStyleFixer
-                        fixer = CodeStyleFixer(
-                            self.__project, file, source, fixCodes, noFixCodes,
-                            maxLineLength, True)  # always fix in place
-                    else:
-                        fixer = None
-                    if ("FileType" in flags and
-                        flags["FileType"] in ["Python", "Python2"]) or \
-                       file in py2files or \
-                       (ext in [".py", ".pyw"] and
-                        Preferences.getProject("DeterminePyFromProject") and
-                        self.__project.isOpen() and
-                        self.__project.isProjectFile(file) and
-                        self.__project.getProjectLanguage() in ["Python",
-                                                                "Python2"]):
-                        from .CodeStyleChecker import CodeStyleCheckerPy2
-                        report = CodeStyleCheckerPy2(
-                            file, [],
-                            repeat=repeatMessages,
-                            select=includeMessages,
-                            ignore=excludeMessages,
-                            max_line_length=maxLineLength,
-                            hang_closing=hangClosing,
-                            docType=docType,
-                        )
-                        errors = report.errors[:]
-                        stats.update(report.counters)
-                    else:
-                        if includeMessages:
-                            select = [s.strip() for s in
-                                      includeMessages.split(',') if s.strip()]
-                        else:
-                            select = []
-                        if excludeMessages:
-                            ignore = [i.strip() for i in
-                                      excludeMessages.split(',') if i.strip()]
-                        else:
-                            ignore = []
-                        
-                        # check coding style
-                        styleGuide = pep8.StyleGuide(
-                            reporter=CodeStyleCheckerReport,
-                            repeat=repeatMessages,
-                            select=select,
-                            ignore=ignore,
-                            max_line_length=maxLineLength,
-                            hang_closing=hangClosing,
-                        )
-                        report = styleGuide.check_files([file])
-                        stats.update(report.counters)
-                        
-                        # check documentation style
-                        docStyleChecker = DocStyleChecker(
-                            source, file, select, ignore, [], repeatMessages,
-                            maxLineLength=maxLineLength, docType=docType)
-                        docStyleChecker.run()
-                        stats.update(docStyleChecker.counters)
-                        
-                        errors = report.errors + docStyleChecker.errors
-                    
-                    deferredFixes = {}
-                    for error in errors:
-                        fname, lineno, position, text = error
-                        if lineno > len(source):
-                            lineno = len(source)
-                        if "__IGNORE_WARNING__" not in \
-                                Utilities.extractLineFlags(
-                                source[lineno - 1].strip()):
-                            self.noResults = False
-                            if fixer:
-                                res, msg, id_ = fixer.fixIssue(lineno,
-                                                               position, text)
-                                if res == 1:
-                                    text += "\n" + \
-                                            self.trUtf8("Fix: {0}").format(msg)
-                                    self.__createResultItem(
-                                        fname, lineno, position, text, True,
-                                        True)
-                                elif res == 0:
-                                    self.__createResultItem(
-                                        fname, lineno, position, text, False,
-                                        True)
-                                else:
-                                    itm = self.__createResultItem(
-                                        fname, lineno, position,
-                                        text, False, False)
-                                    deferredFixes[id_] = itm
-                            else:
-                                self.__createResultItem(
-                                    fname, lineno, position, text, False,
-                                    False)
-                    if fixer:
-                        deferredResults = fixer.finalize()
-                        for id_ in deferredResults:
-                            fixed, msg = deferredResults[id_]
-                            itm = deferredFixes[id_]
-                            if fixed == 1:
-                                text = "\n" + \
-                                    self.trUtf8("Fix: {0}").format(msg)
-                                self.__modifyFixedResultItem(itm, text, True)
-                            else:
-                                self.__modifyFixedResultItem(itm, "", False)
-                        fixer.saveFile(encoding)
-                    self.__updateStatistics(stats, fixer)
-                    progress += 1
-            finally:
-                # reenable updates of the list
-                self.resultList.setSortingEnabled(True)
-                self.resultList.setUpdatesEnabled(True)
-            self.checkProgress.setValue(progress)
+            self.__options = [excludeMessages, includeMessages, repeatMessages,
+                              fixCodes, noFixCodes, fixIssues, maxLineLength,
+                              hangClosing, docType]
+            
+            # now go through all the files
+            self.progress = 0
+            self.files.sort()
+            self.check()
+        
+    def check(self, codestring=''):
+        """
+        Public method to start a style check for one file.
+        
+        The results are reported to the __processResult slot.
+        
+        @keyparam codestring optional sourcestring (str)
+        """
+        if not self.files:
             self.checkProgressLabel.setPath("")
-            QApplication.processEvents()
-            self.__resort()
-        else:
             self.checkProgress.setMaximum(1)
             self.checkProgress.setValue(1)
-        self.__finish()
+            self.__finish()
+            return
+        
+        self.filename = self.files.pop(0)
+        self.checkProgress.setValue(self.progress)
+        self.checkProgressLabel.setPath(self.filename)
+        QApplication.processEvents()
+
+        if self.cancelled:
+            self.__resort()
+            return
+        
+        self.__lastFileItem = None
+        
+        if codestring:
+            self.source = codestring
+        else:
+            try:
+                self.source, encoding = Utilities.readEncodedFile(
+                    self.filename)
+                if encoding.endswith(
+                        ('-selected', '-default', '-guessed', '-ignore')):
+                    encoding = encoding.rsplit('-', 1)[0]
+                
+                self.source = self.source.splitlines(True)
+            except (UnicodeError, IOError) as msg:
+                self.noResults = False
+                self.__createResultItem(
+                    self.filename, 1, 1,
+                    self.tr("Error: {0}").format(str(msg))
+                        .rstrip(), False, False, False)
+                self.progress += 1
+                # Continue with next file
+                self.check()
+                return
+        
+        errors = []
+        self.__itms = []
+        for error, itm in self.__onlyFixes.pop(self.filename, []):
+            errors.append(error)
+            self.__itms.append(itm)
+        
+        eol = self.__getEol(self.filename)
+        args = self.__options + [
+            errors, eol, encoding, Preferences.getEditor("CreateBackupFile")
+        ]
+        self.styleCheckService.styleCheck(
+            None, self.filename, self.source, args)
+
+    def __processResult(self, fn, codeStyleCheckerStats, fixes, results):
+        """
+        Private slot called after perfoming a style check on one file.
+        
+        @param fn filename of the just checked file (str)
+        @param codeStyleCheckerStats stats of style and name check (dict)
+        @param fixes number of applied fixes (int)
+        @param results tuple for each found violation of style (tuple of
+            lineno (int), position (int), text (str), ignored (bool),
+            fixed (bool), autofixing (bool))
+        """
+        # Check if it's the requested file, otherwise ignore signal
+        if fn != self.filename:
+            return
+        
+        # disable updates of the list for speed
+        self.resultList.setUpdatesEnabled(False)
+        self.resultList.setSortingEnabled(False)
+        
+        fixed = None
+        ignoredErrors = 0
+        if self.__itms:
+            for itm, (lineno, position, text, ignored, fixed, autofixing) in \
+                    zip(self.__itms, results):
+                self.__modifyFixedResultItem(itm, text, fixed)
+            self.__updateFixerStatistics(fixes)
+        else:
+            for lineno, position, text, ignored, fixed, autofixing in results:
+                if ignored:
+                    ignoredErrors += 1
+                    if self.showIgnored:
+                        text = self.tr("{0} (ignored)").format(text)
+                    else:
+                        continue
+                self.noResults = False
+                self.__createResultItem(
+                    fn, lineno, position, text, fixed, autofixing, ignored)
+
+            self.__updateStatistics(
+                codeStyleCheckerStats, fixes, ignoredErrors)
+        
+        if fixed:
+            vm = e5App().getObject("ViewManager")
+            editor = vm.getOpenEditor(fn)
+            if editor:
+                editor.refresh()
+        
+        self.progress += 1
+        
+        self.__resort()
+        # reenable updates of the list
+        self.resultList.setSortingEnabled(True)
+        self.resultList.setUpdatesEnabled(True)
+        
+        self.checkProgress.setValue(self.progress)
+        QApplication.processEvents()
+        
+        self.check()
     
     def __finish(self):
         """
@@ -542,7 +502,7 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         self.startButton.setEnabled(True)
         
         if self.noResults:
-            QTreeWidgetItem(self.resultList, [self.trUtf8('No issues found.')])
+            QTreeWidgetItem(self.resultList, [self.tr('No issues found.')])
             QApplication.processEvents()
             self.statisticsButton.setEnabled(False)
             self.showButton.setEnabled(False)
@@ -555,6 +515,19 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         self.checkProgress.setVisible(False)
         self.checkProgressLabel.setVisible(False)
     
+    def __getEol(self, fn):
+        """
+        Private method to get the applicable eol string.
+        
+        @param fn filename where to determine the line ending (str)
+        @return eol string (string)
+        """
+        if self.__project.isOpen() and self.__project.isProjectFile(fn):
+            eol = self.__project.getEolString()
+        else:
+            eol = Utilities.linesep()
+        return eol
+    
     @pyqtSlot()
     def on_startButton_clicked(self):
         """
@@ -569,6 +542,7 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
                 "FixCodes": self.fixIssuesEdit.text(),
                 "NoFixCodes": self.noFixIssuesEdit.text(),
                 "FixIssues": self.fixIssuesCheckBox.isChecked(),
+                "ShowIgnored": self.ignoredCheckBox.isChecked(),
                 "MaxLineLength": self.lineLengthSpinBox.value(),
                 "HangClosing": self.hangClosingCheckBox.isChecked(),
                 "DocstringType": self.docTypeComboBox.itemData(
@@ -651,11 +625,11 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             vm.openSourceFile(fn, lineno=lineno, pos=position + 1)
             editor = vm.getOpenEditor(fn)
             
-            if code == "E901":
+            if code in ["E901", "E902"]:
                 editor.toggleSyntaxError(lineno, 0, True, message, True)
             else:
                 editor.toggleWarning(
-                    lineno, True, message, warningType=editor.WarningStyle)
+                    lineno, 0, True, message, warningType=editor.WarningStyle)
     
     @pyqtSlot()
     def on_resultList_itemSelectionChanged(self):
@@ -688,7 +662,7 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
                 lineno = citm.data(0, self.lineRole)
                 message = citm.data(0, self.messageRole)
                 editor.toggleWarning(
-                    lineno, True, message, warningType=editor.WarningStyle)
+                    lineno, 0, True, message, warningType=editor.WarningStyle)
         
         # go through the list again to clear warning markers for files,
         # that are ok
@@ -699,7 +673,7 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             errorFiles.append(
                 Utilities.normabspath(itm.data(0, self.filenameRole)))
         for file in openFiles:
-            if not file in errorFiles:
+            if file not in errorFiles:
                 editor = vm.getOpenEditor(file)
                 editor.clearStyleWarnings()
     
@@ -731,6 +705,8 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             "PEP8/NoFixCodes", "E501"))
         self.fixIssuesCheckBox.setChecked(Preferences.toBool(
             Preferences.Prefs.settings.value("PEP8/FixIssues")))
+        self.ignoredCheckBox.setChecked(Preferences.toBool(
+            Preferences.Prefs.settings.value("PEP8/ShowIgnored")))
         self.lineLengthSpinBox.setValue(int(Preferences.Prefs.settings.value(
             "PEP8/MaxLineLength", pep8.MAX_LINE_LENGTH)))
         self.hangClosingCheckBox.setChecked(Preferences.toBool(
@@ -758,6 +734,8 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             "PEP8/NoFixCodes", self.noFixIssuesEdit.text())
         Preferences.Prefs.settings.setValue(
             "PEP8/FixIssues", self.fixIssuesCheckBox.isChecked())
+        Preferences.Prefs.settings.setValue(
+            "PEP8/ShowIgnored", self.ignoredCheckBox.isChecked())
         Preferences.Prefs.settings.setValue(
             "PEP8/MaxLineLength", self.lineLengthSpinBox.value())
         Preferences.Prefs.settings.setValue(
@@ -779,6 +757,7 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         Preferences.Prefs.settings.setValue("PEP8/FixCodes", "")
         Preferences.Prefs.settings.setValue("PEP8/NoFixCodes", "E501")
         Preferences.Prefs.settings.setValue("PEP8/FixIssues", False)
+        Preferences.Prefs.settings.setValue("PEP8/ShowIgnored", False)
         Preferences.Prefs.settings.setValue(
             "PEP8/MaxLineLength", pep8.MAX_LINE_LENGTH)
         Preferences.Prefs.settings.setValue("PEP8/HangClosing", False)
@@ -817,82 +796,40 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
     def on_fixButton_clicked(self):
         """
         Private slot to fix selected issues.
-        """
-        from .CodeStyleFixer import CodeStyleFixer
         
-        # build a dictionary of issues to fix
+        Build a dictionary of issues to fix. Update the initialized __options.
+            Then call check with the dict as keyparam to fix selected issues.
+        """
         fixableItems = self.__getSelectedFixableItems()
-        fixesDict = {}      # dictionary of lists of tuples containing
-                            # the issue and the item
+        # dictionary of lists of tuples containing the issue and the item
+        fixesDict = {}
         for itm in fixableItems:
             filename = itm.data(0, self.filenameRole)
             if filename not in fixesDict:
                 fixesDict[filename] = []
             fixesDict[filename].append((
-                (itm.data(0, self.lineRole),
+                (filename, itm.data(0, self.lineRole),
                  itm.data(0, self.positionRole),
                  "{0} {1}".format(itm.data(0, self.codeRole),
                                   itm.data(0, self.messageRole))),
                 itm
             ))
+    
+        # update the configuration values (3: fixCodes, 4: noFixCodes,
+        # 5: fixIssues, 6: maxLineLength)
+        self.__options[3] = self.fixIssuesEdit.text()
+        self.__options[4] = self.noFixIssuesEdit.text()
+        self.__options[5] = True
+        self.__options[6] = self.lineLengthSpinBox.value()
         
-        # extract the configuration values
-        fixCodes = self.fixIssuesEdit.text()
-        noFixCodes = self.noFixIssuesEdit.text()
-        maxLineLength = self.lineLengthSpinBox.value()
-        
+        self.files = list(fixesDict.keys())
         # now go through all the files
-        if fixesDict:
-            self.checkProgress.setMaximum(len(fixesDict))
-            progress = 0
-            for file in fixesDict:
-                self.checkProgress.setValue(progress)
-                QApplication.processEvents()
-                
-                try:
-                    source, encoding = Utilities.readEncodedFile(file)
-                    source = source.splitlines(True)
-                except (UnicodeError, IOError) as msg:
-                    # skip silently because that should not happen
-                    progress += 1
-                    continue
-                
-                deferredFixes = {}
-                fixer = CodeStyleFixer(
-                    self.__project, file, source, fixCodes, noFixCodes,
-                    maxLineLength, True)  # always fix in place
-                errors = fixesDict[file]
-                errors.sort(key=lambda a: a[0][0])
-                for error in errors:
-                    (lineno, position, text), itm = error
-                    if lineno > len(source):
-                        lineno = len(source)
-                    fixed, msg, id_ = fixer.fixIssue(lineno, position, text)
-                    if fixed == 1:
-                        text = "\n" + self.trUtf8("Fix: {0}").format(msg)
-                        self.__modifyFixedResultItem(itm, text, True)
-                    elif fixed == 0:
-                        self.__modifyFixedResultItem(itm, "", False)
-                    else:
-                        # remember item for the deferred fix
-                        deferredFixes[id_] = itm
-                deferredResults = fixer.finalize()
-                for id_ in deferredResults:
-                    fixed, msg = deferredResults[id_]
-                    itm = deferredFixes[id_]
-                    if fixed == 1:
-                        text = "\n" + self.trUtf8("Fix: {0}").format(msg)
-                        self.__modifyFixedResultItem(itm, text, True)
-                    else:
-                        self.__modifyFixedResultItem(itm, "", False)
-                fixer.saveFile(encoding)
-                
-                self.__updateFixerStatistics(fixer)
-                progress += 1
-            
-            self.checkProgress.setValue(progress)
-            QApplication.processEvents()
-
+        self.progress = 0
+        self.files.sort()
+        self.cancelled = False
+        self.__onlyFixes = fixesDict
+        self.check()
+    
     def __getSelectedFixableItems(self):
         """
         Private method to extract all selected items for fixable issues.
@@ -904,9 +841,9 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             if itm.childCount() > 0:
                 for index in range(itm.childCount()):
                     citm = itm.child(index)
-                    if self.__itemFixable(citm) and not citm in fixableItems:
+                    if self.__itemFixable(citm) and citm not in fixableItems:
                         fixableItems.append(citm)
-            elif self.__itemFixable(itm) and not itm in fixableItems:
+            elif self.__itemFixable(itm) and itm not in fixableItems:
                 fixableItems.append(itm)
         
         return fixableItems
@@ -918,4 +855,5 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         @param itm item to be checked (QTreeWidgetItem)
         @return flag indicating a fixable issue (boolean)
         """
-        return itm.data(0, self.fixableRole)
+        return (itm.data(0, self.fixableRole) and
+                not itm.data(0, self.ignoredRole))
