@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2013 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2013 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -22,10 +22,6 @@ import tokenize
 import ast
 import sys
 
-from PyQt4.QtCore import QT_TRANSLATE_NOOP, QCoreApplication
-
-PyCF_ONLY_AST = 1024
-
 
 class DocStyleContext(object):
     """
@@ -115,134 +111,13 @@ class DocStyleChecker(object):
         
         "D203", "D205",
         "D221", "D222",
-        "D231", "D234", "D235", "D236", "D237", "D238", "D239",
+        "D231", "D232", "D234", "D235", "D236", "D237", "D238", "D239",
         "D242", "D243", "D244", "D245", "D246", "D247",
         "D250", "D251",
         
         "D901",
     ]
-    
-    Messages = {
-        "D101": QT_TRANSLATE_NOOP(
-            "DocStyleChecker", "module is missing a docstring"),
-        "D102": QT_TRANSLATE_NOOP(
-            "DocStyleChecker",
-            "public function/method is missing a docstring"),
-        "D103": QT_TRANSLATE_NOOP(
-            "DocStyleChecker",
-            "private function/method may be missing a docstring"),
-        "D104": QT_TRANSLATE_NOOP(
-            "DocStyleChecker", "public class is missing a docstring"),
-        "D105": QT_TRANSLATE_NOOP(
-            "DocStyleChecker", "private class may be missing a docstring"),
-        "D111": QT_TRANSLATE_NOOP(
-            "DocStyleChecker", 'docstring not surrounded by """'),
-        "D112": QT_TRANSLATE_NOOP(
-            "DocStyleChecker",
-            'docstring containing \\ not surrounded by r"""'),
-        "D113": QT_TRANSLATE_NOOP(
-            "DocStyleChecker",
-            'docstring containing unicode character not surrounded by u"""'),
-        "D121": QT_TRANSLATE_NOOP(
-            "DocStyleChecker", "one-liner docstring on multiple lines"),
-        "D122": QT_TRANSLATE_NOOP(
-            "DocStyleChecker", "docstring has wrong indentation"),
-        "D130": QT_TRANSLATE_NOOP(
-            "DocStyleChecker", "docstring does not contain a summary"),
-        "D131": QT_TRANSLATE_NOOP(
-            "DocStyleChecker", "docstring summary does not end with a period"),
-        "D132": QT_TRANSLATE_NOOP(
-            "DocStyleChecker",
-            "docstring summary is not in imperative mood"
-            " (Does instead of Do)"),
-        "D133": QT_TRANSLATE_NOOP(
-            "DocStyleChecker",
-            "docstring summary looks like a function's/method's signature"),
-        "D134": QT_TRANSLATE_NOOP(
-            "DocStyleChecker",
-            "docstring does not mention the return value type"),
-        "D141": QT_TRANSLATE_NOOP(
-            "DocStyleChecker",
-            "function/method docstring is separated by a blank line"),
-        "D142": QT_TRANSLATE_NOOP(
-            "DocStyleChecker",
-            "class docstring is not preceded by a blank line"),
-        "D143": QT_TRANSLATE_NOOP(
-            "DocStyleChecker",
-            "class docstring is not followed by a blank line"),
-        "D144": QT_TRANSLATE_NOOP(
-            "DocStyleChecker",
-            "docstring summary is not followed by a blank line"),
-        "D145": QT_TRANSLATE_NOOP(
-            "DocStyleChecker",
-            "last paragraph of docstring is not followed by a blank line"),
-        
-        "D203": QT_TRANSLATE_NOOP(
-            "DocStyleChecker",
-            "private function/method is missing a docstring"),
-        "D205": QT_TRANSLATE_NOOP(
-            "DocStyleChecker", "private class is missing a docstring"),
-        "D221": QT_TRANSLATE_NOOP(
-            "DocStyleChecker",
-            "leading quotes of docstring not on separate line"),
-        "D222": QT_TRANSLATE_NOOP(
-            "DocStyleChecker",
-            "trailing quotes of docstring not on separate line"),
-        "D231": QT_TRANSLATE_NOOP(
-            "DocStyleChecker", "docstring summary does not end with a period"),
-        "D234": QT_TRANSLATE_NOOP(
-            "DocStyleChecker",
-            "docstring does not contain a @return line but function/method"
-            " returns something"),
-        "D235": QT_TRANSLATE_NOOP(
-            "DocStyleChecker",
-            "docstring contains a @return line but function/method doesn't"
-            " return anything"),
-        "D236": QT_TRANSLATE_NOOP(
-            "DocStyleChecker",
-            "docstring does not contain enough @param/@keyparam lines"),
-        "D237": QT_TRANSLATE_NOOP(
-            "DocStyleChecker",
-            "docstring contains too many @param/@keyparam lines"),
-        "D238": QT_TRANSLATE_NOOP(
-            "DocStyleChecker",
-            "keyword only arguments must be documented with @keyparam lines"),
-        "D239": QT_TRANSLATE_NOOP(
-            "DocStyleChecker", "order of @param/@keyparam lines does"
-            " not match the function/method signature"),
-        "D242": QT_TRANSLATE_NOOP(
-            "DocStyleChecker", "class docstring is preceded by a blank line"),
-        "D243": QT_TRANSLATE_NOOP(
-            "DocStyleChecker", "class docstring is followed by a blank line"),
-        "D244": QT_TRANSLATE_NOOP(
-            "DocStyleChecker",
-            "function/method docstring is preceded by a blank line"),
-        "D245": QT_TRANSLATE_NOOP(
-            "DocStyleChecker",
-            "function/method docstring is followed by a blank line"),
-        "D246": QT_TRANSLATE_NOOP(
-            "DocStyleChecker",
-            "docstring summary is not followed by a blank line"),
-        "D247": QT_TRANSLATE_NOOP(
-            "DocStyleChecker",
-            "last paragraph of docstring is followed by a blank line"),
-        "D250": QT_TRANSLATE_NOOP(
-            "DocStyleChecker",
-            "docstring does not contain a @exception line but function/method"
-            " raises an exception"),
-        "D251": QT_TRANSLATE_NOOP(
-            "DocStyleChecker",
-            "docstring contains a @exception line but function/method doesn't"
-            " raise an exception"),
-        
-        "D901": QT_TRANSLATE_NOOP(
-            "DocStyleChecker", "{0}: {1}"),
-    }
 
-    MessagesSampleArgs = {
-        "D901": ["SyntaxError", "Invalid Syntax"],
-    }
-    
     def __init__(self, source, filename, select, ignore, expected, repeat,
                  maxLineLength=79, docType="pep257"):
         """
@@ -262,7 +137,7 @@ class DocStyleChecker(object):
         assert docType in ("eric", "pep257")
         
         self.__select = tuple(select)
-        self.__ignore = tuple(ignore)
+        self.__ignore = ('',) if select else tuple(ignore)
         self.__expected = expected[:]
         self.__repeat = repeat
         self.__maxLineLength = maxLineLength
@@ -333,6 +208,7 @@ class DocStyleChecker(object):
                      ("D242", "D243")),
                 ],
                 "methodDocstring": [
+                    (self.__checkEricSummary, ("D232")),
                 ],
                 "defDocstring": [
                     (self.__checkFunctionDocstring, ("D102", "D203")),
@@ -399,13 +275,9 @@ class DocStyleChecker(object):
             return
         
         if code and (self.counters[code] == 1 or self.__repeat):
-            if code in DocStyleChecker.Codes:
-                text = self.getMessage(code, *args)
-            else:
-                text = code + " " + QCoreApplication.translate(
-                    "DocStyleChecker", "no message for this code defined")
             # record the issue with one based line number
-            self.errors.append((self.__filename, lineNumber + 1, offset, text))
+            self.errors.append(
+                (self.__filename, lineNumber + 1, offset, (code, args)))
     
     def __reportInvalidSyntax(self):
         """
@@ -421,24 +293,6 @@ class DocStyleChecker(object):
         self.__error(offset[0] - 1, offset[1] or 0,
                      'D901', exc_type.__name__, exc.args[0])
     
-    @classmethod
-    def getMessage(cls, code, *args):
-        """
-        Class method to get a translated and formatted message for a
-        given code.
-        
-        @param code message code (string)
-        @param args arguments for a formatted message (list)
-        @return translated and formatted message (string)
-        """
-        if code in DocStyleChecker.Messages:
-            return code + " " + QCoreApplication.translate(
-                "DocStyleChecker",
-                DocStyleChecker.Messages[code]).format(*args)
-        else:
-            return code + " " + QCoreApplication.translate(
-                "DocStyleChecker", "no message for this code defined")
-    
     def __resetReadline(self):
         """
         Private method to reset the internal readline function.
@@ -461,7 +315,7 @@ class DocStyleChecker(object):
         Public method to check the given source for violations of doc string
         conventions.
         """
-        if not self.__source or not self.__filename:
+        if not self.__filename:
             # don't do anything, if essential data is missing
             return
         
@@ -470,7 +324,7 @@ class DocStyleChecker(object):
             return
         
         try:
-            compile(''.join(self.__source), '', 'exec', PyCF_ONLY_AST)
+            compile(''.join(self.__source), '', 'exec', ast.PyCF_ONLY_AST)
         except (SyntaxError, TypeError):
             self.__reportInvalidSyntax()
             return
@@ -591,12 +445,18 @@ class DocStyleChecker(object):
             arguments = []
             arguments.extend([arg.arg for arg in node.args.args])
             if node.args.vararg is not None:
-                arguments.append(node.args.vararg)
+                if sys.version_info[1] < 4:
+                    arguments.append(node.args.vararg)
+                else:
+                    arguments.append(node.args.vararg.arg)
             
             kwarguments = []
             kwarguments.extend([arg.arg for arg in node.args.kwonlyargs])
             if node.args.kwarg is not None:
-                kwarguments.append(node.args.kwarg)
+                if sys.version_info[1] < 4:
+                    kwarguments.append(node.args.kwarg)
+                else:
+                    kwarguments.append(node.args.kwarg.arg)
             return arguments, kwarguments
     
     ##################################################################
@@ -1018,7 +878,7 @@ class DocStyleChecker(object):
         if "return" not in docstringContext.ssource().lower():
             tokens = list(
                 tokenize.generate_tokens(StringIO(context.ssource()).readline))
-            return_ = [tokens[i + 1][0] for i,  token in enumerate(tokens)
+            return_ = [tokens[i + 1][0] for i, token in enumerate(tokens)
                        if token[1] == "return"]
             if (set(return_) -
                     set([tokenize.COMMENT, tokenize.NL, tokenize.NEWLINE]) !=
@@ -1182,7 +1042,7 @@ class DocStyleChecker(object):
         
         tokens = list(
             tokenize.generate_tokens(StringIO(context.ssource()).readline))
-        return_ = [tokens[i + 1][0] for i,  token in enumerate(tokens)
+        return_ = [tokens[i + 1][0] for i, token in enumerate(tokens)
                    if token[1] in ("return", "yield")]
         if "@return" not in docstringContext.ssource():
             if (set(return_) -
@@ -1258,7 +1118,7 @@ class DocStyleChecker(object):
         
         tokens = list(
             tokenize.generate_tokens(StringIO(context.ssource()).readline))
-        exception = [tokens[i + 1][0] for i,  token in enumerate(tokens)
+        exception = [tokens[i + 1][0] for i, token in enumerate(tokens)
                      if token[1] == "raise"]
         if "@exception" not in docstringContext.ssource() and \
                 "@throws" not in docstringContext.ssource() and \
@@ -1358,3 +1218,48 @@ class DocStyleChecker(object):
         
         if not docstrings[-2].strip():
             self.__error(docstringContext.end(), 0, "D247")
+    
+    def __checkEricSummary(self, docstringContext, context):
+        """
+        Private method to check, that method docstring summaries start with
+        specific words.
+        
+        @param docstringContext docstring context (DocStyleContext)
+        @param context context of the docstring (DocStyleContext)
+        """
+        if docstringContext is None:
+            return
+        
+        summary, lineNumber = self.__getSummaryLine(docstringContext)
+        if summary:
+            # check, if the first word is 'Constructor', 'Public',
+            # 'Protected' or 'Private'
+            functionName, arguments = context.source()[0].lstrip()\
+                .split()[1].split("(", 1)
+            firstWord = summary.strip().split(None, 1)[0].lower()
+            if functionName == '__init__':
+                if firstWord != 'constructor':
+                    self.__error(docstringContext.start() + lineNumber, 0,
+                                 "D232", 'constructor')
+            elif functionName.startswith('__') and \
+                    functionName.endswith('__'):
+                if firstWord != 'special':
+                    self.__error(docstringContext.start() + lineNumber, 0,
+                                 "D232", 'special')
+            elif functionName.startswith(('__', 'on_')):
+                if firstWord != 'private':
+                    self.__error(docstringContext.start() + lineNumber, 0,
+                                 "D232", 'private')
+            elif functionName.startswith('_') or \
+                    functionName.endswith('Event'):
+                if firstWord != 'protected':
+                    self.__error(docstringContext.start() + lineNumber, 0,
+                                 "D232", 'protected')
+            elif arguments.startswith(('cls,', 'cls)')):
+                if firstWord != 'class':
+                    self.__error(docstringContext.start() + lineNumber, 0,
+                                 "D232", 'class')
+            else:
+                if firstWord != 'public':
+                    self.__error(docstringContext.start() + lineNumber, 0,
+                                 "D232", 'public')
