@@ -1,17 +1,19 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a simple Python syntax checker.
 """
 
+from __future__ import unicode_literals
+
 import os
 import fnmatch
 
-from PyQt4.QtCore import pyqtSlot, Qt
-from PyQt4.QtGui import QDialog, QDialogButtonBox, QTreeWidgetItem, \
+from PyQt5.QtCore import pyqtSlot, Qt
+from PyQt5.QtWidgets import QDialog, QDialogButtonBox, QTreeWidgetItem, \
     QApplication, QHeaderView
 
 from E5Gui.E5Application import e5App
@@ -19,7 +21,6 @@ from E5Gui.E5Application import e5App
 from .Ui_SyntaxCheckerDialog import Ui_SyntaxCheckerDialog
 
 import Utilities
-import Preferences
 import UI.PixmapCache
 
 
@@ -39,13 +40,14 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         
         @param parent The parent widget. (QWidget)
         """
-        super().__init__(parent)
+        super(SyntaxCheckerDialog, self).__init__(parent)
         self.setupUi(self)
+        self.setWindowFlags(Qt.Window)
         
         self.showButton = self.buttonBox.addButton(
-            self.trUtf8("Show"), QDialogButtonBox.ActionRole)
+            self.tr("Show"), QDialogButtonBox.ActionRole)
         self.showButton.setToolTip(
-            self.trUtf8("Press to show all files containing an issue"))
+            self.tr("Press to show all files containing an issue"))
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
         
@@ -64,6 +66,13 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         self.checkProgressLabel.setVisible(False)
         self.checkProgressLabel.setMaximumWidth(600)
         
+        try:
+            self.syntaxCheckService = e5App().getObject('SyntaxCheckService')
+            self.syntaxCheckService.syntaxChecked.connect(self.__processResult)
+        except KeyError:
+            self.syntaxCheckService = None
+        self.filename = None
+        
     def __resort(self):
         """
         Private method to resort the tree.
@@ -133,151 +142,122 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         @param fn file or list of files or directory to be checked
                 (string or list of strings)
         @param codestring string containing the code to be checked (string).
-            If this is given, file must be a single file name.
+            If this is given, fn must be a single file name.
         """
-        if self.__project is None:
-            self.__project = e5App().getObject("Project")
-        
-        self.cancelled = False
-        self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
-        self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(True)
-        self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
-        self.checkProgress.setVisible(True)
-        QApplication.processEvents()
-        
-        if isinstance(fn, list):
-            files = fn
-        elif os.path.isdir(fn):
-            files = []
-            for ext in Preferences.getPython("Python3Extensions"):
-                files.extend(
-                    Utilities.direntries(fn, 1, '*{0}'.format(ext), 0))
-            for ext in Preferences.getPython("PythonExtensions"):
-                files.extend(
-                    Utilities.direntries(fn, 1, '*{0}'.format(ext), 0))
-        else:
-            files = [fn]
-        
-        self.__clearErrors(files)
-        
-        py3files = [f for f in files
-                    if f.endswith(
-                        tuple(Preferences.getPython("Python3Extensions")))]
-        py2files = [f for f in files
-                    if f.endswith(
-                        tuple(Preferences.getPython("PythonExtensions")))]
-        
-        if (codestring and len(py3files) == 1) or \
-           (codestring and len(py2files) == 1) or \
-           (not codestring and len(py3files) + len(py2files) > 0):
-            self.checkProgress.setMaximum(len(py3files) + len(py2files))
-            self.checkProgressLabel.setVisible(
-                len(py3files) + len(py2files) > 1)
-            self.checkProgress.setVisible(
-                len(py3files) + len(py2files) > 1)
+        if self.syntaxCheckService is not None:
+            if self.__project is None:
+                self.__project = e5App().getObject("Project")
+            
+            self.cancelled = False
+            self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
+            self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(True)
+            self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
+            self.checkProgress.setVisible(True)
             QApplication.processEvents()
             
-            ignoreStarImportWarnings = \
-                Preferences.getFlakes("IgnoreStarImportWarnings")
+            if isinstance(fn, list):
+                self.files = fn
+            elif os.path.isdir(fn):
+                self.files = []
+                for ext in self.syntaxCheckService.getExtensions():
+                    self.files.extend(
+                        Utilities.direntries(fn, True, '*{0}'.format(ext), 0))
+            else:
+                self.files = [fn]
             
-            # now go through all the files
-            progress = 0
-            for file in py3files + py2files:
-                self.checkProgress.setValue(progress)
-                self.checkProgressLabel.setPath(file)
+            self.__clearErrors(self.files)
+            
+            if codestring or len(self.files) > 0:
+                self.checkProgress.setMaximum(max(1, len(self.files)))
+                self.checkProgress.setVisible(len(self.files) > 1)
+                self.checkProgressLabel.setVisible(len(self.files) > 1)
                 QApplication.processEvents()
-                self.__resort()
-                
-                if self.cancelled:
-                    return
-                
-                self.__lastFileItem = None
-                
-                if codestring:
-                    source = codestring
-                else:
-                    try:
-                        source = Utilities.readEncodedFile(file)[0]
-                        # convert eols
-                        source = Utilities.convertLineEnds(source, "\n")
-                    except (UnicodeError, IOError) as msg:
-                        self.noResults = False
-                        self.__createResultItem(
-                            file, "1", 0,
-                            self.trUtf8("Error: {0}").format(str(msg))
-                            .rstrip()[1:-1], "")
-                        progress += 1
-                        continue
-                
-                flags = Utilities.extractFlags(source)
-                ext = os.path.splitext(file)[1]
-                if ("FileType" in flags and
-                    flags["FileType"] in ["Python", "Python2"]) or \
-                   file in py2files or \
-                   (ext in [".py", ".pyw"] and
-                    Preferences.getProject("DeterminePyFromProject") and
-                    self.__project.isOpen() and
-                    self.__project.isProjectFile(file) and
-                    self.__project.getProjectLanguage() in ["Python",
-                                                            "Python2"]):
-                    isPy3 = False
-                    nok, fname, line, index, code, error, warnings = \
-                        Utilities.py2compile(
-                            file,
-                            checkFlakes=Preferences.getFlakes(
-                                "IncludeInSyntaxCheck"))
-                else:
-                    isPy3 = True
-                    nok, fname, line, index, code, error = \
-                        Utilities.compile(file, source)
-                if nok:
-                    self.noResults = False
-                    self.__createResultItem(fname, line, index, error, code)
-                else:
-                    if Preferences.getFlakes("IncludeInSyntaxCheck"):
-                        if isPy3:
-                            try:
-                                from Utilities.py3flakes.checker import Checker
-                                from Utilities.py3flakes.messages import \
-                                    ImportStarUsed
-                                sourceLines = source.splitlines()
-                                warnings = Checker(source, file)
-                                warnings.messages.sort(key=lambda a: a.lineno)
-                                for warning in warnings.messages:
-                                    if ignoreStarImportWarnings and \
-                                       isinstance(warning, ImportStarUsed):
-                                        continue
-                                    fname, lineno, message = \
-                                        warning.getMessageData()
-                                    if "__IGNORE_WARNING__" not in \
-                                        Utilities.extractLineFlags(
-                                            sourceLines[lineno - 1].strip()):
-                                        self.noResults = False
-                                        self.__createResultItem(
-                                            fname, lineno, 0, message, "",
-                                            isWarning=True)
-                            except SyntaxError as err:
-                                if err.text.strip():
-                                    msg = err.text.strip()
-                                else:
-                                    msg = err.msg
-                                self.__createResultItem(
-                                    err.filename, err.lineno, 0, msg, "")
-                        else:
-                            for warning in warnings:
-                                self.noResults = False
-                                self.__createResultItem(
-                                    warning[0], int(warning[1]), 0,
-                                    warning[2], "", isWarning=True)
-                progress += 1
-            self.checkProgress.setValue(progress)
-            self.checkProgressLabel.setPath("")
-            QApplication.processEvents()
-            self.__resort()
+
+                # now go through all the files
+                self.progress = 0
+                self.check(codestring)
+    
+    def check(self, codestring=''):
+        """
+        Public method to start a check for one file.
+        
+        The results are reported to the __processResult slot.
+        @keyparam codestring optional sourcestring (str)
+        """
+        if self.syntaxCheckService is None or not self.files:
+            self.__finish()
+            return
+        
+        self.filename = self.files.pop(0)
+        self.checkProgress.setValue(self.progress)
+        self.checkProgressLabel.setPath(self.filename)
+        QApplication.processEvents()
+        self.__resort()
+        
+        if self.cancelled:
+            return
+        
+        self.__lastFileItem = None
+        
+        if codestring:
+            self.source = codestring
         else:
+            try:
+                self.source = Utilities.readEncodedFile(self.filename)[0]
+                self.source = Utilities.normalizeCode(self.source)
+            except (UnicodeError, IOError) as msg:
+                self.noResults = False
+                self.__createResultItem(
+                    self.filename, 1, 0,
+                    self.tr("Error: {0}").format(str(msg))
+                    .rstrip(), "")
+                self.progress += 1
+                # Continue with next file
+                self.check()
+                return
+        
+        self.syntaxCheckService.syntaxCheck(None, self.filename, self.source)
+
+    def __processResult(self, fn, problems):
+        """
+        Private slot to display the reported messages.
+        
+        @param fn filename of the checked file (str)
+        @param problems dictionary with the keys 'error' and 'warnings' which
+            hold a list containing details about the error/ warnings
+            (file name, line number, column, codestring (only at syntax
+            errors), the message) (dict)
+        """
+        # Check if it's the requested file, otherwise ignore signal
+        if fn != self.filename:
+            return
+
+        error = problems.get('error')
+        if error:
+            self.noResults = False
+            _fn, lineno, col, code, msg = error
+            self.__createResultItem(_fn, lineno, col, msg, code, False)
+        
+        warnings = problems.get('warnings', [])
+        if warnings:
+            source = self.source.splitlines()
+        for _fn, lineno, col, code, msg in warnings:
+            self.noResults = False
+            scr_line = source[lineno - 1].strip()
+            self.__createResultItem(_fn, lineno, col, msg, scr_line, True)
+
+        self.progress += 1
+        self.checkProgress.setValue(self.progress)
+        QApplication.processEvents()
+        self.__resort()
+
+        if self.files:
+            self.check()
+        else:
+            self.checkProgressLabel.setPath("")
             self.checkProgress.setMaximum(1)
             self.checkProgress.setValue(1)
-        self.__finish()
+            self.__finish()
         
     def __finish(self):
         """
@@ -290,7 +270,7 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         self.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
         
         if self.noResults:
-            QTreeWidgetItem(self.resultList, [self.trUtf8('No issues found.')])
+            QTreeWidgetItem(self.resultList, [self.tr('No issues found.')])
             QApplication.processEvents()
             self.showButton.setEnabled(False)
         else:
@@ -360,7 +340,7 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
             editor = vm.getOpenEditor(fn)
             
             if itm.data(0, self.warningRole):
-                editor.toggleWarning(lineno, True, error)
+                editor.toggleWarning(lineno, 0, True, error)
             else:
                 editor.toggleSyntaxError(lineno, index, True, error, show=True)
         else:
@@ -374,7 +354,7 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
                 index = citm.data(0, self.indexRole)
                 error = citm.data(0, self.errorRole)
                 if citm.data(0, self.warningRole):
-                    editor.toggleWarning(lineno, True, error)
+                    editor.toggleWarning(lineno, 0, True, error)
                 else:
                     editor.toggleSyntaxError(
                         lineno, index, True, error, show=True)
@@ -405,7 +385,7 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
                 index = citm.data(0, self.indexRole)
                 error = citm.data(0, self.errorRole)
                 if citm.data(0, self.warningRole):
-                    editor.toggleWarning(lineno, True, error)
+                    editor.toggleWarning(lineno, 0, True, error)
                 else:
                     editor.toggleSyntaxError(
                         lineno, index, True, error, show=True)
@@ -419,7 +399,7 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
             errorFiles.append(
                 Utilities.normabspath(itm.data(0, self.filenameRole)))
         for file in openFiles:
-            if not file in errorFiles:
+            if file not in errorFiles:
                 editor = vm.getOpenEditor(file)
                 editor.clearSyntaxError()
                 editor.clearFlakesWarnings()
