@@ -13,11 +13,13 @@ Warning: The API provided by this module is likely to change in future
 releases; such changes may not be backward compatible.
 
 This is a modified version to make the original tabnanny better suitable
-for being called from within the eric5 IDE.
+for being called from within the eric6 IDE.
 
 @exception ValueError The tokenize module is too old.
 """
 
+from __future__ import unicode_literals
+
 # Released to the public domain, by Tim Peters, 15 April 1998.
 
 # XXX Note: this is now a standard library module.
@@ -26,7 +28,7 @@ for being called from within the eric5 IDE.
 
 #
 # This is a modified version to make the original tabnanny better suitable
-# for being called from within the eric5 IDE. The modifications are as
+# for being called from within the eric6 IDE. The modifications are as
 # follows:
 #
 # - there is no main function anymore
@@ -35,16 +37,17 @@ for being called from within the eric5 IDE.
 #   linenumber and the error message (boolean, string, string, string). The
 #   values are only valid, if the status equals 1.
 #
-# Mofifications Copyright (c) 2003-2014 Detlev Offenbach
+# Mofifications Copyright (c) 2003-2015 Detlev Offenbach
 # <detlev@die-offenbachs.de>
 #
 
 __version__ = "6_eric"
 
 import tokenize
-import io
-
-import Utilities
+try:
+    import StringIO as io
+except (ImportError):
+    import io    # __IGNORE_WARNING__
 
 if not hasattr(tokenize, 'NL'):
     raise ValueError("tokenize.NL doesn't exist -- tokenize module too old")
@@ -52,6 +55,15 @@ if not hasattr(tokenize, 'NL'):
 __all__ = ["check", "NannyNag", "process_tokens"]
 
 
+def initService():
+    """
+    Initialize the service and return the entry point.
+    
+    @return the entry point for the background client (function)
+    """
+    return check
+
+
 class NannyNag(Exception):
     """
     Class implementing an exception for indentation issues.
@@ -71,7 +83,7 @@ class NannyNag(Exception):
         
     def get_lineno(self):
         """
-        Method to retrieve the line number.
+        Public method to retrieve the line number.
         
         @return The line number (integer)
         """
@@ -79,7 +91,7 @@ class NannyNag(Exception):
         
     def get_msg(self):
         """
-        Method to retrieve the message.
+        Public method to retrieve the message.
         
         @return The error message (string)
         """
@@ -87,7 +99,7 @@ class NannyNag(Exception):
         
     def get_line(self):
         """
-        Method to retrieve the offending line.
+        Public method to retrieve the offending line.
         
         @return The line of code (string)
         """
@@ -109,36 +121,29 @@ def check(file, text=""):
     global indents, check_equal
     indents = [Whitespace("")]
     check_equal = 0
-    
     if not text:
-        try:
-            text = Utilities.readEncodedFile(file)[0]
-        except (UnicodeError, IOError) as msg:
-            return (True, file, "1", "Error: {0}".format(str(msg)))
-            
-        # convert eols
-        text = Utilities.convertLineEnds(text, "\n")
+        return (True, "1", "Error: source code missing.")
     
     source = io.StringIO(text)
     try:
         process_tokens(tokenize.generate_tokens(source.readline))
     
     except tokenize.TokenError as msg:
-        return (True, file, "1", "Token Error: {0}".format(str(msg)))
+        return (True, "1", "Token Error: {0}".format(str(msg)))
     
     except IndentationError as err:
-        return (True, file, err.lineno,
+        return (True, str(err.lineno),
                 "Indentation Error: {0}".format(str(err.msg)))
     
     except NannyNag as nag:
         badline = nag.get_lineno()
         line = nag.get_line()
-        return (True, file, str(badline), line)
+        return (True, str(badline), line)
     
     except Exception as err:
-        return (True, file, "1", "Unspecific Error: {0}".format(str(err)))
+        return (True, "1", "Unspecific Error: {0}".format(str(err)))
     
-    return (False, None, None, None)
+    return (False, None, None)
 
 
 class Whitespace(object):
@@ -199,7 +204,8 @@ class Whitespace(object):
     # preceding a tab)
     def longest_run_of_spaces(self):
         """
-        Method to calculate the length of longest contiguous run of spaces.
+        Public method to calculate the length of longest contiguous run of
+        spaces.
         
         @return The length of longest contiguous run of spaces (whether or not
             preceding a tab)
@@ -209,7 +215,7 @@ class Whitespace(object):
 
     def indent_level(self, tabsize):
         """
-        Method to determine the indentation level.
+        Public method to determine the indentation level.
         
         @param tabsize The length of a tab stop. (integer)
         @return indentation level (integer)
@@ -238,8 +244,8 @@ class Whitespace(object):
     # for all t >= 1
     def equal(self, other):
         """
-        Method to compare the indentation levels of two Whitespace objects for
-        equality.
+        Public method to compare the indentation levels of two Whitespace
+        objects for equality.
         
         @param other Whitespace object to compare against.
         @return True, if we compare equal against the other Whitespace object.
@@ -252,7 +258,7 @@ class Whitespace(object):
     # case it will return at least one witnessing tab size.
     def not_equal_witness(self, other):
         """
-        Method to calculate a tuple of witnessing tab size.
+        Public method to calculate a tuple of witnessing tab size.
         
         Intended to be used after not self.equal(other) is known, in which
         case it will return at least one witnessing tab size.
@@ -286,8 +292,8 @@ class Whitespace(object):
     # Note that M is of the form (T*)(S*) iff len(M.norm[0]) <= 1.
     def less(self, other):
         """
-        Method to compare the indentation level against another Whitespace
-        objects to be smaller.
+        Public method to compare the indentation level against another
+        Whitespace objects to be smaller.
         
         @param other Whitespace object to compare against.
         @return True, if we compare less against the other Whitespace object.
@@ -310,7 +316,7 @@ class Whitespace(object):
     # case it will return at least one witnessing tab size.
     def not_less_witness(self, other):
         """
-        Method to calculate a tuple of witnessing tab size.
+        Public method to calculate a tuple of witnessing tab size.
         
         Intended to be used after not self.less(other is known, in which
         case it will return at least one witnessing tab size.
