@@ -1,16 +1,22 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to show the output of the ericapi process.
 """
 
+from __future__ import unicode_literals
+try:
+    str = unicode
+except NameError:
+    pass
+
 import os.path
 
-from PyQt4.QtCore import QProcess, QTimer
-from PyQt4.QtGui import QDialog, QDialogButtonBox
+from PyQt5.QtCore import QProcess, QTimer
+from PyQt5.QtWidgets import QDialog, QDialogButtonBox
 
 from E5Gui import E5MessageBox
 
@@ -33,7 +39,7 @@ class EricapiExecDialog(QDialog, Ui_EricapiExecDialog):
         @param cmdname name of the ericapi generator (string)
         @param parent parent widget of this dialog (QWidget)
         """
-        super().__init__(parent)
+        super(EricapiExecDialog, self).__init__(parent)
         self.setModal(True)
         self.setupUi(self)
         
@@ -80,14 +86,14 @@ class EricapiExecDialog(QDialog, Ui_EricapiExecDialog):
         self.process.finished.connect(self.__finish)
             
         self.setWindowTitle(
-            self.trUtf8('{0} - {1}').format(self.cmdname, self.filename))
+            self.tr('{0} - {1}').format(self.cmdname, self.filename))
         self.process.start(program, args)
         procStarted = self.process.waitForStarted(5000)
         if not procStarted:
             E5MessageBox.critical(
                 self,
-                self.trUtf8('Process Generation Error'),
-                self.trUtf8(
+                self.tr('Process Generation Error'),
+                self.tr(
                     'The process {0} could not be started. '
                     'Ensure, that it is in the search path.'
                 ).format(program))
@@ -124,7 +130,7 @@ class EricapiExecDialog(QDialog, Ui_EricapiExecDialog):
         self.process = None
         
         self.contents.insertPlainText(
-            self.trUtf8('\n{0} finished.\n').format(self.cmdname))
+            self.tr('\n{0} finished.\n').format(self.cmdname))
         self.contents.ensureCursorVisible()
         
     def __readStdout(self):
