@@ -1,33 +1,37 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
-Module implementing a dialog to enter the parameters for eric5_doc.
+Module implementing a dialog to enter the parameters for eric6_doc.
 """
 
+from __future__ import unicode_literals
+
 import sys
 import os
 import copy
 
-from PyQt4.QtCore import pyqtSlot
-from PyQt4.QtGui import QDialog, QDialogButtonBox, QColorDialog, QColor
+from PyQt5.QtCore import pyqtSlot
+from PyQt5.QtGui import QColor
+from PyQt5.QtWidgets import QDialog, QDialogButtonBox, QColorDialog
 
 from E5Gui.E5Completers import E5DirCompleter
 from E5Gui import E5FileDialog
 
 from .Ui_EricdocConfigDialog import Ui_EricdocConfigDialog
-from DocumentationTools.Config import eric5docDefaultColors, \
-    eric5docColorParameterNames
+from DocumentationTools.Config import eric6docDefaultColors, \
+    eric6docColorParameterNames
 import Utilities
+import UI.PixmapCache
 
-from eric5config import getConfig
+from eric6config import getConfig
 
 
 class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
     """
-    Class implementing a dialog to enter the parameters for eric5_doc.
+    Class implementing a dialog to enter the parameters for eric6_doc.
     """
     def __init__(self, project, parms=None, parent=None):
         """
@@ -37,14 +41,19 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         @param parms parameters to set in the dialog
         @param parent parent widget of this dialog
         """
-        super().__init__(parent)
+        super(EricdocConfigDialog, self).__init__(parent)
         self.setupUi(self)
         
+        self.outputDirButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        self.ignoreDirButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        self.cssButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        self.qtHelpDirButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        
         self.__okButton = self.buttonBox.button(QDialogButtonBox.Ok)
         
         self.__initializeDefaults()
         
-        self.sampleText = self.trUtf8(
+        self.sampleText = self.tr(
             '''<?xml version="1.0" encoding="utf-8"?>'''
             '''<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"'''
             '''"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">'''
@@ -68,7 +77,7 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         
         # get a copy of the defaults to store the user settings
         self.parameters = copy.deepcopy(self.defaults)
-        self.colors = eric5docDefaultColors.copy()
+        self.colors = eric6docDefaultColors.copy()
         
         # combine it with the values of parms
         if parms is not None:
@@ -166,7 +175,7 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         # 1. the program name
         args.append(sys.executable)
         args.append(
-            Utilities.normabsjoinpath(getConfig('ericDir'), "eric5_doc.py"))
+            Utilities.normabsjoinpath(getConfig('ericDir'), "eric6_doc.py"))
         
         # 2. the commandline options
         # 2a. general commandline options
@@ -181,6 +190,9 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
             else:
                 args.append(os.path.join(
                     self.ppath, self.parameters['outputDirectory']))
+        else:
+            self.parameters['outputDirectory'] = \
+                self.defaults['outputDirectory']
         if self.parameters['ignoreDirectories'] != \
                 self.defaults['ignoreDirectories']:
             parms['ignoreDirectories'] = \
@@ -224,10 +236,10 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
                 args.append(
                     os.path.join(self.ppath, self.parameters['cssFile']))
         for key, value in list(self.colors.items()):
-            if self.colors[key] != eric5docDefaultColors[key]:
+            if self.colors[key] != eric6docDefaultColors[key]:
                 parms[key] = self.colors[key]
                 args.append("--{0}={1}".format(
-                    eric5docColorParameterNames[key], self.colors[key]))
+                    eric6docColorParameterNames[key], self.colors[key]))
         
         # 2c. QtHelp commandline options
         parms['qtHelpEnabled'] = self.parameters['qtHelpEnabled']
@@ -287,10 +299,13 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         It displays a directory selection dialog to
         select the directory the documentations is written to.
         """
+        startDir = Utilities.fromNativeSeparators(self.outputDirEdit.text())
+        if not startDir:
+            startDir = Utilities.fromNativeSeparators(self.ppath)
         directory = E5FileDialog.getExistingDirectory(
             self,
-            self.trUtf8("Select output directory"),
-            self.outputDirEdit.text(),
+            self.tr("Select output directory"),
+            startDir,
             E5FileDialog.Options(E5FileDialog.ShowDirsOnly))
             
         if directory:
@@ -309,12 +324,12 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         It displays a directory selection dialog to
         select a directory to be ignored.
         """
-        startDir = self.ignoreDirEdit.text()
+        startDir = Utilities.fromNativeSeparators(self.ignoreDirEdit.text())
         if not startDir:
             startDir = self.ppath
         directory = E5FileDialog.getExistingDirectory(
             self,
-            self.trUtf8("Select directory to exclude"),
+            self.tr("Select directory to exclude"),
             startDir,
             E5FileDialog.Options(E5FileDialog.ShowDirsOnly))
             
@@ -354,9 +369,9 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         """
         cssFile = E5FileDialog.getOpenFileName(
             self,
-            self.trUtf8("Select CSS style sheet"),
+            self.tr("Select CSS style sheet"),
             getConfig('ericCSSDir'),
-            self.trUtf8("Style sheet (*.css);;All files (*)"))
+            self.tr("Style sheet (*.css);;All files (*)"))
             
         if cssFile:
             # make it relative, if it is in a subdirectory of the project path
@@ -503,7 +518,7 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         """
         directory = E5FileDialog.getExistingDirectory(
             self,
-            self.trUtf8("Select output directory for QtHelp files"),
+            self.tr("Select output directory for QtHelp files"),
             self.qtHelpDirEdit.text(),
             E5FileDialog.Options(E5FileDialog.ShowDirsOnly))
             
@@ -517,7 +532,7 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
     
     def accept(self):
         """
-        Protected slot called by the Ok button.
+        Public slot called by the Ok button.
         
         It saves the values in the parameters dictionary.
         """
@@ -558,4 +573,4 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
             self.qtHelpGenerateCollectionCheckBox.isChecked()
         
         # call the accept slot of the base class
-        super().accept()
+        super(EricdocConfigDialog, self).accept()
