@@ -1,16 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Ericdoc plugin.
 """
 
+from __future__ import unicode_literals
+
 import os
 
-from PyQt4.QtCore import QObject
-from PyQt4.QtGui import QDialog, QApplication
+from PyQt5.QtCore import QObject, QCoreApplication
+from PyQt5.QtWidgets import QDialog
 
 from E5Gui.E5Application import e5App
 
@@ -18,14 +20,14 @@ from E5Gui.E5Action import E5Action
 
 import Utilities
 
-from eric5config import getConfig
+from eric6config import getConfig
 
 # Start-Of-Header
 name = "Ericdoc Plugin"
 author = "Detlev Offenbach <detlev@die-offenbachs.de>"
 autoactivate = True
 deactivateable = True
-version = "5.4.0"
+version = "6.0.0"
 className = "EricdocPlugin"
 packageName = "__core__"
 shortDescription = "Show the Ericdoc dialogs."
@@ -33,6 +35,7 @@ longDescription = """This plugin implements the Ericdoc dialogs.""" \
     """ Ericdoc is used to generate a source code documentation""" \
     """ for Python and Ruby projects."""
 pyqtApi = 2
+python2Compatible = True
 # End-Of-Header
 
 error = ""
@@ -47,17 +50,17 @@ def exeDisplayDataList():
     """
     dataList = []
     
-    # 1. eric5_doc
-    exe = 'eric5_doc'
+    # 1. eric6_doc
+    exe = 'eric6_doc'
     if Utilities.isWindowsPlatform():
         exe = os.path.join(getConfig("bindir"), exe + '.bat')
     dataList.append({
         "programEntry": True,
-        "header": QApplication.translate(
-            "EricdocPlugin", "Eric5 Documentation Generator"),
+        "header": QCoreApplication.translate(
+            "EricdocPlugin", "Eric6 Documentation Generator"),
         "exe": exe,
         "versionCommand": '--version',
-        "versionStartsWith": 'eric5_',
+        "versionStartsWith": 'eric6_',
         "versionPosition": -3,
         "version": "",
         "versionCleanup": None,
@@ -69,7 +72,7 @@ def exeDisplayDataList():
         exe += '.exe'
     dataList.append({
         "programEntry": True,
-        "header": QApplication.translate(
+        "header": QCoreApplication.translate(
             "EricdocPlugin", "Qt Help Tools"),
         "exe": exe,
         "versionCommand": '-v',
@@ -85,7 +88,7 @@ def exeDisplayDataList():
         exe += '.exe'
     dataList.append({
         "programEntry": True,
-        "header": QApplication.translate(
+        "header": QCoreApplication.translate(
             "EricdocPlugin", "Qt Help Tools"),
         "exe": exe,
         "versionCommand": '-v',
@@ -108,7 +111,7 @@ class EricdocPlugin(QObject):
         
         @param ui reference to the user interface object (UI.UserInterface)
         """
-        super().__init__(ui)
+        super(EricdocPlugin, self).__init__(ui)
         self.__ui = ui
         self.__initialize()
         
@@ -128,16 +131,16 @@ class EricdocPlugin(QObject):
         if menu:
             self.__projectAct = \
                 E5Action(
-                    self.trUtf8('Generate documentation (eric5_doc)'),
-                    self.trUtf8('Generate &documentation (eric5_doc)'), 0, 0,
-                    self, 'doc_eric5_doc')
+                    self.tr('Generate documentation (eric6_doc)'),
+                    self.tr('Generate &documentation (eric6_doc)'), 0, 0,
+                    self, 'doc_eric6_doc')
             self.__projectAct.setStatusTip(
-                self.trUtf8('Generate API documentation using eric5_doc'))
-            self.__projectAct.setWhatsThis(self.trUtf8(
+                self.tr('Generate API documentation using eric6_doc'))
+            self.__projectAct.setWhatsThis(self.tr(
                 """<b>Generate documentation</b>"""
-                """<p>Generate API documentation using eric5_doc.</p>"""
+                """<p>Generate API documentation using eric6_doc.</p>"""
             ))
-            self.__projectAct.triggered[()].connect(self.__doEricdoc)
+            self.__projectAct.triggered.connect(self.__doEricdoc)
             e5App().getObject("Project").addE5Actions([self.__projectAct])
             menu.addAction(self.__projectAct)
         
@@ -174,7 +177,7 @@ class EricdocPlugin(QObject):
     
     def __doEricdoc(self):
         """
-        Private slot to perform the eric5_doc api documentation generation.
+        Private slot to perform the eric6_doc api documentation generation.
         """
         from DocumentationPlugins.Ericdoc.EricdocConfigDialog import \
             EricdocConfigDialog
@@ -205,7 +208,7 @@ class EricdocPlugin(QObject):
             
             outdir = Utilities.toNativeSeparators(parms['outputDirectory'])
             if outdir == '':
-                outdir = 'doc'      # that is eric5_docs default output dir
+                outdir = 'doc'      # that is eric6_docs default output dir
                 
             # add it to the project data, if it isn't in already
             outdir = project.getRelativePath(outdir)
@@ -218,8 +221,8 @@ class EricdocPlugin(QObject):
                 outdir = Utilities.toNativeSeparators(
                     parms['qtHelpOutputDirectory'])
                 if outdir == '':
-                    outdir = 'help'      # that is eric5_docs default QtHelp
-                                         # output dir
+                    outdir = 'help'
+                    # that is eric6_docs default QtHelp output dir
                     
                 # add it to the project data, if it isn't in already
                 outdir = project.getRelativePath(outdir)
