@@ -1,19 +1,22 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Tabnanny plugin.
 """
 
+from __future__ import unicode_literals
+
 import os
 
-from PyQt4.QtCore import QObject
+from PyQt5.QtCore import QObject, pyqtSignal
 
 from E5Gui.E5Application import e5App
-
 from E5Gui.E5Action import E5Action
+from Project.ProjectBrowserModel import ProjectBrowserFileItem
+from Utilities import determinePythonVersion
 
 import Preferences
 
@@ -22,7 +25,7 @@ name = "Tabnanny Plugin"
 author = "Detlev Offenbach <detlev@die-offenbachs.de>"
 autoactivate = True
 deactivateable = True
-version = "5.4.0"
+version = "6.0.0"
 className = "TabnannyPlugin"
 packageName = "__core__"
 shortDescription = "Show the Tabnanny dialog."
@@ -30,6 +33,7 @@ longDescription = """This plugin implements the Tabnanny dialog.""" \
     """ Tabnanny is used to check Python source files for correct""" \
     """ indentations."""
 pyqtApi = 2
+python2Compatible = True
 # End-Of-Header
 
 error = ""
@@ -38,17 +42,68 @@ error = ""
 class TabnannyPlugin(QObject):
     """
     Class implementing the Tabnanny plugin.
+    
+    @signal indentChecked(str, bool, str, str) emited when the indent
+        check was done.
     """
+    indentChecked = pyqtSignal(str, bool, str, str)
+    
     def __init__(self, ui):
         """
         Constructor
         
         @param ui reference to the user interface object (UI.UserInterface)
         """
-        super().__init__(ui)
+        super(TabnannyPlugin, self).__init__(ui)
         self.__ui = ui
         self.__initialize()
         
+        self.backgroundService = e5App().getObject("BackgroundService")
+        
+        path = os.path.join(
+            os.path.dirname(__file__), 'CheckerPlugins', 'Tabnanny')
+        self.backgroundService.serviceConnect(
+            'indent', 'Python2', path, 'Tabnanny',
+            lambda *args: self.indentChecked.emit(*args),
+            onErrorCallback=self.serviceErrorPy2)
+        self.backgroundService.serviceConnect(
+            'indent', 'Python3', path, 'Tabnanny',
+            lambda *args: self.indentChecked.emit(*args),
+            onErrorCallback=self.serviceErrorPy3)
+    
+    def __serviceError(self, fn, msg):
+        """
+        Private slot handling service errors.
+        
+        @param fn file name (string)
+        @param msg message text (string)
+        """
+        self.indentChecked.emit(fn, True, "1", msg)
+    
+    def serviceErrorPy2(self, fx, lang, fn, msg):
+        """
+        Public method handling service errors for Python 2.
+        
+        @param fx service name (string)
+        @param lang language (string)
+        @param fn file name (string)
+        @param msg message text (string)
+        """
+        if fx == 'indent' and lang == 'Python2':
+            self.__serviceError(fn, msg)
+    
+    def serviceErrorPy3(self, fx, lang, fn, msg):
+        """
+        Public method handling service errors for Python 2.
+        
+        @param fx service name (string)
+        @param lang language (string)
+        @param fn file name (string)
+        @param msg message text (string)
+        """
+        if fx == 'indent' and lang == 'Python3':
+            self.__serviceError(fn, msg)
+    
     def __initialize(self):
         """
         Private slot to (re)initialize the plugin.
@@ -64,6 +119,23 @@ class TabnannyPlugin(QObject):
         self.__editorAct = None
         self.__editorTabnannyDialog = None
 
+    def indentCheck(self, lang, filename, source):
+        """
+        Public method to prepare a style check on one Python source file.
+
+        @param lang language of the file or None to determine by internal
+            algorithm (str or None)
+        @param filename source filename (string)
+        @param source string containing the code to check (string)
+        """
+        if lang is None:
+            lang = 'Python{0}'.format(determinePythonVersion(filename, source))
+        if lang not in ['Python2', 'Python3']:
+            return
+        
+        self.backgroundService.enqueueRequest(
+            'indent', lang, filename, [source])
+
     def activate(self):
         """
         Public method to activate this plugin.
@@ -73,30 +145,30 @@ class TabnannyPlugin(QObject):
         menu = e5App().getObject("Project").getMenu("Checks")
         if menu:
             self.__projectAct = E5Action(
-                self.trUtf8('Check Indentations'),
-                self.trUtf8('&Indentations...'), 0, 0,
+                self.tr('Check Indentations'),
+                self.tr('&Indentations...'), 0, 0,
                 self, 'project_check_indentations')
             self.__projectAct.setStatusTip(
-                self.trUtf8('Check indentations using tabnanny.'))
-            self.__projectAct.setWhatsThis(self.trUtf8(
+                self.tr('Check indentations using tabnanny.'))
+            self.__projectAct.setWhatsThis(self.tr(
                 """<b>Check Indentations...</b>"""
                 """<p>This checks Python files"""
                 """ for bad indentations using tabnanny.</p>"""
             ))
-            self.__projectAct.triggered[()].connect(self.__projectTabnanny)
+            self.__projectAct.triggered.connect(self.__projectTabnanny)
             e5App().getObject("Project").addE5Actions([self.__projectAct])
             menu.addAction(self.__projectAct)
         
         self.__editorAct = E5Action(
-            self.trUtf8('Check Indentations'),
-            self.trUtf8('&Indentations...'), 0, 0,
+            self.tr('Check Indentations'),
+            self.tr('&Indentations...'), 0, 0,
             self, "")
-        self.__editorAct.setWhatsThis(self.trUtf8(
+        self.__editorAct.setWhatsThis(self.tr(
             """<b>Check Indentations...</b>"""
             """<p>This checks Python files"""
             """ for bad indentations using tabnanny.</p>"""
         ))
-        self.__editorAct.triggered[()].connect(self.__editorTabnanny)
+        self.__editorAct.triggered.connect(self.__editorTabnanny)
         
         e5App().getObject("Project").showMenu.connect(self.__projectShowMenu)
         e5App().getObject("ProjectBrowser").getProjectBrowser("sources")\
@@ -168,22 +240,22 @@ class TabnannyPlugin(QObject):
             self.__projectBrowserMenu = menu
             if self.__projectBrowserAct is None:
                 self.__projectBrowserAct = E5Action(
-                    self.trUtf8('Check Indentations'),
-                    self.trUtf8('&Indentations...'), 0, 0,
+                    self.tr('Check Indentations'),
+                    self.tr('&Indentations...'), 0, 0,
                     self, "")
-                self.__projectBrowserAct.setWhatsThis(self.trUtf8(
+                self.__projectBrowserAct.setWhatsThis(self.tr(
                     """<b>Check Indentations...</b>"""
                     """<p>This checks Python files"""
                     """ for bad indentations using tabnanny.</p>"""
                 ))
-                self.__projectBrowserAct.triggered[()].connect(
+                self.__projectBrowserAct.triggered.connect(
                     self.__projectBrowserTabnanny)
-            if not self.__projectBrowserAct in menu.actions():
+            if self.__projectBrowserAct not in menu.actions():
                 menu.addAction(self.__projectBrowserAct)
     
     def __projectTabnanny(self):
         """
-        Public slot used to check the project files for bad indentations.
+        Private slot used to check the project files for bad indentations.
         """
         project = e5App().getObject("Project")
         project.saveAllScripts()
@@ -195,7 +267,7 @@ class TabnannyPlugin(QObject):
                      tuple(Preferences.getPython("PythonExtensions")))]
         
         from CheckerPlugins.Tabnanny.TabnannyDialog import TabnannyDialog
-        self.__projectTabnannyDialog = TabnannyDialog()
+        self.__projectTabnannyDialog = TabnannyDialog(self)
         self.__projectTabnannyDialog.show()
         self.__projectTabnannyDialog.prepare(files, project)
     
@@ -206,14 +278,19 @@ class TabnannyPlugin(QObject):
         """
         browser = e5App().getObject("ProjectBrowser").getProjectBrowser(
             "sources")
-        itm = browser.model().item(browser.currentIndex())
-        try:
-            fn = itm.fileName()
-        except AttributeError:
-            fn = itm.dirName()
+        if browser.getSelectedItemsCount([ProjectBrowserFileItem]) > 1:
+            fn = []
+            for itm in browser.getSelectedItems([ProjectBrowserFileItem]):
+                fn.append(itm.fileName())
+        else:
+            itm = browser.model().item(browser.currentIndex())
+            try:
+                fn = itm.fileName()
+            except AttributeError:
+                fn = itm.dirName()
         
         from CheckerPlugins.Tabnanny.TabnannyDialog import TabnannyDialog
-        self.__projectBrowserTabnannyDialog = TabnannyDialog()
+        self.__projectBrowserTabnannyDialog = TabnannyDialog(self)
         self.__projectBrowserTabnannyDialog.show()
         self.__projectBrowserTabnannyDialog.start(fn)
     
@@ -250,10 +327,9 @@ class TabnannyPlugin(QObject):
         @param editor reference to the editor
         """
         if menuName == "Checks":
-            if not self.__editorAct in menu.actions():
+            if self.__editorAct not in menu.actions():
                 menu.addAction(self.__editorAct)
-            self.__editorAct.setEnabled(
-                editor.isPy3File() or editor.isPy2File())
+            self.__editorAct.setEnabled(editor.isPyFile())
     
     def __editorTabnanny(self):
         """
@@ -264,6 +340,6 @@ class TabnannyPlugin(QObject):
             if editor.checkDirty() and editor.getFileName() is not None:
                 from CheckerPlugins.Tabnanny.TabnannyDialog import \
                     TabnannyDialog
-                self.__editorTabnannyDialog = TabnannyDialog()
+                self.__editorTabnannyDialog = TabnannyDialog(self)
                 self.__editorTabnannyDialog.show()
                 self.__editorTabnannyDialog.start(editor.getFileName())
