@@ -1,16 +1,17 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the PySvn version control plugin.
 """
 
+from __future__ import unicode_literals
+
 import os
 
-from PyQt4.QtCore import QObject
-from PyQt4.QtGui import QApplication
+from PyQt5.QtCore import QObject, QCoreApplication
 
 from E5Gui.E5Application import e5App
 
@@ -24,7 +25,7 @@ name = "PySvn Plugin"
 author = "Detlev Offenbach <detlev@die-offenbachs.de>"
 autoactivate = False
 deactivateable = True
-version = "5.4.0"
+version = "6.0.0"
 pluginType = "version_control"
 pluginTypename = "PySvn"
 className = "VcsPySvnPlugin"
@@ -33,6 +34,7 @@ shortDescription = "Implements the PySvn version control interface."
 longDescription = \
     """This plugin provides the PySvn version control interface."""
 pyqtApi = 2
+python2Compatible = True
 # End-Of-Header
 
 error = ""
@@ -57,7 +59,7 @@ def exeDisplayData():
     
     data = {
         "programEntry": False,
-        "header": QApplication.translate(
+        "header": QCoreApplication.translate(
             "VcsPySvnPlugin", "Version Control - Subversion (pysvn)"),
         "text": text,
         "version": version,
@@ -88,7 +90,8 @@ def displayString():
     """
     try:
         import pysvn        # __IGNORE_WARNING__
-        return QApplication.translate('VcsPySvnPlugin', 'Subversion (pysvn)')
+        return QCoreApplication.translate('VcsPySvnPlugin',
+                                          'Subversion (pysvn)')
     except ImportError:
         return ""
 
@@ -120,7 +123,7 @@ def getConfigData():
     """
     return {
         "zzz_subversionPage":
-        [QApplication.translate("VcsPySvnPlugin", "Subversion"),
+        [QCoreApplication.translate("VcsPySvnPlugin", "Subversion"),
          os.path.join("VcsPlugins", "vcsPySvn", "icons",
                       "preferences-subversion.png"),
          createConfigurationPage, "vcsPage", None],
@@ -146,7 +149,7 @@ class VcsPySvnPlugin(QObject):
         
         @param ui reference to the user interface object (UI.UserInterface)
         """
-        super().__init__(ui)
+        super(VcsPySvnPlugin, self).__init__(ui)
         self.__ui = ui
         
         self.__subversionDefaults = {
