@@ -1,16 +1,17 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Subversion version control plugin.
 """
 
+from __future__ import unicode_literals
+
 import os
 
-from PyQt4.QtCore import QObject
-from PyQt4.QtGui import QApplication
+from PyQt5.QtCore import QObject, QCoreApplication
 
 from E5Gui.E5Application import e5App
 
@@ -26,7 +27,7 @@ name = "Subversion Plugin"
 author = "Detlev Offenbach <detlev@die-offenbachs.de>"
 autoactivate = False
 deactivateable = True
-version = "5.4.0"
+version = "6.0.0"
 pluginType = "version_control"
 pluginTypename = "Subversion"
 className = "VcsSubversionPlugin"
@@ -35,6 +36,7 @@ shortDescription = "Implements the Subversion version control interface."
 longDescription = \
     """This plugin provides the Subversion version control interface."""
 pyqtApi = 2
+python2Compatible = True
 # End-Of-Header
 
 error = ""
@@ -53,7 +55,7 @@ def exeDisplayData():
     
     data = {
         "programEntry": True,
-        "header": QApplication.translate(
+        "header": QCoreApplication.translate(
             "VcsSubversionPlugin", "Version Control - Subversion (svn)"),
         "exe": exe,
         "versionCommand": '--version',
@@ -94,7 +96,7 @@ def displayString():
     if Utilities.isWindowsPlatform():
         exe += '.exe'
     if Utilities.isinpath(exe):
-        return QApplication.translate(
+        return QCoreApplication.translate(
             'VcsSubversionPlugin', 'Subversion (svn)')
     else:
         return ""
@@ -127,7 +129,7 @@ def getConfigData():
     """
     return {
         "zzz_subversionPage":
-        [QApplication.translate("VcsSubversionPlugin", "Subversion"),
+        [QCoreApplication.translate("VcsSubversionPlugin", "Subversion"),
          os.path.join("VcsPlugins", "vcsSubversion", "icons",
                       "preferences-subversion.png"),
          createConfigurationPage, "vcsPage", None],
@@ -153,7 +155,7 @@ class VcsSubversionPlugin(QObject):
         
         @param ui reference to the user interface object (UI.UserInterface)
         """
-        super().__init__(ui)
+        super(VcsSubversionPlugin, self).__init__(ui)
         self.__ui = ui
         
         self.__subversionDefaults = {
