@@ -1,23 +1,25 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Tabview view manager plugin.
 """
 
+from __future__ import unicode_literals
+
 import os
 
-from PyQt4.QtCore import QT_TRANSLATE_NOOP, QObject
-from PyQt4.QtGui import QPixmap
+from PyQt5.QtCore import QT_TRANSLATE_NOOP, QObject
+from PyQt5.QtGui import QPixmap
 
 # Start-Of-Header
 name = "Tabview Plugin"
 author = "Detlev Offenbach <detlev@die-offenbachs.de>"
 autoactivate = False
 deactivateable = False
-version = "5.4.0"
+version = "6.0.0"
 pluginType = "viewmanager"
 pluginTypename = "tabview"
 displayString = QT_TRANSLATE_NOOP('VmTabviewPlugin', 'Tabbed View')
@@ -26,6 +28,7 @@ packageName = "__core__"
 shortDescription = "Implements the Tabview view manager."
 longDescription = """This plugin provides the tabbed view view manager."""
 pyqtApi = 2
+python2Compatible = True
 # End-Of-Header
 
 error = ""
@@ -52,7 +55,7 @@ class VmTabviewPlugin(QObject):
         
         @param ui reference to the user interface object (UI.UserInterface)
         """
-        super().__init__(ui)
+        super(VmTabviewPlugin, self).__init__(ui)
         self.__ui = ui
 
     def activate(self):
