@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Python re wizard plugin.
 """
 
-from PyQt4.QtCore import QObject
-from PyQt4.QtGui import QDialog
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import QObject
+from PyQt5.QtWidgets import QDialog
 
 from E5Gui.E5Application import e5App
 from E5Gui.E5Action import E5Action
@@ -19,12 +21,13 @@ name = "Python re Wizard Plugin"
 author = "Detlev Offenbach <detlev@die-offenbachs.de>"
 autoactivate = True
 deactivateable = True
-version = "5.4.0"
+version = "6.0.0"
 className = "PyRegExpWizard"
 packageName = "__core__"
 shortDescription = "Show the Python re wizard."
 longDescription = """This plugin shows the Python re wizard."""
 pyqtApi = 2
+python2Compatible = True
 # End-Of-Header
 
 error = ""
@@ -40,7 +43,7 @@ class PyRegExpWizard(QObject):
         
         @param ui reference to the user interface object (UI.UserInterface)
         """
-        super().__init__(ui)
+        super(PyRegExpWizard, self).__init__(ui)
         self.__ui = ui
 
     def activate(self):
@@ -68,17 +71,17 @@ class PyRegExpWizard(QObject):
         Private method to initialize the action.
         """
         self.action = E5Action(
-            self.trUtf8('Python re Wizard'),
-            self.trUtf8('&Python re Wizard...'), 0, 0, self,
+            self.tr('Python re Wizard'),
+            self.tr('&Python re Wizard...'), 0, 0, self,
             'wizards_python_re')
-        self.action.setStatusTip(self.trUtf8('Python re Wizard'))
-        self.action.setWhatsThis(self.trUtf8(
+        self.action.setStatusTip(self.tr('Python re Wizard'))
+        self.action.setWhatsThis(self.tr(
             """<b>Python re Wizard</b>"""
             """<p>This wizard opens a dialog for entering all the parameters"""
             """ needed to create a Python re string. The generated code is"""
             """ inserted at the current cursor position.</p>"""
         ))
-        self.action.triggered[()].connect(self.__handle)
+        self.action.triggered.connect(self.__handle)
         
         self.__ui.addE5Actions([self.action], 'wizards')
 
@@ -120,8 +123,8 @@ class PyRegExpWizard(QObject):
         if editor is None:
             E5MessageBox.critical(
                 self.__ui,
-                self.trUtf8('No current editor'),
-                self.trUtf8('Please open or create a file first.'))
+                self.tr('No current editor'),
+                self.tr('Please open or create a file first.'))
         else:
             code, ok = self.__callForm(editor)
             if ok:
