@@ -1,16 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the QFileDialog wizard plugin.
 """
 
+from __future__ import unicode_literals
+
 import re
 
-from PyQt4.QtCore import QObject
-from PyQt4.QtGui import QDialog
+from PyQt5.QtCore import QObject
+from PyQt5.QtWidgets import QDialog
 
 from E5Gui.E5Application import e5App
 from E5Gui.E5Action import E5Action
@@ -21,12 +23,13 @@ name = "QFileDialog Wizard Plugin"
 author = "Detlev Offenbach <detlev@die-offenbachs.de>"
 autoactivate = True
 deactivateable = True
-version = "5.4.0"
+version = "6.0.0"
 className = "FileDialogWizard"
 packageName = "__core__"
 shortDescription = "Show the QFileDialog wizard."
 longDescription = """This plugin shows the QFileDialog wizard."""
 pyqtApi = 2
+python2Compatible = True
 # End-Of-Header
 
 error = ""
@@ -42,7 +45,7 @@ class FileDialogWizard(QObject):
         
         @param ui reference to the user interface object (UI.UserInterface)
         """
-        super().__init__(ui)
+        super(FileDialogWizard, self).__init__(ui)
         self.__ui = ui
         
         self.__pyqtRe = re.compile(r"(?:import|from)\s+PyQt([45])")
@@ -72,17 +75,17 @@ class FileDialogWizard(QObject):
         Private method to initialize the action.
         """
         self.action = E5Action(
-            self.trUtf8('QFileDialog Wizard'),
-            self.trUtf8('Q&FileDialog Wizard...'), 0, 0, self,
+            self.tr('QFileDialog Wizard'),
+            self.tr('Q&FileDialog Wizard...'), 0, 0, self,
             'wizards_qfiledialog')
-        self.action.setStatusTip(self.trUtf8('QFileDialog Wizard'))
-        self.action.setWhatsThis(self.trUtf8(
+        self.action.setStatusTip(self.tr('QFileDialog Wizard'))
+        self.action.setWhatsThis(self.tr(
             """<b>QFileDialog Wizard</b>"""
             """<p>This wizard opens a dialog for entering all the parameters"""
             """ needed to create a QFileDialog. The generated code is"""
             """ inserted at the current cursor position.</p>"""
         ))
-        self.action.triggered[()].connect(self.__handle)
+        self.action.triggered.connect(self.__handle)
         
         self.__ui.addE5Actions([self.action], 'wizards')
 
@@ -130,8 +133,8 @@ class FileDialogWizard(QObject):
         if editor is None:
             E5MessageBox.critical(
                 self.__ui,
-                self.trUtf8('No current editor'),
-                self.trUtf8('Please open or create a file first.'))
+                self.tr('No current editor'),
+                self.tr('Please open or create a file first.'))
         else:
             code, ok = self.__callForm(editor)
             if ok:
