@@ -1,17 +1,23 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to show the output of the hg diff command process.
 """
 
+from __future__ import unicode_literals
+try:
+    str = unicode
+except NameError:
+    pass
+
 import os
 
-from PyQt4.QtCore import pyqtSlot, QProcess, QTimer, QFileInfo, Qt
-from PyQt4.QtGui import QWidget, QDialogButtonBox, QBrush, QColor, \
-    QTextCursor, QLineEdit, QApplication, QCursor
+from PyQt5.QtCore import pyqtSlot, QProcess, QTimer, QFileInfo, Qt
+from PyQt5.QtGui import QBrush, QColor, QTextCursor, QCursor
+from PyQt5.QtWidgets import QWidget, QDialogButtonBox, QLineEdit, QApplication
 
 from E5Gui import E5MessageBox, E5FileDialog
 from E5Gui.E5Application import e5App
@@ -34,7 +40,7 @@ class HgDiffDialog(QWidget, Ui_HgDiffDialog):
         @param vcs reference to the vcs object
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(HgDiffDialog, self).__init__(parent)
         self.setupUi(self)
         
         self.buttonBox.button(QDialogButtonBox.Save).setEnabled(False)
@@ -62,7 +68,7 @@ class HgDiffDialog(QWidget, Ui_HgDiffDialog):
     
     def closeEvent(self, e):
         """
-        Private slot implementing a close event handler.
+        Protected slot implementing a close event handler.
         
         @param e close event (QCloseEvent)
         """
@@ -110,14 +116,11 @@ class HgDiffDialog(QWidget, Ui_HgDiffDialog):
         
         self.filesCombo.clear()
         
-        args = []
         if qdiff:
-            args.append('qdiff')
-            self.setWindowTitle(self.trUtf8("Patch Contents"))
+            args = self.vcs.initCommand("qdiff")
+            self.setWindowTitle(self.tr("Patch Contents"))
         else:
-            args.append('diff')
-            self.vcs.addArguments(args, self.vcs.options['global'])
-            self.vcs.addArguments(args, self.vcs.options['diff'])
+            args = self.vcs.initCommand("diff")
             
             if self.vcs.hasSubrepositories():
                 args.append("--subrepos")
@@ -194,8 +197,8 @@ class HgDiffDialog(QWidget, Ui_HgDiffDialog):
                 self.inputGroup.hide()
                 E5MessageBox.critical(
                     self,
-                    self.trUtf8('Process Generation Error'),
-                    self.trUtf8(
+                    self.tr('Process Generation Error'),
+                    self.tr(
                         'The process {0} could not be started. '
                         'Ensure, that it is in the search path.'
                     ).format('hg'))
@@ -219,11 +222,11 @@ class HgDiffDialog(QWidget, Ui_HgDiffDialog):
         self.inputGroup.hide()
         
         if self.paras == 0:
-            self.contents.insertPlainText(
-                self.trUtf8('There is no difference.'))
-            return
+            self.contents.setCurrentCharFormat(self.cNormalFormat)
+            self.contents.setPlainText(
+                self.tr('There is no difference.'))
         
-        self.buttonBox.button(QDialogButtonBox.Save).setEnabled(True)
+        self.buttonBox.button(QDialogButtonBox.Save).setEnabled(self.paras > 0)
         self.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
         self.buttonBox.button(QDialogButtonBox.Close).setFocus(
             Qt.OtherFocusReason)
@@ -233,8 +236,8 @@ class HgDiffDialog(QWidget, Ui_HgDiffDialog):
         self.contents.setTextCursor(tc)
         self.contents.ensureCursorVisible()
         
-        self.filesCombo.addItem(self.trUtf8("<Start>"), 0)
-        self.filesCombo.addItem(self.trUtf8("<End>"), -1)
+        self.filesCombo.addItem(self.tr("<Start>"), 0)
+        self.filesCombo.addItem(self.tr("<End>"), -1)
         for oldFile, newFile, pos in sorted(self.__fileSeparators):
             if oldFile != newFile:
                 self.filesCombo.addItem(
@@ -312,8 +315,7 @@ class HgDiffDialog(QWidget, Ui_HgDiffDialog):
         self.process.setReadChannel(QProcess.StandardOutput)
         
         while self.process.canReadLine():
-            line = str(self.process.readLine(),
-                       Preferences.getSystem("IOEncoding"),
+            line = str(self.process.readLine(), self.vcs.getEncoding(),
                        'replace')
             self.__processOutputLine(line)
     
@@ -326,8 +328,7 @@ class HgDiffDialog(QWidget, Ui_HgDiffDialog):
         """
         if self.process is not None:
             s = str(self.process.readAllStandardError(),
-                    Preferences.getSystem("IOEncoding"),
-                    'replace')
+                    self.vcs.getEncoding(), 'replace')
             self.__showError(s)
     
     def __showError(self, out):
@@ -405,9 +406,9 @@ class HgDiffDialog(QWidget, Ui_HgDiffDialog):
         
         fname, selectedFilter = E5FileDialog.getSaveFileNameAndFilter(
             self,
-            self.trUtf8("Save Diff"),
+            self.tr("Save Diff"),
             fname,
-            self.trUtf8("Patch Files (*.diff)"),
+            self.tr("Patch Files (*.diff)"),
             None,
             E5FileDialog.Options(E5FileDialog.DontConfirmOverwrite))
         
@@ -422,9 +423,9 @@ class HgDiffDialog(QWidget, Ui_HgDiffDialog):
         if QFileInfo(fname).exists():
             res = E5MessageBox.yesNo(
                 self,
-                self.trUtf8("Save Diff"),
-                self.trUtf8("<p>The patch file <b>{0}</b> already exists."
-                            " Overwrite it?</p>").format(fname),
+                self.tr("Save Diff"),
+                self.tr("<p>The patch file <b>{0}</b> already exists."
+                        " Overwrite it?</p>").format(fname),
                 icon=E5MessageBox.Warning)
             if not res:
                 return
@@ -437,8 +438,8 @@ class HgDiffDialog(QWidget, Ui_HgDiffDialog):
             f.close()
         except IOError as why:
             E5MessageBox.critical(
-                self, self.trUtf8('Save Diff'),
-                self.trUtf8(
+                self, self.tr('Save Diff'),
+                self.tr(
                     '<p>The patch file <b>{0}</b> could not be saved.'
                     '<br>Reason: {1}</p>')
                 .format(fname, str(why)))
@@ -491,4 +492,4 @@ class HgDiffDialog(QWidget, Ui_HgDiffDialog):
             self.intercept = False
             evt.accept()
             return
-        super().keyPressEvent(evt)
+        super(HgDiffDialog, self).keyPressEvent(evt)
