@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2011 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the base class for Mercurial extension interfaces.
 """
 
-from PyQt4.QtCore import QObject
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import QObject
 
 
 class HgExtension(QObject):
@@ -20,7 +22,7 @@ class HgExtension(QObject):
         
         @param vcs reference to the Mercurial vcs object
         """
-        super().__init__(vcs)
+        super(HgExtension, self).__init__(vcs)
         
         self.vcs = vcs
     
