@@ -1,26 +1,33 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to browse the log history.
 """
 
-import os
+from __future__ import unicode_literals
+try:
+    str = unicode
+except NameError:
+    pass
 
-from PyQt4.QtCore import pyqtSlot, Qt, QDate, QProcess, QTimer, QRegExp, \
+import os
+import re
+
+from PyQt5.QtCore import pyqtSlot, Qt, QDate, QProcess, QTimer, QRegExp, \
     QSize, QPoint
-from PyQt4.QtGui import QDialog, QDialogButtonBox, QHeaderView, \
-    QTreeWidgetItem, QApplication, QCursor, QLineEdit, QColor, \
-    QPixmap, QPainter, QPen, QBrush, QIcon
+from PyQt5.QtGui import QCursor, QColor, QPixmap, QPainter, QPen, QBrush, QIcon
+from PyQt5.QtWidgets import QWidget, QDialogButtonBox, QHeaderView, \
+    QTreeWidgetItem, QApplication, QLineEdit, QMenu
 
 from E5Gui.E5Application import e5App
 from E5Gui import E5MessageBox
 
 from .Ui_HgLogBrowserDialog import Ui_HgLogBrowserDialog
 
-import Preferences
+import UI.PixmapCache
 
 COLORNAMES = ["blue", "darkgreen", "red", "green", "darkblue", "purple",
               "cyan", "olive", "magenta", "darkred", "darkmagenta",
@@ -28,7 +35,7 @@ COLORNAMES = ["blue", "darkgreen", "red", "green", "darkblue", "purple",
 COLORS = [str(QColor(x).name()) for x in COLORNAMES]
 
 
-class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
+class HgLogBrowserDialog(QWidget, Ui_HgLogBrowserDialog):
     """
     Class implementing a dialog to browse the log history.
     """
@@ -41,27 +48,31 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
     MessageColumn = 6
     TagsColumn = 7
     
-    def __init__(self, vcs, mode="log", bundle=None, isFile=False,
-                 parent=None):
+    LargefilesCacheL = ".hglf/"
+    LargefilesCacheW = ".hglf\\"
+    PathSeparatorRe = re.compile(r"/|\\")
+    
+    ClosedIndicator = " \u2612"
+    
+    def __init__(self, vcs, mode="log", parent=None):
         """
         Constructor
         
         @param vcs reference to the vcs object
         @param mode mode of the dialog (string; one of log, incoming, outgoing)
-        @param bundle name of a bundle file (string)
-        @param isFile flag indicating log for a file is to be shown (boolean)
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(HgLogBrowserDialog, self).__init__(parent)
         self.setupUi(self)
-        self.setWindowFlags(self.windowFlags() | Qt.WindowMinMaxButtonsHint)
+        
+        self.__position = QPoint()
         
         if mode == "log":
-            self.setWindowTitle(self.trUtf8("Mercurial Log"))
+            self.setWindowTitle(self.tr("Mercurial Log"))
         elif mode == "incoming":
-            self.setWindowTitle(self.trUtf8("Mercurial Log (Incoming)"))
+            self.setWindowTitle(self.tr("Mercurial Log (Incoming)"))
         elif mode == "outgoing":
-            self.setWindowTitle(self.trUtf8("Mercurial Log (Outgoing)"))
+            self.setWindowTitle(self.tr("Mercurial Log (Outgoing)"))
         
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
@@ -70,41 +81,45 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
         self.filesTree.header().setSortIndicator(0, Qt.AscendingOrder)
         
         self.refreshButton = self.buttonBox.addButton(
-            self.trUtf8("&Refresh"), QDialogButtonBox.ActionRole)
+            self.tr("&Refresh"), QDialogButtonBox.ActionRole)
         self.refreshButton.setToolTip(
-            self.trUtf8("Press to refresh the list of changesets"))
+            self.tr("Press to refresh the list of changesets"))
         self.refreshButton.setEnabled(False)
         
-        self.sbsCheckBox.setEnabled(isFile)
-        self.sbsCheckBox.setVisible(isFile)
-        
         self.vcs = vcs
         if mode in ("log", "incoming", "outgoing"):
             self.commandMode = mode
             self.initialCommandMode = mode
         else:
             self.commandMode = "log"
-        self.bundle = bundle
+            self.initialCommandMode = "log"
         self.__hgClient = vcs.getClient()
         
+        self.__detailsTemplate = self.tr(
+            "<table>"
+            "<tr><td><b>Revision</b></td><td>{0}</td></tr>"
+            "<tr><td><b>Date</b></td><td>{1}</td></tr>"
+            "<tr><td><b>Author</b></td><td>{2}</td></tr>"
+            "<tr><td><b>Branch</b></td><td>{3}</td></tr>"
+            "<tr><td><b>Tags</b></td><td>{4}</td></tr>"
+            "<tr><td><b>Bookmarks</b></td><td>{5}</td></tr>"
+            "<tr><td><b>Parents</b></td><td>{6}</td></tr>"
+            "</table>"
+        )
+        
+        self.__bundle = ""
+        self.__filename = ""
+        self.__isFile = False
+        self.__currentRevision = ""
+        self.intercept = False
+        
         self.__initData()
         
-        self.__allBranchesFilter = self.trUtf8("All")
+        self.__allBranchesFilter = self.tr("All")
         
         self.fromDate.setDisplayFormat("yyyy-MM-dd")
         self.toDate.setDisplayFormat("yyyy-MM-dd")
-        self.fromDate.setDate(QDate.currentDate())
-        self.toDate.setDate(QDate.currentDate())
-        self.fieldCombo.setCurrentIndex(self.fieldCombo.findText(
-            self.trUtf8("Message")))
-        self.limitSpinBox.setValue(self.vcs.getPlugin().getPreferences(
-            "LogLimit"))
-        self.stopCheckBox.setChecked(self.vcs.getPlugin().getPreferences(
-            "StopLogOnCopy"))
-        
-        if mode in ("incoming", "outgoing"):
-            self.nextButton.setEnabled(False)
-            self.limitSpinBox.setEnabled(False)
+        self.__resetUI()
         
         self.__messageRole = Qt.UserRole
         self.__changesRole = Qt.UserRole + 1
@@ -120,9 +135,9 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
             self.process.readyReadStandardError.connect(self.__readStderr)
         
         self.flags = {
-            'A': self.trUtf8('Added'),
-            'D': self.trUtf8('Deleted'),
-            'M': self.trUtf8('Modified'),
+            'A': self.tr('Added'),
+            'D': self.tr('Deleted'),
+            'M': self.tr('Modified'),
         }
         
         self.__dotRadius = 8
@@ -130,19 +145,53 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
         
         self.logTree.setIconSize(
             QSize(100 * self.__rowHeight, self.__rowHeight))
-        if self.vcs.version >= (1, 8):
-            self.logTree.headerItem().setText(
-                self.logTree.columnCount(), self.trUtf8("Bookmarks"))
+        self.BookmarksColumn = self.logTree.columnCount()
+        self.logTree.headerItem().setText(
+            self.BookmarksColumn, self.tr("Bookmarks"))
         if self.vcs.version < (2, 1):
             self.logTree.setColumnHidden(self.PhaseColumn, True)
-            self.phaseLine.hide()
-            self.phaseButton.hide()
-        if self.vcs.version < (2, 0):
-            self.graftButton.setEnabled(False)
-            self.graftButton.hide()
-        if self.phaseButton.isHidden() and \
-           self.graftButton.isHidden():
-            self.phaseLine.hide()
+        
+        self.__actionsMenu = QMenu()
+        if self.vcs.version >= (2, 0):
+            self.__graftAct = self.__actionsMenu.addAction(
+                self.tr("Copy Changesets"), self.__graftActTriggered)
+            self.__graftAct.setToolTip(self.tr(
+                "Copy the selected changesets to the current branch"))
+        else:
+            self.__graftAct = None
+        
+        if self.vcs.version >= (2, 1):
+            self.__phaseAct = self.__actionsMenu.addAction(
+                self.tr("Change Phase"), self.__phaseActTriggered)
+            self.__phaseAct.setToolTip(self.tr(
+                "Change the phase of the selected revisions"))
+            self.__phaseAct.setWhatsThis(self.tr(
+                """<b>Change Phase</b>\n<p>This changes the phase of the"""
+                """ selected revisions. The selected revisions have to have"""
+                """ the same current phase.</p>"""))
+        else:
+            self.__phaseAct = None
+        
+        self.__tagAct = self.__actionsMenu.addAction(
+            self.tr("Tag"), self.__tagActTriggered)
+        self.__tagAct.setToolTip(self.tr("Tag the selected revision"))
+        
+        self.__switchAct = self.__actionsMenu.addAction(
+            self.tr("Switch"), self.__switchActTriggered)
+        self.__switchAct.setToolTip(self.tr(
+            "Switch the working directory to the selected revision"))
+        
+        if self.vcs.version >= (2, 0):
+            self.__lfPullAct = self.__actionsMenu.addAction(
+                self.tr("Pull Large Files"), self.__lfPullActTriggered)
+            self.__lfPullAct.setToolTip(self.tr(
+                "Pull large files for selected revisions"))
+        else:
+            self.__lfPullAct = None
+        
+        self.actionsButton.setIcon(
+            UI.PixmapCache.getIcon("actionsToolButton.png"))
+        self.actionsButton.setMenu(self.__actionsMenu)
     
     def __initData(self):
         """
@@ -170,7 +219,7 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
     
     def closeEvent(self, e):
         """
-        Private slot implementing a close event handler.
+        Protected slot implementing a close event handler.
         
         @param e close event (QCloseEvent)
         """
@@ -184,8 +233,45 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
                 QTimer.singleShot(2000, self.process.kill)
                 self.process.waitForFinished(3000)
         
+        self.__position = self.pos()
+        
         e.accept()
     
+    def show(self):
+        """
+        Public slot to show the dialog.
+        """
+        if not self.__position.isNull():
+            self.move(self.__position)
+        self.__resetUI()
+        
+        super(HgLogBrowserDialog, self).show()
+    
+    def __resetUI(self):
+        """
+        Private method to reset the user interface.
+        """
+        self.branchCombo.clear()
+        self.fromDate.setDate(QDate.currentDate())
+        self.toDate.setDate(QDate.currentDate())
+        self.fieldCombo.setCurrentIndex(self.fieldCombo.findText(
+            self.tr("Message")))
+        self.limitSpinBox.setValue(self.vcs.getPlugin().getPreferences(
+            "LogLimit"))
+        self.stopCheckBox.setChecked(self.vcs.getPlugin().getPreferences(
+            "StopLogOnCopy"))
+        
+        if self.initialCommandMode in ("incoming", "outgoing"):
+            self.nextButton.setEnabled(False)
+            self.limitSpinBox.setEnabled(False)
+        else:
+            self.nextButton.setEnabled(True)
+            self.limitSpinBox.setEnabled(True)
+        
+        self.logTree.clear()
+        
+        self.commandMode = self.initialCommandMode
+    
     def __resizeColumnsLog(self):
         """
         Private method to resize the log tree columns.
@@ -385,12 +471,11 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
         parents = [-1]
         
         if int(rev) > 0:
-            args = []
-            args.append("parents")
+            args = self.vcs.initCommand("parents")
             if self.commandMode == "incoming":
-                if self.bundle:
+                if self.__bundle:
                     args.append("--repository")
-                    args.append(self.bundle)
+                    args.append(self.__bundle)
                 elif self.vcs.bundleFile and \
                         os.path.exists(self.vcs.bundleFile):
                     args.append("--repository")
@@ -400,7 +485,7 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
             args.append("-r")
             args.append(rev)
             if not self.projectMode:
-                args.append(self.filename)
+                args.append(self.__filename)
             
             output = ""
             if self.__hgClient:
@@ -413,21 +498,19 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
                 if procStarted:
                     finished = process.waitForFinished(30000)
                     if finished and process.exitCode() == 0:
-                        output = \
-                            str(process.readAllStandardOutput(),
-                                Preferences.getSystem("IOEncoding"),
-                                'replace')
+                        output = str(process.readAllStandardOutput(),
+                                     self.vcs.getEncoding(), 'replace')
                     else:
                         if not finished:
-                            errMsg = self.trUtf8(
+                            errMsg = self.tr(
                                 "The hg process did not finish within 30s.")
                 else:
-                    errMsg = self.trUtf8("Could not start the hg executable.")
+                    errMsg = self.tr("Could not start the hg executable.")
             
             if errMsg:
                 E5MessageBox.critical(
                     self,
-                    self.trUtf8("Mercurial Error"),
+                    self.tr("Mercurial Error"),
                     errMsg)
             
             if output:
@@ -441,8 +524,7 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
         """
         errMsg = ""
         
-        args = []
-        args.append("identify")
+        args = self.vcs.initCommand("identify")
         args.append("-nb")
         
         output = ""
@@ -456,21 +538,19 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
             if procStarted:
                 finished = process.waitForFinished(30000)
                 if finished and process.exitCode() == 0:
-                    output = \
-                        str(process.readAllStandardOutput(),
-                            Preferences.getSystem("IOEncoding"),
-                            'replace')
+                    output = str(process.readAllStandardOutput(),
+                                 self.vcs.getEncoding(), 'replace')
                 else:
                     if not finished:
-                        errMsg = self.trUtf8(
+                        errMsg = self.tr(
                             "The hg process did not finish within 30s.")
             else:
-                errMsg = self.trUtf8("Could not start the hg executable.")
+                errMsg = self.tr("Could not start the hg executable.")
         
         if errMsg:
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Mercurial Error"),
+                self.tr("Mercurial Error"),
                 errMsg)
         
         if output:
@@ -488,8 +568,7 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
         self.__closedBranchesRevs = []
         errMsg = ""
         
-        args = []
-        args.append("branches")
+        args = self.vcs.initCommand("branches")
         args.append("--closed")
         
         output = ""
@@ -503,21 +582,19 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
             if procStarted:
                 finished = process.waitForFinished(30000)
                 if finished and process.exitCode() == 0:
-                    output = \
-                        str(process.readAllStandardOutput(),
-                            Preferences.getSystem("IOEncoding"),
-                            'replace')
+                    output = str(process.readAllStandardOutput(),
+                                 self.vcs.getEncoding(), 'replace')
                 else:
                     if not finished:
-                        errMsg = self.trUtf8(
+                        errMsg = self.tr(
                             "The hg process did not finish within 30s.")
             else:
-                errMsg = self.trUtf8("Could not start the hg executable.")
+                errMsg = self.tr("Could not start the hg executable.")
         
         if errMsg:
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Mercurial Error"),
+                self.tr("Mercurial Error"),
                 errMsg)
         
         if output:
@@ -551,7 +628,7 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
         
         rev, node = revision.split(":")
         if rev in self.__closedBranchesRevs:
-            closedStr = "--"
+            closedStr = self.ClosedIndicator
         else:
             closedStr = ""
         msgtxt = msg[0]
@@ -646,10 +723,7 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
         self.intercept = False
         
         preargs = []
-        args = []
-        args.append(self.commandMode)
-        self.vcs.addArguments(args, self.vcs.options['global'])
-        self.vcs.addArguments(args, self.vcs.options['log'])
+        args = self.vcs.initCommand(self.commandMode)
         args.append('--verbose')
         if self.commandMode not in ("incoming", "outgoing"):
             args.append('--limit')
@@ -667,22 +741,24 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
             args.append('--follow')
         if self.commandMode == "log":
             args.append('--copies')
-        args.append('--style')
-        if self.vcs.version >= (2, 1):
+        if self.vcs.version >= (3, 0):
+            args.append('--template')
             args.append(os.path.join(os.path.dirname(__file__),
-                                     "styles",
-                                     "logBrowserBookmarkPhase.style"))
-        elif self.vcs.version >= (1, 8):
-            args.append(os.path.join(os.path.dirname(__file__),
-                                     "styles",
-                                     "logBrowserBookmark.style"))
+                                     "templates",
+                                     "logBrowserBookmarkPhase.tmpl"))
         else:
-            args.append(os.path.join(os.path.dirname(__file__),
-                                     "styles",
-                                     "logBrowser.style"))
+            args.append('--style')
+            if self.vcs.version >= (2, 1):
+                args.append(os.path.join(os.path.dirname(__file__),
+                                         "styles",
+                                         "logBrowserBookmarkPhase.style"))
+            else:
+                args.append(os.path.join(os.path.dirname(__file__),
+                                         "styles",
+                                         "logBrowserBookmark.style"))
         if self.commandMode == "incoming":
-            if self.bundle:
-                args.append(self.bundle)
+            if self.__bundle:
+                args.append(self.__bundle)
             elif not self.vcs.hasSubrepositories():
                 project = e5App().getObject("Project")
                 self.vcs.bundleFile = os.path.join(
@@ -695,7 +771,7 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
                 preargs.append(self.vcs.bundleFile)
                 args.append(self.vcs.bundleFile)
         if not self.projectMode:
-            args.append(self.filename)
+            args.append(self.__filename)
         
         if self.__hgClient:
             self.inputGroup.setEnabled(False)
@@ -708,9 +784,9 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
             if err:
                 self.__showError(err)
             elif self.commandMode != "incoming" or \
-                (self.vcs.bundleFile and 
+                (self.vcs.bundleFile and
                  os.path.exists(self.vcs.bundleFile)) or \
-                    self.bundle:
+                    self.__bundle:
                 out, err = self.__hgClient.runcommand(args)
                 self.buf = out.splitlines(True)
                 if err:
@@ -734,9 +810,9 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
                     process.waitForFinished(30000)
             
             if self.commandMode != "incoming" or \
-                (self.vcs.bundleFile and 
+                (self.vcs.bundleFile and
                  os.path.exists(self.vcs.bundleFile)) or \
-                    self.bundle:
+                    self.__bundle:
                 self.process.start('hg', args)
                 procStarted = self.process.waitForStarted(5000)
                 if not procStarted:
@@ -744,24 +820,35 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
                     self.inputGroup.hide()
                     E5MessageBox.critical(
                         self,
-                        self.trUtf8('Process Generation Error'),
-                        self.trUtf8(
+                        self.tr('Process Generation Error'),
+                        self.tr(
                             'The process {0} could not be started. '
                             'Ensure, that it is in the search path.'
                         ).format('hg'))
             else:
                 self.__finish()
     
-    def start(self, fn):
+    def start(self, fn, bundle=None, isFile=False):
         """
         Public slot to start the hg log command.
         
         @param fn filename to show the log for (string)
+        @keyparam bundle name of a bundle file (string)
+        @keyparam isFile flag indicating log for a file is to be shown
+            (boolean)
         """
+        self.__bundle = bundle
+        self.__isFile = isFile
+        
+        self.sbsCheckBox.setEnabled(isFile)
+        self.sbsCheckBox.setVisible(isFile)
+        
         self.errorGroup.hide()
         QApplication.processEvents()
         
-        self.filename = fn
+        self.__initData()
+        
+        self.__filename = fn
         self.dname, self.fname = self.vcs.splitPath(fn)
         
         # find the root of the repo
@@ -813,6 +900,19 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
         self.inputGroup.hide()
         self.refreshButton.setEnabled(True)
     
+    def __modifyForLargeFiles(self, filename):
+        """
+        Private method to convert the displayed file name for a large file.
+        
+        @param filename file name to be processed (string)
+        @return processed file name (string)
+        """
+        if filename.startswith((self.LargefilesCacheL, self.LargefilesCacheW)):
+            return self.tr("{0} (large file)").format(
+                self.PathSeparatorRe.split(filename, 1)[1])
+        else:
+            return filename
+    
     def __processBuffer(self):
         """
         Private method to process the buffered output of the hg log command.
@@ -848,13 +948,14 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
                             if f in fileCopies:
                                 changedPaths.append({
                                     "action": "A",
-                                    "path": f,
-                                    "copyfrom": fileCopies[f],
+                                    "path": self.__modifyForLargeFiles(f),
+                                    "copyfrom": self.__modifyForLargeFiles(
+                                        fileCopies[f]),
                                 })
                             else:
                                 changedPaths.append({
                                     "action": "A",
-                                    "path": f,
+                                    "path": self.__modifyForLargeFiles(f),
                                     "copyfrom": "",
                                 })
                 elif key == "files_mods":
@@ -862,7 +963,7 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
                         for f in value.strip().split(", "):
                             changedPaths.append({
                                 "action": "M",
-                                "path": f,
+                                "path": self.__modifyForLargeFiles(f),
                                 "copyfrom": "",
                             })
                 elif key == "file_dels":
@@ -870,7 +971,7 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
                         for f in value.strip().split(", "):
                             changedPaths.append({
                                 "action": "D",
-                                "path": f,
+                                "path": self.__modifyForLargeFiles(f),
                                 "copyfrom": "",
                             })
                 elif key == "file_copies":
@@ -954,8 +1055,15 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
         self.__filterLogs()
         
         self.__updateDiffButtons()
-        self.__updatePhaseButton()
-        self.__updateGraftButton()
+        self.__updateToolMenuActions()
+        
+        # restore current item
+        if self.__currentRevision:
+            items = self.logTree.findItems(
+                self.__currentRevision, Qt.MatchExactly, self.RevisionColumn)
+            if items:
+                self.logTree.setCurrentItem(items[0])
+                self.__currentRevision = ""
     
     def __readStdout(self):
         """
@@ -966,8 +1074,7 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
         self.process.setReadChannel(QProcess.StandardOutput)
         
         while self.process.canReadLine():
-            line = str(self.process.readLine(),
-                       Preferences.getSystem("IOEncoding"),
+            line = str(self.process.readLine(), self.vcs.getEncoding(),
                        'replace')
             self.buf.append(line)
     
@@ -980,8 +1087,7 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
         """
         if self.process is not None:
             s = str(self.process.readAllStandardError(),
-                    Preferences.getSystem("IOEncoding"),
-                    'replace')
+                    self.vcs.getEncoding(), 'replace')
             self.__showError(s)
     
     def __showError(self, out):
@@ -1002,14 +1108,15 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
         @param rev2 second revision number (integer)
         """
         if self.sbsCheckBox.isEnabled() and self.sbsCheckBox.isChecked():
-            self.vcs.hgSbsDiff(self.filename, revisions=(str(rev1), str(rev2)))
+            self.vcs.hgSbsDiff(self.__filename,
+                               revisions=(str(rev1), str(rev2)))
         else:
             if self.diff is None:
                 from .HgDiffDialog import HgDiffDialog
                 self.diff = HgDiffDialog(self.vcs)
             self.diff.show()
             self.diff.raise_()
-            self.diff.start(self.filename, [rev1, rev2], self.bundle)
+            self.diff.start(self.__filename, [rev1, rev2], self.__bundle)
     
     def on_buttonBox_clicked(self, button):
         """
@@ -1055,40 +1162,35 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
             
             self.diffRevisionsButton.setEnabled(False)
     
-    def __updatePhaseButton(self):
+    def __updateToolMenuActions(self):
         """
-        Private slot to update the status of the phase button.
+        Private slot to update the status of the tool menu actions and
+        the tool menu button.
         """
-        if self.initialCommandMode == "log":
-            # step 1: count entries with changeable phases
-            secret = 0
-            draft = 0
-            public = 0
-            for itm in self.logTree.selectedItems():
-                phase = itm.text(self.PhaseColumn)
-                if phase == "draft":
-                    draft += 1
-                elif phase == "secret":
-                    secret += 1
+        if self.initialCommandMode == "log" and self.projectMode:
+            if self.__phaseAct is not None:
+                # step 1: count entries with changeable phases
+                secret = 0
+                draft = 0
+                public = 0
+                for itm in self.logTree.selectedItems():
+                    phase = itm.text(self.PhaseColumn)
+                    if phase == "draft":
+                        draft += 1
+                    elif phase == "secret":
+                        secret += 1
+                    else:
+                        public += 1
+                
+                # step 2: set the status of the phase button
+                if public == 0 and \
+                   ((secret > 0 and draft == 0) or
+                        (secret == 0 and draft > 0)):
+                    self.__phaseAct.setEnabled(True)
                 else:
-                    public += 1
+                    self.__phaseAct.setEnabled(False)
             
-            # step 2: set the status of the phase button
-            if public == 0 and \
-               ((secret > 0 and draft == 0) or
-                    (secret == 0 and draft > 0)):
-                self.phaseButton.setEnabled(True)
-            else:
-                self.phaseButton.setEnabled(False)
-        else:
-            self.phaseButton.setEnabled(False)
-    
-    def __updateGraftButton(self):
-        """
-        Private slot to update the status of the graft button.
-        """
-        if self.graftButton.isVisible():
-            if self.initialCommandMode == "log":
+            if self.__graftAct is not None:
                 # step 1: count selected entries not belonging to the
                 #         current branch
                 otherBranches = 0
@@ -1097,22 +1199,48 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
                     if branch != self.__projectBranch:
                         otherBranches += 1
                 
-                # step 2: set the status of the graft button
-                self.graftButton.setEnabled(otherBranches > 0)
-            else:
-                self.graftButton.setEnabled(False)
+                # step 2: set the status of the graft action
+                self.__graftAct.setEnabled(otherBranches > 0)
+            
+            self.__tagAct.setEnabled(len(self.logTree.selectedItems()) == 1)
+            self.__switchAct.setEnabled(len(self.logTree.selectedItems()) == 1)
+            
+            if self.__lfPullAct is not None:
+                if self.vcs.isExtensionActive("largefiles"):
+                    self.__lfPullAct.setEnabled(bool(
+                        self.logTree.selectedItems()))
+                else:
+                    self.__lfPullAct.setEnabled(False)
+            
+            self.actionsButton.setEnabled(True)
+        else:
+            self.actionsButton.setEnabled(False)
     
     def __updateGui(self, itm):
         """
-        Private slot to update GUI elements except the diff and phase buttons.
+        Private slot to update GUI elements except tool menu actions.
         
         @param itm reference to the item the update should be based on
             (QTreeWidgetItem)
         """
+        self.detailsEdit.clear()
         self.messageEdit.clear()
         self.filesTree.clear()
         
         if itm is not None:
+            self.detailsEdit.setHtml(self.__detailsTemplate.format(
+                itm.text(self.RevisionColumn),
+                itm.text(self.DateColumn),
+                itm.text(self.AuthorColumn),
+                itm.text(self.BranchColumn).replace(
+                    self.ClosedIndicator, ""),
+                itm.text(self.TagsColumn),
+                itm.text(self.BookmarksColumn),
+                ", ".join(
+                    [str(x) for x in itm.data(0, self.__parentsRole)]
+                ),
+            ))
+            
             for line in itm.data(0, self.__messageRole):
                 self.messageEdit.append(line.strip())
             
@@ -1134,8 +1262,7 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
         """
         self.__updateGui(current)
         self.__updateDiffButtons()
-        self.__updatePhaseButton()
-        self.__updateGraftButton()
+        self.__updateToolMenuActions()
     
     @pyqtSlot()
     def on_logTree_itemSelectionChanged(self):
@@ -1146,8 +1273,7 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
             self.__updateGui(self.logTree.selectedItems()[0])
         
         self.__updateDiffButtons()
-        self.__updatePhaseButton()
-        self.__updateGraftButton()
+        self.__updateToolMenuActions()
     
     @pyqtSlot()
     def on_nextButton_clicked(self):
@@ -1267,10 +1393,10 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
             closedBranch = branch + '--'
             
             txt = self.fieldCombo.currentText()
-            if txt == self.trUtf8("Author"):
+            if txt == self.tr("Author"):
                 fieldIndex = self.AuthorColumn
                 searchRx = QRegExp(self.rxEdit.text(), Qt.CaseInsensitive)
-            elif txt == self.trUtf8("Revision"):
+            elif txt == self.tr("Revision"):
                 fieldIndex = self.RevisionColumn
                 txt = self.rxEdit.text()
                 if txt.startswith("^"):
@@ -1325,7 +1451,12 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
         self.inputGroup.show()
         self.refreshButton.setEnabled(False)
         
-        self.__initData()
+        # save the current items commit ID
+        itm = self.logTree.currentItem()
+        if itm is not None:
+            self.__currentRevision = itm.text(self.RevisionColumn)
+        else:
+            self.__currentRevision = ""
         
         if self.initialCommandMode in ("incoming", "outgoing"):
             self.nextButton.setEnabled(False)
@@ -1335,7 +1466,7 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
             self.limitSpinBox.setEnabled(True)
         
         self.commandMode = self.initialCommandMode
-        self.start(self.filename)
+        self.start(self.__filename, isFile=self.__isFile)
     
     def on_passwordCheckBox_toggled(self, isOn):
         """
@@ -1351,7 +1482,7 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
     @pyqtSlot()
     def on_sendButton_clicked(self):
         """
-        Private slot to send the input to the merurial process.
+        Private slot to send the input to the mercurial process.
         """
         input = self.input.text()
         input += os.linesep
@@ -1386,12 +1517,12 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
             self.intercept = False
             evt.accept()
             return
-        super().keyPressEvent(evt)
+        super(HgLogBrowserDialog, self).keyPressEvent(evt)
     
     @pyqtSlot()
-    def on_phaseButton_clicked(self):
+    def __phaseActTriggered(self):
         """
-        Private slot to handle the Change Phase button.
+        Private slot to handle the Change Phase action.
         """
         currentPhase = self.logTree.selectedItems()[0].text(self.PhaseColumn)
         revs = []
@@ -1401,7 +1532,7 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
                     itm.text(self.RevisionColumn).split(":")[0].strip())
         
         if not revs:
-            self.phaseButton.setEnabled(False)
+            self.__phaseAct.setEnabled(False)
             return
         
         if currentPhase == "draft":
@@ -1416,9 +1547,9 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
                 itm.setText(self.PhaseColumn, newPhase)
     
     @pyqtSlot()
-    def on_graftButton_clicked(self):
+    def __graftActTriggered(self):
         """
-        Private slot to handle the Copy Changesets button.
+        Private slot to handle the Copy Changesets action.
         """
         revs = []
         
@@ -1433,11 +1564,63 @@ class HgLogBrowserDialog(QDialog, Ui_HgLogBrowserDialog):
             if shouldReopen:
                 res = E5MessageBox.yesNo(
                     None,
-                    self.trUtf8("Copy Changesets"),
-                    self.trUtf8(
+                    self.tr("Copy Changesets"),
+                    self.tr(
                         """The project should be reread. Do this now?"""),
                     yesDefault=True)
                 if res:
                     e5App().getObject("Project").reopenProject()
-            else:
+                    return
+            
+            self.on_refreshButton_clicked()
+    
+    @pyqtSlot()
+    def __tagActTriggered(self):
+        """
+        Private slot to tag the selected revision.
+        """
+        if len(self.logTree.selectedItems()) == 1:
+            itm = self.logTree.selectedItems()[0]
+            rev = itm.text(self.RevisionColumn).strip().split(":", 1)[0]
+            tag = itm.text(self.TagsColumn).strip().split(", ", 1)[0]
+            res = self.vcs.vcsTag(self.repodir, revision=rev, tagName=tag)
+            if res:
                 self.on_refreshButton_clicked()
+    
+    @pyqtSlot()
+    def __switchActTriggered(self):
+        """
+        Private slot to switch the working directory to the
+        selected revision.
+        """
+        if len(self.logTree.selectedItems()) == 1:
+            itm = self.logTree.selectedItems()[0]
+            rev = itm.text(self.RevisionColumn).strip().split(":", 1)[0]
+            if rev:
+                shouldReopen = self.vcs.vcsUpdate(self.repodir, revision=rev)
+                if shouldReopen:
+                    res = E5MessageBox.yesNo(
+                        None,
+                        self.tr("Switch"),
+                        self.tr(
+                            """The project should be reread. Do this now?"""),
+                        yesDefault=True)
+                    if res:
+                        e5App().getObject("Project").reopenProject()
+                        return
+                
+                self.on_refreshButton_clicked()
+    
+    def __lfPullActTriggered(self):
+        """
+        Private slot to pull large files of selected revisions.
+        """
+        revs = []
+        for itm in self.logTree.selectedItems():
+            rev = itm.text(self.RevisionColumn).strip().split(":", 1)[0]
+            if rev:
+                revs.append(rev)
+        
+        if revs:
+            self.vcs.getExtensionObject("largefiles").hgLfPull(
+                self.repodir, revisions=revs)
