@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,7 +8,9 @@ Module implementing a dialog to enter options used to start a project in
 the VCS.
 """
 
-from PyQt4.QtGui import QDialog
+from __future__ import unicode_literals
+
+from PyQt5.QtWidgets import QDialog
 
 from .Ui_HgOptionsDialog import Ui_HgOptionsDialog
 
@@ -26,8 +28,11 @@ class HgOptionsDialog(QDialog, Ui_HgOptionsDialog):
         @param project reference to the project object
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(HgOptionsDialog, self).__init__(parent)
         self.setupUi(self)
+        
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
     
     def getData(self):
         """
