@@ -1,22 +1,24 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing some common utility functions for the Mercurial package.
 """
 
+from __future__ import unicode_literals
+
 import os
 
-from PyQt4.QtCore import QProcessEnvironment
+from PyQt5.QtCore import QProcessEnvironment
 
 import Utilities
 
 
 def getConfigPath():
     """
-    Public method to get the filename of the config file.
+    Public function to get the filename of the config file.
     
     @return filename of the config file (string)
     """
@@ -30,7 +32,7 @@ def getConfigPath():
 
 def prepareProcess(proc, encoding="", language=""):
     """
-    Public method to prepare the given process.
+    Public function to prepare the given process.
     
     @param proc reference to the proces to be prepared (QProcess)
     @param encoding encoding to be used by the process (string)
