@@ -1,15 +1,19 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the VCS project browser helper for Mercurial.
 """
 
+from __future__ import unicode_literals
+
 import os
 
-from PyQt4.QtGui import QMenu, QDialog
+from PyQt5.QtWidgets import QMenu, QDialog
+
+from E5Gui.E5Application import e5App
 
 from Project.ProjectBrowserModel import ProjectBrowserFileItem
 
@@ -38,10 +42,54 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         VcsProjectBrowserHelper.__init__(self, vcsObject, browserObject,
                                          projectObject, isTranslationsBrowser,
                                          parent, name)
+        
+        # instantiate the extensions
+        from .ShelveExtension.ProjectBrowserHelper import \
+            ShelveProjectBrowserHelper
+        from .LargefilesExtension.ProjectBrowserHelper import \
+            LargefilesProjectBrowserHelper
+        self.__extensions = {
+            "shelve": ShelveProjectBrowserHelper(
+                vcsObject, browserObject, projectObject),
+            "largefiles": LargefilesProjectBrowserHelper(
+                vcsObject, browserObject, projectObject),
+        }
+        
+        self.__extensionMenuTitles = {}
+        for extension in self.__extensions:
+            self.__extensionMenuTitles[
+                self.__extensions[extension].menuTitle()] = extension
+        self.__extensionMenus = {}
+        for extension in self.__extensions:
+            self.__extensionMenus[extension] = \
+                self.__extensions[extension].initMenus()
+    
+    def __showExtensionMenu(self, key, controlled):
+        """
+        Private slot showing the extensions menu.
+        
+        @param key menu key (string, one of 'mainMenu', 'multiMenu',
+            'backMenu', 'dirMenu' or 'dirMultiMenu')
+        @param controlled flag indicating to show the menu for a
+            version controlled entry or a non-version controlled entry
+            (boolean)
+        """
+        for extensionName in self.__extensionMenus:
+            if key in self.__extensionMenus[extensionName]:
+                self.__extensionMenus[extensionName][key].setEnabled(
+                    self.vcs.isExtensionActive(extensionName))
+                if self.__extensionMenus[extensionName][key].isEnabled():
+                    # adjust individual extension menu entries
+                    self.__extensions[extensionName].showExtensionMenu(
+                        key, controlled)
+                if (not self.__extensionMenus[extensionName][key].isEnabled()
+                    and self.__extensionMenus[extensionName][key]
+                        .isTearOffMenuVisible()):
+                    self.__extensionMenus[extensionName][key].hideTearOffMenu()
     
     def showContextMenu(self, menu, standardItems):
         """
-        Slot called before the context menu is shown.
+        Public slot called before the context menu is shown.
         
         It enables/disables the VCS menu entries depending on the overall
         VCS status and the file status.
@@ -51,6 +99,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
             activation/deactivation depending on the overall VCS status
         """
         if self.browser.currentItem().data(1) == self.vcs.vcsName():
+            controlled = True
             for act in self.vcsMenuActions:
                 act.setEnabled(True)
             for act in self.vcsAddMenuActions:
@@ -60,16 +109,19 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
             if not hasattr(self.browser.currentItem(), 'fileName'):
                 self.annotateAct.setEnabled(False)
         else:
+            controlled = False
             for act in self.vcsMenuActions:
                 act.setEnabled(False)
             for act in self.vcsAddMenuActions:
                 act.setEnabled(True)
             for act in standardItems:
                 act.setEnabled(True)
+        self.__showExtensionMenu("mainMenu", controlled)
     
     def showContextMenuMulti(self, menu, standardItems):
         """
-        Slot called before the context menu (multiple selections) is shown.
+        Public slot called before the context menu (multiple selections) is
+        shown.
         
         It enables/disables the VCS menu entries depending on the overall
         VCS status and the files status.
@@ -87,6 +139,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
                 vcsItems += 1
         
         if vcsItems > 0:
+            controlled = True
             if vcsItems != len(items):
                 for act in self.vcsMultiMenuActions:
                     act.setEnabled(False)
@@ -98,16 +151,18 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
             for act in standardItems:
                 act.setEnabled(False)
         else:
+            controlled = False
             for act in self.vcsMultiMenuActions:
                 act.setEnabled(False)
             for act in self.vcsAddMultiMenuActions:
                 act.setEnabled(True)
             for act in standardItems:
                 act.setEnabled(True)
+        self.__showExtensionMenu("multiMenu", controlled)
     
     def showContextMenuDir(self, menu, standardItems):
         """
-        Slot called before the context menu is shown.
+        Public slot called before the context menu is shown.
         
         It enables/disables the VCS menu entries depending on the overall
         VCS status and the directory status.
@@ -117,6 +172,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
             activation/deactivation depending on the overall VCS status
         """
         if self.browser.currentItem().data(1) == self.vcs.vcsName():
+            controlled = True
             for act in self.vcsDirMenuActions:
                 act.setEnabled(True)
             for act in self.vcsAddDirMenuActions:
@@ -124,16 +180,18 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
             for act in standardItems:
                 act.setEnabled(False)
         else:
+            controlled = False
             for act in self.vcsDirMenuActions:
                 act.setEnabled(False)
             for act in self.vcsAddDirMenuActions:
                 act.setEnabled(True)
             for act in standardItems:
                 act.setEnabled(True)
+        self.__showExtensionMenu("dirMenu", controlled)
     
     def showContextMenuDirMulti(self, menu, standardItems):
         """
-        Slot called before the context menu is shown.
+        Public slot called before the context menu is shown.
         
         It enables/disables the VCS menu entries depending on the overall
         VCS status and the directory status.
@@ -151,6 +209,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
                 vcsItems += 1
         
         if vcsItems > 0:
+            controlled = True
             if vcsItems != len(items):
                 for act in self.vcsDirMultiMenuActions:
                     act.setEnabled(False)
@@ -162,17 +221,48 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
             for act in standardItems:
                 act.setEnabled(False)
         else:
+            controlled = False
             for act in self.vcsDirMultiMenuActions:
                 act.setEnabled(False)
             for act in self.vcsAddDirMultiMenuActions:
                 act.setEnabled(True)
             for act in standardItems:
                 act.setEnabled(True)
-
+        self.__showExtensionMenu("dirMultiMenu", controlled)
+    
     ###########################################################################
-    # Protected menu generation methods below
+    ## Private menu generation methods below
     ###########################################################################
-
+    
+    def __addExtensionsMenu(self, menu, key):
+        """
+        Private method to add an extension menu entry.
+        
+        @param menu menu to add it to (QMenu)
+        @param key menu key (string, one of 'mainMenu', 'multiMenu',
+            'backMenu', 'dirMenu' or 'dirMultiMenu')
+        @return reference to the menu action (QAction)
+        """
+        act = None
+        if key in ['mainMenu', 'multiMenu', 'backMenu', 'dirMenu',
+                   'dirMultiMenu']:
+            extensionsMenu = QMenu(self.tr("Extensions"), menu)
+            extensionsMenu.setTearOffEnabled(True)
+            for extensionMenuTitle in sorted(self.__extensionMenuTitles):
+                extensionName = self.__extensionMenuTitles[extensionMenuTitle]
+                if key in self.__extensionMenus[extensionName]:
+                    extensionsMenu.addMenu(
+                        self.__extensionMenus[extensionName][key])
+            if not extensionsMenu.isEmpty():
+                if not menu.isEmpty():
+                    menu.addSeparator()
+                act = menu.addMenu(extensionsMenu)
+        return act
+    
+    ###########################################################################
+    ## Protected menu generation methods below
+    ###########################################################################
+    
     def _addVCSMenu(self, mainMenu):
         """
         Protected method used to add the VCS menu to all project browsers.
@@ -182,7 +272,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         self.vcsMenuActions = []
         self.vcsAddMenuActions = []
         
-        menu = QMenu(self.trUtf8("Version Control"))
+        menu = QMenu(self.tr("Version Control"))
         
         act = menu.addAction(
             UI.PixmapCache.getIcon(
@@ -196,85 +286,93 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsCommit.png"),
-            self.trUtf8('Commit changes to repository...'),
+            self.tr('Commit changes to repository...'),
             self._VCSCommit)
         self.vcsMenuActions.append(act)
+        self.__addExtensionsMenu(menu, 'mainMenu')
         menu.addSeparator()
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsAdd.png"),
-            self.trUtf8('Add to repository'),
+            self.tr('Add to repository'),
             self._VCSAdd)
         self.vcsAddMenuActions.append(act)
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsRemove.png"),
-            self.trUtf8('Remove from repository (and disk)'),
+            self.tr('Remove from repository (and disk)'),
             self._VCSRemove)
         self.vcsMenuActions.append(act)
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsRemove.png"),
-            self.trUtf8('Remove from repository only'),
+            self.tr('Remove from repository only'),
             self.__HgForget)
         self.vcsMenuActions.append(act)
         menu.addSeparator()
-        act = menu.addAction(self.trUtf8('Copy'), self.__HgCopy)
+        act = menu.addAction(self.tr('Copy'), self.__HgCopy)
         self.vcsMenuActions.append(act)
-        act = menu.addAction(self.trUtf8('Move'), self.__HgMove)
+        act = menu.addAction(self.tr('Move'), self.__HgMove)
         self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsLog.png"),
-            self.trUtf8('Show log'), self._VCSLog)
+            self.tr('Show log'), self._VCSLog)
         self.vcsMenuActions.append(act)
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsLog.png"),
-            self.trUtf8('Show log browser'), self.__HgLogBrowser)
+            self.tr('Show log browser'), self._VCSLogBrowser)
         self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsStatus.png"),
-            self.trUtf8('Show status'), self._VCSStatus)
+            self.tr('Show status'), self._VCSStatus)
         self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsDiff.png"),
-            self.trUtf8('Show differences'), self._VCSDiff)
+            self.tr('Show differences'), self._VCSDiff)
         self.vcsMenuActions.append(act)
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsSbsDiff.png"),
-            self.trUtf8('Show differences side-by-side'), self.__HgSbsDiff)
+            self.tr('Show differences side-by-side'), self.__HgSbsDiff)
         self.vcsMenuActions.append(act)
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsDiff.png"),
-            self.trUtf8('Show differences (extended)'),
+            self.tr('Show differences (extended)'),
             self.__HgExtendedDiff)
         self.vcsMenuActions.append(act)
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsSbsDiff.png"),
-            self.trUtf8('Show differences side-by-side (extended)'),
+            self.tr('Show differences side-by-side (extended)'),
             self.__HgSbsExtendedDiff)
         self.vcsMenuActions.append(act)
         self.annotateAct = menu.addAction(
-            self.trUtf8('Show annotated file'),
+            self.tr('Show annotated file'),
             self.__HgAnnotate)
         self.vcsMenuActions.append(self.annotateAct)
         menu.addSeparator()
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsRevert.png"),
-            self.trUtf8('Revert changes'), self.__HgRevert)
+            self.tr('Revert changes'), self.__HgRevert)
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            self.trUtf8('Conflict resolved'), self.__HgResolve)
+            self.tr('Conflicts resolved'), self.__HgResolved)
+        self.vcsMenuActions.append(act)
+        act = menu.addAction(
+            self.tr('Conflicts unresolved'), self.__HgUnresolved)
+        self.vcsMenuActions.append(act)
+        act = menu.addAction(
+            self.tr('Re-Merge'), self.__HgReMerge)
         self.vcsMenuActions.append(act)
         menu.addSeparator()
-        menu.addAction(self.trUtf8('Select all local file entries'),
+        menu.addAction(self.tr('Select all local file entries'),
                        self.browser.selectLocalEntries)
-        menu.addAction(self.trUtf8('Select all versioned file entries'),
+        menu.addAction(self.tr('Select all versioned file entries'),
                        self.browser.selectVCSEntries)
-        menu.addAction(self.trUtf8('Select all local directory entries'),
+        menu.addAction(self.tr('Select all local directory entries'),
                        self.browser.selectLocalDirEntries)
-        menu.addAction(self.trUtf8('Select all versioned directory entries'),
+        menu.addAction(self.tr('Select all versioned directory entries'),
                        self.browser.selectVCSDirEntries)
         menu.addSeparator()
+        menu.addAction(self.tr("Configure..."), self.__HgConfigure)
         
         mainMenu.addSeparator()
         mainMenu.addMenu(menu)
@@ -290,7 +388,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         self.vcsMultiMenuActions = []
         self.vcsAddMultiMenuActions = []
         
-        menu = QMenu(self.trUtf8("Version Control"))
+        menu = QMenu(self.tr("Version Control"))
         
         act = menu.addAction(
             UI.PixmapCache.getIcon(
@@ -304,57 +402,65 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsCommit.png"),
-            self.trUtf8('Commit changes to repository...'),
+            self.tr('Commit changes to repository...'),
             self._VCSCommit)
         self.vcsMultiMenuActions.append(act)
+        self.__addExtensionsMenu(menu, 'multiMenu')
         menu.addSeparator()
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsAdd.png"),
-            self.trUtf8('Add to repository'), self._VCSAdd)
+            self.tr('Add to repository'), self._VCSAdd)
         self.vcsAddMultiMenuActions.append(act)
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsRemove.png"),
-            self.trUtf8('Remove from repository (and disk)'),
+            self.tr('Remove from repository (and disk)'),
             self._VCSRemove)
         self.vcsMultiMenuActions.append(act)
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsRemove.png"),
-            self.trUtf8('Remove from repository only'),
+            self.tr('Remove from repository only'),
             self.__HgForget)
         self.vcsMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsStatus.png"),
-            self.trUtf8('Show status'), self._VCSStatus)
+            self.tr('Show status'), self._VCSStatus)
         self.vcsMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsDiff.png"),
-            self.trUtf8('Show differences'), self._VCSDiff)
+            self.tr('Show differences'), self._VCSDiff)
         self.vcsMultiMenuActions.append(act)
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsDiff.png"),
-            self.trUtf8('Show differences (extended)'),
+            self.tr('Show differences (extended)'),
             self.__HgExtendedDiff)
         self.vcsMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsRevert.png"),
-            self.trUtf8('Revert changes'), self.__HgRevert)
+            self.tr('Revert changes'), self.__HgRevert)
         self.vcsMultiMenuActions.append(act)
         act = menu.addAction(
-            self.trUtf8('Conflict resolved'), self.__HgResolve)
+            self.tr('Conflicts resolved'), self.__HgResolved)
+        self.vcsMultiMenuActions.append(act)
+        act = menu.addAction(
+            self.tr('Conflicts unresolved'), self.__HgUnresolved)
+        self.vcsMultiMenuActions.append(act)
+        act = menu.addAction(
+            self.tr('Re-Merge'), self.__HgReMerge)
         self.vcsMultiMenuActions.append(act)
         menu.addSeparator()
-        menu.addAction(self.trUtf8('Select all local file entries'),
+        menu.addAction(self.tr('Select all local file entries'),
                        self.browser.selectLocalEntries)
-        menu.addAction(self.trUtf8('Select all versioned file entries'),
+        menu.addAction(self.tr('Select all versioned file entries'),
                        self.browser.selectVCSEntries)
-        menu.addAction(self.trUtf8('Select all local directory entries'),
+        menu.addAction(self.tr('Select all local directory entries'),
                        self.browser.selectLocalDirEntries)
-        menu.addAction(self.trUtf8('Select all versioned directory entries'),
+        menu.addAction(self.tr('Select all versioned directory entries'),
                        self.browser.selectVCSDirEntries)
         menu.addSeparator()
+        menu.addAction(self.tr("Configure..."), self.__HgConfigure)
         
         mainMenu.addSeparator()
         mainMenu.addMenu(menu)
@@ -366,7 +472,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         
         @param mainMenu reference to the menu to be amended
         """
-        menu = QMenu(self.trUtf8("Version Control"))
+        menu = QMenu(self.tr("Version Control"))
         
         act = menu.addAction(
             UI.PixmapCache.getIcon(
@@ -378,15 +484,16 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         act.setFont(font)
         menu.addSeparator()
         
-        menu.addAction(self.trUtf8('Select all local file entries'),
+        menu.addAction(self.tr('Select all local file entries'),
                        self.browser.selectLocalEntries)
-        menu.addAction(self.trUtf8('Select all versioned file entries'),
+        menu.addAction(self.tr('Select all versioned file entries'),
                        self.browser.selectVCSEntries)
-        menu.addAction(self.trUtf8('Select all local directory entries'),
+        menu.addAction(self.tr('Select all local directory entries'),
                        self.browser.selectLocalDirEntries)
-        menu.addAction(self.trUtf8('Select all versioned directory entries'),
+        menu.addAction(self.tr('Select all versioned directory entries'),
                        self.browser.selectVCSDirEntries)
         menu.addSeparator()
+        menu.addAction(self.tr("Configure..."), self.__HgConfigure)
         
         mainMenu.addSeparator()
         mainMenu.addMenu(menu)
@@ -404,7 +511,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         self.vcsDirMenuActions = []
         self.vcsAddDirMenuActions = []
         
-        menu = QMenu(self.trUtf8("Version Control"))
+        menu = QMenu(self.tr("Version Control"))
         
         act = menu.addAction(
             UI.PixmapCache.getIcon(
@@ -418,66 +525,74 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsCommit.png"),
-            self.trUtf8('Commit changes to repository...'),
+            self.tr('Commit changes to repository...'),
             self._VCSCommit)
         self.vcsDirMenuActions.append(act)
+        self.__addExtensionsMenu(menu, 'dirMenu')
         menu.addSeparator()
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsAdd.png"),
-            self.trUtf8('Add to repository'), self._VCSAdd)
+            self.tr('Add to repository'), self._VCSAdd)
         self.vcsAddDirMenuActions.append(act)
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsRemove.png"),
-            self.trUtf8('Remove from repository (and disk)'),
+            self.tr('Remove from repository (and disk)'),
             self._VCSRemove)
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
-        act = menu.addAction(self.trUtf8('Copy'), self.__HgCopy)
+        act = menu.addAction(self.tr('Copy'), self.__HgCopy)
         self.vcsDirMenuActions.append(act)
-        act = menu.addAction(self.trUtf8('Move'), self.__HgMove)
+        act = menu.addAction(self.tr('Move'), self.__HgMove)
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsLog.png"),
-            self.trUtf8('Show log'), self._VCSLog)
+            self.tr('Show log'), self._VCSLog)
         self.vcsDirMenuActions.append(act)
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsLog.png"),
-            self.trUtf8('Show log browser'), self.__HgLogBrowser)
+            self.tr('Show log browser'), self._VCSLogBrowser)
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsStatus.png"),
-            self.trUtf8('Show status'), self._VCSStatus)
+            self.tr('Show status'), self._VCSStatus)
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsDiff.png"),
-            self.trUtf8('Show differences'), self._VCSDiff)
+            self.tr('Show differences'), self._VCSDiff)
         self.vcsDirMenuActions.append(act)
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsDiff.png"),
-            self.trUtf8('Show differences (extended)'),
+            self.tr('Show differences (extended)'),
             self.__HgExtendedDiff)
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsRevert.png"),
-            self.trUtf8('Revert changes'), self.__HgRevert)
+            self.tr('Revert changes'), self.__HgRevert)
         self.vcsDirMenuActions.append(act)
         act = menu.addAction(
-            self.trUtf8('Conflict resolved'), self.__HgResolve)
+            self.tr('Conflicts resolved'), self.__HgResolved)
+        self.vcsDirMenuActions.append(act)
+        act = menu.addAction(
+            self.tr('Conflicts unresolved'), self.__HgUnresolved)
+        self.vcsDirMenuActions.append(act)
+        act = menu.addAction(
+            self.tr('Re-Merge'), self.__HgReMerge)
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
-        menu.addAction(self.trUtf8('Select all local file entries'),
+        menu.addAction(self.tr('Select all local file entries'),
                        self.browser.selectLocalEntries)
-        menu.addAction(self.trUtf8('Select all versioned file entries'),
+        menu.addAction(self.tr('Select all versioned file entries'),
                        self.browser.selectVCSEntries)
-        menu.addAction(self.trUtf8('Select all local directory entries'),
+        menu.addAction(self.tr('Select all local directory entries'),
                        self.browser.selectLocalDirEntries)
-        menu.addAction(self.trUtf8('Select all versioned directory entries'),
+        menu.addAction(self.tr('Select all versioned directory entries'),
                        self.browser.selectVCSDirEntries)
         menu.addSeparator()
+        menu.addAction(self.tr("Configure..."), self.__HgConfigure)
         
         mainMenu.addSeparator()
         mainMenu.addMenu(menu)
@@ -495,7 +610,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         self.vcsDirMultiMenuActions = []
         self.vcsAddDirMultiMenuActions = []
         
-        menu = QMenu(self.trUtf8("Version Control"))
+        menu = QMenu(self.tr("Version Control"))
         
         act = menu.addAction(
             UI.PixmapCache.getIcon(
@@ -509,64 +624,72 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsCommit.png"),
-            self.trUtf8('Commit changes to repository...'),
+            self.tr('Commit changes to repository...'),
             self._VCSCommit)
         self.vcsDirMultiMenuActions.append(act)
+        self.__addExtensionsMenu(menu, 'dirMultiMenu')
         menu.addSeparator()
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsAdd.png"),
-            self.trUtf8('Add to repository'), self._VCSAdd)
+            self.tr('Add to repository'), self._VCSAdd)
         self.vcsAddDirMultiMenuActions.append(act)
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsRemove.png"),
-            self.trUtf8('Remove from repository (and disk)'),
+            self.tr('Remove from repository (and disk)'),
             self._VCSRemove)
         self.vcsDirMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsStatus.png"),
-            self.trUtf8('Show status'), self._VCSStatus)
+            self.tr('Show status'), self._VCSStatus)
         self.vcsDirMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsDiff.png"),
-            self.trUtf8('Show differences'), self._VCSDiff)
+            self.tr('Show differences'), self._VCSDiff)
         self.vcsDirMultiMenuActions.append(act)
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsDiff.png"),
-            self.trUtf8('Show differences (extended)'),
+            self.tr('Show differences (extended)'),
             self.__HgExtendedDiff)
         self.vcsDirMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
             UI.PixmapCache.getIcon("vcsRevert.png"),
-            self.trUtf8('Revert changes'), self.__HgRevert)
+            self.tr('Revert changes'), self.__HgRevert)
         self.vcsDirMultiMenuActions.append(act)
         act = menu.addAction(
-            self.trUtf8('Conflict resolved'), self.__HgResolve)
+            self.tr('Conflicts resolved'), self.__HgResolved)
+        self.vcsDirMultiMenuActions.append(act)
+        act = menu.addAction(
+            self.tr('Conflicts unresolved'), self.__HgUnresolved)
+        self.vcsDirMultiMenuActions.append(act)
+        act = menu.addAction(
+            self.tr('Re-Merge'), self.__HgReMerge)
         self.vcsDirMultiMenuActions.append(act)
         menu.addSeparator()
-        menu.addAction(self.trUtf8('Select all local file entries'),
+        menu.addAction(self.tr('Select all local file entries'),
                        self.browser.selectLocalEntries)
-        menu.addAction(self.trUtf8('Select all versioned file entries'),
+        menu.addAction(self.tr('Select all versioned file entries'),
                        self.browser.selectVCSEntries)
-        menu.addAction(self.trUtf8('Select all local directory entries'),
+        menu.addAction(self.tr('Select all local directory entries'),
                        self.browser.selectLocalDirEntries)
-        menu.addAction(self.trUtf8('Select all versioned directory entries'),
+        menu.addAction(self.tr('Select all versioned directory entries'),
                        self.browser.selectVCSDirEntries)
         menu.addSeparator()
+        menu.addAction(self.tr("Configure..."), self.__HgConfigure)
         
         mainMenu.addSeparator()
         mainMenu.addMenu(menu)
         self.menuDirMulti = menu
     
     ###########################################################################
-    # Menu handling methods below
+    ## Menu handling methods below
     ###########################################################################
     
     def __HgRevert(self):
         """
-        Protected slot called by the context menu to revert changes made.
+        Private slot called by the context menu to revert changes made.
         """
         names = []
         for itm in self.browser.getSelectedItems():
@@ -650,23 +773,10 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         fn = itm.fileName()
         self.vcs.hgAnnotate(fn)
     
-    def __HgLogBrowser(self):
+    def __HgResolved(self):
         """
-        Private slot called by the context menu to show the log browser for a
-        file.
-        """
-        itm = self.browser.currentItem()
-        try:
-            fn = itm.fileName()
-            isFile = True
-        except AttributeError:
-            fn = itm.dirName()
-            isFile = False
-        self.vcs.hgLogBrowser(fn, isFile=isFile)
-    
-    def __HgResolve(self):
-        """
-        Private slot called by the context menu to resolve conflicts of a file.
+        Private slot called by the context menu to mark conflicts of a file
+        as being resolved.
         """
         names = []
         for itm in self.browser.getSelectedItems():
@@ -674,8 +784,33 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
                 names.append(itm.fileName())
             except AttributeError:
                 names.append(itm.dirName())
-        self.vcs.hgResolve(names)
-        
+        self.vcs.hgResolved(names)
+    
+    def __HgUnresolved(self):
+        """
+        Private slot called by the context menu to mark conflicts of a file
+        as being unresolved.
+        """
+        names = []
+        for itm in self.browser.getSelectedItems():
+            try:
+                names.append(itm.fileName())
+            except AttributeError:
+                names.append(itm.dirName())
+        self.vcs.hgResolved(names, unresolve=True)
+    
+    def __HgReMerge(self):
+        """
+        Private slot called by the context menu to re-merge a file.
+        """
+        names = []
+        for itm in self.browser.getSelectedItems():
+            try:
+                names.append(itm.fileName())
+            except AttributeError:
+                names.append(itm.dirName())
+        self.vcs.hgReMerge(names)
+    
     def __HgForget(self):
         """
         Private slot called by the context menu to remove the selected file
@@ -689,8 +824,8 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
             
             dlg = DeleteFilesConfirmationDialog(
                 self.parent(),
-                self.trUtf8("Remove from repository only"),
-                self.trUtf8(
+                self.tr("Remove from repository only"),
+                self.tr(
                     "Do you really want to remove these files"
                     " from the repository?"),
                 names)
@@ -702,8 +837,8 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
             
             dlg = DeleteFilesConfirmationDialog(
                 self.parent(),
-                self.trUtf8("Remove from repository only"),
-                self.trUtf8(
+                self.tr("Remove from repository only"),
+                self.tr(
                     "Do you really want to remove these files"
                     " from the repository?"),
                 files)
@@ -713,3 +848,10 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         
         for fn in names:
             self._updateVCSStatus(fn)
+    
+    def __HgConfigure(self):
+        """
+        Private method to open the configuration dialog.
+        """
+        e5App().getObject("UserInterface")\
+            .showPreferences("zzz_mercurialPage")
