@@ -1,12 +1,14 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module defining configuration variables for the subversion package.
 """
 
+from __future__ import unicode_literals
+
 # Available protocols for the repository URL
 ConfigSvnProtocols = [
     'file://',
@@ -117,8 +119,8 @@ DefaultConfig = "\n".join([
     "global-ignores = *.o *.lo *.la *.al .libs *.so *.so.[0-9]* *.a *.pyc",
     "  *.pyo .*.rej *.rej .*~ *~ #*# .#* .*.swp .DS_Store",
     "  *.orig *.bak cur tmp __pycache__ .directory",
-    "  .ropeproject .eric4project .eric5project",
-    "  _ropeproject _eric4project _eric5project",
+    "  .ropeproject .eric4project .eric5project .eric6project",
+    "  _ropeproject _eric4project _eric5project _eric6project",
     "### Set log-encoding to the default encoding for log messages",
     "# log-encoding = latin1",
     "### Set use-commit-times to make checkout/update/switch/revert",
@@ -182,7 +184,9 @@ DefaultIgnores = [
     ".ropeproject",
     ".eric4project",
     ".eric5project",
+    ".eric6project",
     "_ropeproject",
     "_eric4project",
     "_eric5project",
+    "_eric6project",
 ]
