@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Subversion configuration page.
 """
 
-from PyQt4.QtCore import pyqtSlot
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSlot
 
 from Preferences.ConfigurationPages.ConfigurationPageBase import \
     ConfigurationPageBase
@@ -24,7 +26,7 @@ class SubversionPage(ConfigurationPageBase, Ui_SubversionPage):
         
         @param plugin reference to the plugin object
         """
-        super().__init__()
+        super(SubversionPage, self).__init__()
         self.setupUi(self)
         self.setObjectName("SubversionPage")
         
