@@ -1,24 +1,27 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to show the output of the svn blame command.
 """
 
+from __future__ import unicode_literals
+
 import os
+import sys
 
 import pysvn
 
-from PyQt4.QtCore import QMutexLocker, Qt
-from PyQt4.QtGui import QHeaderView, QDialog, QDialogButtonBox, QFont, \
+from PyQt5.QtCore import QMutexLocker, Qt
+from PyQt5.QtWidgets import QHeaderView, QDialog, QDialogButtonBox, \
     QTreeWidgetItem
 
 from .SvnDialogMixin import SvnDialogMixin
 from .Ui_SvnBlameDialog import Ui_SvnBlameDialog
 
-import Utilities
+import Preferences
 
 
 class SvnBlameDialog(QDialog, SvnDialogMixin, Ui_SvnBlameDialog):
@@ -32,9 +35,10 @@ class SvnBlameDialog(QDialog, SvnDialogMixin, Ui_SvnBlameDialog):
         @param vcs reference to the vcs object
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(SvnBlameDialog, self).__init__(parent)
         self.setupUi(self)
         SvnDialogMixin.__init__(self)
+        self.setWindowFlags(Qt.Window)
         
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
@@ -42,11 +46,7 @@ class SvnBlameDialog(QDialog, SvnDialogMixin, Ui_SvnBlameDialog):
         self.vcs = vcs
         
         self.blameList.headerItem().setText(self.blameList.columnCount(), "")
-        font = QFont(self.blameList.font())
-        if Utilities.isWindowsPlatform():
-            font.setFamily("Lucida Console")
-        else:
-            font.setFamily("Monospace")
+        font = Preferences.getEditorOtherFonts("MonospacedFont")
         self.blameList.setFont(font)
         
         self.client = self.vcs.getClient()
@@ -75,9 +75,14 @@ class SvnBlameDialog(QDialog, SvnDialogMixin, Ui_SvnBlameDialog):
             annotations = self.client.annotate(fname)
             locker.unlock()
             for annotation in annotations:
+                author = annotation["author"]
+                line = annotation["line"]
+                if sys.version_info[0] == 2:
+                    author = author.decode('utf-8')
+                    line = line.decode('utf-8')
                 self.__generateItem(
-                    annotation["revision"].number, annotation["author"],
-                    annotation["number"] + 1, annotation["line"])
+                    annotation["revision"].number, author,
+                    annotation["number"] + 1, line)
         except pysvn.ClientError as e:
             locker.unlock()
             self.__showError(e.args[0] + '\n')
