@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Subversion command dialog.
 """
 
-from PyQt4.QtCore import pyqtSlot
-from PyQt4.QtGui import QDialog, QDialogButtonBox
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSlot
+from PyQt5.QtWidgets import QDialog, QDialogButtonBox
 
 from E5Gui.E5Completers import E5DirCompleter
 from E5Gui import E5FileDialog
@@ -16,6 +18,7 @@ from E5Gui import E5FileDialog
 from .Ui_SvnCommandDialog import Ui_SvnCommandDialog
 
 import Utilities
+import UI.PixmapCache
 
 
 class SvnCommandDialog(QDialog, Ui_SvnCommandDialog):
@@ -35,9 +38,11 @@ class SvnCommandDialog(QDialog, Ui_SvnCommandDialog):
         @param ppath pathname of the project directory (string)
         @param parent parent widget of this dialog (QWidget)
         """
-        super().__init__(parent)
+        super(SvnCommandDialog, self).__init__(parent)
         self.setupUi(self)
         
+        self.dirButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        
         self.workdirCompleter = E5DirCompleter(self.workdirCombo)
         
         self.okButton = self.buttonBox.button(QDialogButtonBox.Ok)
@@ -59,6 +64,9 @@ class SvnCommandDialog(QDialog, Ui_SvnCommandDialog):
             t += Utilities.getPercentReplacementHelp()
             self.commandCombo.setWhatsThis(t)
         
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
+        
     @pyqtSlot()
     def on_dirButton_clicked(self):
         """
@@ -69,7 +77,7 @@ class SvnCommandDialog(QDialog, Ui_SvnCommandDialog):
             cwd = self.projectDirLabel.text()
         d = E5FileDialog.getExistingDirectory(
             self,
-            self.trUtf8("Working directory"),
+            self.tr("Working directory"),
             cwd,
             E5FileDialog.Options(E5FileDialog.ShowDirsOnly))
         
