@@ -1,16 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to enter the commit message.
 """
 
+from __future__ import unicode_literals
+
 import pysvn
 
-from PyQt4.QtCore import pyqtSignal, Qt, pyqtSlot
-from PyQt4.QtGui import QWidget, QDialogButtonBox
+from PyQt5.QtCore import pyqtSignal, Qt, pyqtSlot
+from PyQt5.QtWidgets import QWidget, QDialogButtonBox
 
 from .Ui_SvnCommitDialog import Ui_SvnCommitDialog
 
@@ -34,7 +36,8 @@ class SvnCommitDialog(QWidget, Ui_SvnCommitDialog):
         @param changelists list of available change lists (list of strings)
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent, Qt.WindowFlags(Qt.Window))
+        super(SvnCommitDialog, self).__init__(
+            parent, Qt.WindowFlags(Qt.Window))
         self.setupUi(self)
         
         if pysvn.svn_version < (1, 5, 0) or pysvn.version < (1, 6, 0):
@@ -44,7 +47,7 @@ class SvnCommitDialog(QWidget, Ui_SvnCommitDialog):
         
     def showEvent(self, evt):
         """
-        Public method called when the dialog is about to be shown.
+        Protected method called when the dialog is about to be shown.
         
         @param evt the event (QShowEvent)
         """
