@@ -1,16 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to enter the data for a copy operation.
 """
 
+from __future__ import unicode_literals
+
 import os.path
 
-from PyQt4.QtCore import pyqtSlot
-from PyQt4.QtGui import QDialog, QDialogButtonBox
+from PyQt5.QtCore import pyqtSlot
+from PyQt5.QtWidgets import QDialog, QDialogButtonBox
 
 from E5Gui.E5Completers import E5FileCompleter, E5DirCompleter
 from E5Gui import E5FileDialog
@@ -18,6 +20,7 @@ from E5Gui import E5FileDialog
 from .Ui_SvnCopyDialog import Ui_SvnCopyDialog
 
 import Utilities
+import UI.PixmapCache
 
 
 class SvnCopyDialog(QDialog, Ui_SvnCopyDialog):
@@ -34,9 +37,11 @@ class SvnCopyDialog(QDialog, Ui_SvnCopyDialog):
         @param move flag indicating a move operation (boolean)
         @param force flag indicating a forced operation (boolean)
         """
-        super().__init__(parent)
+        super(SvnCopyDialog, self).__init__(parent)
         self.setupUi(self)
         
+        self.dirButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        
         self.source = source
         if os.path.isdir(self.source):
             self.targetCompleter = E5DirCompleter(self.targetEdit)
@@ -44,7 +49,7 @@ class SvnCopyDialog(QDialog, Ui_SvnCopyDialog):
             self.targetCompleter = E5FileCompleter(self.targetEdit)
         
         if move:
-            self.setWindowTitle(self.trUtf8('Subversion Move'))
+            self.setWindowTitle(self.tr('Subversion Move'))
         else:
             self.forceCheckBox.setEnabled(False)
         self.forceCheckBox.setChecked(force)
@@ -53,6 +58,9 @@ class SvnCopyDialog(QDialog, Ui_SvnCopyDialog):
         
         self.buttonBox.button(QDialogButtonBox.Ok).setEnabled(False)
         
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
+        
     def getData(self):
         """
         Public method to retrieve the copy data.
@@ -76,13 +84,13 @@ class SvnCopyDialog(QDialog, Ui_SvnCopyDialog):
         if os.path.isdir(self.source):
             target = E5FileDialog.getExistingDirectory(
                 None,
-                self.trUtf8("Select target"),
+                self.tr("Select target"),
                 self.targetEdit.text(),
                 E5FileDialog.Options(E5FileDialog.ShowDirsOnly))
         else:
             target = E5FileDialog.getSaveFileName(
                 None,
-                self.trUtf8("Select target"),
+                self.tr("Select target"),
                 self.targetEdit.text(),
                 "",
                 E5FileDialog.Options(E5FileDialog.DontConfirmOverwrite))
