@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,13 +8,16 @@ Module implementing a dialog to show the output of the svn diff command
 process.
 """
 
+from __future__ import unicode_literals
+
 import os
+import sys
 
 import pysvn
 
-from PyQt4.QtCore import QMutexLocker, QFileInfo, QDateTime, Qt, pyqtSlot
-from PyQt4.QtGui import QWidget, QColor, QCursor, QBrush, QApplication, \
-    QTextCursor, QDialogButtonBox
+from PyQt5.QtCore import QMutexLocker, QFileInfo, QDateTime, Qt, pyqtSlot
+from PyQt5.QtGui import QColor, QCursor, QBrush, QTextCursor
+from PyQt5.QtWidgets import QWidget, QApplication, QDialogButtonBox
 
 from E5Gui.E5Application import e5App
 from E5Gui import E5MessageBox, E5FileDialog
@@ -37,7 +40,7 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         @param vcs reference to the vcs object
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(SvnDiffDialog, self).__init__(parent)
         self.setupUi(self)
         SvnDialogMixin.__init__(self)
         
@@ -160,8 +163,8 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         else:
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Subversion Diff"),
-                self.trUtf8("""There is no temporary directory available."""))
+                self.tr("Subversion Diff"),
+                self.tr("""There is no temporary directory available."""))
             return
         
         tmpdir = os.path.join(tmpdir, 'svn_tmp')
@@ -202,7 +205,7 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
                 dname += "/"
             for name in fnames:
                 self.__showError(
-                    self.trUtf8("Processing file '{0}'...\n").format(name))
+                    self.tr("Processing file '{0}'...\n").format(name))
                 if urls is not None:
                     url1 = "{0}/{1}{2}".format(urls[0], dname, name)
                     url2 = "{0}/{1}{2}".format(urls[1], dname, name)
@@ -213,10 +216,13 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
                             recurse=recurse)
                         diff_list = []
                         for diff_sum in diff_summary:
+                            path = diff_sum['path']
+                            if sys.version_info[0] == 2:
+                                path = path.decode('utf-8')
                             diff_list.append("{0} {1}".format(
                                 self.__getDiffSummaryKind(
                                     diff_sum['summarize_kind']),
-                                diff_sum['path']))
+                                path))
                         diffText = os.linesep.join(diff_list)
                     else:
                         diffText = self.client.diff(
@@ -224,6 +230,8 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
                             url1, revision1=rev1,
                             url_or_path2=url2, revision2=rev2,
                             recurse=recurse)
+                        if sys.version_info[0] == 2:
+                            diffText = diffText.decode('utf-8')
                 else:
                     if pegRev is not None:
                         diffText = self.client.diff_peg(
@@ -235,6 +243,8 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
                         diffText = self.client.diff(
                             tmpdir, name,
                             revision1=rev1, revision2=rev2, recurse=recurse)
+                    if sys.version_info[0] == 2:
+                        diffText = diffText.decode('utf-8')
                 counter = 0
                 for line in diffText.splitlines():
                     if line.startswith("--- ") or \
@@ -257,11 +267,11 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         self.__finish()
         
         if self.paras == 0:
-            self.contents.insertPlainText(
-                self.trUtf8('There is no difference.'))
-            return
+            self.contents.setCurrentCharFormat(self.cNormalFormat)
+            self.contents.setPlainText(
+                self.tr('There is no difference.'))
         
-        self.buttonBox.button(QDialogButtonBox.Save).setEnabled(True)
+        self.buttonBox.button(QDialogButtonBox.Save).setEnabled(self.paras > 0)
         
     def __appendText(self, line):
         """
@@ -327,8 +337,8 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         self.contents.setTextCursor(tc)
         self.contents.ensureCursorVisible()
         
-        self.filesCombo.addItem(self.trUtf8("<Start>"), 0)
-        self.filesCombo.addItem(self.trUtf8("<End>"), -1)
+        self.filesCombo.addItem(self.tr("<Start>"), 0)
+        self.filesCombo.addItem(self.tr("<End>"), -1)
         for oldFile, newFile, pos in sorted(self.__fileSeparators):
             if oldFile != newFile:
                 self.filesCombo.addItem(
@@ -407,9 +417,9 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         
         fname, selectedFilter = E5FileDialog.getSaveFileNameAndFilter(
             self,
-            self.trUtf8("Save Diff"),
+            self.tr("Save Diff"),
             fname,
-            self.trUtf8("Patch Files (*.diff)"),
+            self.tr("Patch Files (*.diff)"),
             None,
             E5FileDialog.Options(E5FileDialog.DontConfirmOverwrite))
         
@@ -424,9 +434,9 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         if QFileInfo(fname).exists():
             res = E5MessageBox.yesNo(
                 self,
-                self.trUtf8("Save Diff"),
-                self.trUtf8("<p>The patch file <b>{0}</b> already exists."
-                            " Overwrite it?</p>").format(fname),
+                self.tr("Save Diff"),
+                self.tr("<p>The patch file <b>{0}</b> already exists."
+                        " Overwrite it?</p>").format(fname),
                 icon=E5MessageBox.Warning)
             if not res:
                 return
@@ -439,8 +449,8 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
             f.close()
         except IOError as why:
             E5MessageBox.critical(
-                self, self.trUtf8('Save Diff'),
-                self.trUtf8(
+                self, self.tr('Save Diff'),
+                self.tr(
                     '<p>The patch file <b>{0}</b> could not be saved.'
                     '<br>Reason: {1}</p>')
                 .format(fname, str(why)))
