@@ -1,19 +1,22 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to show the output of the svn log command process.
 """
 
+from __future__ import unicode_literals
+
 import os
+import sys
 
 import pysvn
 
-from PyQt4.QtCore import QMutexLocker, QByteArray, QUrl, Qt
-from PyQt4.QtGui import QWidget, QCursor, QApplication, QTextCursor, \
-    QDialogButtonBox
+from PyQt5.QtCore import QMutexLocker, QUrl, Qt, QByteArray, qVersion
+from PyQt5.QtGui import QCursor, QTextCursor
+from PyQt5.QtWidgets import QWidget, QApplication, QDialogButtonBox
 
 from .SvnUtilities import formatTime
 
@@ -38,7 +41,7 @@ class SvnLogDialog(QWidget, SvnDialogMixin, Ui_SvnLogDialog):
         @param isFile flag indicating log for a file is to be shown (boolean)
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(SvnLogDialog, self).__init__(parent)
         self.setupUi(self)
         SvnDialogMixin.__init__(self)
         
@@ -48,17 +51,17 @@ class SvnLogDialog(QWidget, SvnDialogMixin, Ui_SvnLogDialog):
         self.vcs = vcs
         
         self.contents.setHtml(
-            self.trUtf8('<b>Processing your request, please wait...</b>'))
+            self.tr('<b>Processing your request, please wait...</b>'))
         
         self.contents.anchorClicked.connect(self.__sourceChanged)
         
         self.flags = {
-            'A': self.trUtf8('Added'),
-            'D': self.trUtf8('Deleted'),
-            'M': self.trUtf8('Modified')
+            'A': self.tr('Added'),
+            'D': self.tr('Deleted'),
+            'M': self.tr('Modified')
         }
         
-        self.revString = self.trUtf8('revision')
+        self.revString = self.tr('revision')
         self.diff = None
         
         self.sbsCheckBox.setEnabled(isFile)
@@ -137,42 +140,57 @@ class SvnLogDialog(QWidget, SvnDialogMixin, Ui_SvnLogDialog):
                     url = QUrl()
                     url.setScheme("file")
                     url.setPath(self.filename)
-                    query = QByteArray()
-                    query.append(lv).append('_').append(ver)
-                    url.setEncodedQuery(query)
+                    if qVersion() >= "5.0.0":
+                        query = lv + '_' + ver
+                        url.setQuery(query)
+                    else:
+                        query = QByteArray()
+                        query.append(lv).append('_').append(ver)
+                        url.setEncodedQuery(query)
                     dstr += ' [<a href="{0}" name="{1}">{2}</a>]'.format(
                         url.toString(), query,
-                        self.trUtf8('diff to {0}').format(lv)
+                        self.tr('diff to {0}').format(lv)
                     )
                 except IndexError:
                     pass
                 dstr += '<br />\n'
                 self.contents.insertHtml(dstr)
                 
-                dstr = self.trUtf8('<i>author: {0}</i><br />\n')\
-                    .format(log["author"])
+                author = log["author"]
+                message = log["message"]
+                if sys.version_info[0] == 2:
+                    author = author.decode('utf-8')
+                    message = message.decode('utf-8')
+                dstr = self.tr('<i>author: {0}</i><br />\n')\
+                    .format(author)
                 self.contents.insertHtml(dstr)
                 
-                dstr = self.trUtf8('<i>date: {0}</i><br />\n')\
+                dstr = self.tr('<i>date: {0}</i><br />\n')\
                     .format(formatTime(log["date"]))
                 self.contents.insertHtml(dstr)
                 
                 self.contents.insertHtml('<br />\n')
                 
-                for line in log["message"].splitlines():
+                for line in message.splitlines():
                     self.contents.insertHtml(Utilities.html_encode(line))
                     self.contents.insertHtml('<br />\n')
                 
                 if len(log['changed_paths']) > 0:
                     self.contents.insertHtml('<br />\n')
                     for changeInfo in log['changed_paths']:
-                        dstr = '{0} {1}'\
-                               .format(self.flags[changeInfo["action"]],
-                                       changeInfo["path"])
+                        action = changeInfo["action"]
+                        path = changeInfo["path"]
+                        if sys.version_info[0] == 2:
+                            action = action.decode('utf-8')
+                            path = path.decode('utf-8')
+                        dstr = '{0} {1}'.format(self.flags[action], path)
                         if changeInfo["copyfrom_path"] is not None:
-                            dstr += self.trUtf8(
+                            copyfrom_path = changeInfo["copyfrom_path"]
+                            if sys.version_info[0] == 2:
+                                copyfrom_path = copyfrom_path.decode('utf-8')
+                            dstr += self.tr(
                                 " (copied from {0}, revision {1})")\
-                                .format(changeInfo["copyfrom_path"],
+                                .format(copyfrom_path,
                                         changeInfo["copyfrom_revision"].number)
                         dstr += '<br />\n'
                         self.contents.insertHtml(dstr)
@@ -223,7 +241,10 @@ class SvnLogDialog(QWidget, SvnDialogMixin, Ui_SvnLogDialog):
         if Utilities.isWindowsPlatform():
             if filename.startswith("/"):
                 filename = filename[1:]
-        ver = bytes(url.encodedQuery()).decode()
+        if qVersion() >= "5.0.0":
+            ver = url.query()
+        else:
+            ver = bytes(url.encodedQuery()).decode()
         v1 = ver.split('_')[0]
         v2 = ver.split('_')[1]
         if not v1 or not v2:
