@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the login dialog for pysvn.
 """
 
-from PyQt4.QtGui import QDialog
+from __future__ import unicode_literals
+
+from PyQt5.QtWidgets import QDialog
 
 from .Ui_SvnLoginDialog import Ui_SvnLoginDialog
 
@@ -26,17 +28,20 @@ class SvnLoginDialog(QDialog, Ui_SvnLoginDialog):
             the answers returned (boolean)
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(SvnLoginDialog, self).__init__(parent)
         self.setupUi(self)
         
         self.realmLabel.setText(
-            self.trUtf8("<b>Enter login data for realm {0}.</b>")
+            self.tr("<b>Enter login data for realm {0}.</b>")
             .format(realm))
         self.usernameEdit.setText(username)
         self.saveCheckBox.setEnabled(may_save)
         if not may_save:
             self.saveCheckBox.setChecked(False)
         
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
+        
     def getData(self):
         """
         Public method to retrieve the login data.
