@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,10 +8,12 @@ Module implementing the Subversion Options Dialog for a new project from the
 repository.
 """
 
+from __future__ import unicode_literals
+
 import os
 
-from PyQt4.QtCore import QDir, pyqtSlot
-from PyQt4.QtGui import QDialog, QDialogButtonBox
+from PyQt5.QtCore import QDir, pyqtSlot
+from PyQt5.QtWidgets import QDialog, QDialogButtonBox
 
 from E5Gui.E5Completers import E5DirCompleter
 from E5Gui import E5FileDialog
@@ -21,6 +23,7 @@ from .Config import ConfigSvnProtocols
 
 import Utilities
 import Preferences
+import UI.PixmapCache
 
 
 class SvnNewProjectOptionsDialog(QDialog, Ui_SvnNewProjectOptionsDialog):
@@ -35,9 +38,12 @@ class SvnNewProjectOptionsDialog(QDialog, Ui_SvnNewProjectOptionsDialog):
         @param vcs reference to the version control object
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(SvnNewProjectOptionsDialog, self).__init__(parent)
         self.setupUi(self)
         
+        self.vcsUrlButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        self.projectDirButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        
         self.vcsDirectoryCompleter = E5DirCompleter(self.vcsUrlEdit)
         self.vcsProjectDirCompleter = E5DirCompleter(self.vcsProjectDirEdit)
         
@@ -65,6 +71,9 @@ class SvnNewProjectOptionsDialog(QDialog, Ui_SvnNewProjectOptionsDialog):
         self.resize(self.width(), self.minimumSizeHint().height())
         
         self.buttonBox.button(QDialogButtonBox.Ok).setEnabled(False)
+        
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
     
     @pyqtSlot(str)
     def on_vcsProjectDirEdit_textChanged(self, txt):
@@ -85,7 +94,7 @@ class SvnNewProjectOptionsDialog(QDialog, Ui_SvnNewProjectOptionsDialog):
         if self.protocolCombo.currentText() == "file://":
             directory = E5FileDialog.getExistingDirectory(
                 self,
-                self.trUtf8("Select Repository-Directory"),
+                self.tr("Select Repository-Directory"),
                 self.vcsUrlEdit.text(),
                 E5FileDialog.Options(E5FileDialog.ShowDirsOnly))
             
@@ -113,7 +122,7 @@ class SvnNewProjectOptionsDialog(QDialog, Ui_SvnNewProjectOptionsDialog):
         """
         directory = E5FileDialog.getExistingDirectory(
             self,
-            self.trUtf8("Select Project Directory"),
+            self.tr("Select Project Directory"),
             self.vcsProjectDirEdit.text(),
             E5FileDialog.Options(E5FileDialog.ShowDirsOnly))
         
@@ -142,13 +151,13 @@ class SvnNewProjectOptionsDialog(QDialog, Ui_SvnNewProjectOptionsDialog):
         if protocol == "file://":
             self.networkPath = self.vcsUrlEdit.text()
             self.vcsUrlEdit.setText(self.localPath)
-            self.vcsUrlLabel.setText(self.trUtf8("Pat&h:"))
+            self.vcsUrlLabel.setText(self.tr("Pat&h:"))
             self.localProtocol = True
         else:
             if self.localProtocol:
                 self.localPath = self.vcsUrlEdit.text()
                 self.vcsUrlEdit.setText(self.networkPath)
-                self.vcsUrlLabel.setText(self.trUtf8("&URL:"))
+                self.vcsUrlLabel.setText(self.tr("&URL:"))
                 self.localProtocol = False
     
     @pyqtSlot(str)
