@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to enter the data for a new property.
 """
 
-from PyQt4.QtGui import QDialog, QDialogButtonBox
+from __future__ import unicode_literals
+
+from PyQt5.QtWidgets import QDialog, QDialogButtonBox
 
 from .Ui_SvnPropDelDialog import Ui_SvnPropDelDialog
 
@@ -23,7 +25,7 @@ class SvnPropDelDialog(QDialog, Ui_SvnPropDelDialog):
         @param recursive flag indicating a recursive set is requested
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(SvnPropDelDialog, self).__init__(parent)
         self.setupUi(self)
         
         self.okButton = self.buttonBox.button(QDialogButtonBox.Ok)
@@ -31,6 +33,9 @@ class SvnPropDelDialog(QDialog, Ui_SvnPropDelDialog):
         
         self.recurseCheckBox.setChecked(recursive)
         
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
+        
     def on_propNameEdit_textChanged(self, text):
         """
         Private method used to enable/disable the OK-button.
