@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,13 +8,16 @@ Module implementing a dialog to show the output of the svn proplist command
 process.
 """
 
+from __future__ import unicode_literals
+
 import os
+import sys
 
 import pysvn
 
-from PyQt4.QtCore import QMutexLocker, Qt
-from PyQt4.QtGui import QWidget, QHeaderView, QApplication, QDialogButtonBox, \
-    QTreeWidgetItem
+from PyQt5.QtCore import QMutexLocker, Qt
+from PyQt5.QtWidgets import QWidget, QHeaderView, QApplication, \
+    QDialogButtonBox, QTreeWidgetItem
 
 from .SvnDialogMixin import SvnDialogMixin
 from .Ui_SvnPropListDialog import Ui_SvnPropListDialog
@@ -32,7 +35,7 @@ class SvnPropListDialog(QWidget, SvnDialogMixin, Ui_SvnPropListDialog):
         @param vcs reference to the vcs object
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(SvnPropListDialog, self).__init__(parent)
         self.setupUi(self)
         SvnDialogMixin.__init__(self)
         
@@ -102,7 +105,12 @@ class SvnPropListDialog(QWidget, SvnDialogMixin, Ui_SvnPropListDialog):
                 proplist = self.client.proplist(name, recurse=recursive)
                 counter = 0
                 for path, prop in proplist:
+                    if sys.version_info[0] == 2:
+                        path = path.decode('utf-8')
                     for propName, propVal in list(prop.items()):
+                        if sys.version_info[0] == 2:
+                            propName = propName.decode('utf-8')
+                            propVal = propVal.decode('utf-8')
                         self.__generateItem(path, propName, propVal)
                         self.propsFound = True
                     counter += 1
@@ -125,7 +133,7 @@ class SvnPropListDialog(QWidget, SvnDialogMixin, Ui_SvnPropListDialog):
         button.
         """
         if not self.propsFound:
-            self.__generateItem("", self.trUtf8("None"), "")
+            self.__generateItem("", self.tr("None"), "")
         
         self.__resort()
         self.__resizeColumns()
