@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to enter the data for a new property.
 """
 
-from PyQt4.QtGui import QDialog
+from __future__ import unicode_literals
+
+from PyQt5.QtWidgets import QDialog
 
 from .Ui_SvnPropSetDialog import Ui_SvnPropSetDialog
 
@@ -23,7 +25,7 @@ class SvnPropSetDialog(QDialog, Ui_SvnPropSetDialog):
         @param recursive flag indicating a recursive set is requested
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(SvnPropSetDialog, self).__init__(parent)
         self.setupUi(self)
         
         self.recurseCheckBox.setChecked(recursive)
