@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c)2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c)2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to enter the data to relocate the workspace.
 """
 
-from PyQt4.QtGui import QDialog
+from __future__ import unicode_literals
+
+from PyQt5.QtWidgets import QDialog
 
 from .Ui_SvnRelocateDialog import Ui_SvnRelocateDialog
 
@@ -23,12 +25,15 @@ class SvnRelocateDialog(QDialog, Ui_SvnRelocateDialog):
         @param currUrl current repository URL (string)
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(SvnRelocateDialog, self).__init__(parent)
         self.setupUi(self)
         
         self.currUrlLabel.setText(currUrl)
         self.newUrlEdit.setText(currUrl)
         
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
+        
     def getData(self):
         """
         Public slot used to retrieve the data entered into the dialog.
