@@ -1,16 +1,19 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the subversion repository browser dialog.
 """
 
+from __future__ import unicode_literals
+
 import pysvn
 
-from PyQt4.QtCore import QMutexLocker, Qt, pyqtSlot
-from PyQt4.QtGui import QCursor, QHeaderView, QDialog, QApplication, \
+from PyQt5.QtCore import QMutexLocker, Qt, pyqtSlot
+from PyQt5.QtGui import QCursor
+from PyQt5.QtWidgets import QHeaderView, QDialog, QApplication, \
     QDialogButtonBox, QTreeWidgetItem
 
 from E5Gui import E5MessageBox
@@ -35,9 +38,10 @@ class SvnRepoBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnRepoBrowserDialog):
         @param mode mode of the dialog (string, "browse" or "select")
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(SvnRepoBrowserDialog, self).__init__(parent)
         self.setupUi(self)
         SvnDialogMixin.__init__(self)
+        self.setWindowFlags(Qt.Window)
         
         self.repoTree.headerItem().setText(self.repoTree.columnCount(), "")
         self.repoTree.header().setSortIndicator(0, Qt.AscendingOrder)
@@ -159,6 +163,7 @@ class SvnRepoBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnRepoBrowserDialog):
             try:
                 entries = self.client.list(url, recurse=False)
                 firstTime = parent == self.repoTree
+                # dirent elements are all unicode in Python 2
                 for dirent, lock in entries:
                     if (firstTime and dirent["path"] != url) or \
                        (parent != self.repoTree and dirent["path"] == url):
@@ -198,8 +203,8 @@ class SvnRepoBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnRepoBrowserDialog):
                 self.__showError(e.args[0])
             except AttributeError:
                 self.__showError(
-                    self.trUtf8("The installed version of PySvn should be "
-                                "1.4.0 or better."))
+                    self.tr("The installed version of PySvn should be "
+                            "1.4.0 or better."))
         finally:
             locker.unlock()
             QApplication.restoreOverrideCursor()
@@ -275,7 +280,7 @@ class SvnRepoBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnRepoBrowserDialog):
         """
         E5MessageBox.critical(
             self,
-            self.trUtf8("Subversion Error"),
+            self.tr("Subversion Error"),
             msg)
     
     def accept(self):
@@ -285,7 +290,7 @@ class SvnRepoBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnRepoBrowserDialog):
         if self.focusWidget() == self.urlCombo:
             return
         
-        super().accept()
+        super(SvnRepoBrowserDialog, self).accept()
     
     def getSelectedUrl(self):
         """
