@@ -1,34 +1,40 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to enter the revisions for the svn diff command.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from __future__ import unicode_literals
 
-from Ui_SvnRevisionSelectionDialog import Ui_SvnRevisionSelectionDialog
+from PyQt5.QtCore import QDate, QDateTime, Qt
+from PyQt5.QtWidgets import QDialog
+
+from .Ui_SvnRevisionSelectionDialog import Ui_SvnRevisionSelectionDialog
 
 
 class SvnRevisionSelectionDialog(QDialog, Ui_SvnRevisionSelectionDialog):
     """
-    Class implementing a dialog to enter the revisions for the svn diff command.
+    Class implementing a dialog to enter the revisions for the svn diff
+    command.
     """
-    def __init__(self,parent = None):
+    def __init__(self, parent=None):
         """
         Constructor
         
         @param parent parent widget of the dialog (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super(SvnRevisionSelectionDialog, self).__init__(parent)
         self.setupUi(self)
         
         self.date1Edit.setDate(QDate.currentDate())
         self.date2Edit.setDate(QDate.currentDate())
         
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
+        
     def __getRevision(self, no):
         """
         Private method to generate the revision.
@@ -62,8 +68,9 @@ class SvnRevisionSelectionDialog(QDialog, Ui_SvnRevisionSelectionDialog):
         if numberButton.isChecked():
             return numberSpinBox.value()
         elif dateButton.isChecked():
-            return "{%s}" % \
-                QDateTime(dateEdit.date(), timeEdit.time()).toString(Qt.ISODate)
+            return "{{{0}}}".format(
+                QDateTime(dateEdit.date(), timeEdit.time())
+                .toString(Qt.ISODate))
         elif headButton.isChecked():
             return "HEAD"
         elif workingButton.isChecked():
