@@ -1,18 +1,20 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to show a list of tags or branches.
 """
 
+from __future__ import unicode_literals
+
 import os
 
 import pysvn
 
-from PyQt4.QtCore import QMutexLocker, QRegExp, Qt
-from PyQt4.QtGui import QHeaderView, QLineEdit, QDialog, QInputDialog, \
+from PyQt5.QtCore import QMutexLocker, QRegExp, Qt
+from PyQt5.QtWidgets import QHeaderView, QLineEdit, QDialog, QInputDialog, \
     QApplication, QDialogButtonBox, QTreeWidgetItem
 
 from E5Gui import E5MessageBox
@@ -35,9 +37,10 @@ class SvnTagBranchListDialog(QDialog, SvnDialogMixin,
         @param vcs reference to the vcs object
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(SvnTagBranchListDialog, self).__init__(parent)
         self.setupUi(self)
         SvnDialogMixin.__init__(self)
+        self.setWindowFlags(Qt.Window)
         
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
@@ -67,7 +70,7 @@ class SvnTagBranchListDialog(QDialog, SvnDialogMixin,
         self.errorGroup.hide()
         
         if not tags:
-            self.setWindowTitle(self.trUtf8("Subversion Branches List"))
+            self.setWindowTitle(self.tr("Subversion Branches List"))
         self.activateWindow()
         QApplication.processEvents()
         
@@ -77,8 +80,8 @@ class SvnTagBranchListDialog(QDialog, SvnDialogMixin,
         if reposURL is None:
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Subversion Error"),
-                self.trUtf8(
+                self.tr("Subversion Error"),
+                self.tr(
                     """The URL of the project repository could not be"""
                     """ retrieved from the working copy. The list operation"""
                     """ will be aborted"""))
@@ -91,8 +94,8 @@ class SvnTagBranchListDialog(QDialog, SvnDialogMixin,
             if not rx_base.exactMatch(reposURL):
                 E5MessageBox.critical(
                     self,
-                    self.trUtf8("Subversion Error"),
-                    self.trUtf8(
+                    self.tr("Subversion Error"),
+                    self.tr(
                         """The URL of the project repository has an"""
                         """ invalid format. The list operation will"""
                         """ be aborted"""))
@@ -107,9 +110,9 @@ class SvnTagBranchListDialog(QDialog, SvnDialogMixin,
         else:
             reposPath, ok = QInputDialog.getText(
                 self,
-                self.trUtf8("Subversion List"),
-                self.trUtf8("Enter the repository URL containing the"
-                            " tags or branches"),
+                self.tr("Subversion List"),
+                self.tr("Enter the repository URL containing the"
+                        " tags or branches"),
                 QLineEdit.Normal,
                 self.vcs.svnNormalizeURL(reposURL))
             if not ok:
@@ -118,8 +121,8 @@ class SvnTagBranchListDialog(QDialog, SvnDialogMixin,
             if not reposPath:
                 E5MessageBox.critical(
                     self,
-                    self.trUtf8("Subversion List"),
-                    self.trUtf8(
+                    self.tr("Subversion List"),
+                    self.tr(
                         """The repository URL is empty. Aborting..."""))
                 self.close()
                 return False
@@ -131,6 +134,7 @@ class SvnTagBranchListDialog(QDialog, SvnDialogMixin,
         os.chdir(dname)
         try:
             entries = self.client.list(path, recurse=False)
+            # dirent, lock already unicode in Python 2
             for dirent, lock in entries:
                 if dirent["path"] != path:
                     name = dirent["path"].replace(path + '/', "")
@@ -150,8 +154,8 @@ class SvnTagBranchListDialog(QDialog, SvnDialogMixin,
             res = False
         except AttributeError:
             self.__showError(
-                self.trUtf8("The installed version of PySvn should be"
-                            " 1.4.0 or better."))
+                self.tr("The installed version of PySvn should be"
+                        " 1.4.0 or better."))
             res = False
         locker.unlock()
         self.__finish()
