@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to enter the data for a tagging operation.
 """
 
-from PyQt4.QtCore import pyqtSlot
-from PyQt4.QtGui import QDialog, QDialogButtonBox
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSlot
+from PyQt5.QtWidgets import QDialog, QDialogButtonBox
 
 from .Ui_SvnTagDialog import Ui_SvnTagDialog
 
@@ -27,7 +29,7 @@ class SvnTagDialog(QDialog, Ui_SvnTagDialog):
             repository (boolean)
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(SvnTagDialog, self).__init__(parent)
         self.setupUi(self)
        
         self.okButton = self.buttonBox.button(QDialogButtonBox.Ok)
@@ -42,6 +44,9 @@ class SvnTagDialog(QDialog, Ui_SvnTagDialog):
         if not standardLayout:
             self.TagActionGroup.setEnabled(False)
         
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
+        
     @pyqtSlot(str)
     def on_tagCombo_editTextChanged(self, text):
         """
