@@ -1,19 +1,22 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the version control systems interface to Subversion.
 """
 
+from __future__ import unicode_literals
+
 import os
+import sys
 import shutil
-import urllib.parse
 import time
 
-from PyQt4.QtCore import Qt, QMutexLocker, pyqtSignal, QRegExp, QDateTime
-from PyQt4.QtGui import QLineEdit, QDialog, QInputDialog, QApplication
+from PyQt5.QtCore import Qt, QMutexLocker, pyqtSignal, QRegExp, QDateTime, \
+    QCoreApplication
+from PyQt5.QtWidgets import QLineEdit, QDialog, QInputDialog, QApplication
 
 from E5Gui.E5Application import e5App
 from E5Gui import E5MessageBox
@@ -104,8 +107,8 @@ class Subversion(VersionControl):
         self.__commitData = {}
         self.__commitDialog = None
         
-        self.__wcng = True      # assume new generation working copy
-                                # metadata format
+        self.__wcng = True
+        # assume new generation working copy metadata format
     
     def getPlugin(self):
         """
@@ -177,7 +180,7 @@ class Subversion(VersionControl):
         """
         Public method used to initialize the subversion repository.
         
-        The subversion repository has to be initialized from outside eric5
+        The subversion repository has to be initialized from outside eric6
         because the respective command always works locally. Therefore we
         always return TRUE without doing anything.
         
@@ -199,8 +202,8 @@ class Subversion(VersionControl):
         if not success:
             E5MessageBox.critical(
                 self.__ui,
-                self.trUtf8("Create project in repository"),
-                self.trUtf8(
+                self.tr("Create project in repository"),
+                self.tr(
                     """The project could not be created in the repository."""
                     """ Maybe the given repository doesn't exist or the"""
                     """ repository server is down."""))
@@ -223,8 +226,8 @@ class Subversion(VersionControl):
             if not os.path.isfile(pfn):
                 E5MessageBox.critical(
                     self.__ui,
-                    self.trUtf8("New project"),
-                    self.trUtf8(
+                    self.tr("New project"),
+                    self.tr(
                         """The project could not be checked out of the"""
                         """ repository.<br />"""
                         """Restoring the original contents."""))
@@ -295,7 +298,7 @@ class Subversion(VersionControl):
         client = self.getClient()
         if not noDialog:
             dlg = SvnDialog(
-                self.trUtf8('Importing project into Subversion repository'),
+                self.tr('Importing project into Subversion repository'),
                 "import{0} --message {1} .".format(
                     (not recurse) and " --non-recursive" or "", msg),
                 client)
@@ -310,7 +313,7 @@ class Subversion(VersionControl):
                 dlg.showError(e.args[0])
         locker.unlock()
         if not noDialog:
-            rev and dlg.showMessage(self.trUtf8("Imported revision {0}.\n")
+            rev and dlg.showMessage(self.tr("Imported revision {0}.\n")
                                     .format(rev.number))
             dlg.finish()
             dlg.exec_()
@@ -348,8 +351,8 @@ class Subversion(VersionControl):
                         not tag.startswith('branches'):
                     type_, ok = QInputDialog.getItem(
                         None,
-                        self.trUtf8("Subversion Checkout"),
-                        self.trUtf8(
+                        self.tr("Subversion Checkout"),
+                        self.tr(
                             "The tag must be a normal tag (tags) or"
                             " a branch tag (branches)."
                             " Please select from the list."),
@@ -368,7 +371,7 @@ class Subversion(VersionControl):
         client = self.getClient()
         if not noDialog:
             dlg = SvnDialog(
-                self.trUtf8('Checking project out of Subversion repository'),
+                self.tr('Checking project out of Subversion repository'),
                 "checkout{0} {1} {2}".format(
                     (not recurse) and " --non-recursive" or "",
                     url, projectDir),
@@ -413,8 +416,8 @@ class Subversion(VersionControl):
                         not tag.startswith('branches'):
                     type_, ok = QInputDialog.getItem(
                         None,
-                        self.trUtf8("Subversion Export"),
-                        self.trUtf8(
+                        self.tr("Subversion Export"),
+                        self.tr(
                             "The tag must be a normal tag (tags) or"
                             " a branch tag (branches)."
                             " Please select from the list."),
@@ -432,7 +435,7 @@ class Subversion(VersionControl):
         url = self.__svnURL(svnUrl)
         client = self.getClient()
         dlg = SvnDialog(
-            self.trUtf8('Exporting project from Subversion repository'),
+            self.tr('Exporting project from Subversion repository'),
             "export --force{0} {1} {2}".format(
                 (not recurse) and " --non-recursive" or "",
                 url, projectDir),
@@ -513,8 +516,8 @@ class Subversion(VersionControl):
             if not ok:
                 res = E5MessageBox.yesNo(
                     self.__ui,
-                    self.trUtf8("Commit Changes"),
-                    self.trUtf8(
+                    self.tr("Commit Changes"),
+                    self.tr(
                         """The commit affects files, that have unsaved"""
                         """ changes. Shall the commit be continued?"""),
                     icon=E5MessageBox.Warning)
@@ -555,7 +558,7 @@ class Subversion(VersionControl):
         client = self.getClient()
         if not noDialog:
             dlg = SvnDialog(
-                self.trUtf8('Commiting changes to Subversion repository'),
+                self.tr('Commiting changes to Subversion repository'),
                 "commit{0}{1}{2}{3} --message {4} {5}".format(
                     (not recurse) and " --non-recursive" or "",
                     keeplocks and " --keep-locks" or "",
@@ -580,7 +583,7 @@ class Subversion(VersionControl):
                 dlg.showError(e.args[0])
         locker.unlock()
         if not noDialog:
-            rev and dlg.showMessage(self.trUtf8("Committed revision {0}.")
+            rev and dlg.showMessage(self.tr("Committed revision {0}.")
                                     .format(rev.number))
             dlg.finish()
             dlg.exec_()
@@ -613,7 +616,7 @@ class Subversion(VersionControl):
         client = self.getClient()
         if not noDialog:
             dlg = SvnDialog(
-                self.trUtf8('Synchronizing with the Subversion repository'),
+                self.tr('Synchronizing with the Subversion repository'),
                 "update{0} {1}".format(
                     (not recurse) and " --non-recursive" or "",
                     " ".join(fnames)),
@@ -691,8 +694,8 @@ class Subversion(VersionControl):
                         repodir = os.path.dirname(repodir)
                         if os.path.splitdrive(repodir)[1] == os.sep:
                             return  # oops, project is not version controlled
-                    while os.path.normcase(d) != \
-                            os.path.normcase(repodir) and \
+                    while (os.path.normcase(d) !=
+                            os.path.normcase(repodir)) and \
                         (d not in tree2 + tree) and \
                         (os.path.normcase(d) not in self.statusCache or
                          self.statusCache[os.path.normcase(d)] ==
@@ -721,8 +724,8 @@ class Subversion(VersionControl):
         client = self.getClient()
         if not noDialog:
             dlg = SvnDialog(
-                self.trUtf8('Adding files/directories to the Subversion'
-                            ' repository'),
+                self.tr('Adding files/directories to the Subversion'
+                        ' repository'),
                 "add --non-recursive{0}{1} {2}".format(
                     force and " --force" or "",
                     noignore and " --no-ignore" or "",
@@ -771,8 +774,8 @@ class Subversion(VersionControl):
                         repodir = os.path.dirname(repodir)
                         if os.path.splitdrive(repodir)[1] == os.sep:
                             return  # oops, project is not version controlled
-                    while os.path.normcase(d) != \
-                            os.path.normcase(repodir) and \
+                    while (os.path.normcase(d) !=
+                            os.path.normcase(repodir)) and \
                         (d not in tree) and \
                         (os.path.normcase(d) not in self.statusCache or
                          self.statusCache[os.path.normcase(d)] ==
@@ -796,8 +799,8 @@ class Subversion(VersionControl):
                     repodir = os.path.dirname(repodir)
                     if os.path.splitdrive(repodir)[1] == os.sep:
                         return  # oops, project is not version controlled
-                while os.path.normcase(dname) != \
-                        os.path.normcase(repodir) and \
+                while (os.path.normcase(dname) !=
+                        os.path.normcase(repodir)) and \
                     (os.path.normcase(dname) not in self.statusCache or
                      self.statusCache[os.path.normcase(dname)] ==
                         self.canBeAdded):
@@ -829,7 +832,7 @@ class Subversion(VersionControl):
         ignore = "--ignore" in opts
         client = self.getClient()
         dlg = SvnDialog(
-            self.trUtf8('Adding directory trees to the Subversion repository'),
+            self.tr('Adding directory trees to the Subversion repository'),
             "add{0}{1} {2}".format(
                 force and " --force" or "",
                 ignore and " --ignore" or "",
@@ -866,8 +869,8 @@ class Subversion(VersionControl):
         client = self.getClient()
         if not noDialog:
             dlg = SvnDialog(
-                self.trUtf8('Removing files/directories from the Subversion'
-                            ' repository'),
+                self.tr('Removing files/directories from the Subversion'
+                        ' repository'),
                 "remove{0} {1}".format(
                     force and " --force" or "",
                     " ".join(name)),
@@ -932,7 +935,7 @@ class Subversion(VersionControl):
             if not noDialog:
                 dlg = \
                     SvnDialog(
-                        self.trUtf8('Moving {0}').format(name),
+                        self.tr('Moving {0}').format(name),
                         "move{0}{1} {2} {3}".format(
                             force and " --force" or "",
                             log and (" --message {0}".format(log)) or "",
@@ -974,8 +977,8 @@ class Subversion(VersionControl):
         isFile = os.path.isfile(name)
         noEntries, ok = QInputDialog.getInt(
             None,
-            self.trUtf8("Subversion Log"),
-            self.trUtf8("Select number of entries to show."),
+            self.tr("Subversion Log"),
+            self.tr("Select number of entries to show."),
             self.getPlugin().getPreferences("LogLimit"), 1, 999999, 1)
         if ok:
             from .SvnLogDialog import SvnLogDialog
@@ -1042,8 +1045,8 @@ class Subversion(VersionControl):
         if reposURL is None:
             E5MessageBox.critical(
                 self.__ui,
-                self.trUtf8("Subversion Error"),
-                self.trUtf8(
+                self.tr("Subversion Error"),
+                self.tr(
                     """The URL of the project repository could not be"""
                     """ retrieved from the working copy. The tag operation"""
                     """ will be aborted"""))
@@ -1069,8 +1072,8 @@ class Subversion(VersionControl):
             if not rx_base.exactMatch(reposURL):
                 E5MessageBox.critical(
                     self.__ui,
-                    self.trUtf8("Subversion Error"),
-                    self.trUtf8(
+                    self.tr("Subversion Error"),
+                    self.tr(
                         """The URL of the project repository has an"""
                         """ invalid format. The tag operation will"""
                         """ be aborted"""))
@@ -1078,10 +1081,10 @@ class Subversion(VersionControl):
             
             reposRoot = rx_base.cap(1)
             if tagOp in [1, 4]:
-                url = '{0}/tags/{1}'.format(reposRoot, urllib.parse.quote(tag))
+                url = '{0}/tags/{1}'.format(reposRoot, Utilities.quote(tag))
             elif tagOp in [2, 8]:
                 url = '{0}/branches/{1}'.format(
-                    reposRoot, urllib.parse.quote(tag))
+                    reposRoot, Utilities.quote(tag))
         else:
             url = self.__svnURL(tag)
         
@@ -1091,7 +1094,7 @@ class Subversion(VersionControl):
         if tagOp in [1, 2]:
             log = 'Created tag <{0}>'.format(self.tagName)
             dlg = SvnDialog(
-                self.trUtf8('Tagging {0} in the Subversion repository')
+                self.tr('Tagging {0} in the Subversion repository')
                     .format(name),
                 "copy --message {0} {1} {2}".format(log, reposURL, url),
                 client, log=log)
@@ -1105,7 +1108,7 @@ class Subversion(VersionControl):
         else:
             log = 'Deleted tag <{0}>'.format(self.tagName)
             dlg = SvnDialog(
-                self.trUtf8('Tagging {0} in the Subversion repository')
+                self.tr('Tagging {0} in the Subversion repository')
                     .format(name),
                 "remove --message {0} {1}".format(log, url),
                 client, log=log)
@@ -1117,7 +1120,7 @@ class Subversion(VersionControl):
                 dlg.showError(e.args[0])
             locker.unlock()
         rev and dlg.showMessage(
-            self.trUtf8("Revision {0}.\n").format(rev.number))
+            self.tr("Revision {0}.\n").format(rev.number))
         dlg.finish()
         dlg.exec_()
         
@@ -1140,8 +1143,8 @@ class Subversion(VersionControl):
                 DeleteFilesConfirmationDialog
             dia = DeleteFilesConfirmationDialog(
                 self.parent(),
-                self.trUtf8("Revert changes"),
-                self.trUtf8(
+                self.tr("Revert changes"),
+                self.tr(
                     "Do you really want to revert all changes to these files"
                     " or directories?"),
                 name)
@@ -1149,13 +1152,13 @@ class Subversion(VersionControl):
         else:
             yes = E5MessageBox.yesNo(
                 None,
-                self.trUtf8("Revert changes"),
-                self.trUtf8("""Do you really want to revert all changes of"""
-                            """ the project?"""))
+                self.tr("Revert changes"),
+                self.tr("""Do you really want to revert all changes of"""
+                        """ the project?"""))
         if yes:
             client = self.getClient()
             dlg = SvnDialog(
-                self.trUtf8('Reverting changes'),
+                self.tr('Reverting changes'),
                 "revert {0} {1}".format(
                     (not recurse) and " --non-recursive" or "",
                     " ".join(name)),
@@ -1185,8 +1188,8 @@ class Subversion(VersionControl):
         if reposURL is None:
             E5MessageBox.critical(
                 self.__ui,
-                self.trUtf8("Subversion Error"),
-                self.trUtf8(
+                self.tr("Subversion Error"),
+                self.tr(
                     """The URL of the project repository could not be"""
                     """ retrieved from the working copy. The switch"""
                     """ operation will be aborted"""))
@@ -1212,8 +1215,8 @@ class Subversion(VersionControl):
             if not rx_base.exactMatch(reposURL):
                 E5MessageBox.critical(
                     self.__ui,
-                    self.trUtf8("Subversion Error"),
-                    self.trUtf8(
+                    self.tr("Subversion Error"),
+                    self.tr(
                         """The URL of the project repository has an"""
                         """ invalid format. The switch operation will"""
                         """ be aborted"""))
@@ -1222,10 +1225,10 @@ class Subversion(VersionControl):
             reposRoot = rx_base.cap(1)
             tn = tag
             if tagType == 1:
-                url = '{0}/tags/{1}'.format(reposRoot, urllib.parse.quote(tag))
+                url = '{0}/tags/{1}'.format(reposRoot, Utilities.quote(tag))
             elif tagType == 2:
                 url = '{0}/branches/{1}'.format(
-                    reposRoot, urllib.parse.quote(tag))
+                    reposRoot, Utilities.quote(tag))
             elif tagType == 4:
                 url = '{0}/trunk'.format(reposRoot)
                 tn = 'HEAD'
@@ -1234,14 +1237,14 @@ class Subversion(VersionControl):
             tn = url
         
         client = self.getClient()
-        dlg = SvnDialog(self.trUtf8('Switching to {0}').format(tn),
+        dlg = SvnDialog(self.tr('Switching to {0}').format(tn),
                         "switch {0} {1}".format(url, name),
                         client)
         QApplication.processEvents()
         locker = QMutexLocker(self.vcsExecutionMutex)
         try:
             rev = client.switch(name, url)
-            dlg.showMessage(self.trUtf8("Revision {0}.\n").format(rev.number))
+            dlg.showMessage(self.tr("Revision {0}.\n").format(rev.number))
         except pysvn.ClientError as e:
             dlg.showError(e.args[0])
         locker.unlock()
@@ -1338,7 +1341,7 @@ class Subversion(VersionControl):
         client = self.getClient()
         dlg = \
             SvnDialog(
-                self.trUtf8('Merging {0}').format(name),
+                self.tr('Merging {0}').format(name),
                 "merge{0}{1} {2} {3} {4}".format(
                     (not recurse) and " --non-recursive" or "",
                     force and " --force" or "",
@@ -1495,6 +1498,7 @@ class Subversion(VersionControl):
                 locker.unlock()
                 dirs = [x for x in names.keys() if os.path.isdir(x)]
                 for file in allFiles:
+                    # file.path is always unicode in Python 2
                     name = os.path.normcase(file.path)
                     if self.__isVersioned(file):
                         if name in names:
@@ -1569,6 +1573,7 @@ class Subversion(VersionControl):
                                          ignore=True, update=False)
                 locker.unlock()
                 for file in allFiles:
+                    # file.path is always unicode in Python 2
                     name = os.path.normcase(file.path)
                     if self.__isVersioned(file):
                         if name in names:
@@ -1636,7 +1641,7 @@ class Subversion(VersionControl):
         @param name directory name to be cleaned up (string)
         """
         client = self.getClient()
-        dlg = SvnDialog(self.trUtf8('Cleaning up {0}').format(name),
+        dlg = SvnDialog(self.tr('Cleaning up {0}').format(name),
                         "cleanup {0}".format(name),
                         client)
         QApplication.processEvents()
@@ -1675,7 +1680,7 @@ class Subversion(VersionControl):
             
             from Plugins.VcsPlugins.vcsSubversion.SvnDialog import \
                 SvnDialog as SvnProcessDialog
-            dia = SvnProcessDialog(self.trUtf8('Subversion command'))
+            dia = SvnProcessDialog(self.tr('Subversion command'))
             res = dia.startProcess(args, wd)
             if res:
                 dia.exec_()
@@ -1723,8 +1728,12 @@ class Subversion(VersionControl):
                 ".".join([str(v) for v in pysvn.svn_api_version[:3]]),
                 pysvn.svn_api_version[3])
         else:
-            apiVersion = QApplication.translate('subversion', "unknown")
-        return QApplication.translate(
+            apiVersion = QCoreApplication.translate('subversion', "unknown")
+        
+        hmsz = time.strftime("%H:%M:%S %Z", time.localtime(entry.commit_time))
+        if sys.version_info[0] == 2:
+            hmsz = hmsz.decode(sys.getfilesystemencoding())
+        return QCoreApplication.translate(
             'subversion',
             """<h3>Repository information</h3>"""
             """<table>"""
@@ -1747,8 +1756,7 @@ class Subversion(VersionControl):
                     entry.commit_revision.number,
                     time.strftime(
                         "%Y-%m-%d", time.localtime(entry.commit_time)),
-                    time.strftime(
-                        "%H:%M:%S %Z", time.localtime(entry.commit_time)),
+                    hmsz,
                     entry.commit_author
                     )
     
@@ -1792,7 +1800,7 @@ class Subversion(VersionControl):
         opts = self.options['global']
         recurse = "--non-recursive" not in opts
         client = self.getClient()
-        dlg = SvnDialog(self.trUtf8('Resolving conficts'),
+        dlg = SvnDialog(self.tr('Resolving conficts'),
                         "resolved{0} {1}".format(
                             (not recurse) and " --non-recursive" or "",
                             " ".join(fnames)),
@@ -1833,7 +1841,7 @@ class Subversion(VersionControl):
                 target = target
             dlg = \
                 SvnDialog(
-                    self.trUtf8('Copying {0}').format(name),
+                    self.tr('Copying {0}').format(name),
                     "copy{0} {1} {2}".format(
                         log and (" --message {0}".format(log)) or "",
                         name, target),
@@ -1885,8 +1893,8 @@ class Subversion(VersionControl):
             if not propName:
                 E5MessageBox.critical(
                     self.__ui,
-                    self.trUtf8("Subversion Set Property"),
-                    self.trUtf8(
+                    self.tr("Subversion Set Property"),
+                    self.tr(
                         """You have to supply a property name. Aborting."""))
                 return
             
@@ -1904,7 +1912,7 @@ class Subversion(VersionControl):
             client = self.getClient()
             dlg = \
                 SvnDialog(
-                    self.trUtf8('Subversion Set Property'),
+                    self.tr('Subversion Set Property'),
                     "propset{0}{1} {2} {3} {4}".format(
                         recurse and " --recurse" or "",
                         skipchecks and " --skip-checks" or "",
@@ -1919,7 +1927,7 @@ class Subversion(VersionControl):
             except pysvn.ClientError as e:
                 dlg.showError(e.args[0])
             locker.unlock()
-            dlg.showMessage(self.trUtf8("Property set."))
+            dlg.showMessage(self.tr("Property set."))
             dlg.finish()
             dlg.exec_()
             os.chdir(cwd)
@@ -1939,8 +1947,8 @@ class Subversion(VersionControl):
             if not propName:
                 E5MessageBox.critical(
                     self.__ui,
-                    self.trUtf8("Subversion Delete Property"),
-                    self.trUtf8(
+                    self.tr("Subversion Delete Property"),
+                    self.tr(
                         """You have to supply a property name. Aborting."""))
                 return
             
@@ -1958,7 +1966,7 @@ class Subversion(VersionControl):
             client = self.getClient()
             dlg = \
                 SvnDialog(
-                    self.trUtf8('Subversion Delete Property'),
+                    self.tr('Subversion Delete Property'),
                     "propdel{0}{1} {2} {3}".format(
                         recurse and " --recurse" or "",
                         skipchecks and " --skip-checks" or "",
@@ -1972,7 +1980,7 @@ class Subversion(VersionControl):
             except pysvn.ClientError as e:
                 dlg.showError(e.args[0])
             locker.unlock()
-            dlg.showMessage(self.trUtf8("Property deleted."))
+            dlg.showMessage(self.tr("Property deleted."))
             dlg.finish()
             dlg.exec_()
             os.chdir(cwd)
@@ -2131,7 +2139,7 @@ class Subversion(VersionControl):
                 output = client.cat(name, revision=rev)
             else:
                 output = client.cat(name)
-            output = output.decode()
+            output = output.decode('utf-8')
         except pysvn.ClientError as e:
             error = str(e)
         
@@ -2168,7 +2176,7 @@ class Subversion(VersionControl):
         if error:
             E5MessageBox.critical(
                 self.__ui,
-                self.trUtf8("Subversion Side-by-Side Difference"),
+                self.tr("Subversion Side-by-Side Difference"),
                 error)
             return
         name1 = "{0} (rev. {1})".format(name, rev1 and rev1 or ".")
@@ -2178,7 +2186,7 @@ class Subversion(VersionControl):
             if error:
                 E5MessageBox.critical(
                     self.__ui,
-                    self.trUtf8("Subversion Side-by-Side Difference"),
+                    self.tr("Subversion Side-by-Side Difference"),
                     error)
                 return
             name2 = "{0} (rev. {1})".format(name, rev2)
@@ -2191,8 +2199,8 @@ class Subversion(VersionControl):
             except IOError:
                 E5MessageBox.critical(
                     self.__ui,
-                    self.trUtf8("Subversion Side-by-Side Difference"),
-                    self.trUtf8(
+                    self.tr("Subversion Side-by-Side Difference"),
+                    self.tr(
                         """<p>The file <b>{0}</b> could not be read.</p>""")
                     .format(name))
                 return
@@ -2203,19 +2211,20 @@ class Subversion(VersionControl):
         self.sbsDiff.show()
         self.sbsDiff.compare(output1, output2, name1, name2)
     
-    def svnLogBrowser(self, path, isFile=False):
+    def vcsLogBrowser(self, name, isFile=False):
         """
         Public method used to browse the log of a file/directory from the
         Subversion repository.
         
-        @param path file/directory name to show the log of (string)
+        @param name file/directory name to show the log of (string)
         @param isFile flag indicating log for a file is to be shown (boolean)
         """
-        from .SvnLogBrowserDialog import SvnLogBrowserDialog
-        self.logBrowser = SvnLogBrowserDialog(self, isFile=isFile)
+        if self.logBrowser is None:
+            from .SvnLogBrowserDialog import SvnLogBrowserDialog
+            self.logBrowser = SvnLogBrowserDialog(self)
         self.logBrowser.show()
         QApplication.processEvents()
-        self.logBrowser.start(path)
+        self.logBrowser.start(name, isFile=isFile)
         
     def svnLock(self, name, stealIt=False, parent=None):
         """
@@ -2229,8 +2238,8 @@ class Subversion(VersionControl):
         """
         comment, ok = QInputDialog.getText(
             None,
-            self.trUtf8("Subversion Lock"),
-            self.trUtf8("Enter lock comment"),
+            self.tr("Subversion Lock"),
+            self.tr("Enter lock comment"),
             QLineEdit.Normal)
         
         if not ok:
@@ -2248,7 +2257,7 @@ class Subversion(VersionControl):
         client = self.getClient()
         dlg = \
             SvnDialog(
-                self.trUtf8('Locking in the Subversion repository'),
+                self.tr('Locking in the Subversion repository'),
                 "lock{0}{1} {2}".format(
                     stealIt and " --force" or "",
                     comment and (" --message {0}".format(comment)) or "",
@@ -2288,7 +2297,7 @@ class Subversion(VersionControl):
         client = self.getClient()
         dlg = \
             SvnDialog(
-                self.trUtf8('Unlocking in the Subversion repository'),
+                self.tr('Unlocking in the Subversion repository'),
                 "unlock{0} {1}".format(
                     breakIt and " --force" or "",
                     " ".join(fnames)),
@@ -2335,7 +2344,7 @@ class Subversion(VersionControl):
                                                     projectPath)
             client = self.getClient()
             dlg = \
-                SvnDialog(self.trUtf8('Relocating'), msg, client)
+                SvnDialog(self.tr('Relocating'), msg, client)
             QApplication.processEvents()
             locker = QMutexLocker(self.vcsExecutionMutex)
             try:
@@ -2363,8 +2372,8 @@ class Subversion(VersionControl):
         if url is None:
             url, ok = QInputDialog.getText(
                 None,
-                self.trUtf8("Repository Browser"),
-                self.trUtf8("Enter the repository URL."),
+                self.tr("Repository Browser"),
+                self.tr("Enter the repository URL."),
                 QLineEdit.Normal)
             if not ok or not url:
                 return
@@ -2386,7 +2395,7 @@ class Subversion(VersionControl):
             names = [names]
         client = self.getClient()
         dlg = \
-            SvnDialog(self.trUtf8('Remove from changelist'),
+            SvnDialog(self.tr('Remove from changelist'),
                       "changelist --remove {0}".format(" ".join(names)),
                       client)
         QApplication.processEvents()
@@ -2414,8 +2423,8 @@ class Subversion(VersionControl):
         
         clname, ok = QInputDialog.getItem(
             None,
-            self.trUtf8("Add to changelist"),
-            self.trUtf8("Enter name of the changelist:"),
+            self.tr("Add to changelist"),
+            self.tr("Enter name of the changelist:"),
             sorted(self.svnGetChangelists()),
             0, True)
         if not ok or not clname:
@@ -2423,7 +2432,7 @@ class Subversion(VersionControl):
 
         client = self.getClient()
         dlg = \
-            SvnDialog(self.trUtf8('Add to changelist'),
+            SvnDialog(self.tr('Add to changelist'),
                       "changelist {0}".format(" ".join(names)),
                       client)
         QApplication.processEvents()
@@ -2466,6 +2475,8 @@ class Subversion(VersionControl):
                                                 depth=pysvn.depth.infinity)
                 for entry in entries:
                     changelist = entry[1]
+                    if sys.version_info[0] == 2:
+                        changelist = changelist.decode('utf-8')
                     if changelist not in changelists:
                         changelists.append(changelist)
             except pysvn.ClientError:
@@ -2482,7 +2493,7 @@ class Subversion(VersionControl):
         """
         client = self.getClient()
         dlg = \
-            SvnDialog(self.trUtf8('Upgrade'),
+            SvnDialog(self.tr('Upgrade'),
                       "upgrade {0}".format(path),
                       client)
         QApplication.processEvents()
@@ -2513,11 +2524,11 @@ class Subversion(VersionControl):
             host = url[1]
             port, path = url[2].split("/", 1)
             return "{0}:{1}:{2}/{3}".format(scheme, host, port,
-                                            urllib.parse.quote(path))
+                                            Utilities.quote(path))
         else:
             scheme = url[0]
             if scheme == "file":
-                return "{0}:{1}".format(scheme, urllib.parse.quote(url[1]))
+                return "{0}:{1}".format(scheme, Utilities.quote(url[1]))
             else:
                 try:
                     host, path = url[1][2:].split("/", 1)
@@ -2525,7 +2536,7 @@ class Subversion(VersionControl):
                     host = url[1][2:]
                     path = ""
                 return "{0}://{1}/{2}".format(scheme, host,
-                                              urllib.parse.quote(path))
+                                              Utilities.quote(path))
 
     def svnNormalizeURL(self, url):
         """
