@@ -1,24 +1,29 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to show the output of the svn blame command.
 """
 
+from __future__ import unicode_literals
+try:
+    str = unicode
+except NameError:
+    pass
+
 import os
 
-from PyQt4.QtCore import QTimer, QProcess, Qt, pyqtSlot
-from PyQt4.QtGui import QHeaderView, QLineEdit, QDialog, QDialogButtonBox, \
-    QFont, QTreeWidgetItem
+from PyQt5.QtCore import QTimer, QProcess, Qt, pyqtSlot
+from PyQt5.QtWidgets import QHeaderView, QLineEdit, QDialog, \
+    QDialogButtonBox, QTreeWidgetItem
 
 from E5Gui import E5MessageBox
 
 from .Ui_SvnBlameDialog import Ui_SvnBlameDialog
 
 import Preferences
-import Utilities
 
 
 class SvnBlameDialog(QDialog, Ui_SvnBlameDialog):
@@ -32,8 +37,9 @@ class SvnBlameDialog(QDialog, Ui_SvnBlameDialog):
         @param vcs reference to the vcs object
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(SvnBlameDialog, self).__init__(parent)
         self.setupUi(self)
+        self.setWindowFlags(Qt.Window)
         
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
@@ -42,11 +48,7 @@ class SvnBlameDialog(QDialog, Ui_SvnBlameDialog):
         self.vcs = vcs
         
         self.blameList.headerItem().setText(self.blameList.columnCount(), "")
-        font = QFont(self.blameList.font())
-        if Utilities.isWindowsPlatform():
-            font.setFamily("Lucida Console")
-        else:
-            font.setFamily("Monospace")
+        font = Preferences.getEditorOtherFonts("MonospacedFont")
         self.blameList.setFont(font)
         
         self.__ioEncoding = Preferences.getSystem("IOEncoding")
@@ -57,7 +59,7 @@ class SvnBlameDialog(QDialog, Ui_SvnBlameDialog):
         
     def closeEvent(self, e):
         """
-        Private slot implementing a close event handler.
+        Protected slot implementing a close event handler.
         
         @param e close event (QCloseEvent)
         """
@@ -98,8 +100,8 @@ class SvnBlameDialog(QDialog, Ui_SvnBlameDialog):
             self.inputGroup.hide()
             E5MessageBox.critical(
                 self,
-                self.trUtf8('Process Generation Error'),
-                self.trUtf8(
+                self.tr('Process Generation Error'),
+                self.tr(
                     'The process {0} could not be started. '
                     'Ensure, that it is in the search path.'
                 ).format('svn'))
@@ -255,4 +257,4 @@ class SvnBlameDialog(QDialog, Ui_SvnBlameDialog):
             self.intercept = False
             evt.accept()
             return
-        super().keyPressEvent(evt)
+        super(SvnBlameDialog, self).keyPressEvent(evt)
