@@ -1,16 +1,22 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog starting a process and showing its output.
 """
 
+from __future__ import unicode_literals
+try:
+    str = unicode
+except NameError:
+    pass
+
 import os
 
-from PyQt4.QtCore import QTimer, QProcess, pyqtSlot, Qt, QProcessEnvironment
-from PyQt4.QtGui import QLineEdit, QDialog, QDialogButtonBox
+from PyQt5.QtCore import QTimer, QProcess, pyqtSlot, Qt, QProcessEnvironment
+from PyQt5.QtWidgets import QLineEdit, QDialog, QDialogButtonBox
 
 from E5Gui import E5MessageBox
 
@@ -34,8 +40,9 @@ class SvnDialog(QDialog, Ui_SvnDialog):
         @param text text to be shown by the label (string)
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(SvnDialog, self).__init__(parent)
         self.setupUi(self)
+        self.setWindowFlags(Qt.Window)
         
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
@@ -146,8 +153,8 @@ class SvnDialog(QDialog, Ui_SvnDialog):
             self.inputGroup.hide()
             E5MessageBox.critical(
                 self,
-                self.trUtf8('Process Generation Error'),
-                self.trUtf8(
+                self.tr('Process Generation Error'),
+                self.tr(
                     'The process {0} could not be started. '
                     'Ensure, that it is in the search path.'
                 ).format('svn'))
@@ -250,7 +257,7 @@ class SvnDialog(QDialog, Ui_SvnDialog):
             self.intercept = False
             evt.accept()
             return
-        super().keyPressEvent(evt)
+        super(SvnDialog, self).keyPressEvent(evt)
         
     def hasAddOrDelete(self):
         """
