@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,8 +8,15 @@ Module implementing a dialog to show the output of the svn proplist command
 process.
 """
 
-from PyQt4.QtCore import QTimer, QProcess, QProcessEnvironment, QRegExp, Qt
-from PyQt4.QtGui import QWidget, QHeaderView, QDialogButtonBox, QTreeWidgetItem
+from __future__ import unicode_literals
+try:
+    str = unicode
+except NameError:
+    pass
+
+from PyQt5.QtCore import QTimer, QProcess, QProcessEnvironment, QRegExp, Qt
+from PyQt5.QtWidgets import QWidget, QHeaderView, QDialogButtonBox, \
+    QTreeWidgetItem
 
 from E5Gui import E5MessageBox
 
@@ -30,7 +37,7 @@ class SvnPropListDialog(QWidget, Ui_SvnPropListDialog):
         @param vcs reference to the vcs object
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(SvnPropListDialog, self).__init__(parent)
         self.setupUi(self)
         
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
@@ -82,7 +89,7 @@ class SvnPropListDialog(QWidget, Ui_SvnPropListDialog):
         
     def closeEvent(self, e):
         """
-        Private slot implementing a close event handler.
+        Protected slot implementing a close event handler.
         
         @param e close event (QCloseEvent)
         """
@@ -125,8 +132,8 @@ class SvnPropListDialog(QWidget, Ui_SvnPropListDialog):
         if not procStarted:
             E5MessageBox.critical(
                 self,
-                self.trUtf8('Process Generation Error'),
-                self.trUtf8(
+                self.tr('Process Generation Error'),
+                self.tr(
                     'The process {0} could not be started. '
                     'Ensure, that it is in the search path.'
                 ).format('svn'))
