@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to enter the data for a new property.
 """
 
-from PyQt4.QtCore import pyqtSlot
-from PyQt4.QtGui import QDialog
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSlot
+from PyQt5.QtWidgets import QDialog
 
 from E5Gui.E5Completers import E5FileCompleter
 from E5Gui import E5FileDialog
@@ -16,6 +18,7 @@ from E5Gui import E5FileDialog
 from .Ui_SvnPropSetDialog import Ui_SvnPropSetDialog
 
 import Utilities
+import UI.PixmapCache
 
 
 class SvnPropSetDialog(QDialog, Ui_SvnPropSetDialog):
@@ -28,9 +31,11 @@ class SvnPropSetDialog(QDialog, Ui_SvnPropSetDialog):
         
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(SvnPropSetDialog, self).__init__(parent)
         self.setupUi(self)
         
+        self.fileButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        
         self.propFileCompleter = E5FileCompleter(self.propFileEdit)
         
     @pyqtSlot()
@@ -40,7 +45,7 @@ class SvnPropSetDialog(QDialog, Ui_SvnPropSetDialog):
         """
         fn = E5FileDialog.getOpenFileName(
             self,
-            self.trUtf8("Select file for property"),
+            self.tr("Select file for property"),
             self.propFileEdit.text(),
             "")
         
