@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to enter the URLs for the svn diff command.
 """
 
-from PyQt4.QtCore import QRegExp, pyqtSlot
-from PyQt4.QtGui import QDialog
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import QRegExp, pyqtSlot
+from PyQt5.QtWidgets import QDialog
 
 from E5Gui.E5Application import e5App
 from E5Gui import E5MessageBox
@@ -32,7 +34,7 @@ class SvnUrlSelectionDialog(QDialog, Ui_SvnUrlSelectionDialog):
         @param path pathname to determine the repository URL from (string)
         @param parent parent widget of the dialog (QWidget)
         """
-        super().__init__(parent)
+        super(SvnUrlSelectionDialog, self).__init__(parent)
         self.setupUi(self)
         
         if vcs.version < (1, 4, 0):
@@ -50,8 +52,8 @@ class SvnUrlSelectionDialog(QDialog, Ui_SvnUrlSelectionDialog):
         if reposURL is None:
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Subversion Error"),
-                self.trUtf8(
+                self.tr("Subversion Error"),
+                self.tr(
                     """The URL of the project repository could not be"""
                     """ retrieved from the working copy. The operation will"""
                     """ be aborted"""))
@@ -64,8 +66,8 @@ class SvnUrlSelectionDialog(QDialog, Ui_SvnUrlSelectionDialog):
             if not rx_base.exactMatch(reposURL):
                 E5MessageBox.critical(
                     self,
-                    self.trUtf8("Subversion Error"),
-                    self.trUtf8(
+                    self.tr("Subversion Error"),
+                    self.tr(
                         """The URL of the project repository has an"""
                         """ invalid format. The list operation will"""
                         """ be aborted"""))
@@ -90,6 +92,9 @@ class SvnUrlSelectionDialog(QDialog, Ui_SvnUrlSelectionDialog):
             self.labelCombo2.addItems([reposURL] + sorted(self.vcs.tagsList))
             self.labelCombo2.setEnabled(True)
         
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
+        
     def __changeLabelCombo(self, labelCombo, type_):
         """
         Private method used to change the label combo depending on the
