@@ -1,19 +1,24 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the version control systems interface to Subversion.
 """
 
+from __future__ import unicode_literals
+try:
+    str = unicode
+except NameError:
+    pass
+
 import os
 import re
 import shutil
-import urllib.parse
 
-from PyQt4.QtCore import pyqtSignal, QProcess, QRegExp
-from PyQt4.QtGui import QLineEdit, QDialog, QInputDialog, QApplication
+from PyQt5.QtCore import pyqtSignal, QProcess, QRegExp, QCoreApplication
+from PyQt5.QtWidgets import QLineEdit, QDialog, QInputDialog, QApplication
 
 from E5Gui.E5Application import e5App
 from E5Gui import E5MessageBox
@@ -45,18 +50,18 @@ class Subversion(VersionControl):
         """
         VersionControl.__init__(self, parent, name)
         self.defaultOptions = {
-            'global':   [''],
-            'commit':   [''],
+            'global': [''],
+            'commit': [''],
             'checkout': [''],
-            'update':   [''],
-            'add':      [''],
-            'remove':   [''],
-            'diff':     [''],
-            'log':      [''],
-            'history':  [''],
-            'status':   [''],
-            'tag':      [''],
-            'export':   ['']
+            'update': [''],
+            'add': [''],
+            'remove': [''],
+            'diff': [''],
+            'log': [''],
+            'history': [''],
+            'status': [''],
+            'tag': [''],
+            'export': ['']
         }
         self.interestingDataKeys = [
             "standardLayout",
@@ -95,6 +100,7 @@ class Subversion(VersionControl):
         self.tagbranchList = None
         self.blame = None
         self.repoBrowser = None
+        self.logBrowser = None
         
         # regular expression object for evaluation of the status output
         self.rx_status1 = QRegExp(
@@ -105,8 +111,8 @@ class Subversion(VersionControl):
         self.__commitData = {}
         self.__commitDialog = None
         
-        self.__wcng = True      # assume new generation working copy
-                                # metadata format
+        self.__wcng = True
+        # assume new generation working copy metadata format
         
     def getPlugin(self):
         """
@@ -136,6 +142,8 @@ class Subversion(VersionControl):
             self.blame.close()
         if self.repoBrowser is not None:
             self.repoBrowser.close()
+        if self.logBrowser is not None:
+            self.logBrowser.close()
         
     def vcsExists(self):
         """
@@ -170,14 +178,14 @@ class Subversion(VersionControl):
                 return True, errMsg
             else:
                 if finished:
-                    errMsg = self.trUtf8(
+                    errMsg = self.tr(
                         "The svn process finished with the exit code {0}")\
                         .format(process.exitCode())
                 else:
-                    errMsg = self.trUtf8(
+                    errMsg = self.tr(
                         "The svn process did not finish within 30s.")
         else:
-            errMsg = self.trUtf8("Could not start the svn executable.")
+            errMsg = self.tr("Could not start the svn executable.")
         
         return False, errMsg
         
@@ -185,7 +193,7 @@ class Subversion(VersionControl):
         """
         Public method used to initialize the subversion repository.
         
-        The subversion repository has to be initialized from outside eric5
+        The subversion repository has to be initialized from outside eric6
         because the respective command always works locally. Therefore we
         always return TRUE without doing anything.
         
@@ -207,8 +215,8 @@ class Subversion(VersionControl):
         if not success:
             E5MessageBox.critical(
                 self.__ui,
-                self.trUtf8("Create project in repository"),
-                self.trUtf8(
+                self.tr("Create project in repository"),
+                self.tr(
                     """The project could not be created in the repository."""
                     """ Maybe the given repository doesn't exist or the"""
                     """ repository server is down."""))
@@ -231,8 +239,8 @@ class Subversion(VersionControl):
             if not os.path.isfile(pfn):
                 E5MessageBox.critical(
                     self.__ui,
-                    self.trUtf8("New project"),
-                    self.trUtf8(
+                    self.tr("New project"),
+                    self.tr(
                         """The project could not be checked out of the"""
                         """ repository.<br />"""
                         """Restoring the original contents."""))
@@ -306,7 +314,7 @@ class Subversion(VersionControl):
                 QProcess(), "svn", args, os.path.join(tmpDir, project))
         else:
             dia = SvnDialog(
-                self.trUtf8('Importing project into Subversion repository'))
+                self.tr('Importing project into Subversion repository'))
             res = dia.startProcess(args, os.path.join(tmpDir, project))
             if res:
                 dia.exec_()
@@ -344,8 +352,8 @@ class Subversion(VersionControl):
                         not tag.startswith('branches'):
                     type, ok = QInputDialog.getItem(
                         None,
-                        self.trUtf8("Subversion Checkout"),
-                        self.trUtf8(
+                        self.tr("Subversion Checkout"),
+                        self.tr(
                             "The tag must be a normal tag (tags) or"
                             " a branch tag (branches)."
                             " Please select from the list."),
@@ -369,7 +377,7 @@ class Subversion(VersionControl):
             return self.startSynchronizedProcess(QProcess(), 'svn', args)
         else:
             dia = SvnDialog(
-                self.trUtf8('Checking project out of Subversion repository'))
+                self.tr('Checking project out of Subversion repository'))
             res = dia.startProcess(args)
             if res:
                 dia.exec_()
@@ -400,8 +408,8 @@ class Subversion(VersionControl):
                         not tag.startswith('branches'):
                     type, ok = QInputDialog.getItem(
                         None,
-                        self.trUtf8("Subversion Export"),
-                        self.trUtf8(
+                        self.tr("Subversion Export"),
+                        self.tr(
                             "The tag must be a normal tag (tags) or"
                             " a branch tag (branches)."
                             " Please select from the list."),
@@ -422,7 +430,7 @@ class Subversion(VersionControl):
         args.append(projectDir)
         
         dia = SvnDialog(
-            self.trUtf8('Exporting project from Subversion repository'))
+            self.tr('Exporting project from Subversion repository'))
         res = dia.startProcess(args)
         if res:
             dia.exec_()
@@ -492,8 +500,8 @@ class Subversion(VersionControl):
             if not ok:
                 res = E5MessageBox.yesNo(
                     self.__ui,
-                    self.trUtf8("Commit Changes"),
-                    self.trUtf8(
+                    self.tr("Commit Changes"),
+                    self.tr(
                         """The commit affects files, that have unsaved"""
                         """ changes. Shall the commit be continued?"""),
                     icon=E5MessageBox.Warning)
@@ -541,7 +549,7 @@ class Subversion(VersionControl):
             self.startSynchronizedProcess(QProcess(), "svn", args, dname)
         else:
             dia = SvnDialog(
-                self.trUtf8('Commiting changes to Subversion repository'))
+                self.tr('Commiting changes to Subversion repository'))
             res = dia.startProcess(args, dname)
             if res:
                 dia.exec_()
@@ -578,7 +586,7 @@ class Subversion(VersionControl):
             res = False
         else:
             dia = SvnDialog(
-                self.trUtf8('Synchronizing with the Subversion repository'))
+                self.tr('Synchronizing with the Subversion repository'))
             res = dia.startProcess(args, dname, True)
             if res:
                 dia.exec_()
@@ -674,8 +682,8 @@ class Subversion(VersionControl):
             self.startSynchronizedProcess(QProcess(), "svn", args, wdir)
         else:
             dia = SvnDialog(
-                self.trUtf8('Adding files/directories to the Subversion'
-                            ' repository'))
+                self.tr('Adding files/directories to the Subversion'
+                        ' repository'))
             res = dia.startProcess(args, wdir)
             if res:
                 dia.exec_()
@@ -764,7 +772,7 @@ class Subversion(VersionControl):
             args.append(path)
         
         dia = SvnDialog(
-            self.trUtf8('Adding directory trees to the Subversion repository'))
+            self.tr('Adding directory trees to the Subversion repository'))
         res = dia.startProcess(args, dname)
         if res:
             dia.exec_()
@@ -799,8 +807,8 @@ class Subversion(VersionControl):
             res = self.startSynchronizedProcess(QProcess(), "svn", args)
         else:
             dia = SvnDialog(
-                self.trUtf8('Removing files/directories from the Subversion'
-                            ' repository'))
+                self.tr('Removing files/directories from the Subversion'
+                        ' repository'))
             res = dia.startProcess(args)
             if res:
                 dia.exec_()
@@ -860,7 +868,7 @@ class Subversion(VersionControl):
             if noDialog:
                 res = self.startSynchronizedProcess(QProcess(), "svn", args)
             else:
-                dia = SvnDialog(self.trUtf8('Moving {0}')
+                dia = SvnDialog(self.tr('Moving {0}')
                                 .format(name))
                 res = dia.startProcess(args)
                 if res:
@@ -889,8 +897,8 @@ class Subversion(VersionControl):
         isFile = os.path.isfile(name)
         noEntries, ok = QInputDialog.getInt(
             None,
-            self.trUtf8("Subversion Log"),
-            self.trUtf8("Select number of entries to show."),
+            self.tr("Subversion Log"),
+            self.tr("Select number of entries to show."),
             self.getPlugin().getPreferences("LogLimit"), 1, 999999, 1)
         if ok:
             from .SvnLogDialog import SvnLogDialog
@@ -955,8 +963,8 @@ class Subversion(VersionControl):
         if reposURL is None:
             E5MessageBox.critical(
                 self.__ui,
-                self.trUtf8("Subversion Error"),
-                self.trUtf8(
+                self.tr("Subversion Error"),
+                self.tr(
                     """The URL of the project repository could not be"""
                     """ retrieved from the working copy. The tag operation"""
                     """ will be aborted"""))
@@ -982,8 +990,8 @@ class Subversion(VersionControl):
             if not rx_base.exactMatch(reposURL):
                 E5MessageBox.critical(
                     self.__ui,
-                    self.trUtf8("Subversion Error"),
-                    self.trUtf8(
+                    self.tr("Subversion Error"),
+                    self.tr(
                         """The URL of the project repository has an"""
                         """ invalid format. The tag operation will"""
                         """ be aborted"""))
@@ -991,10 +999,10 @@ class Subversion(VersionControl):
             
             reposRoot = rx_base.cap(1)
             if tagOp in [1, 4]:
-                url = '{0}/tags/{1}'.format(reposRoot, urllib.parse.quote(tag))
+                url = '{0}/tags/{1}'.format(reposRoot, Utilities.quote(tag))
             elif tagOp in [2, 8]:
                 url = '{0}/branches/{1}'.format(
-                    reposRoot, urllib.parse.quote(tag))
+                    reposRoot, Utilities.quote(tag))
         else:
             url = self.__svnURL(tag)
         
@@ -1015,7 +1023,7 @@ class Subversion(VersionControl):
             args.append('Deleted tag <{0}>'.format(tag))
             args.append(url)
         
-        dia = SvnDialog(self.trUtf8('Tagging {0} in the Subversion repository')
+        dia = SvnDialog(self.tr('Tagging {0} in the Subversion repository')
                         .format(name))
         res = dia.startProcess(args)
         if res:
@@ -1046,19 +1054,19 @@ class Subversion(VersionControl):
                 DeleteFilesConfirmationDialog
             dlg = DeleteFilesConfirmationDialog(
                 self.parent(),
-                self.trUtf8("Revert changes"),
-                self.trUtf8("Do you really want to revert all changes to"
-                            " these files or directories?"),
+                self.tr("Revert changes"),
+                self.tr("Do you really want to revert all changes to"
+                        " these files or directories?"),
                 names)
             yes = dlg.exec_() == QDialog.Accepted
         else:
             yes = E5MessageBox.yesNo(
                 None,
-                self.trUtf8("Revert changes"),
-                self.trUtf8("""Do you really want to revert all changes of"""
-                            """ the project?"""))
+                self.tr("Revert changes"),
+                self.tr("""Do you really want to revert all changes of"""
+                        """ the project?"""))
         if yes:
-            dia = SvnDialog(self.trUtf8('Reverting changes'))
+            dia = SvnDialog(self.tr('Reverting changes'))
             res = dia.startProcess(args)
             if res:
                 dia.exec_()
@@ -1077,8 +1085,8 @@ class Subversion(VersionControl):
         if reposURL is None:
             E5MessageBox.critical(
                 self.__ui,
-                self.trUtf8("Subversion Error"),
-                self.trUtf8(
+                self.tr("Subversion Error"),
+                self.tr(
                     """The URL of the project repository could not be"""
                     """ retrieved from the working copy. The switch"""
                     """ operation will be aborted"""))
@@ -1104,8 +1112,8 @@ class Subversion(VersionControl):
             if not rx_base.exactMatch(reposURL):
                 E5MessageBox.critical(
                     self.__ui,
-                    self.trUtf8("Subversion Error"),
-                    self.trUtf8(
+                    self.tr("Subversion Error"),
+                    self.tr(
                         """The URL of the project repository has an"""
                         """ invalid format. The switch operation will"""
                         """ be aborted"""))
@@ -1114,10 +1122,10 @@ class Subversion(VersionControl):
             reposRoot = rx_base.cap(1)
             tn = tag
             if tagType == 1:
-                url = '{0}/tags/{1}'.format(reposRoot, urllib.parse.quote(tag))
+                url = '{0}/tags/{1}'.format(reposRoot, Utilities.quote(tag))
             elif tagType == 2:
                 url = '{0}/branches/{1}'.format(
-                    reposRoot, urllib.parse.quote(tag))
+                    reposRoot, Utilities.quote(tag))
             elif tagType == 4:
                 url = '{0}/trunk'.format(reposRoot)
                 tn = 'HEAD'
@@ -1133,7 +1141,7 @@ class Subversion(VersionControl):
         args.append(url)
         args.append(name)
         
-        dia = SvnDialog(self.trUtf8('Switching to {0}')
+        dia = SvnDialog(self.tr('Switching to {0}')
                         .format(tn))
         res = dia.startProcess(args, setLanguage=True)
         if res:
@@ -1198,7 +1206,7 @@ class Subversion(VersionControl):
             args.append(self.__svnURL(urlrev2))
         args.append(fname)
         
-        dia = SvnDialog(self.trUtf8('Merging {0}').format(name))
+        dia = SvnDialog(self.tr('Merging {0}').format(name))
         res = dia.startProcess(args, dname)
         if res:
             dia.exec_()
@@ -1464,7 +1472,7 @@ class Subversion(VersionControl):
         self.addArguments(args, self.options['global'])
         args.append(name)
         
-        dia = SvnDialog(self.trUtf8('Cleaning up {0}')
+        dia = SvnDialog(self.tr('Cleaning up {0}')
                         .format(name))
         res = dia.startProcess(args)
         if res:
@@ -1494,7 +1502,7 @@ class Subversion(VersionControl):
             args = []
             self.addArguments(args, commandList)
             
-            dia = SvnDialog(self.trUtf8('Subversion command'))
+            dia = SvnDialog(self.tr('Subversion command'))
             res = dia.startProcess(args, wd)
             if res:
                 dia.exec_()
@@ -1587,7 +1595,7 @@ class Subversion(VersionControl):
                         info['committed-time'] = "{0}{1}".format(
                             time.split('.')[0], time[-1])
         
-        return QApplication.translate(
+        return QCoreApplication.translate(
             'subversion',
             """<h3>Repository information</h3>"""
             """<table>"""
@@ -1664,7 +1672,7 @@ class Subversion(VersionControl):
                 args.append('--recursive')
             args.append(name)
         
-        dia = SvnDialog(self.trUtf8('Resolving conficts'))
+        dia = SvnDialog(self.tr('Resolving conficts'))
         res = dia.startProcess(args)
         if res:
             dia.exec_()
@@ -1695,7 +1703,7 @@ class Subversion(VersionControl):
             args.append(name)
             args.append(target)
             
-            dia = SvnDialog(self.trUtf8('Copying {0}')
+            dia = SvnDialog(self.tr('Copying {0}')
                             .format(name))
             res = dia.startProcess(args)
             if res:
@@ -1736,9 +1744,9 @@ class Subversion(VersionControl):
             if not propName:
                 E5MessageBox.critical(
                     self.__ui,
-                    self.trUtf8("Subversion Set Property"),
-                    self.trUtf8("""You have to supply a property name."""
-                                """ Aborting."""))
+                    self.tr("Subversion Set Property"),
+                    self.tr("""You have to supply a property name."""
+                            """ Aborting."""))
                 return
             
             args = []
@@ -1757,7 +1765,7 @@ class Subversion(VersionControl):
                 dname, fname = self.splitPath(name)
                 args.append(fname)
             
-            dia = SvnDialog(self.trUtf8('Subversion Set Property'))
+            dia = SvnDialog(self.tr('Subversion Set Property'))
             res = dia.startProcess(args, dname)
             if res:
                 dia.exec_()
@@ -1771,8 +1779,8 @@ class Subversion(VersionControl):
         """
         propName, ok = QInputDialog.getText(
             None,
-            self.trUtf8("Subversion Delete Property"),
-            self.trUtf8("Enter property name"),
+            self.tr("Subversion Delete Property"),
+            self.tr("Enter property name"),
             QLineEdit.Normal)
         
         if not ok:
@@ -1781,9 +1789,9 @@ class Subversion(VersionControl):
         if not propName:
             E5MessageBox.critical(
                 self.__ui,
-                self.trUtf8("Subversion Delete Property"),
-                self.trUtf8("""You have to supply a property name."""
-                            """ Aborting."""))
+                self.tr("Subversion Delete Property"),
+                self.tr("""You have to supply a property name."""
+                        """ Aborting."""))
             return
         
         args = []
@@ -1799,7 +1807,7 @@ class Subversion(VersionControl):
             dname, fname = self.splitPath(name)
             args.append(fname)
         
-        dia = SvnDialog(self.trUtf8('Subversion Delete Property'))
+        dia = SvnDialog(self.tr('Subversion Delete Property'))
         res = dia.startProcess(args, dname)
         if res:
             dia.exec_()
@@ -1956,10 +1964,10 @@ class Subversion(VersionControl):
                         process.readAllStandardError(),
                         Preferences.getSystem("IOEncoding"), 'replace')
             else:
-                error = self.trUtf8(
+                error = self.tr(
                     "The svn process did not finish within 30s.")
         else:
-            error = self.trUtf8(
+            error = self.tr(
                 'The process {0} could not be started. '
                 'Ensure, that it is in the search path.').format('svn')
         
@@ -1996,7 +2004,7 @@ class Subversion(VersionControl):
         if error:
             E5MessageBox.critical(
                 self.__ui,
-                self.trUtf8("Subversion Side-by-Side Difference"),
+                self.tr("Subversion Side-by-Side Difference"),
                 error)
             return
         name1 = "{0} (rev. {1})".format(name, rev1 and rev1 or ".")
@@ -2006,7 +2014,7 @@ class Subversion(VersionControl):
             if error:
                 E5MessageBox.critical(
                     self.__ui,
-                    self.trUtf8("Subversion Side-by-Side Difference"),
+                    self.tr("Subversion Side-by-Side Difference"),
                     error)
                 return
             name2 = "{0} (rev. {1})".format(name, rev2)
@@ -2019,8 +2027,8 @@ class Subversion(VersionControl):
             except IOError:
                 E5MessageBox.critical(
                     self.__ui,
-                    self.trUtf8("Subversion Side-by-Side Difference"),
-                    self.trUtf8(
+                    self.tr("Subversion Side-by-Side Difference"),
+                    self.tr(
                         """<p>The file <b>{0}</b> could not be read.</p>""")
                     .format(name))
                 return
@@ -2031,18 +2039,19 @@ class Subversion(VersionControl):
         self.sbsDiff.show()
         self.sbsDiff.compare(output1, output2, name1, name2)
     
-    def svnLogBrowser(self, path, isFile=False):
+    def vcsLogBrowser(self, name, isFile=False):
         """
         Public method used to browse the log of a file/directory from the
         Subversion repository.
         
-        @param path file/directory name to show the log of (string)
+        @param name file/directory name to show the log of (string)
         @param isFile flag indicating log for a file is to be shown (boolean)
         """
-        from .SvnLogBrowserDialog import SvnLogBrowserDialog
-        self.logBrowser = SvnLogBrowserDialog(self, isFile=isFile)
+        if self.logBrowser is None:
+            from .SvnLogBrowserDialog import SvnLogBrowserDialog
+            self.logBrowser = SvnLogBrowserDialog(self)
         self.logBrowser.show()
-        self.logBrowser.start(path)
+        self.logBrowser.start(name, isFile=isFile)
         
     def svnLock(self, name, stealIt=False, parent=None):
         """
@@ -2067,7 +2076,7 @@ class Subversion(VersionControl):
             args.append(fname)
         
         dia = SvnDialog(
-            self.trUtf8('Locking in the Subversion repository'), parent)
+            self.tr('Locking in the Subversion repository'), parent)
         res = dia.startProcess(args, dname)
         if res:
             dia.exec_()
@@ -2095,7 +2104,7 @@ class Subversion(VersionControl):
             args.append(fname)
         
         dia = SvnDialog(
-            self.trUtf8('Unlocking in the Subversion repository'), parent)
+            self.tr('Unlocking in the Subversion repository'), parent)
         res = dia.startProcess(args, dname)
         if res:
             dia.exec_()
@@ -2119,7 +2128,7 @@ class Subversion(VersionControl):
             args.append(newUrl)
             args.append(projectPath)
             
-            dia = SvnDialog(self.trUtf8('Relocating'))
+            dia = SvnDialog(self.tr('Relocating'))
             res = dia.startProcess(args)
             if res:
                 dia.exec_()
@@ -2138,8 +2147,8 @@ class Subversion(VersionControl):
         if url is None:
             url, ok = QInputDialog.getText(
                 None,
-                self.trUtf8("Repository Browser"),
-                self.trUtf8("Enter the repository URL."),
+                self.tr("Repository Browser"),
+                self.tr("Enter the repository URL."),
                 QLineEdit.Normal)
             if not ok or not url:
                 return
@@ -2170,7 +2179,7 @@ class Subversion(VersionControl):
             dname, fname = self.splitPath(names)
             args.append(fname)
         
-        dia = SvnDialog(self.trUtf8('Remove from changelist'))
+        dia = SvnDialog(self.tr('Remove from changelist'))
         res = dia.startProcess(args, dname)
         if res:
             dia.exec_()
@@ -2186,8 +2195,8 @@ class Subversion(VersionControl):
         """
         clname, ok = QInputDialog.getItem(
             None,
-            self.trUtf8("Add to changelist"),
-            self.trUtf8("Enter name of the changelist:"),
+            self.tr("Add to changelist"),
+            self.tr("Enter name of the changelist:"),
             sorted(self.svnGetChangelists()),
             0, True)
         if not ok or not clname:
@@ -2205,7 +2214,7 @@ class Subversion(VersionControl):
             dname, fname = self.splitPath(names)
             args.append(fname)
         
-        dia = SvnDialog(self.trUtf8('Remove from changelist'))
+        dia = SvnDialog(self.tr('Remove from changelist'))
         res = dia.startProcess(args, dname)
         if res:
             dia.exec_()
@@ -2229,10 +2238,9 @@ class Subversion(VersionControl):
         @return list of defined change list names (list of strings)
         """
         changelists = []
-        rx_changelist = \
-            QRegExp('--- \\S+ .([\\w\\s]+).:\\s*')
-            # three dashes, Changelist (translated), quote,
-            # changelist name, quote, :
+        rx_changelist = QRegExp('--- \\S+ .([\\w\\s]+).:\\s*')
+        # three dashes, Changelist (translated), quote,
+        # changelist name, quote, :
         
         args = []
         args.append("status")
@@ -2270,7 +2278,7 @@ class Subversion(VersionControl):
         args.append("upgrade")
         args.append(".")
         
-        dia = SvnDialog(self.trUtf8('Upgrade'))
+        dia = SvnDialog(self.tr('Upgrade'))
         res = dia.startProcess(args, path)
         if res:
             dia.exec_()
@@ -2293,11 +2301,11 @@ class Subversion(VersionControl):
             host = url[1]
             port, path = url[2].split("/", 1)
             return "{0}:{1}:{2}/{3}".format(
-                scheme, host, port, urllib.parse.quote(path))
+                scheme, host, port, Utilities.quote(path))
         else:
             scheme = url[0]
             if scheme == "file":
-                return "{0}:{1}".format(scheme, urllib.parse.quote(url[1]))
+                return "{0}:{1}".format(scheme, Utilities.quote(url[1]))
             else:
                 try:
                     host, path = url[1][2:].split("/", 1)
@@ -2305,7 +2313,7 @@ class Subversion(VersionControl):
                     host = url[1][2:]
                     path = ""
                 return "{0}://{1}/{2}".format(
-                    scheme, host, urllib.parse.quote(path))
+                    scheme, host, Utilities.quote(path))
 
     def svnNormalizeURL(self, url):
         """
