@@ -1,16 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the listspace viewmanager class.
 """
 
+from __future__ import unicode_literals
+
 import os
 
-from PyQt4.QtCore import pyqtSignal, QFileInfo, QEvent, Qt
-from PyQt4.QtGui import QStackedWidget, QSplitter, QListWidget, \
+from PyQt5.QtCore import pyqtSignal, QFileInfo, QEvent, Qt
+from PyQt5.QtWidgets import QStackedWidget, QSplitter, QListWidget, \
     QListWidgetItem, QSizePolicy, QMenu, QApplication
 
 from ViewManager.ViewManager import ViewManager
@@ -31,33 +33,32 @@ class StackedWidget(QStackedWidget):
         
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
-        self.setAttribute(Qt.WA_DeleteOnClose, True)
+        super(StackedWidget, self).__init__(parent)
         
         self.editors = []
         
     def addWidget(self, assembly):
         """
-        Overwritten method to add a new widget.
+        Public method to add a new widget.
         
         @param assembly editor assembly object to be added
             (QScintilla.EditorAssembly.EditorAssembly)
         """
         editor = assembly.getEditor()
-        super().addWidget(assembly)
-        if not editor in self.editors:
+        super(StackedWidget, self).addWidget(assembly)
+        if editor not in self.editors:
             self.editors.append(editor)
         
     def removeWidget(self, widget):
         """
-        Overwritten method to remove a widget.
+        Public method to remove a widget.
         
         @param widget widget to be removed (QWidget)
         """
         if isinstance(widget, QScintilla.Editor.Editor):
             self.editors.remove(widget)
             widget = widget.parent()
-        super().removeWidget(widget)
+        super(StackedWidget, self).removeWidget(widget)
         
     def currentWidget(self):
         """
@@ -65,14 +66,14 @@ class StackedWidget(QStackedWidget):
         
         @return reference to the current editor (Editor)
         """
-        widget = super().currentWidget()
+        widget = super(StackedWidget, self).currentWidget()
         if widget is not None:
             widget = widget.getEditor()
         return widget
         
     def setCurrentWidget(self, widget):
         """
-        Overwritten method to set the current widget.
+        Public method to set the current widget.
         
         @param widget widget to be made current (QWidget)
         """
@@ -80,11 +81,11 @@ class StackedWidget(QStackedWidget):
             self.editors.remove(widget)
             self.editors.insert(0, widget)
             widget = widget.parent()
-        super().setCurrentWidget(widget)
+        super(StackedWidget, self).setCurrentWidget(widget)
         
     def setCurrentIndex(self, index):
         """
-        Overwritten method to set the current widget by its index.
+        Public method to set the current widget by its index.
         
         @param index index of widget to be made current (integer)
         """
@@ -147,7 +148,10 @@ class Listspace(QSplitter, ViewManager):
     @signal editorClosed(str) emitted just before an editor window gets closed
     @signal editorClosedEd(Editor) emitted just before an editor window gets
         closed
+    @signal editorRenamed(str) emitted after an editor was renamed
+    @signal editorRenamedEd(Editor) emitted after an editor was renamed
     @signal editorSaved(str) emitted after an editor window was saved
+    @signal editorSavedEd(Editor) emitted after an editor window was saved
     @signal checkActions(Editor) emitted when some actions should be checked
         for their status
     @signal cursorChanged(Editor) emitted after the cursor position of the
@@ -172,7 +176,10 @@ class Listspace(QSplitter, ViewManager):
     editorOpenedEd = pyqtSignal(Editor)
     editorClosed = pyqtSignal(str)
     editorClosedEd = pyqtSignal(Editor)
+    editorRenamed = pyqtSignal(str)
+    editorRenamedEd = pyqtSignal(Editor)
     editorSaved = pyqtSignal(str)
+    editorSavedEd = pyqtSignal(Editor)
     checkActions = pyqtSignal(Editor)
     cursorChanged = pyqtSignal(Editor)
     breakpointToggled = pyqtSignal(Editor)
@@ -227,34 +234,34 @@ class Listspace(QSplitter, ViewManager):
         self.__menu = QMenu(self)
         self.__menu.addAction(
             UI.PixmapCache.getIcon("tabClose.png"),
-            self.trUtf8('Close'), self.__contextMenuClose)
+            self.tr('Close'), self.__contextMenuClose)
         self.closeOthersMenuAct = self.__menu.addAction(
             UI.PixmapCache.getIcon("tabCloseOther.png"),
-            self.trUtf8("Close Others"),
+            self.tr("Close Others"),
             self.__contextMenuCloseOthers)
         self.__menu.addAction(
-            self.trUtf8('Close All'), self.__contextMenuCloseAll)
+            self.tr('Close All'), self.__contextMenuCloseAll)
         self.__menu.addSeparator()
         self.saveMenuAct = self.__menu.addAction(
             UI.PixmapCache.getIcon("fileSave.png"),
-            self.trUtf8('Save'), self.__contextMenuSave)
+            self.tr('Save'), self.__contextMenuSave)
         self.__menu.addAction(
             UI.PixmapCache.getIcon("fileSaveAs.png"),
-            self.trUtf8('Save As...'), self.__contextMenuSaveAs)
+            self.tr('Save As...'), self.__contextMenuSaveAs)
         self.__menu.addAction(
             UI.PixmapCache.getIcon("fileSaveAll.png"),
-            self.trUtf8('Save All'), self.__contextMenuSaveAll)
+            self.tr('Save All'), self.__contextMenuSaveAll)
         self.__menu.addSeparator()
         self.openRejectionsMenuAct = self.__menu.addAction(
-            self.trUtf8("Open 'rejection' file"),
+            self.tr("Open 'rejection' file"),
             self.__contextMenuOpenRejections)
         self.__menu.addSeparator()
         self.__menu.addAction(
             UI.PixmapCache.getIcon("print.png"),
-            self.trUtf8('Print'), self.__contextMenuPrintFile)
+            self.tr('Print'), self.__contextMenuPrintFile)
         self.__menu.addSeparator()
         self.copyPathAct = self.__menu.addAction(
-            self.trUtf8("Copy Path to Clipboard"),
+            self.tr("Copy Path to Clipboard"),
             self.__contextMenuCopyPathToClipboard)
         
     def __showMenu(self, point):
@@ -384,13 +391,13 @@ class Listspace(QSplitter, ViewManager):
         if fn is None:
             if not noName:
                 self.untitledCount += 1
-                noName = self.trUtf8("Untitled {0}").format(self.untitledCount)
+                noName = self.tr("Untitled {0}").format(self.untitledCount)
             self.viewlist.addItem(noName)
             editor.setNoName(noName)
         else:
             txt = os.path.basename(fn)
             if not QFileInfo(fn).isWritable():
-                txt = self.trUtf8("{0} (ro)").format(txt)
+                txt = self.tr("{0} (ro)").format(txt)
             itm = QListWidgetItem(txt)
             itm.setToolTip(fn)
             self.viewlist.addItem(itm)
@@ -495,7 +502,7 @@ class Listspace(QSplitter, ViewManager):
         
     def setEditorName(self, editor, newName):
         """
-        Change the displayed name of the editor.
+        Public method to change the displayed name of the editor.
         
         @param editor editor window to be changed
         @param newName new name to be shown (string)
@@ -505,7 +512,7 @@ class Listspace(QSplitter, ViewManager):
             index = self.editors.index(editor)
             txt = os.path.basename(newName)
             if not QFileInfo(newName).isWritable():
-                txt = self.trUtf8("{0} (ro)").format(txt)
+                txt = self.tr("{0} (ro)").format(txt)
             itm = self.viewlist.item(index)
             itm.setText(txt)
             itm.setToolTip(newName)
@@ -521,18 +528,17 @@ class Listspace(QSplitter, ViewManager):
         """
         currentRow = self.viewlist.currentRow()
         index = self.editors.index(editor)
+        keys = []
         if m:
-            self.viewlist.item(index).setIcon(
-                UI.PixmapCache.getIcon("fileModified.png"))
-        elif editor.hasSyntaxErrors():
-            self.viewlist.item(index).setIcon(
-                UI.PixmapCache.getIcon("syntaxError.png"))
+            keys.append("fileModified.png")
+        if editor.hasSyntaxErrors():
+            keys.append("syntaxError22.png")
         elif editor.hasWarnings():
-            self.viewlist.item(index).setIcon(
-                UI.PixmapCache.getIcon("warning.png"))
-        else:
-            self.viewlist.item(index).setIcon(
-                UI.PixmapCache.getIcon("empty.png"))
+            keys.append("warning22.png")
+        if not keys:
+            keys.append("empty.png")
+        self.viewlist.item(index).setIcon(
+            UI.PixmapCache.getCombinedIcon(keys))
         self.viewlist.setCurrentRow(currentRow)
         self._checkActions(editor)
         
@@ -544,18 +550,17 @@ class Listspace(QSplitter, ViewManager):
         """
         currentRow = self.viewlist.currentRow()
         index = self.editors.index(editor)
+        keys = []
+        if editor.isModified():
+            keys.append("fileModified.png")
         if editor.hasSyntaxErrors():
-            self.viewlist.item(index).setIcon(
-                UI.PixmapCache.getIcon("syntaxError.png"))
+            keys.append("syntaxError22.png")
         elif editor.hasWarnings():
-            self.viewlist.item(index).setIcon(
-                UI.PixmapCache.getIcon("warning.png"))
-        elif editor.isModified():
-            self.viewlist.item(index).setIcon(
-                UI.PixmapCache.getIcon("fileModified.png"))
-        else:
-            self.viewlist.item(index).setIcon(
-                UI.PixmapCache.getIcon("empty.png"))
+            keys.append("warning22.png")
+        if not keys:
+            keys.append("empty.png")
+        self.viewlist.item(index).setIcon(
+            UI.PixmapCache.getCombinedIcon(keys))
         self.viewlist.setCurrentRow(currentRow)
         
         ViewManager._syntaxErrorToggled(self, editor)
@@ -771,7 +776,7 @@ class Listspace(QSplitter, ViewManager):
         
     def eventFilter(self, watched, event):
         """
-        Method called to filter the event queue.
+        Public method called to filter the event queue.
         
         @param watched the QObject being watched
         @param event the event that occurred
@@ -779,6 +784,7 @@ class Listspace(QSplitter, ViewManager):
         """
         if event.type() == QEvent.MouseButtonPress and \
            not event.button() == Qt.RightButton:
+            switched = True
             if isinstance(watched, QStackedWidget):
                 switched = watched is not self.currentStack
                 self.currentStack = watched
