@@ -1,18 +1,21 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a tabbed viewmanager class.
 """
 
+from __future__ import unicode_literals
+
 import os
 
-from PyQt4.QtCore import QPoint, QFileInfo, pyqtSignal, QEvent, QByteArray, \
-    QMimeData, Qt
-from PyQt4.QtGui import QWidget, QColor, QHBoxLayout, QDrag, QPixmap, \
-    QSplitter, QTabBar, QApplication, QToolButton, QMenu, QLabel
+from PyQt5.QtCore import QPoint, QFileInfo, pyqtSignal, QEvent, QByteArray, \
+    QMimeData, Qt, QSize
+from PyQt5.QtGui import QColor, QDrag, QPixmap
+from PyQt5.QtWidgets import QWidget, QHBoxLayout, QSplitter, QTabBar, \
+    QApplication, QToolButton, QMenu, QLabel
 
 from E5Gui.E5Application import e5App
 
@@ -29,7 +32,7 @@ from E5Gui.E5Led import E5Led
 import Preferences
 from Globals import isMacPlatform
 
-from eric5config import getConfig
+from eric6config import getConfig
 
 
 class TabBar(E5WheelTabBar):
@@ -57,7 +60,7 @@ class TabBar(E5WheelTabBar):
         
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(TabBar, self).__init__(parent)
         self.setAcceptDrops(True)
         
         self.__dragStartPos = QPoint()
@@ -70,7 +73,7 @@ class TabBar(E5WheelTabBar):
         """
         if event.button() == Qt.LeftButton:
             self.__dragStartPos = QPoint(event.pos())
-        super().mousePressEvent(event)
+        super(TabBar, self).mousePressEvent(event)
     
     def mouseMoveEvent(self, event):
         """
@@ -85,18 +88,20 @@ class TabBar(E5WheelTabBar):
             mimeData = QMimeData()
             index = self.tabAt(event.pos())
             mimeData.setText(self.tabText(index))
-            mimeData.setData("action", "tab-reordering")
-            mimeData.setData("tabbar-id", str(id(self)))
+            mimeData.setData("action", b"tab-reordering")
+            mimeData.setData("tabbar-id", str(id(self)).encode("utf-8"))
             mimeData.setData(
                 "source-index",
                 QByteArray.number(self.tabAt(self.__dragStartPos)))
-            mimeData.setData("tabwidget-id", str(id(self.parentWidget())))
+            mimeData.setData(
+                "tabwidget-id",
+                str(id(self.parentWidget())).encode("utf-8"))
             drag.setMimeData(mimeData)
             if event.modifiers() == Qt.KeyboardModifiers(Qt.ShiftModifier):
                 drag.exec_(Qt.DropActions(Qt.CopyAction))
             elif event.modifiers() == Qt.KeyboardModifiers(Qt.NoModifier):
                 drag.exec_(Qt.DropActions(Qt.MoveAction))
-        super().mouseMoveEvent(event)
+        super(TabBar, self).mouseMoveEvent(event)
     
     def dragEnterEvent(self, event):
         """
@@ -107,12 +112,12 @@ class TabBar(E5WheelTabBar):
         mimeData = event.mimeData()
         formats = mimeData.formats()
         if "action" in formats and \
-           mimeData.data("action") == "tab-reordering" and \
+           mimeData.data("action") == b"tab-reordering" and \
            "tabbar-id" in formats and \
            "source-index" in formats and \
            "tabwidget-id" in formats:
             event.acceptProposedAction()
-        super().dragEnterEvent(event)
+        super(TabBar, self).dragEnterEvent(event)
     
     def dropEvent(self, event):
         """
@@ -122,7 +127,7 @@ class TabBar(E5WheelTabBar):
         """
         mimeData = event.mimeData()
         oldID = int(mimeData.data("tabbar-id"))
-        fromIndex = mimeData.data("source-index").toInt()[0]
+        fromIndex = int(mimeData.data("source-index"))
         toIndex = self.tabAt(event.pos())
         if oldID != id(self):
             parentID = int(mimeData.data("tabwidget-id"))
@@ -142,7 +147,7 @@ class TabBar(E5WheelTabBar):
                 elif event.proposedAction() == Qt.CopyAction:
                     self.tabCopyRequested[int, int].emit(fromIndex, toIndex)
                     event.acceptProposedAction()
-        super().dropEvent(event)
+        super(TabBar, self).dropEvent(event)
 
 
 class TabWidget(E5TabWidget):
@@ -155,11 +160,13 @@ class TabWidget(E5TabWidget):
         
         @param vm view manager widget (Tabview)
         """
-        super().__init__()
-        self.setAttribute(Qt.WA_DeleteOnClose, True)
+        super(TabWidget, self).__init__()
         
         self.__tabBar = TabBar(self)
         self.setTabBar(self.__tabBar)
+        iconSize = self.__tabBar.iconSize()
+        self.__tabBar.setIconSize(
+            QSize(2 * iconSize.width(), iconSize.height()))
         
         self.setUsesScrollButtons(True)
         self.setElideMode(Qt.ElideNone)
@@ -189,7 +196,7 @@ class TabWidget(E5TabWidget):
         
         self.navigationButton = QToolButton(self)
         self.navigationButton.setIcon(UI.PixmapCache.getIcon("1downarrow.png"))
-        self.navigationButton.setToolTip(self.trUtf8("Show a navigation menu"))
+        self.navigationButton.setToolTip(self.tr("Show a navigation menu"))
         self.navigationButton.setPopupMode(QToolButton.InstantPopup)
         self.navigationButton.setMenu(self.__navigationMenu)
         self.navigationButton.setEnabled(False)
@@ -200,7 +207,7 @@ class TabWidget(E5TabWidget):
             self.closeButton = QToolButton(self)
             self.closeButton.setIcon(UI.PixmapCache.getIcon("close.png"))
             self.closeButton.setToolTip(
-                self.trUtf8("Close the current editor"))
+                self.tr("Close the current editor"))
             self.closeButton.setEnabled(False)
             self.closeButton.clicked[bool].connect(self.__closeButtonClicked)
             self.rightCornerWidgetLayout.addWidget(self.closeButton)
@@ -222,8 +229,9 @@ class TabWidget(E5TabWidget):
         self.emptyLabel = QLabel()
         self.emptyLabel.setPixmap(ericPic)
         self.emptyLabel.setAlignment(Qt.AlignVCenter | Qt.AlignHCenter)
-        super().addTab(self.emptyLabel,
-                       UI.PixmapCache.getIcon("empty.png"), "")
+        super(TabWidget, self).addTab(
+            self.emptyLabel,
+            UI.PixmapCache.getIcon("empty.png"), "")
         
     def __initMenu(self):
         """
@@ -232,46 +240,46 @@ class TabWidget(E5TabWidget):
         self.__menu = QMenu(self)
         self.leftMenuAct = self.__menu.addAction(
             UI.PixmapCache.getIcon("1leftarrow.png"),
-            self.trUtf8('Move Left'), self.__contextMenuMoveLeft)
+            self.tr('Move Left'), self.__contextMenuMoveLeft)
         self.rightMenuAct = self.__menu.addAction(
             UI.PixmapCache.getIcon("1rightarrow.png"),
-            self.trUtf8('Move Right'), self.__contextMenuMoveRight)
+            self.tr('Move Right'), self.__contextMenuMoveRight)
         self.firstMenuAct = self.__menu.addAction(
             UI.PixmapCache.getIcon("2leftarrow.png"),
-            self.trUtf8('Move First'), self.__contextMenuMoveFirst)
+            self.tr('Move First'), self.__contextMenuMoveFirst)
         self.lastMenuAct = self.__menu.addAction(
             UI.PixmapCache.getIcon("2rightarrow.png"),
-            self.trUtf8('Move Last'), self.__contextMenuMoveLast)
+            self.tr('Move Last'), self.__contextMenuMoveLast)
         self.__menu.addSeparator()
         self.__menu.addAction(
             UI.PixmapCache.getIcon("tabClose.png"),
-            self.trUtf8('Close'), self.__contextMenuClose)
+            self.tr('Close'), self.__contextMenuClose)
         self.closeOthersMenuAct = self.__menu.addAction(
             UI.PixmapCache.getIcon("tabCloseOther.png"),
-            self.trUtf8("Close Others"), self.__contextMenuCloseOthers)
+            self.tr("Close Others"), self.__contextMenuCloseOthers)
         self.__menu.addAction(
-            self.trUtf8('Close All'), self.__contextMenuCloseAll)
+            self.tr('Close All'), self.__contextMenuCloseAll)
         self.__menu.addSeparator()
         self.saveMenuAct = self.__menu.addAction(
             UI.PixmapCache.getIcon("fileSave.png"),
-            self.trUtf8('Save'), self.__contextMenuSave)
+            self.tr('Save'), self.__contextMenuSave)
         self.__menu.addAction(
             UI.PixmapCache.getIcon("fileSaveAs.png"),
-            self.trUtf8('Save As...'), self.__contextMenuSaveAs)
+            self.tr('Save As...'), self.__contextMenuSaveAs)
         self.__menu.addAction(
             UI.PixmapCache.getIcon("fileSaveAll.png"),
-            self.trUtf8('Save All'), self.__contextMenuSaveAll)
+            self.tr('Save All'), self.__contextMenuSaveAll)
         self.__menu.addSeparator()
         self.openRejectionsMenuAct = self.__menu.addAction(
-            self.trUtf8("Open 'rejection' file"),
+            self.tr("Open 'rejection' file"),
             self.__contextMenuOpenRejections)
         self.__menu.addSeparator()
         self.__menu.addAction(
             UI.PixmapCache.getIcon("print.png"),
-            self.trUtf8('Print'), self.__contextMenuPrintFile)
+            self.tr('Print'), self.__contextMenuPrintFile)
         self.__menu.addSeparator()
         self.copyPathAct = self.__menu.addAction(
-            self.trUtf8("Copy Path to Clipboard"),
+            self.tr("Copy Path to Clipboard"),
             self.__contextMenuCopyPathToClipboard)
         
     def __showContextMenu(self, coord, index):
@@ -338,21 +346,22 @@ class TabWidget(E5TabWidget):
         
     def addTab(self, assembly, title):
         """
-        Overwritten method to add a new tab.
+        Public method to add a new tab.
         
         @param assembly editor assembly object to be added
             (QScintilla.EditorAssembly.EditorAssembly)
         @param title title for the new tab (string)
         """
         editor = assembly.getEditor()
-        super().addTab(assembly, UI.PixmapCache.getIcon("empty.png"), title)
+        super(TabWidget, self).addTab(
+            assembly, UI.PixmapCache.getIcon("empty.png"), title)
         if self.closeButton:
             self.closeButton.setEnabled(True)
         else:
             self.setTabsClosable(True)
         self.navigationButton.setEnabled(True)
         
-        if not editor in self.editors:
+        if editor not in self.editors:
             self.editors.append(editor)
             editor.captionChanged.connect(self.__captionChange)
             editor.cursorLineChanged.connect(self.__cursorLineChanged)
@@ -363,7 +372,7 @@ class TabWidget(E5TabWidget):
         
     def insertWidget(self, index, assembly, title):
         """
-        Overwritten method to insert a new tab.
+        Public method to insert a new tab.
         
         @param index index position for the new tab (integer)
         @param assembly editor assembly object to be added
@@ -372,16 +381,17 @@ class TabWidget(E5TabWidget):
         @return index of the inserted tab (integer)
         """
         editor = assembly.getEditor()
-        newIndex = super().insertTab(index, assembly,
-                                     UI.PixmapCache.getIcon("empty.png"),
-                                     title)
+        newIndex = super(TabWidget, self).insertTab(
+            index, assembly,
+            UI.PixmapCache.getIcon("empty.png"),
+            title)
         if self.closeButton:
             self.closeButton.setEnabled(True)
         else:
             self.setTabsClosable(True)
         self.navigationButton.setEnabled(True)
         
-        if not editor in self.editors:
+        if editor not in self.editors:
             self.editors.append(editor)
             editor.captionChanged.connect(self.__captionChange)
             editor.cursorLineChanged.connect(self.__cursorLineChanged)
@@ -413,7 +423,7 @@ class TabWidget(E5TabWidget):
             if len(txt) > maxFileNameChars:
                 txt = "...{0}".format(txt[-maxFileNameChars:])
             if editor.isReadOnly():
-                txt = self.trUtf8("{0} (ro)").format(txt)
+                txt = self.tr("{0} (ro)").format(txt)
             
             assembly = editor.parent()
             index = self.indexOf(assembly)
@@ -450,7 +460,7 @@ class TabWidget(E5TabWidget):
             self.removeTab(index)
         
         if not self.editors:
-            super().addTab(
+            super(TabWidget, self).addTab(
                 self.emptyLabel, UI.PixmapCache.getIcon("empty.png"), "")
             self.emptyLabel.show()
             if self.closeButton:
@@ -519,14 +529,14 @@ class TabWidget(E5TabWidget):
         
     def currentWidget(self):
         """
-        Overridden method to return a reference to the current page.
+        Public method to return a reference to the current page.
         
         @return reference to the current page (Editor)
         """
         if not self.editors:
             return None
         else:
-            return super().currentWidget()
+            return super(TabWidget, self).currentWidget()
         
     def setCurrentWidget(self, assembly):
         """
@@ -535,7 +545,7 @@ class TabWidget(E5TabWidget):
         @param assembly editor assembly to determine current tab from
             (EditorAssembly.EditorAssembly)
         """
-        super().setCurrentWidget(assembly)
+        super(TabWidget, self).setCurrentWidget(assembly)
         
     def indexOf(self, object):
         """
@@ -546,7 +556,7 @@ class TabWidget(E5TabWidget):
         """
         if isinstance(object, QScintilla.Editor.Editor):
             object = object.parent()
-        return super().indexOf(object)
+        return super(TabWidget, self).indexOf(object)
         
     def hasEditor(self, editor):
         """
@@ -702,7 +712,10 @@ class Tabview(QSplitter, ViewManager):
     @signal editorClosed(str) emitted just before an editor window gets closed
     @signal editorClosedEd(Editor) emitted just before an editor window gets
         closed
+    @signal editorRenamed(str) emitted after an editor was renamed
+    @signal editorRenamedEd(Editor) emitted after an editor was renamed
     @signal editorSaved(str) emitted after an editor window was saved
+    @signal editorSavedEd(Editor) emitted after an editor window was saved
     @signal checkActions(Editor) emitted when some actions should be checked
         for their status
     @signal cursorChanged(Editor) emitted after the cursor position of the
@@ -727,7 +740,10 @@ class Tabview(QSplitter, ViewManager):
     editorOpenedEd = pyqtSignal(Editor)
     editorClosed = pyqtSignal(str)
     editorClosedEd = pyqtSignal(Editor)
+    editorRenamed = pyqtSignal(str)
+    editorRenamedEd = pyqtSignal(Editor)
     editorSaved = pyqtSignal(str)
+    editorSavedEd = pyqtSignal(Editor)
     checkActions = pyqtSignal(Editor)
     cursorChanged = pyqtSignal(Editor)
     breakpointToggled = pyqtSignal(Editor)
@@ -854,7 +870,7 @@ class Tabview(QSplitter, ViewManager):
         if fn is None:
             if not noName:
                 self.untitledCount += 1
-                noName = self.trUtf8("Untitled {0}").format(self.untitledCount)
+                noName = self.tr("Untitled {0}").format(self.untitledCount)
             self.currentTabWidget.addTab(win, noName)
             editor.setNoName(noName)
         else:
@@ -865,7 +881,7 @@ class Tabview(QSplitter, ViewManager):
             if len(txt) > self.maxFileNameChars:
                 txt = "...{0}".format(txt[-self.maxFileNameChars:])
             if not QFileInfo(fn).isWritable():
-                txt = self.trUtf8("{0} (ro)").format(txt)
+                txt = self.tr("{0} (ro)").format(txt)
             self.currentTabWidget.addTab(win, txt)
             index = self.currentTabWidget.indexOf(win)
             self.currentTabWidget.setTabToolTip(index, fn)
@@ -882,7 +898,7 @@ class Tabview(QSplitter, ViewManager):
         
     def insertView(self, win, tabWidget, index, fn=None, noName=""):
         """
-        Protected method to add a view (i.e. window).
+        Public method to add a view (i.e. window).
         
         @param win editor assembly to be inserted
         @param tabWidget reference to the tab widget to insert the editor into
@@ -895,7 +911,7 @@ class Tabview(QSplitter, ViewManager):
         if fn is None:
             if not noName:
                 self.untitledCount += 1
-                noName = self.trUtf8("Untitled {0}").format(self.untitledCount)
+                noName = self.tr("Untitled {0}").format(self.untitledCount)
             tabWidget.insertWidget(index, win, noName)
             editor.setNoName(noName)
         else:
@@ -906,7 +922,7 @@ class Tabview(QSplitter, ViewManager):
             if len(txt) > self.maxFileNameChars:
                 txt = "...{0}".format(txt[-self.maxFileNameChars:])
             if not QFileInfo(fn).isWritable():
-                txt = self.trUtf8("{0} (ro)").format(txt)
+                txt = self.tr("{0} (ro)").format(txt)
             nindex = tabWidget.insertWidget(index, win, txt)
             tabWidget.setTabToolTip(nindex, fn)
         tabWidget.setCurrentWidget(win)
@@ -998,14 +1014,16 @@ class Tabview(QSplitter, ViewManager):
             if tw.hasEditor(editor):
                 break
         index = tw.indexOf(editor)
+        keys = []
         if m:
-            tw.setTabIcon(index, UI.PixmapCache.getIcon("fileModified.png"))
-        elif editor.hasSyntaxErrors():
-            tw.setTabIcon(index, UI.PixmapCache.getIcon("syntaxError.png"))
+            keys.append("fileModified.png")
+        if editor.hasSyntaxErrors():
+            keys.append("syntaxError22.png")
         elif editor.hasWarnings():
-            tw.setTabIcon(index, UI.PixmapCache.getIcon("warning.png"))
-        else:
-            tw.setTabIcon(index, UI.PixmapCache.getIcon("empty.png"))
+            keys.append("warning22.png")
+        if not keys:
+            keys.append("empty.png")
+        tw.setTabIcon(index, UI.PixmapCache.getCombinedIcon(keys))
         self._checkActions(editor)
         
     def _syntaxErrorToggled(self, editor):
@@ -1018,14 +1036,16 @@ class Tabview(QSplitter, ViewManager):
             if tw.hasEditor(editor):
                 break
         index = tw.indexOf(editor)
+        keys = []
+        if editor.isModified():
+            keys.append("fileModified.png")
         if editor.hasSyntaxErrors():
-            tw.setTabIcon(index, UI.PixmapCache.getIcon("syntaxError.png"))
+            keys.append("syntaxError22.png")
         elif editor.hasWarnings():
-            tw.setTabIcon(index, UI.PixmapCache.getIcon("warning.png"))
-        elif editor.isModified():
-            tw.setTabIcon(index, UI.PixmapCache.getIcon("fileModified.png"))
-        else:
-            tw.setTabIcon(index, UI.PixmapCache.getIcon("empty.png"))
+            keys.append("warning22.png")
+        if not keys:
+            keys.append("empty.png")
+        tw.setTabIcon(index, UI.PixmapCache.getCombinedIcon(keys))
         
         ViewManager._syntaxErrorToggled(self, editor)
         
@@ -1173,6 +1193,7 @@ class Tabview(QSplitter, ViewManager):
         """
         if event.type() == QEvent.MouseButtonPress and \
            not event.button() == Qt.RightButton:
+            switched = True
             self.currentTabWidget.showIndicator(False)
             if isinstance(watched, E5TabWidget):
                 switched = watched is not self.currentTabWidget
@@ -1233,7 +1254,7 @@ class Tabview(QSplitter, ViewManager):
                         if len(txt) > self.maxFileNameChars:
                             txt = "...{0}".format(txt[-self.maxFileNameChars:])
                         if not QFileInfo(fn).isWritable():
-                            txt = self.trUtf8("{0} (ro)").format(txt)
+                            txt = self.tr("{0} (ro)").format(txt)
                         tabWidget.setTabText(index, txt)
         
     def getTabWidgetById(self, id_):
