@@ -1,16 +1,19 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the color dialog wizard dialog.
 """
 
+from __future__ import unicode_literals
+
 import os
 
-from PyQt4.QtCore import pyqtSlot
-from PyQt4.QtGui import QColor, QColorDialog, QDialog, QDialogButtonBox
+from PyQt5.QtCore import pyqtSlot
+from PyQt5.QtGui import QColor
+from PyQt5.QtWidgets import QColorDialog, QDialog, QDialogButtonBox
 
 from E5Gui import E5MessageBox
 
@@ -30,11 +33,14 @@ class ColorDialogWizardDialog(QDialog, Ui_ColorDialogWizardDialog):
         
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(ColorDialogWizardDialog, self).__init__(parent)
         self.setupUi(self)
         
         self.bTest = self.buttonBox.addButton(
-            self.trUtf8("Test"), QDialogButtonBox.ActionRole)
+            self.tr("Test"), QDialogButtonBox.ActionRole)
+        
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
     
     def on_buttonBox_clicked(self, button):
         """
@@ -60,14 +66,14 @@ class ColorDialogWizardDialog(QDialog, Ui_ColorDialogWizardDialog):
                 else:
                     coStr = "QColor({0})".format(coStr)
                 try:
-                    exec('from PyQt4.QtCore import Qt;'
+                    exec('from PyQt5.QtCore import Qt;'
                          ' QColorDialog.getColor({0}, None, "{1}")'.format(
                              coStr, self.eTitle.text()))
                 except:
                     E5MessageBox.critical(
                         self,
-                        self.trUtf8("QColorDialog Wizard Error"),
-                        self.trUtf8(
+                        self.tr("QColorDialog Wizard Error"),
+                        self.tr(
                             """<p>The colour <b>{0}</b> is not valid.</p>""")
                         .format(coStr))
             
@@ -148,7 +154,7 @@ class ColorDialogWizardDialog(QDialog, Ui_ColorDialogWizardDialog):
             else:
                 code += '{0}QColor(Qt.white),{1}'.format(istring, os.linesep)
             code += '{0}{1},{2}'.format(istring, parent, os.linesep)
-            code += '{0}self.trUtf8("{1}"),{2}'.format(
+            code += '{0}self.tr("{1}"),{2}'.format(
                 istring, self.eTitle.text(), os.linesep)
             code += '{0}QColorDialog.ColorDialogOptions(' \
                 'QColorDialog.ShowAlphaChannel)'.format(istring)
@@ -163,7 +169,7 @@ class ColorDialogWizardDialog(QDialog, Ui_ColorDialogWizardDialog):
                 code += '{0}{1},{2}'.format(
                     istring, self.eRGB.text(), os.linesep)
             code += '{0}{1},{2}'.format(istring, parent, os.linesep)
-            code += '{0}self.trUtf8("{1}"),{2}'.format(
+            code += '{0}self.tr("{1}"),{2}'.format(
                 istring, self.eTitle.text(), os.linesep)
             code += '{0}QColorDialog.ColorDialogOptions(' \
                 'QColorDialog.ShowAlphaChannel)'.format(istring)
