@@ -1,16 +1,19 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the file dialog wizard dialog.
 """
 
+from __future__ import unicode_literals
+
 import os
 
-from PyQt4.QtCore import pyqtSlot
-from PyQt4.QtGui import QDialog, QDialogButtonBox, QFileDialog, QButtonGroup
+from PyQt5.QtCore import pyqtSlot
+from PyQt5.QtWidgets import QDialog, QDialogButtonBox, QFileDialog, \
+    QButtonGroup
 
 from E5Gui.E5Completers import E5FileCompleter, E5DirCompleter
 
@@ -33,7 +36,7 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
         @param pyqtVariant variant of PyQt (integer; 0, 4 or 5)
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(FileDialogWizardDialog, self).__init__(parent)
         self.setupUi(self)
         
         self.eStartWithCompleter = E5FileCompleter(self.eStartWith)
@@ -55,6 +58,7 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
         self.__toggleInitialFilterAndResult(1)
         
         self.pyqtComboBox.addItems(["PyQt4", "PyQt5"])
+        self.__pyqtVariant = pyqtVariant
         if self.__pyqtVariant == 5:
             self.pyqtComboBox.setCurrentIndex(1)
         else:
@@ -68,7 +72,10 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
         self.cFilters.toggled[bool].connect(self.__toggleGroupsAndTest)
         
         self.bTest = self.buttonBox.addButton(
-            self.trUtf8("Test"), QDialogButtonBox.ActionRole)
+            self.tr("Test"), QDialogButtonBox.ActionRole)
+        
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
     
     def __adjustOptions(self, options):
         """
@@ -126,20 +133,38 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
                 options = QFileDialog.Options()
             options = self.__adjustOptions(options)
             if self.rOpenFile.isChecked() and self.__pyqtVariant == 4:
-                QFileDialog.getOpenFileName(
-                    None,
-                    self.eCaption.text(),
-                    self.eStartWith.text(),
-                    self.eFilters.text(),
-                    options)
+                try:
+                    QFileDialog.getOpenFileName(
+                        None,
+                        self.eCaption.text(),
+                        self.eStartWith.text(),
+                        self.eFilters.text(),
+                        options)
+                except TypeError:
+                    QFileDialog.getOpenFileName(
+                        None,
+                        self.eCaption.text(),
+                        self.eStartWith.text(),
+                        self.eFilters.text(),
+                        self.eInitialFilter.text(),
+                        options)
             else:
-                QFileDialog.getOpenFileNameAndFilter(
-                    None,
-                    self.eCaption.text(),
-                    self.eStartWith.text(),
-                    self.eFilters.text(),
-                    self.eInitialFilter.text(),
-                    options)
+                try:
+                    QFileDialog.getOpenFileNameAndFilter(
+                        None,
+                        self.eCaption.text(),
+                        self.eStartWith.text(),
+                        self.eFilters.text(),
+                        self.eInitialFilter.text(),
+                        options)
+                except AttributeError:
+                    QFileDialog.getOpenFileName(
+                        None,
+                        self.eCaption.text(),
+                        self.eStartWith.text(),
+                        self.eFilters.text(),
+                        self.eInitialFilter.text(),
+                        options)
         elif self.rOpenFiles.isChecked() or self.rfOpenFiles.isChecked():
             if not self.cSymlinks.isChecked():
                 options = QFileDialog.Options(QFileDialog.DontResolveSymlinks)
@@ -147,20 +172,38 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
                 options = QFileDialog.Options()
             options = self.__adjustOptions(options)
             if self.rOpenFiles.isChecked() and self.__pyqtVariant == 4:
-                QFileDialog.getOpenFileNames(
-                    None,
-                    self.eCaption.text(),
-                    self.eStartWith.text(),
-                    self.eFilters.text(),
-                    options)
+                try:
+                    QFileDialog.getOpenFileNames(
+                        None,
+                        self.eCaption.text(),
+                        self.eStartWith.text(),
+                        self.eFilters.text(),
+                        options)
+                except TypeError:
+                    QFileDialog.getOpenFileNames(
+                        None,
+                        self.eCaption.text(),
+                        self.eStartWith.text(),
+                        self.eFilters.text(),
+                        self.eInitialFilter.text(),
+                        options)
             else:
-                QFileDialog.getOpenFileNamesAndFilter(
-                    None,
-                    self.eCaption.text(),
-                    self.eStartWith.text(),
-                    self.eFilters.text(),
-                    self.eInitialFilter.text(),
-                    options)
+                try:
+                    QFileDialog.getOpenFileNamesAndFilter(
+                        None,
+                        self.eCaption.text(),
+                        self.eStartWith.text(),
+                        self.eFilters.text(),
+                        self.eInitialFilter.text(),
+                        options)
+                except AttributeError:
+                    QFileDialog.getOpenFileNames(
+                        None,
+                        self.eCaption.text(),
+                        self.eStartWith.text(),
+                        self.eFilters.text(),
+                        self.eInitialFilter.text(),
+                        options)
         elif self.rSaveFile.isChecked() or self.rfSaveFile.isChecked():
             if not self.cSymlinks.isChecked():
                 options = QFileDialog.Options(QFileDialog.DontResolveSymlinks)
@@ -168,20 +211,38 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
                 options = QFileDialog.Options()
             options = self.__adjustOptions(options)
             if self.rSaveFile.isChecked() and self.__pyqtVariant == 4:
-                QFileDialog.getSaveFileName(
-                    None,
-                    self.eCaption.text(),
-                    self.eStartWith.text(),
-                    self.eFilters.text(),
-                    options)
+                try:
+                    QFileDialog.getSaveFileName(
+                        None,
+                        self.eCaption.text(),
+                        self.eStartWith.text(),
+                        self.eFilters.text(),
+                        options)
+                except TypeError:
+                    QFileDialog.getSaveFileName(
+                        None,
+                        self.eCaption.text(),
+                        self.eStartWith.text(),
+                        self.eFilters.text(),
+                        self.eInitialFilter.text(),
+                        options)
             else:
-                QFileDialog.getSaveFileNameAndFilter(
-                    None,
-                    self.eCaption.text(),
-                    self.eStartWith.text(),
-                    self.eFilters.text(),
-                    self.eInitialFilter.text(),
-                    options)
+                try:
+                    QFileDialog.getSaveFileNameAndFilter(
+                        None,
+                        self.eCaption.text(),
+                        self.eStartWith.text(),
+                        self.eFilters.text(),
+                        self.eInitialFilter.text(),
+                        options)
+                except AttributeError:
+                    QFileDialog.getSaveFileName(
+                        None,
+                        self.eCaption.text(),
+                        self.eStartWith.text(),
+                        self.eFilters.text(),
+                        self.eInitialFilter.text(),
+                        options)
         elif self.rDirectory.isChecked():
             options = QFileDialog.Options()
             if not self.cSymlinks.isChecked():
@@ -279,9 +340,9 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
             if (self.__pyqtVariant == 4 and
                 self.__typeButtonsGroup.checkedButton() in [
                     self.rfOpenFile, self.rfOpenFiles, self.rfSaveFile]) or \
-                (self.__pyqtVariant == 5 and
-                 self.__typeButtonsGroup.checkedButton() in [
-                    self.rOpenFile, self.rOpenFiles, self.rSaveFile]):
+                    (self.__pyqtVariant == 5 and
+                        self.__typeButtonsGroup.checkedButton() in [
+                            self.rOpenFile, self.rOpenFiles, self.rSaveFile]):
                 filterVariable = ", selectedFilter"
             else:
                 filterVariable = ""
@@ -297,7 +358,7 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
             if not self.eCaption.text():
                 code += '"",{0}{1}'.format(os.linesep, istring)
             else:
-                code += 'self.trUtf8("{0}"),{1}{2}'.format(
+                code += 'self.tr("{0}"),{1}{2}'.format(
                     self.eCaption.text(), os.linesep, istring)
             if not self.eStartWith.text():
                 code += '"",{0}{1}'.format(os.linesep, istring)
@@ -305,7 +366,7 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
                 if self.cStartWith.isChecked():
                     fmt = '{0},{1}{2}'
                 else:
-                    fmt = 'self.trUtf8("{0}"),{1}{2}'
+                    fmt = 'self.tr("{0}"),{1}{2}'
                 code += fmt.format(self.eStartWith.text(), os.linesep, istring)
             if self.eFilters.text() == "":
                 code += '""'
@@ -313,7 +374,7 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
                 if self.cFilters.isChecked():
                     fmt = '{0}'
                 else:
-                    fmt = 'self.trUtf8("{0}")'
+                    fmt = 'self.tr("{0}")'
                 code += fmt.format(self.eFilters.text())
             if self.rfOpenFile.isChecked() or self.__pyqtVariant == 5:
                 if self.eInitialFilter.text() == "":
@@ -322,7 +383,7 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
                     if self.cInitialFilter.isChecked():
                         fmt = '{0}'
                     else:
-                        fmt = 'self.trUtf8("{0}")'
+                        fmt = 'self.tr("{0}")'
                     filter = fmt.format(self.eInitialFilter.text())
                 code += ',{0}{1}{2}'.format(os.linesep, istring, filter)
             if not self.cSymlinks.isChecked():
@@ -341,7 +402,7 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
             if not self.eCaption.text():
                 code += '"",{0}{1}'.format(os.linesep, istring)
             else:
-                code += 'self.trUtf8("{0}"),{1}{2}'.format(
+                code += 'self.tr("{0}"),{1}{2}'.format(
                     self.eCaption.text(), os.linesep, istring)
             if not self.eStartWith.text():
                 code += '"",{0}{1}'.format(os.linesep, istring)
@@ -349,7 +410,7 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
                 if self.cStartWith.isChecked():
                     fmt = '{0},{1}{2}'
                 else:
-                    fmt = 'self.trUtf8("{0}"),{1}{2}'
+                    fmt = 'self.tr("{0}"),{1}{2}'
                 code += fmt.format(self.eStartWith.text(), os.linesep, istring)
             if not self.eFilters.text():
                 code += '""'
@@ -357,7 +418,7 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
                 if self.cFilters.isChecked():
                     fmt = '{0}'
                 else:
-                    fmt = 'self.trUtf8("{0}")'
+                    fmt = 'self.tr("{0}")'
                 code += fmt.format(self.eFilters.text())
             if self.rfOpenFiles.isChecked() or self.__pyqtVariant == 5:
                 if self.eInitialFilter.text() == "":
@@ -366,7 +427,7 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
                     if self.cInitialFilter.isChecked():
                         fmt = '{0}'
                     else:
-                        fmt = 'self.trUtf8("{0}")'
+                        fmt = 'self.tr("{0}")'
                     filter = fmt.format(self.eInitialFilter.text())
                 code += ',{0}{1}{2}'.format(os.linesep, istring, filter)
             if not self.cSymlinks.isChecked():
@@ -385,7 +446,7 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
             if not self.eCaption.text():
                 code += '"",{0}{1}'.format(os.linesep, istring)
             else:
-                code += 'self.trUtf8("{0}"),{1}{2}'.format(
+                code += 'self.tr("{0}"),{1}{2}'.format(
                     self.eCaption.text(), os.linesep, istring)
             if not self.eStartWith.text():
                 code += '"",{0}{1}'.format(os.linesep, istring)
@@ -393,7 +454,7 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
                 if self.cStartWith.isChecked():
                     fmt = '{0},{1}{2}'
                 else:
-                    fmt = 'self.trUtf8("{0}"),{1}{2}'
+                    fmt = 'self.tr("{0}"),{1}{2}'
                 code += fmt.format(self.eStartWith.text(), os.linesep, istring)
             if not self.eFilters.text():
                 code += '""'
@@ -401,7 +462,7 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
                 if self.cFilters.isChecked():
                     fmt = '{0}'
                 else:
-                    fmt = 'self.trUtf8("{0}")'
+                    fmt = 'self.tr("{0}")'
                 code += fmt.format(self.eFilters.text())
             if self.rfSaveFile.isChecked() or self.__pyqtVariant == 5:
                 if self.eInitialFilter.text() == "":
@@ -410,7 +471,7 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
                     if self.cInitialFilter.isChecked():
                         fmt = '{0}'
                     else:
-                        fmt = 'self.trUtf8("{0}")'
+                        fmt = 'self.tr("{0}")'
                     filter = fmt.format(self.eInitialFilter.text())
                 code += ',{0}{1}{2}'.format(os.linesep, istring, filter)
             if (not self.cSymlinks.isChecked()) or \
@@ -432,7 +493,7 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
             if not self.eCaption.text():
                 code += '"",{0}{1}'.format(os.linesep, istring)
             else:
-                code += 'self.trUtf8("{0}"),{1}{2}'.format(
+                code += 'self.tr("{0}"),{1}{2}'.format(
                     self.eCaption.text(), os.linesep, istring)
             if not self.eWorkDir.text():
                 code += '""'
@@ -440,7 +501,7 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
                 if self.cWorkDir.isChecked():
                     fmt = '{0}'
                 else:
-                    fmt = 'self.trUtf8("{0}")'
+                    fmt = 'self.tr("{0}")'
                 code += fmt.format(self.eWorkDir.text())
             code += ',{0}{1}QFileDialog.Options('.format(os.linesep, istring)
             if not self.cSymlinks.isChecked():
