@@ -1,18 +1,21 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Python re wizard dialog.
 """
 
+from __future__ import unicode_literals
+
 import os
 import re
 
-from PyQt4.QtCore import QFileInfo, pyqtSlot
-from PyQt4.QtGui import QWidget, QDialog, QInputDialog, QApplication, \
-    QClipboard, QTextCursor, QDialogButtonBox, QVBoxLayout, QTableWidgetItem
+from PyQt5.QtCore import QFileInfo, pyqtSlot
+from PyQt5.QtGui import QClipboard, QTextCursor
+from PyQt5.QtWidgets import QWidget, QDialog, QInputDialog, QApplication, \
+    QDialogButtonBox, QVBoxLayout, QTableWidgetItem
 
 from E5Gui import E5MessageBox, E5FileDialog
 from E5Gui.E5MainWindow import E5MainWindow
@@ -34,9 +37,9 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
         Constructor
         
         @param parent parent widget (QWidget)
-        @param fromEric flag indicating a call from within eric5
+        @param fromEric flag indicating a call from within eric6
         """
-        super().__init__(parent)
+        super(PyRegExpWizardWidget, self).__init__(parent)
         self.setupUi(self)
         
         # initialize icons of the tool buttons
@@ -70,25 +73,25 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
         self.namedGroups = re.compile(r"""\(?P<([^>]+)>""").findall
         
         self.saveButton = self.buttonBox.addButton(
-            self.trUtf8("Save"), QDialogButtonBox.ActionRole)
+            self.tr("Save"), QDialogButtonBox.ActionRole)
         self.saveButton.setToolTip(
-            self.trUtf8("Save the regular expression to a file"))
+            self.tr("Save the regular expression to a file"))
         self.loadButton = self.buttonBox.addButton(
-            self.trUtf8("Load"), QDialogButtonBox.ActionRole)
+            self.tr("Load"), QDialogButtonBox.ActionRole)
         self.loadButton.setToolTip(
-            self.trUtf8("Load a regular expression from a file"))
+            self.tr("Load a regular expression from a file"))
         self.validateButton = self.buttonBox.addButton(
-            self.trUtf8("Validate"), QDialogButtonBox.ActionRole)
+            self.tr("Validate"), QDialogButtonBox.ActionRole)
         self.validateButton.setToolTip(
-            self.trUtf8("Validate the regular expression"))
+            self.tr("Validate the regular expression"))
         self.executeButton = self.buttonBox.addButton(
-            self.trUtf8("Execute"), QDialogButtonBox.ActionRole)
+            self.tr("Execute"), QDialogButtonBox.ActionRole)
         self.executeButton.setToolTip(
-            self.trUtf8("Execute the regular expression"))
+            self.tr("Execute the regular expression"))
         self.nextButton = self.buttonBox.addButton(
-            self.trUtf8("Next match"), QDialogButtonBox.ActionRole)
+            self.tr("Next match"), QDialogButtonBox.ActionRole)
         self.nextButton.setToolTip(
-            self.trUtf8("Show the next match of the regular expression"))
+            self.tr("Show the next match of the regular expression"))
         self.nextButton.setEnabled(False)
         
         if fromEric:
@@ -97,9 +100,9 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
             self.copyButton = None
         else:
             self.copyButton = self.buttonBox.addButton(
-                self.trUtf8("Copy"), QDialogButtonBox.ActionRole)
+                self.tr("Copy"), QDialogButtonBox.ActionRole)
             self.copyButton.setToolTip(
-                self.trUtf8("Copy the regular expression to the clipboard"))
+                self.tr("Copy the regular expression to the clipboard"))
             self.buttonBox.setStandardButtons(QDialogButtonBox.Close)
             self.variableLabel.hide()
             self.variableLineEdit.hide()
@@ -178,14 +181,14 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
         if not names:
             E5MessageBox.information(
                 self,
-                self.trUtf8("Named reference"),
-                self.trUtf8("""No named groups have been defined yet."""))
+                self.tr("Named reference"),
+                self.tr("""No named groups have been defined yet."""))
             return
         
         groupName, ok = QInputDialog.getItem(
             self,
-            self.trUtf8("Named reference"),
-            self.trUtf8("Select group name:"),
+            self.tr("Named reference"),
+            self.tr("Select group name:"),
             names,
             0, True)
         if ok and groupName:
@@ -315,9 +318,9 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
         """
         fname, selectedFilter = E5FileDialog.getSaveFileNameAndFilter(
             self,
-            self.trUtf8("Save regular expression"),
+            self.tr("Save regular expression"),
             "",
-            self.trUtf8("RegExp Files (*.rx);;All Files (*)"),
+            self.tr("RegExp Files (*.rx);;All Files (*)"),
             None,
             E5FileDialog.Options(E5FileDialog.DontConfirmOverwrite))
         if fname:
@@ -329,9 +332,9 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
             if QFileInfo(fname).exists():
                 res = E5MessageBox.yesNo(
                     self,
-                    self.trUtf8("Save regular expression"),
-                    self.trUtf8("<p>The file <b>{0}</b> already exists."
-                                " Overwrite it?</p>").format(fname),
+                    self.tr("Save regular expression"),
+                    self.tr("<p>The file <b>{0}</b> already exists."
+                            " Overwrite it?</p>").format(fname),
                     icon=E5MessageBox.Warning)
                 if not res:
                     return
@@ -344,9 +347,9 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
             except IOError as err:
                 E5MessageBox.information(
                     self,
-                    self.trUtf8("Save regular expression"),
-                    self.trUtf8("""<p>The regular expression could not"""
-                                """ be saved.</p><p>Reason: {0}</p>""")
+                    self.tr("Save regular expression"),
+                    self.tr("""<p>The regular expression could not"""
+                            """ be saved.</p><p>Reason: {0}</p>""")
                     .format(str(err)))
     
     @pyqtSlot()
@@ -356,9 +359,9 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
         """
         fname = E5FileDialog.getOpenFileName(
             self,
-            self.trUtf8("Load regular expression"),
+            self.tr("Load regular expression"),
             "",
-            self.trUtf8("RegExp Files (*.rx);;All Files (*)"))
+            self.tr("RegExp Files (*.rx);;All Files (*)"))
         if fname:
             try:
                 f = open(
@@ -369,9 +372,9 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
             except IOError as err:
                 E5MessageBox.information(
                     self,
-                    self.trUtf8("Save regular expression"),
-                    self.trUtf8("""<p>The regular expression could not"""
-                                """ be saved.</p><p>Reason: {0}</p>""")
+                    self.tr("Save regular expression"),
+                    self.tr("""<p>The regular expression could not"""
+                            """ be saved.</p><p>Reason: {0}</p>""")
                     .format(str(err)))
 
     @pyqtSlot()
@@ -379,7 +382,7 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
         """
         Private slot to copy the regexp string into the clipboard.
         
-        This slot is only available, if not called from within eric5.
+        This slot is only available, if not called from within eric6.
         """
         escaped = self.regexpTextEdit.toPlainText()
         if escaped:
@@ -417,27 +420,27 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
                 re.compile(regex, flags)
                 E5MessageBox.information(
                     self,
-                    self.trUtf8("Validation"),
-                    self.trUtf8("""The regular expression is valid."""))
+                    self.tr("Validation"),
+                    self.tr("""The regular expression is valid."""))
             except re.error as e:
                 E5MessageBox.critical(
                     self,
-                    self.trUtf8("Error"),
-                    self.trUtf8("""Invalid regular expression: {0}""")
+                    self.tr("Error"),
+                    self.tr("""Invalid regular expression: {0}""")
                     .format(str(e)))
                 return
             except IndexError:
                 E5MessageBox.critical(
                     self,
-                    self.trUtf8("Error"),
-                    self.trUtf8("""Invalid regular expression: missing"""
-                                """ group name"""))
+                    self.tr("Error"),
+                    self.tr("""Invalid regular expression: missing"""
+                            """ group name"""))
                 return
         else:
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Error"),
-                self.trUtf8("""A regular expression must be given."""))
+                self.tr("Error"),
+                self.tr("""A regular expression must be given."""))
 
     @pyqtSlot()
     def on_executeButton_clicked(self, startpos=0):
@@ -486,7 +489,7 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
                 self.resultTable.setRowCount(0)
                 self.resultTable.setRowCount(OFFSET)
                 self.resultTable.setItem(
-                    row, 0, QTableWidgetItem(self.trUtf8("Regexp")))
+                    row, 0, QTableWidgetItem(self.tr("Regexp")))
                 self.resultTable.setItem(
                     row, 1, QTableWidgetItem(regex))
                 
@@ -497,7 +500,7 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
                     row += 1
                     self.resultTable.setItem(
                         row, 0,
-                        QTableWidgetItem(self.trUtf8("Offset")))
+                        QTableWidgetItem(self.tr("Offset")))
                     self.resultTable.setItem(
                         row, 1,
                         QTableWidgetItem("{0:d}".format(matchobj.start(0))))
@@ -505,22 +508,22 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
                     row += 1
                     self.resultTable.setItem(
                         row, 0,
-                        QTableWidgetItem(self.trUtf8("Captures")))
+                        QTableWidgetItem(self.tr("Captures")))
                     self.resultTable.setItem(
                         row, 1,
                         QTableWidgetItem("{0:d}".format(captures)))
                     row += 1
                     self.resultTable.setItem(
                         row, 1,
-                        QTableWidgetItem(self.trUtf8("Text")))
+                        QTableWidgetItem(self.tr("Text")))
                     self.resultTable.setItem(
                         row, 2,
-                        QTableWidgetItem(self.trUtf8("Characters")))
+                        QTableWidgetItem(self.tr("Characters")))
                     
                     row += 1
                     self.resultTable.setItem(
                         row, 0,
-                        QTableWidgetItem(self.trUtf8("Match")))
+                        QTableWidgetItem(self.tr("Match")))
                     self.resultTable.setItem(
                         row, 1,
                         QTableWidgetItem(matchobj.group(0)))
@@ -536,7 +539,7 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
                             self.resultTable.setItem(
                                 row, 0,
                                 QTableWidgetItem(
-                                    self.trUtf8("Capture #{0}").format(i)))
+                                    self.tr("Capture #{0}").format(i)))
                             self.resultTable.setItem(
                                 row, 1, QTableWidgetItem(matchobj.group(i)))
                             self.resultTable.setItem(
@@ -555,11 +558,11 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
                     if startpos > 0:
                         self.resultTable.setItem(
                             row, 0,
-                            QTableWidgetItem(self.trUtf8("No more matches")))
+                            QTableWidgetItem(self.tr("No more matches")))
                     else:
                         self.resultTable.setItem(
                             row, 0,
-                            QTableWidgetItem(self.trUtf8("No matches")))
+                            QTableWidgetItem(self.tr("No matches")))
                     
                     # remove the highlight
                     tc = self.textTextEdit.textCursor()
@@ -573,23 +576,23 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
             except re.error as e:
                 E5MessageBox.critical(
                     self,
-                    self.trUtf8("Error"),
-                    self.trUtf8("""Invalid regular expression: {0}""")
+                    self.tr("Error"),
+                    self.tr("""Invalid regular expression: {0}""")
                     .format(str(e)))
                 return
             except IndexError:
                 E5MessageBox.critical(
                     self,
-                    self.trUtf8("Error"),
-                    self.trUtf8("""Invalid regular expression: missing"""
-                                """ group name"""))
+                    self.tr("Error"),
+                    self.tr("""Invalid regular expression: missing"""
+                            """ group name"""))
                 return
         else:
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Error"),
-                self.trUtf8("""A regular expression and a text must be"""
-                            """ given."""))
+                self.tr("Error"),
+                self.tr("""A regular expression and a text must be"""
+                        """ given."""))
         
     @pyqtSlot()
     def on_nextButton_clicked(self):
@@ -615,9 +618,9 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
         # set the checkboxes
         self.localeCheckBox.setEnabled(checked)
         if checked:
-            self.unicodeCheckBox.setText(self.trUtf8("Unicode"))
+            self.unicodeCheckBox.setText(self.tr("Unicode"))
         else:
-            self.unicodeCheckBox.setText(self.trUtf8("ASCII"))
+            self.unicodeCheckBox.setText(self.tr("ASCII"))
         self.unicodeCheckBox.setChecked(not self.unicodeCheckBox.isChecked())
         
         # clear the result table
@@ -690,9 +693,9 @@ class PyRegExpWizardDialog(QDialog):
         Constructor
         
         @param parent parent widget (QWidget)
-        @param fromEric flag indicating a call from within eric5
+        @param fromEric flag indicating a call from within eric6
         """
-        super().__init__(parent)
+        super(PyRegExpWizardDialog, self).__init__(parent)
         self.setModal(fromEric)
         self.setSizeGripEnabled(True)
         
@@ -706,8 +709,8 @@ class PyRegExpWizardDialog(QDialog):
         self.resize(size)
         self.setWindowTitle(self.cw.windowTitle())
         
-        self.cw.buttonBox.accepted[()].connect(self.accept)
-        self.cw.buttonBox.rejected[()].connect(self.reject)
+        self.cw.buttonBox.accepted.connect(self.accept)
+        self.cw.buttonBox.rejected.connect(self.reject)
     
     def getCode(self, indLevel, indString):
         """
@@ -730,7 +733,7 @@ class PyRegExpWizardWindow(E5MainWindow):
         
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(PyRegExpWizardWindow, self).__init__(parent)
         self.cw = PyRegExpWizardWidget(self, fromEric=False)
         size = self.cw.size()
         self.setCentralWidget(self.cw)
@@ -740,5 +743,5 @@ class PyRegExpWizardWindow(E5MainWindow):
         self.setStyle(
             Preferences.getUI("Style"), Preferences.getUI("StyleSheet"))
         
-        self.cw.buttonBox.accepted[()].connect(self.close)
-        self.cw.buttonBox.rejected[()].connect(self.close)
+        self.cw.buttonBox.accepted.connect(self.close)
+        self.cw.buttonBox.rejected.connect(self.close)
