@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog for entering repeat counts.
 """
 
-from PyQt4.QtCore import pyqtSlot
-from PyQt4.QtGui import QDialog
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSlot
+from PyQt5.QtWidgets import QDialog
 
 from .Ui_PyRegExpWizardRepeatDialog import Ui_PyRegExpWizardRepeatDialog
 
@@ -23,11 +25,14 @@ class PyRegExpWizardRepeatDialog(QDialog, Ui_PyRegExpWizardRepeatDialog):
         
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(PyRegExpWizardRepeatDialog, self).__init__(parent)
         self.setupUi(self)
         
         self.unlimitedButton.setChecked(True)
         
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
+        
     @pyqtSlot(int)
     def on_lowerSpin_valueChanged(self, value):
         """
