@@ -1,16 +1,19 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2013 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2013 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog for entering character classes.
 """
 
-from PyQt4.QtCore import QRegExp
-from PyQt4.QtGui import QWidget, QDialog, QVBoxLayout, QHBoxLayout, \
-    QScrollArea, QPushButton, QSpacerItem, QSizePolicy, QComboBox, \
-    QRegExpValidator, QLineEdit, QLabel
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import QRegExp
+from PyQt5.QtGui import QRegExpValidator
+from PyQt5.QtWidgets import QWidget, QDialog, QVBoxLayout, QHBoxLayout, \
+    QScrollArea, QPushButton, QSpacerItem, QSizePolicy, QComboBox, QLineEdit, \
+    QLabel
 
 from .Ui_QRegularExpressionWizardCharactersDialog import \
     Ui_QRegularExpressionWizardCharactersDialog
@@ -27,35 +30,35 @@ class QRegularExpressionWizardCharactersDialog(
         
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(QRegularExpressionWizardCharactersDialog, self).__init__(parent)
         self.setupUi(self)
         
         self.__initCharacterSelectors()
         
         self.comboItems = []
         self.singleComboItems = []      # these are in addition to the above
-        self.comboItems.append((self.trUtf8("Normal character"), "-c"))
-        self.comboItems.append((self.trUtf8(
+        self.comboItems.append((self.tr("Normal character"), "-c"))
+        self.comboItems.append((self.tr(
             "Unicode character in hexadecimal notation"), "-h"))
-        self.comboItems.append((self.trUtf8(
+        self.comboItems.append((self.tr(
             "ASCII/Latin1 character in octal notation"), "-o"))
         self.singleComboItems.extend([
             ("---", "-i"),
-            (self.trUtf8("Bell character (\\a)"), "\\a"),
-            (self.trUtf8("Escape character (\\e)"), "\\e"),
-            (self.trUtf8("Page break (\\f)"), "\\f"),
-            (self.trUtf8("Line feed (\\n)"), "\\n"),
-            (self.trUtf8("Carriage return (\\r)"), "\\r"),
-            (self.trUtf8("Horizontal tabulator (\\t)"), "\\t"),
+            (self.tr("Bell character (\\a)"), "\\a"),
+            (self.tr("Escape character (\\e)"), "\\e"),
+            (self.tr("Page break (\\f)"), "\\f"),
+            (self.tr("Line feed (\\n)"), "\\n"),
+            (self.tr("Carriage return (\\r)"), "\\r"),
+            (self.tr("Horizontal tabulator (\\t)"), "\\t"),
             ("---", "-i"),
-            (self.trUtf8("Character Category"), "-ccp"),
-            (self.trUtf8("Special Character Category"), "-csp"),
-            (self.trUtf8("Character Block"), "-cbp"),
-            (self.trUtf8("POSIX Named Set"), "-psp"),
-            (self.trUtf8("Not Character Category"), "-ccn"),
-            (self.trUtf8("Not Character Block"), "-cbn"),
-            (self.trUtf8("Not Special Character Category"), "-csn"),
-            (self.trUtf8("Not POSIX Named Set"), "-psn"),
+            (self.tr("Character Category"), "-ccp"),
+            (self.tr("Special Character Category"), "-csp"),
+            (self.tr("Character Block"), "-cbp"),
+            (self.tr("POSIX Named Set"), "-psp"),
+            (self.tr("Not Character Category"), "-ccn"),
+            (self.tr("Not Character Block"), "-cbn"),
+            (self.tr("Not Special Character Category"), "-csn"),
+            (self.tr("Not POSIX Named Set"), "-psn"),
         ])
         
         self.charValidator = QRegExpValidator(QRegExp(".{0,1}"), self)
@@ -88,14 +91,14 @@ class QRegularExpressionWizardCharactersDialog(
         hlayout0.setSpacing(6)
         hlayout0.setObjectName("hlayout0")
         self.moreSinglesButton = QPushButton(
-            self.trUtf8("Additional Entries"), self.singlesBox)
+            self.tr("Additional Entries"), self.singlesBox)
         self.moreSinglesButton.setObjectName("moreSinglesButton")
         hlayout0.addWidget(self.moreSinglesButton)
         hspacer0 = QSpacerItem(
             30, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)
         hlayout0.addItem(hspacer0)
         self.singlesBoxLayout.addLayout(hlayout0)
-        self.moreSinglesButton.clicked[()].connect(self.__addSinglesLine)
+        self.moreSinglesButton.clicked.connect(self.__addSinglesLine)
         
         # generate dialog part for character ranges
         self.rangesBoxLayout = QVBoxLayout(self.rangesBox)
@@ -123,14 +126,14 @@ class QRegularExpressionWizardCharactersDialog(
         hlayout1.setSpacing(6)
         hlayout1.setObjectName("hlayout1")
         self.moreRangesButton = QPushButton(
-            self.trUtf8("Additional Entries"), self.rangesBox)
+            self.tr("Additional Entries"), self.rangesBox)
         self.moreSinglesButton.setObjectName("moreRangesButton")
         hlayout1.addWidget(self.moreRangesButton)
         hspacer1 = QSpacerItem(
             30, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)
         hlayout1.addItem(hspacer1)
         self.rangesBoxLayout.addLayout(hlayout1)
-        self.moreRangesButton.clicked[()].connect(self.__addRangesLine)
+        self.moreRangesButton.clicked.connect(self.__addRangesLine)
     
     def __initCharacterSelectors(self):
         """
@@ -138,177 +141,177 @@ class QRegularExpressionWizardCharactersDialog(
         """
         self.__characterCategories = (
             # display name                                  code
-            (self.trUtf8("Letter, Any"),                    "L"),
-            (self.trUtf8("Letter, Lower case"),             "Ll"),
-            (self.trUtf8("Letter, Modifier"),               "Lm"),
-            (self.trUtf8("Letter, Other"),                  "Lo"),
-            (self.trUtf8("Letter, Title case"),             "Lt"),
-            (self.trUtf8("Letter, Upper case"),             "Lu"),
-            (self.trUtf8("Letter, Lower, Upper or Title"),  "L&"),
-            (self.trUtf8("Mark, Any"),                      "M"),
-            (self.trUtf8("Mark, Spacing"),                  "Mc"),
-            (self.trUtf8("Mark, Enclosing"),                "Me"),
-            (self.trUtf8("Mark, Non-spacing"),              "Mn"),
-            (self.trUtf8("Number, Any"),                    "N"),
-            (self.trUtf8("Number, Decimal"),                "Nd"),
-            (self.trUtf8("Number, Letter"),                 "Nl"),
-            (self.trUtf8("Number, Other"),                  "No"),
-            (self.trUtf8("Punctuation, Any"),               "P"),
-            (self.trUtf8("Punctuation, Connector"),         "Pc"),
-            (self.trUtf8("Punctuation, Dash"),              "Pd"),
-            (self.trUtf8("Punctuation, Close"),             "Pe"),
-            (self.trUtf8("Punctuation, Final"),             "Pf"),
-            (self.trUtf8("Punctuation, Initial"),           "Pi"),
-            (self.trUtf8("Punctuation, Other"),             "Po"),
-            (self.trUtf8("Punctuation, Open"),              "Ps"),
-            (self.trUtf8("Symbol, Any"),                    "S"),
-            (self.trUtf8("Symbol, Currency"),               "Sc"),
-            (self.trUtf8("Symbol, Modifier"),               "Sk"),
-            (self.trUtf8("Symbol, Mathematical"),           "Sm"),
-            (self.trUtf8("Symbol, Other"),                  "So"),
-            (self.trUtf8("Separator, Any"),                 "Z"),
-            (self.trUtf8("Separator, Line"),                "Zl"),
-            (self.trUtf8("Separator, Paragraph"),           "Zp"),
-            (self.trUtf8("Separator, Space"),               "Zs"),
-            (self.trUtf8("Other, Any"),                     "C"),
-            (self.trUtf8("Other, Control"),                 "Cc"),
-            (self.trUtf8("Other, Format"),                  "Cf"),
-            (self.trUtf8("Other, Unassigned"),              "Cn"),
-            (self.trUtf8("Other, Private Use"),             "Co"),
-            (self.trUtf8("Other, Surrogat"),                "Cn"),
+            (self.tr("Letter, Any"), "L"),
+            (self.tr("Letter, Lower case"), "Ll"),
+            (self.tr("Letter, Modifier"), "Lm"),
+            (self.tr("Letter, Other"), "Lo"),
+            (self.tr("Letter, Title case"), "Lt"),
+            (self.tr("Letter, Upper case"), "Lu"),
+            (self.tr("Letter, Lower, Upper or Title"), "L&"),
+            (self.tr("Mark, Any"), "M"),
+            (self.tr("Mark, Spacing"), "Mc"),
+            (self.tr("Mark, Enclosing"), "Me"),
+            (self.tr("Mark, Non-spacing"), "Mn"),
+            (self.tr("Number, Any"), "N"),
+            (self.tr("Number, Decimal"), "Nd"),
+            (self.tr("Number, Letter"), "Nl"),
+            (self.tr("Number, Other"), "No"),
+            (self.tr("Punctuation, Any"), "P"),
+            (self.tr("Punctuation, Connector"), "Pc"),
+            (self.tr("Punctuation, Dash"), "Pd"),
+            (self.tr("Punctuation, Close"), "Pe"),
+            (self.tr("Punctuation, Final"), "Pf"),
+            (self.tr("Punctuation, Initial"), "Pi"),
+            (self.tr("Punctuation, Other"), "Po"),
+            (self.tr("Punctuation, Open"), "Ps"),
+            (self.tr("Symbol, Any"), "S"),
+            (self.tr("Symbol, Currency"), "Sc"),
+            (self.tr("Symbol, Modifier"), "Sk"),
+            (self.tr("Symbol, Mathematical"), "Sm"),
+            (self.tr("Symbol, Other"), "So"),
+            (self.tr("Separator, Any"), "Z"),
+            (self.tr("Separator, Line"), "Zl"),
+            (self.tr("Separator, Paragraph"), "Zp"),
+            (self.tr("Separator, Space"), "Zs"),
+            (self.tr("Other, Any"), "C"),
+            (self.tr("Other, Control"), "Cc"),
+            (self.tr("Other, Format"), "Cf"),
+            (self.tr("Other, Unassigned"), "Cn"),
+            (self.tr("Other, Private Use"), "Co"),
+            (self.tr("Other, Surrogat"), "Cn"),
         )
         
         self.__specialCharacterCategories = (
             # display name                           code
-            (self.trUtf8("Alphanumeric"),            "Xan"),
-            (self.trUtf8("POSIX Space"),             "Xps"),
-            (self.trUtf8("Perl Space"),              "Xsp"),
-            (self.trUtf8("Universal Character"),     "Xuc"),
-            (self.trUtf8("Perl Word"),               "Xan"),
+            (self.tr("Alphanumeric"), "Xan"),
+            (self.tr("POSIX Space"), "Xps"),
+            (self.tr("Perl Space"), "Xsp"),
+            (self.tr("Universal Character"), "Xuc"),
+            (self.tr("Perl Word"), "Xan"),
         )
         
         self.__characterBlocks = (
             # display name                           code
-            (self.trUtf8("Arabic"),                  "Arabic"),
-            (self.trUtf8("Armenian"),                "Armenian"),
-            (self.trUtf8("Avestan"),                 "Avestan"),
-            (self.trUtf8("Balinese"),                "Balinese"),
-            (self.trUtf8("Bamum"),                   "Bamum"),
-            (self.trUtf8("Batak"),                   "Batak"),
-            (self.trUtf8("Bengali"),                 "Bengali"),
-            (self.trUtf8("Bopomofo"),                "Bopomofo"),
-            (self.trUtf8("Brahmi"),                  "Brahmi"),
-            (self.trUtf8("Braille"),                 "Braille"),
-            (self.trUtf8("Buginese"),                "Buginese"),
-            (self.trUtf8("Buhid"),                   "Buhid"),
-            (self.trUtf8("Canadian Aboriginal"),     "Canadian_Aboriginal"),
-            (self.trUtf8("Carian"),                  "Carian"),
-            (self.trUtf8("Chakma"),                  "Chakma"),
-            (self.trUtf8("Cham"),                    "Cham"),
-            (self.trUtf8("Cherokee"),                "Cherokee"),
-            (self.trUtf8("Common"),                  "Common"),
-            (self.trUtf8("Coptic"),                  "Coptic"),
-            (self.trUtf8("Cuneiform"),               "Cuneiform"),
-            (self.trUtf8("Cypriot"),                 "Cypriot"),
-            (self.trUtf8("Cyrillic"),                "Cyrillic"),
-            (self.trUtf8("Deseret"),                 "Deseret,"),
-            (self.trUtf8("Devanagari"),              "Devanagari"),
-            (self.trUtf8("Egyptian Hieroglyphs"),    "Egyptian_Hieroglyphs"),
-            (self.trUtf8("Ethiopic"),                "Ethiopic"),
-            (self.trUtf8("Georgian"),                "Georgian"),
-            (self.trUtf8("Glagolitic"),              "Glagolitic"),
-            (self.trUtf8("Gothic"),                  "Gothic"),
-            (self.trUtf8("Greek"),                   "Greek"),
-            (self.trUtf8("Gujarati"),                "Gujarati"),
-            (self.trUtf8("Gurmukhi"),                "Gurmukhi"),
-            (self.trUtf8("Han"),                     "Han"),
-            (self.trUtf8("Hangul"),                  "Hangul"),
-            (self.trUtf8("Hanunoo"),                 "Hanunoo"),
-            (self.trUtf8("Hebrew"),                  "Hebrew"),
-            (self.trUtf8("Hiragana"),                "Hiragana"),
-            (self.trUtf8("Imperial Aramaic"),        "Imperial_Aramaic"),
-            (self.trUtf8("Inherited"),               "Inherited"),
-            (self.trUtf8("Inscriptional Pahlavi"),   "Inscriptional_Pahlavi"),
-            (self.trUtf8("Inscriptional Parthian"),  "Inscriptional_Parthian"),
-            (self.trUtf8("Javanese"),                "Javanese"),
-            (self.trUtf8("Kaithi"),                  "Kaithi"),
-            (self.trUtf8("Kannada"),                 "Kannada"),
-            (self.trUtf8("Katakana"),                "Katakana"),
-            (self.trUtf8("Kayah Li"),                "Kayah_Li"),
-            (self.trUtf8("Kharoshthi"),              "Kharoshthi"),
-            (self.trUtf8("Khmer"),                   "Khmer"),
-            (self.trUtf8("Lao"),                     "Lao"),
-            (self.trUtf8("Latin"),                   "Latin"),
-            (self.trUtf8("Lepcha"),                  "Lepcha"),
-            (self.trUtf8("Limbu"),                   "Limbu"),
-            (self.trUtf8("Linear B"),                "Linear_B"),
-            (self.trUtf8("Lisu"),                    "Lisu"),
-            (self.trUtf8("Lycian"),                  "Lycian"),
-            (self.trUtf8("Lydian"),                  "Lydian"),
-            (self.trUtf8("Malayalam"),               "Malayalam"),
-            (self.trUtf8("Mandaic"),                 "Mandaic"),
-            (self.trUtf8("Meetei Mayek"),            "Meetei_Mayek"),
-            (self.trUtf8("Meroitic Cursive"),        "Meroitic_Cursive"),
-            (self.trUtf8("Meroitic Hieroglyphs"),    "Meroitic_Hieroglyphs"),
-            (self.trUtf8("Miao"),                    "Miao"),
-            (self.trUtf8("Mongolian"),               "Mongolian"),
-            (self.trUtf8("Myanmar"),                 "Myanmar"),
-            (self.trUtf8("New Tai Lue"),             "New_Tai_Lue"),
-            (self.trUtf8("N'Ko"),                    "Nko"),
-            (self.trUtf8("Ogham"),                   "Ogham"),
-            (self.trUtf8("Old Italic"),              "Old_Italic"),
-            (self.trUtf8("Old Persian"),             "Old_Persian"),
-            (self.trUtf8("Old South Arabian"),       "Old_South_Arabian"),
-            (self.trUtf8("Old Turkic"),              "Old_Turkic,"),
-            (self.trUtf8("Ol Chiki"),                "Ol_Chiki"),
-            (self.trUtf8("Oriya"),                   "Oriya"),
-            (self.trUtf8("Osmanya"),                 "Osmanya"),
-            (self.trUtf8("Phags-pa"),                "Phags_Pa"),
-            (self.trUtf8("Phoenician"),              "Phoenician"),
-            (self.trUtf8("Rejang"),                  "Rejang"),
-            (self.trUtf8("Runic"),                   "Runic"),
-            (self.trUtf8("Samaritan"),               "Samaritan"),
-            (self.trUtf8("Saurashtra"),              "Saurashtra"),
-            (self.trUtf8("Sharada"),                 "Sharada"),
-            (self.trUtf8("Shavian"),                 "Shavian"),
-            (self.trUtf8("Sinhala"),                 "Sinhala"),
-            (self.trUtf8("Sora Sompeng"),            "Sora_Sompeng"),
-            (self.trUtf8("Sundanese"),               "Sundanese"),
-            (self.trUtf8("Syloti Nagri"),            "Syloti_Nagri"),
-            (self.trUtf8("Syriac"),                  "Syriac"),
-            (self.trUtf8("Tagalog"),                 "Tagalog"),
-            (self.trUtf8("Tagbanwa"),                "Tagbanwa"),
-            (self.trUtf8("Tai Le"),                  "Tai_Le"),
-            (self.trUtf8("Tai Tham"),                "Tai_Tham"),
-            (self.trUtf8("Tai Viet"),                "Tai_Viet"),
-            (self.trUtf8("Takri"),                   "Takri"),
-            (self.trUtf8("Tamil"),                   "Tamil"),
-            (self.trUtf8("Telugu"),                  "Telugu"),
-            (self.trUtf8("Thaana"),                  "Thaana"),
-            (self.trUtf8("Thai"),                    "Thai"),
-            (self.trUtf8("Tibetan"),                 "Tibetan"),
-            (self.trUtf8("Tifinagh"),                "Tifinagh"),
-            (self.trUtf8("Ugaritic"),                "Ugaritic"),
-            (self.trUtf8("Vai"),                     "Vai"),
-            (self.trUtf8("Yi"),                      "Yi"),
+            (self.tr("Arabic"), "Arabic"),
+            (self.tr("Armenian"), "Armenian"),
+            (self.tr("Avestan"), "Avestan"),
+            (self.tr("Balinese"), "Balinese"),
+            (self.tr("Bamum"), "Bamum"),
+            (self.tr("Batak"), "Batak"),
+            (self.tr("Bengali"), "Bengali"),
+            (self.tr("Bopomofo"), "Bopomofo"),
+            (self.tr("Brahmi"), "Brahmi"),
+            (self.tr("Braille"), "Braille"),
+            (self.tr("Buginese"), "Buginese"),
+            (self.tr("Buhid"), "Buhid"),
+            (self.tr("Canadian Aboriginal"), "Canadian_Aboriginal"),
+            (self.tr("Carian"), "Carian"),
+            (self.tr("Chakma"), "Chakma"),
+            (self.tr("Cham"), "Cham"),
+            (self.tr("Cherokee"), "Cherokee"),
+            (self.tr("Common"), "Common"),
+            (self.tr("Coptic"), "Coptic"),
+            (self.tr("Cuneiform"), "Cuneiform"),
+            (self.tr("Cypriot"), "Cypriot"),
+            (self.tr("Cyrillic"), "Cyrillic"),
+            (self.tr("Deseret"), "Deseret,"),
+            (self.tr("Devanagari"), "Devanagari"),
+            (self.tr("Egyptian Hieroglyphs"), "Egyptian_Hieroglyphs"),
+            (self.tr("Ethiopic"), "Ethiopic"),
+            (self.tr("Georgian"), "Georgian"),
+            (self.tr("Glagolitic"), "Glagolitic"),
+            (self.tr("Gothic"), "Gothic"),
+            (self.tr("Greek"), "Greek"),
+            (self.tr("Gujarati"), "Gujarati"),
+            (self.tr("Gurmukhi"), "Gurmukhi"),
+            (self.tr("Han"), "Han"),
+            (self.tr("Hangul"), "Hangul"),
+            (self.tr("Hanunoo"), "Hanunoo"),
+            (self.tr("Hebrew"), "Hebrew"),
+            (self.tr("Hiragana"), "Hiragana"),
+            (self.tr("Imperial Aramaic"), "Imperial_Aramaic"),
+            (self.tr("Inherited"), "Inherited"),
+            (self.tr("Inscriptional Pahlavi"), "Inscriptional_Pahlavi"),
+            (self.tr("Inscriptional Parthian"), "Inscriptional_Parthian"),
+            (self.tr("Javanese"), "Javanese"),
+            (self.tr("Kaithi"), "Kaithi"),
+            (self.tr("Kannada"), "Kannada"),
+            (self.tr("Katakana"), "Katakana"),
+            (self.tr("Kayah Li"), "Kayah_Li"),
+            (self.tr("Kharoshthi"), "Kharoshthi"),
+            (self.tr("Khmer"), "Khmer"),
+            (self.tr("Lao"), "Lao"),
+            (self.tr("Latin"), "Latin"),
+            (self.tr("Lepcha"), "Lepcha"),
+            (self.tr("Limbu"), "Limbu"),
+            (self.tr("Linear B"), "Linear_B"),
+            (self.tr("Lisu"), "Lisu"),
+            (self.tr("Lycian"), "Lycian"),
+            (self.tr("Lydian"), "Lydian"),
+            (self.tr("Malayalam"), "Malayalam"),
+            (self.tr("Mandaic"), "Mandaic"),
+            (self.tr("Meetei Mayek"), "Meetei_Mayek"),
+            (self.tr("Meroitic Cursive"), "Meroitic_Cursive"),
+            (self.tr("Meroitic Hieroglyphs"), "Meroitic_Hieroglyphs"),
+            (self.tr("Miao"), "Miao"),
+            (self.tr("Mongolian"), "Mongolian"),
+            (self.tr("Myanmar"), "Myanmar"),
+            (self.tr("New Tai Lue"), "New_Tai_Lue"),
+            (self.tr("N'Ko"), "Nko"),
+            (self.tr("Ogham"), "Ogham"),
+            (self.tr("Old Italic"), "Old_Italic"),
+            (self.tr("Old Persian"), "Old_Persian"),
+            (self.tr("Old South Arabian"), "Old_South_Arabian"),
+            (self.tr("Old Turkic"), "Old_Turkic,"),
+            (self.tr("Ol Chiki"), "Ol_Chiki"),
+            (self.tr("Oriya"), "Oriya"),
+            (self.tr("Osmanya"), "Osmanya"),
+            (self.tr("Phags-pa"), "Phags_Pa"),
+            (self.tr("Phoenician"), "Phoenician"),
+            (self.tr("Rejang"), "Rejang"),
+            (self.tr("Runic"), "Runic"),
+            (self.tr("Samaritan"), "Samaritan"),
+            (self.tr("Saurashtra"), "Saurashtra"),
+            (self.tr("Sharada"), "Sharada"),
+            (self.tr("Shavian"), "Shavian"),
+            (self.tr("Sinhala"), "Sinhala"),
+            (self.tr("Sora Sompeng"), "Sora_Sompeng"),
+            (self.tr("Sundanese"), "Sundanese"),
+            (self.tr("Syloti Nagri"), "Syloti_Nagri"),
+            (self.tr("Syriac"), "Syriac"),
+            (self.tr("Tagalog"), "Tagalog"),
+            (self.tr("Tagbanwa"), "Tagbanwa"),
+            (self.tr("Tai Le"), "Tai_Le"),
+            (self.tr("Tai Tham"), "Tai_Tham"),
+            (self.tr("Tai Viet"), "Tai_Viet"),
+            (self.tr("Takri"), "Takri"),
+            (self.tr("Tamil"), "Tamil"),
+            (self.tr("Telugu"), "Telugu"),
+            (self.tr("Thaana"), "Thaana"),
+            (self.tr("Thai"), "Thai"),
+            (self.tr("Tibetan"), "Tibetan"),
+            (self.tr("Tifinagh"), "Tifinagh"),
+            (self.tr("Ugaritic"), "Ugaritic"),
+            (self.tr("Vai"), "Vai"),
+            (self.tr("Yi"), "Yi"),
         )
         
         self.__posixNamedSets = (
             # display name                                  code
-            (self.trUtf8("Alphanumeric"),                   "alnum"),
-            (self.trUtf8("Alphabetic"),                     "alpha"),
-            (self.trUtf8("ASCII"),                          "ascii"),
-            (self.trUtf8("Word Letter"),                    "word"),
-            (self.trUtf8("Lower Case Letter"),              "lower"),
-            (self.trUtf8("Upper Case Letter"),              "upper"),
-            (self.trUtf8("Decimal Digit"),                  "digit"),
-            (self.trUtf8("Hexadecimal Digit"),              "xdigit"),
-            (self.trUtf8("Space or Tab"),                   "blank"),
-            (self.trUtf8("White Space"),                    "space"),
-            (self.trUtf8("Printing (excl. space)"),         "graph"),
-            (self.trUtf8("Printing (incl. space)"),         "print"),
-            (self.trUtf8("Printing (excl. alphanumeric)"),  "punct"),
-            (self.trUtf8("Control Character"),              "cntrl"),
+            (self.tr("Alphanumeric"), "alnum"),
+            (self.tr("Alphabetic"), "alpha"),
+            (self.tr("ASCII"), "ascii"),
+            (self.tr("Word Letter"), "word"),
+            (self.tr("Lower Case Letter"), "lower"),
+            (self.tr("Upper Case Letter"), "upper"),
+            (self.tr("Decimal Digit"), "digit"),
+            (self.tr("Hexadecimal Digit"), "xdigit"),
+            (self.tr("Space or Tab"), "blank"),
+            (self.tr("White Space"), "space"),
+            (self.tr("Printing (excl. space)"), "graph"),
+            (self.tr("Printing (incl. space)"), "print"),
+            (self.tr("Printing (excl. alphanumeric)"), "punct"),
+            (self.tr("Control Character"), "cntrl"),
         )
     
     def __populateCharTypeCombo(self, combo, isSingle):
@@ -381,12 +384,12 @@ class QRegularExpressionWizardCharactersDialog(
         cb1.setEditable(False)
         self.__populateCharTypeCombo(cb1, False)
         hboxLayout.addWidget(cb1)
-        l1 = QLabel(self.trUtf8("Between:"), hbox)
+        l1 = QLabel(self.tr("Between:"), hbox)
         hboxLayout.addWidget(l1)
         le1 = QLineEdit(hbox)
         le1.setValidator(self.charValidator)
         hboxLayout.addWidget(le1)
-        l2 = QLabel(self.trUtf8("And:"), hbox)
+        l2 = QLabel(self.tr("And:"), hbox)
         hboxLayout.addWidget(l2)
         le2 = QLineEdit(hbox)
         le2.setValidator(self.charValidator)
