@@ -1,20 +1,23 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2013 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2013 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the QRegularExpression wizard dialog.
 """
 
+from __future__ import unicode_literals
+
 import os
 import re
 import sys
 import json
 
-from PyQt4.QtCore import QFileInfo, pyqtSlot, QProcess, QByteArray
-from PyQt4.QtGui import QWidget, QDialog, QInputDialog, QApplication, \
-    QClipboard, QTextCursor, QDialogButtonBox, QVBoxLayout, QTableWidgetItem
+from PyQt5.QtCore import QFileInfo, pyqtSlot, QProcess, QByteArray
+from PyQt5.QtGui import QClipboard, QTextCursor
+from PyQt5.QtWidgets import QWidget, QDialog, QInputDialog, QApplication, \
+    QDialogButtonBox, QVBoxLayout, QTableWidgetItem
 
 from E5Gui import E5MessageBox, E5FileDialog
 from E5Gui.E5MainWindow import E5MainWindow
@@ -38,9 +41,9 @@ class QRegularExpressionWizardWidget(QWidget,
         Constructor
         
         @param parent parent widget (QWidget)
-        @param fromEric flag indicating a call from within eric5
+        @param fromEric flag indicating a call from within eric6
         """
-        super().__init__(parent)
+        super(QRegularExpressionWizardWidget, self).__init__(parent)
         self.setupUi(self)
         
         # initialize icons of the tool buttons
@@ -90,26 +93,26 @@ class QRegularExpressionWizardWidget(QWidget,
                     self.__pyqt5Available = True
         
         self.saveButton = self.buttonBox.addButton(
-            self.trUtf8("Save"), QDialogButtonBox.ActionRole)
+            self.tr("Save"), QDialogButtonBox.ActionRole)
         self.saveButton.setToolTip(
-            self.trUtf8("Save the regular expression to a file"))
+            self.tr("Save the regular expression to a file"))
         self.loadButton = self.buttonBox.addButton(
-            self.trUtf8("Load"), QDialogButtonBox.ActionRole)
+            self.tr("Load"), QDialogButtonBox.ActionRole)
         self.loadButton.setToolTip(
-            self.trUtf8("Load a regular expression from a file"))
+            self.tr("Load a regular expression from a file"))
         if self.__pyqt5Available:
             self.validateButton = self.buttonBox.addButton(
-                self.trUtf8("Validate"), QDialogButtonBox.ActionRole)
+                self.tr("Validate"), QDialogButtonBox.ActionRole)
             self.validateButton.setToolTip(
-                self.trUtf8("Validate the regular expression"))
+                self.tr("Validate the regular expression"))
             self.executeButton = self.buttonBox.addButton(
-                self.trUtf8("Execute"), QDialogButtonBox.ActionRole)
+                self.tr("Execute"), QDialogButtonBox.ActionRole)
             self.executeButton.setToolTip(
-                self.trUtf8("Execute the regular expression"))
+                self.tr("Execute the regular expression"))
             self.nextButton = self.buttonBox.addButton(
-                self.trUtf8("Next match"), QDialogButtonBox.ActionRole)
+                self.tr("Next match"), QDialogButtonBox.ActionRole)
             self.nextButton.setToolTip(
-                self.trUtf8("Show the next match of the regular expression"))
+                self.tr("Show the next match of the regular expression"))
             self.nextButton.setEnabled(False)
         else:
             self.validateButton = None
@@ -122,9 +125,9 @@ class QRegularExpressionWizardWidget(QWidget,
             self.copyButton = None
         else:
             self.copyButton = self.buttonBox.addButton(
-                self.trUtf8("Copy"), QDialogButtonBox.ActionRole)
+                self.tr("Copy"), QDialogButtonBox.ActionRole)
             self.copyButton.setToolTip(
-                self.trUtf8("Copy the regular expression to the clipboard"))
+                self.tr("Copy the regular expression to the clipboard"))
             self.buttonBox.setStandardButtons(QDialogButtonBox.Close)
             self.variableLabel.hide()
             self.variableLineEdit.hide()
@@ -164,9 +167,9 @@ class QRegularExpressionWizardWidget(QWidget,
             if responseDict["error"]:
                 E5MessageBox.critical(
                     self,
-                    self.trUtf8("Communication Error"),
-                    self.trUtf8("""<p>The PyQt5 backend reported"""
-                                """ an error.</p><p>{0}</p>""")
+                    self.tr("Communication Error"),
+                    self.tr("""<p>The PyQt5 backend reported"""
+                            """ an error.</p><p>{0}</p>""")
                     .format(responseDict["error"]))
                 responseDict = {}
         
@@ -279,14 +282,14 @@ class QRegularExpressionWizardWidget(QWidget,
         if not names:
             E5MessageBox.information(
                 self,
-                self.trUtf8("Named reference"),
-                self.trUtf8("""No named groups have been defined yet."""))
+                self.tr("Named reference"),
+                self.tr("""No named groups have been defined yet."""))
             return
         
         groupName, ok = QInputDialog.getItem(
             self,
-            self.trUtf8("Named reference"),
-            self.trUtf8("Select group name:"),
+            self.tr("Named reference"),
+            self.tr("Select group name:"),
             names,
             0, True)
         if ok and groupName:
@@ -395,9 +398,9 @@ class QRegularExpressionWizardWidget(QWidget,
         """
         fname, selectedFilter = E5FileDialog.getSaveFileNameAndFilter(
             self,
-            self.trUtf8("Save regular expression"),
+            self.tr("Save regular expression"),
             "",
-            self.trUtf8("RegExp Files (*.rx);;All Files (*)"),
+            self.tr("RegExp Files (*.rx);;All Files (*)"),
             None,
             E5FileDialog.Options(E5FileDialog.DontConfirmOverwrite))
         if fname:
@@ -409,9 +412,9 @@ class QRegularExpressionWizardWidget(QWidget,
             if QFileInfo(fname).exists():
                 res = E5MessageBox.yesNo(
                     self,
-                    self.trUtf8("Save regular expression"),
-                    self.trUtf8("<p>The file <b>{0}</b> already exists."
-                                " Overwrite it?</p>").format(fname),
+                    self.tr("Save regular expression"),
+                    self.tr("<p>The file <b>{0}</b> already exists."
+                            " Overwrite it?</p>").format(fname),
                     icon=E5MessageBox.Warning)
                 if not res:
                     return
@@ -424,9 +427,9 @@ class QRegularExpressionWizardWidget(QWidget,
             except IOError as err:
                 E5MessageBox.information(
                     self,
-                    self.trUtf8("Save regular expression"),
-                    self.trUtf8("""<p>The regular expression could not"""
-                                """ be saved.</p><p>Reason: {0}</p>""")
+                    self.tr("Save regular expression"),
+                    self.tr("""<p>The regular expression could not"""
+                            """ be saved.</p><p>Reason: {0}</p>""")
                     .format(str(err)))
     
     @pyqtSlot()
@@ -436,9 +439,9 @@ class QRegularExpressionWizardWidget(QWidget,
         """
         fname = E5FileDialog.getOpenFileName(
             self,
-            self.trUtf8("Load regular expression"),
+            self.tr("Load regular expression"),
             "",
-            self.trUtf8("RegExp Files (*.rx);;All Files (*)"))
+            self.tr("RegExp Files (*.rx);;All Files (*)"))
         if fname:
             try:
                 f = open(
@@ -449,9 +452,9 @@ class QRegularExpressionWizardWidget(QWidget,
             except IOError as err:
                 E5MessageBox.information(
                     self,
-                    self.trUtf8("Save regular expression"),
-                    self.trUtf8("""<p>The regular expression could not"""
-                                """ be saved.</p><p>Reason: {0}</p>""")
+                    self.tr("Save regular expression"),
+                    self.tr("""<p>The regular expression could not"""
+                            """ be saved.</p><p>Reason: {0}</p>""")
                     .format(str(err)))
 
     @pyqtSlot()
@@ -459,7 +462,7 @@ class QRegularExpressionWizardWidget(QWidget,
         """
         Private slot to copy the QRegularExpression string into the clipboard.
         
-        This slot is only available, if not called from within eric5.
+        This slot is only available, if not called from within eric6.
         """
         escaped = self.regexpTextEdit.toPlainText()
         if escaped:
@@ -502,14 +505,14 @@ class QRegularExpressionWizardWidget(QWidget,
                     if response["valid"]:
                         E5MessageBox.information(
                             self,
-                            self.trUtf8("Validation"),
-                            self.trUtf8(
+                            self.tr("Validation"),
+                            self.tr(
                                 """The regular expression is valid."""))
                     else:
                         E5MessageBox.critical(
                             self,
-                            self.trUtf8("Error"),
-                            self.trUtf8("""Invalid regular expression: {0}""")
+                            self.tr("Error"),
+                            self.tr("""Invalid regular expression: {0}""")
                             .format(response["errorMessage"]))
                         # move cursor to error offset
                         offset = response["errorOffset"]
@@ -521,20 +524,20 @@ class QRegularExpressionWizardWidget(QWidget,
                 else:
                     E5MessageBox.critical(
                         self,
-                        self.trUtf8("Communication Error"),
-                        self.trUtf8("""Invalid response received from"""
-                                    """ PyQt5 backend."""))
+                        self.tr("Communication Error"),
+                        self.tr("""Invalid response received from"""
+                                """ PyQt5 backend."""))
             else:
                 E5MessageBox.critical(
                     self,
-                    self.trUtf8("Communication Error"),
-                    self.trUtf8("""Communication with PyQt5 backend"""
-                                """ failed."""))
+                    self.tr("Communication Error"),
+                    self.tr("""Communication with PyQt5 backend"""
+                            """ failed."""))
         else:
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Error"),
-                self.trUtf8("""A regular expression must be given."""))
+                self.tr("Error"),
+                self.tr("""A regular expression must be given."""))
 
     @pyqtSlot()
     def on_executeButton_clicked(self, startpos=0):
@@ -577,8 +580,8 @@ class QRegularExpressionWizardWidget(QWidget,
                     if "valid" in response:
                         E5MessageBox.critical(
                             self,
-                            self.trUtf8("Error"),
-                            self.trUtf8("""Invalid regular expression: {0}""")
+                            self.tr("Error"),
+                            self.tr("""Invalid regular expression: {0}""")
                             .format(response["errorMessage"]))
                         # move cursor to error offset
                         offset = response["errorOffset"]
@@ -596,7 +599,7 @@ class QRegularExpressionWizardWidget(QWidget,
                         self.resultTable.setRowCount(0)
                         self.resultTable.setRowCount(OFFSET)
                         self.resultTable.setItem(
-                            row, 0, QTableWidgetItem(self.trUtf8("Regexp")))
+                            row, 0, QTableWidgetItem(self.tr("Regexp")))
                         self.resultTable.setItem(
                             row, 1, QTableWidgetItem(regexp))
                         if response["matched"]:
@@ -608,7 +611,7 @@ class QRegularExpressionWizardWidget(QWidget,
                             row += 1
                             self.resultTable.setItem(
                                 row, 0,
-                                QTableWidgetItem(self.trUtf8("Offset")))
+                                QTableWidgetItem(self.tr("Offset")))
                             self.resultTable.setItem(
                                 row, 1,
                                 QTableWidgetItem("{0:d}".format(offset)))
@@ -616,7 +619,7 @@ class QRegularExpressionWizardWidget(QWidget,
                             row += 1
                             self.resultTable.setItem(
                                 row, 0,
-                                QTableWidgetItem(self.trUtf8("Captures")))
+                                QTableWidgetItem(self.tr("Captures")))
                             self.resultTable.setItem(
                                 row, 1,
                                 QTableWidgetItem(
@@ -624,15 +627,15 @@ class QRegularExpressionWizardWidget(QWidget,
                             row += 1
                             self.resultTable.setItem(
                                 row, 1,
-                                QTableWidgetItem(self.trUtf8("Text")))
+                                QTableWidgetItem(self.tr("Text")))
                             self.resultTable.setItem(
                                 row, 2,
-                                QTableWidgetItem(self.trUtf8("Characters")))
+                                QTableWidgetItem(self.tr("Characters")))
                             
                             row += 1
                             self.resultTable.setItem(
                                 row, 0,
-                                QTableWidgetItem(self.trUtf8("Match")))
+                                QTableWidgetItem(self.tr("Match")))
                             self.resultTable.setItem(
                                 row, 1,
                                 QTableWidgetItem(captures[0][0]))
@@ -648,7 +651,7 @@ class QRegularExpressionWizardWidget(QWidget,
                                     self.resultTable.setItem(
                                         row, 0,
                                         QTableWidgetItem(
-                                            self.trUtf8("Capture #{0}")
+                                            self.tr("Capture #{0}")
                                             .format(i)))
                                     self.resultTable.setItem(
                                         row, 1,
@@ -672,12 +675,12 @@ class QRegularExpressionWizardWidget(QWidget,
                                 self.resultTable.setItem(
                                     row, 0,
                                     QTableWidgetItem(
-                                        self.trUtf8("No more matches")))
+                                        self.tr("No more matches")))
                             else:
                                 self.resultTable.setItem(
                                     row, 0,
                                     QTableWidgetItem(
-                                        self.trUtf8("No matches")))
+                                        self.tr("No matches")))
                             
                             # remove the highlight
                             tc = self.textTextEdit.textCursor()
@@ -691,21 +694,21 @@ class QRegularExpressionWizardWidget(QWidget,
                 else:
                     E5MessageBox.critical(
                         self,
-                        self.trUtf8("Communication Error"),
-                        self.trUtf8("""Invalid response received from"""
-                                    """ PyQt5 backend."""))
+                        self.tr("Communication Error"),
+                        self.tr("""Invalid response received from"""
+                                """ PyQt5 backend."""))
             else:
                 E5MessageBox.critical(
                     self,
-                    self.trUtf8("Communication Error"),
-                    self.trUtf8("""Communication with PyQt5"""
-                                """ backend failed."""))
+                    self.tr("Communication Error"),
+                    self.tr("""Communication with PyQt5"""
+                            """ backend failed."""))
         else:
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Error"),
-                self.trUtf8("""A regular expression and a text must"""
-                            """ be given."""))
+                self.tr("Error"),
+                self.tr("""A regular expression and a text must"""
+                        """ be given."""))
     
     @pyqtSlot()
     def on_nextButton_clicked(self):
@@ -778,9 +781,9 @@ class QRegularExpressionWizardDialog(QDialog):
         Constructor
         
         @param parent parent widget (QWidget)
-        @param fromEric flag indicating a call from within eric5
+        @param fromEric flag indicating a call from within eric6
         """
-        super().__init__(parent)
+        super(QRegularExpressionWizardDialog, self).__init__(parent)
         self.setModal(fromEric)
         self.setSizeGripEnabled(True)
         
@@ -794,8 +797,8 @@ class QRegularExpressionWizardDialog(QDialog):
         self.resize(size)
         self.setWindowTitle(self.cw.windowTitle())
         
-        self.cw.buttonBox.accepted[()].connect(self.accept)
-        self.cw.buttonBox.rejected[()].connect(self.reject)
+        self.cw.buttonBox.accepted.connect(self.accept)
+        self.cw.buttonBox.rejected.connect(self.reject)
     
     def getCode(self, indLevel, indString):
         """
@@ -812,14 +815,14 @@ class QRegularExpressionWizardDialog(QDialog):
         Public slot to hide the dialog and set the result code to Accepted.
         """
         self.cw.shutdown()
-        super().accept()
+        super(QRegularExpressionWizardDialog, self).accept()
     
     def reject(self):
         """
         Public slot to hide the dialog and set the result code to Rejected.
         """
         self.cw.shutdown()
-        super().reject()
+        super(QRegularExpressionWizardDialog, self).reject()
 
 
 class QRegularExpressionWizardWindow(E5MainWindow):
@@ -832,7 +835,7 @@ class QRegularExpressionWizardWindow(E5MainWindow):
         
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(QRegularExpressionWizardWindow, self).__init__(parent)
         self.cw = QRegularExpressionWizardWidget(self, fromEric=False)
         size = self.cw.size()
         self.setCentralWidget(self.cw)
@@ -842,8 +845,8 @@ class QRegularExpressionWizardWindow(E5MainWindow):
         self.setStyle(
             Preferences.getUI("Style"), Preferences.getUI("StyleSheet"))
         
-        self.cw.buttonBox.accepted[()].connect(self.close)
-        self.cw.buttonBox.rejected[()].connect(self.close)
+        self.cw.buttonBox.accepted.connect(self.close)
+        self.cw.buttonBox.rejected.connect(self.close)
     
     def closeEvent(self, evt):
         """
@@ -852,4 +855,4 @@ class QRegularExpressionWizardWindow(E5MainWindow):
         @param evt close event (QCloseEvent)
         """
         self.cw.shutdown()
-        super().closeEvent(evt)
+        super(QRegularExpressionWizardWindow, self).closeEvent(evt)
