@@ -1,20 +1,22 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
-Module implementing a dialog for the configuration of eric5.
+Module implementing a dialog for the configuration of eric6.
 """
 
+from __future__ import unicode_literals
+
 import os
 import types
 
-from PyQt4.QtCore import QMetaObject, pyqtSignal, Qt, QRect, pyqtSlot
-from PyQt4.QtGui import QSizePolicy, QSpacerItem, QWidget, QPixmap, \
-    QTreeWidget, QStackedWidget, QDialog, QSplitter, QScrollArea, \
-    QApplication, QDialogButtonBox, QFrame, QVBoxLayout, QTreeWidgetItem, \
-    QLabel
+from PyQt5.QtCore import QMetaObject, pyqtSignal, Qt, QRect, pyqtSlot
+from PyQt5.QtGui import QPixmap
+from PyQt5.QtWidgets import QSizePolicy, QSpacerItem, QWidget, QTreeWidget, \
+    QStackedWidget, QDialog, QSplitter, QScrollArea, QApplication, \
+    QDialogButtonBox, QFrame, QVBoxLayout, QTreeWidgetItem, QLabel
 
 from E5Gui.E5Application import e5App
 from E5Gui.E5LineEdit import E5ClearableLineEdit
@@ -27,7 +29,7 @@ import Preferences
 
 import UI.PixmapCache
 
-from eric5config import getConfig
+from eric6config import getConfig
 
 
 class ConfigurationPageItem(QTreeWidgetItem):
@@ -44,7 +46,7 @@ class ConfigurationPageItem(QTreeWidgetItem):
         @param pageName name of the configuration page (string)
         @param iconFile file name of the icon to be shown (string)
         """
-        super().__init__(parent, [text])
+        super(ConfigurationPageItem, self).__init__(parent, [text])
         self.setIcon(0, UI.PixmapCache.getIcon(iconFile))
         
         self.__pageName = pageName
@@ -60,7 +62,7 @@ class ConfigurationPageItem(QTreeWidgetItem):
 
 class ConfigurationWidget(QWidget):
     """
-    Class implementing a dialog for the configuration of eric5.
+    Class implementing a dialog for the configuration of eric6.
     
     @signal preferencesChanged() emitted after settings have been changed
     @signal masterPasswordChanged(str, str) emitted after the master
@@ -83,7 +85,7 @@ class ConfigurationWidget(QWidget):
         
         @param parent The parent widget of this dialog. (QWidget)
         @keyparam fromEric flag indicating a dialog generation from within the
-            eric5 ide (boolean)
+            eric6 ide (boolean)
         @keyparam displayMode mode of the configuration dialog
             (DefaultMode, HelpBrowserMode, TrayStarterMode)
         @exception RuntimeError raised to indicate an invalid dialog mode
@@ -94,7 +96,7 @@ class ConfigurationWidget(QWidget):
             ConfigurationWidget.TrayStarterMode
         )
         
-        super().__init__(parent)
+        super(ConfigurationWidget, self).__init__(parent)
         self.fromEric = fromEric
         self.displayMode = displayMode
         
@@ -119,191 +121,191 @@ class ConfigurationWidget(QWidget):
                 # create the configuration page. This must have the method
                 # save to save the settings.
                 "applicationPage":
-                [self.trUtf8("Application"), "preferences-application.png",
+                [self.tr("Application"), "preferences-application.png",
                  "ApplicationPage", None, None],
                 "cooperationPage":
-                [self.trUtf8("Cooperation"), "preferences-cooperation.png",
+                [self.tr("Cooperation"), "preferences-cooperation.png",
                  "CooperationPage", None, None],
                 "corbaPage":
-                [self.trUtf8("CORBA"), "preferences-orbit.png",
+                [self.tr("CORBA"), "preferences-orbit.png",
                  "CorbaPage", None, None],
                 "emailPage":
-                [self.trUtf8("Email"), "preferences-mail_generic.png",
+                [self.tr("Email"), "preferences-mail_generic.png",
                  "EmailPage", None, None],
                 "graphicsPage":
-                [self.trUtf8("Graphics"), "preferences-graphics.png",
+                [self.tr("Graphics"), "preferences-graphics.png",
                  "GraphicsPage", None, None],
                 "iconsPage":
-                [self.trUtf8("Icons"), "preferences-icons.png",
+                [self.tr("Icons"), "preferences-icons.png",
                  "IconsPage", None, None],
                 "ircPage":
-                [self.trUtf8("IRC"), "irc.png",
+                [self.tr("IRC"), "irc.png",
                  "IrcPage", None, None],
                 "networkPage":
-                [self.trUtf8("Network"), "preferences-network.png",
+                [self.tr("Network"), "preferences-network.png",
                  "NetworkPage", None, None],
                 "notificationsPage":
-                [self.trUtf8("Notifications"),
+                [self.tr("Notifications"),
                  "preferences-notifications.png",
                  "NotificationsPage", None, None],
                 "pluginManagerPage":
-                [self.trUtf8("Plugin Manager"),
+                [self.tr("Plugin Manager"),
                  "preferences-pluginmanager.png",
                  "PluginManagerPage", None, None],
                 "printerPage":
-                [self.trUtf8("Printer"), "preferences-printer.png",
+                [self.tr("Printer"), "preferences-printer.png",
                  "PrinterPage", None, None],
                 "pythonPage":
-                [self.trUtf8("Python"), "preferences-python.png",
+                [self.tr("Python"), "preferences-python.png",
                  "PythonPage", None, None],
                 "qtPage":
-                [self.trUtf8("Qt"), "preferences-qtlogo.png",
+                [self.tr("Qt"), "preferences-qtlogo.png",
                  "QtPage", None, None],
                 "securityPage":
-                [self.trUtf8("Security"), "preferences-security.png",
+                [self.tr("Security"), "preferences-security.png",
                  "SecurityPage", None, None],
                 "shellPage":
-                [self.trUtf8("Shell"), "preferences-shell.png",
+                [self.tr("Shell"), "preferences-shell.png",
                  "ShellPage", None, None],
                 "tasksPage":
-                [self.trUtf8("Tasks"), "task.png",
+                [self.tr("Tasks"), "task.png",
                  "TasksPage", None, None],
                 "templatesPage":
-                [self.trUtf8("Templates"), "preferences-template.png",
+                [self.tr("Templates"), "preferences-template.png",
                  "TemplatesPage", None, None],
                 "trayStarterPage":
-                [self.trUtf8("Tray Starter"), "erict.png",
+                [self.tr("Tray Starter"), "erict.png",
                  "TrayStarterPage", None, None],
                 "vcsPage":
-                [self.trUtf8("Version Control Systems"),
+                [self.tr("Version Control Systems"),
                  "preferences-vcs.png",
                  "VcsPage", None, None],
                 
                 "0debuggerPage":
-                [self.trUtf8("Debugger"), "preferences-debugger.png",
+                [self.tr("Debugger"), "preferences-debugger.png",
                  None, None, None],
                 "debuggerGeneralPage":
-                [self.trUtf8("General"), "preferences-debugger.png",
+                [self.tr("General"), "preferences-debugger.png",
                  "DebuggerGeneralPage", "0debuggerPage", None],
                 "debuggerPythonPage":
-                [self.trUtf8("Python"), "preferences-pyDebugger.png",
+                [self.tr("Python"), "preferences-pyDebugger.png",
                  "DebuggerPythonPage", "0debuggerPage", None],
                 "debuggerPython3Page":
-                [self.trUtf8("Python3"), "preferences-pyDebugger.png",
+                [self.tr("Python3"), "preferences-pyDebugger.png",
                  "DebuggerPython3Page", "0debuggerPage", None],
                 "debuggerRubyPage":
-                [self.trUtf8("Ruby"), "preferences-rbDebugger.png",
+                [self.tr("Ruby"), "preferences-rbDebugger.png",
                  "DebuggerRubyPage", "0debuggerPage", None],
                 
                 "0editorPage":
-                [self.trUtf8("Editor"), "preferences-editor.png",
+                [self.tr("Editor"), "preferences-editor.png",
                  None, None, None],
                 "editorAPIsPage":
-                [self.trUtf8("APIs"), "preferences-api.png",
+                [self.tr("APIs"), "preferences-api.png",
                  "EditorAPIsPage", "0editorPage", None],
                 "editorAutocompletionPage":
-                [self.trUtf8("Autocompletion"),
+                [self.tr("Autocompletion"),
                  "preferences-autocompletion.png",
                  "EditorAutocompletionPage", "0editorPage", None],
                 "editorAutocompletionQScintillaPage":
-                [self.trUtf8("QScintilla"), "qscintilla.png",
+                [self.tr("QScintilla"), "qscintilla.png",
                  "EditorAutocompletionQScintillaPage",
                  "editorAutocompletionPage", None],
                 "editorCalltipsPage":
-                [self.trUtf8("Calltips"), "preferences-calltips.png",
+                [self.tr("Calltips"), "preferences-calltips.png",
                  "EditorCalltipsPage", "0editorPage", None],
                 "editorCalltipsQScintillaPage":
-                [self.trUtf8("QScintilla"), "qscintilla.png",
+                [self.tr("QScintilla"), "qscintilla.png",
                  "EditorCalltipsQScintillaPage", "editorCalltipsPage", None],
                 "editorGeneralPage":
-                [self.trUtf8("General"), "preferences-general.png",
+                [self.tr("General"), "preferences-general.png",
                  "EditorGeneralPage", "0editorPage", None],
                 "editorFilePage":
-                [self.trUtf8("Filehandling"),
+                [self.tr("Filehandling"),
                  "preferences-filehandling.png",
                  "EditorFilePage", "0editorPage", None],
                 "editorSearchPage":
-                [self.trUtf8("Searching"), "preferences-search.png",
+                [self.tr("Searching"), "preferences-search.png",
                  "EditorSearchPage", "0editorPage", None],
                 "editorSpellCheckingPage":
-                [self.trUtf8("Spell checking"),
+                [self.tr("Spell checking"),
                  "preferences-spellchecking.png",
                  "EditorSpellCheckingPage", "0editorPage", None],
                 "editorStylesPage":
-                [self.trUtf8("Style"), "preferences-styles.png",
+                [self.tr("Style"), "preferences-styles.png",
                  "EditorStylesPage", "0editorPage", None],
                 "editorSyntaxPage":
-                [self.trUtf8("Code Checkers"), "preferences-debugger.png",
+                [self.tr("Code Checkers"), "preferences-debugger.png",
                  "EditorSyntaxPage", "0editorPage", None],
                 "editorTypingPage":
-                [self.trUtf8("Typing"), "preferences-typing.png",
+                [self.tr("Typing"), "preferences-typing.png",
                  "EditorTypingPage", "0editorPage", None],
                 "editorExportersPage":
-                [self.trUtf8("Exporters"), "preferences-exporters.png",
+                [self.tr("Exporters"), "preferences-exporters.png",
                  "EditorExportersPage", "0editorPage", None],
                 
                 "1editorLexerPage":
-                [self.trUtf8("Highlighters"),
+                [self.tr("Highlighters"),
                  "preferences-highlighting-styles.png",
                  None, "0editorPage", None],
                 "editorHighlightersPage":
-                [self.trUtf8("Filetype Associations"),
+                [self.tr("Filetype Associations"),
                  "preferences-highlighter-association.png",
                  "EditorHighlightersPage", "1editorLexerPage", None],
                 "editorHighlightingStylesPage":
-                [self.trUtf8("Styles"),
+                [self.tr("Styles"),
                  "preferences-highlighting-styles.png",
                  "EditorHighlightingStylesPage", "1editorLexerPage", None],
                 "editorKeywordsPage":
-                [self.trUtf8("Keywords"), "preferences-keywords.png",
+                [self.tr("Keywords"), "preferences-keywords.png",
                  "EditorKeywordsPage", "1editorLexerPage", None],
                 "editorPropertiesPage":
-                [self.trUtf8("Properties"), "preferences-properties.png",
+                [self.tr("Properties"), "preferences-properties.png",
                  "EditorPropertiesPage", "1editorLexerPage", None],
                 
                 "0helpPage":
-                [self.trUtf8("Help"), "preferences-help.png",
+                [self.tr("Help"), "preferences-help.png",
                  None, None, None],
                 "helpAppearancePage":
-                [self.trUtf8("Appearance"), "preferences-styles.png",
+                [self.tr("Appearance"), "preferences-styles.png",
                  "HelpAppearancePage", "0helpPage", None],
                 "helpDocumentationPage":
-                [self.trUtf8("Help Documentation"),
+                [self.tr("Help Documentation"),
                  "preferences-helpdocumentation.png",
                  "HelpDocumentationPage", "0helpPage", None],
                 "helpViewersPage":
-                [self.trUtf8("Help Viewers"),
+                [self.tr("Help Viewers"),
                  "preferences-helpviewers.png",
                  "HelpViewersPage", "0helpPage", None],
-                "helpVirusTotalPage":
-                [self.trUtf8("VirusTotal Interface"), "virustotal.png",
-                 "HelpVirusTotalPage", "0helpPage", None],
+##                "helpVirusTotalPage":
+##                [self.tr("VirusTotal Interface"), "virustotal.png",
+##                 "HelpVirusTotalPage", "0helpPage", None],
                 "helpWebBrowserPage":
-                [self.trUtf8("eric5 Web Browser"), "ericWeb.png",
+                [self.tr("eric6 Web Browser"), "ericWeb.png",
                  "HelpWebBrowserPage", "0helpPage", None],
                 
                 "0projectPage":
-                [self.trUtf8("Project"), "preferences-project.png",
+                [self.tr("Project"), "preferences-project.png",
                  None, None, None],
                 "projectBrowserPage":
-                [self.trUtf8("Project Viewer"), "preferences-project.png",
+                [self.tr("Project Viewer"), "preferences-project.png",
                  "ProjectBrowserPage", "0projectPage", None],
                 "projectPage":
-                [self.trUtf8("Project"), "preferences-project.png",
+                [self.tr("Project"), "preferences-project.png",
                  "ProjectPage", "0projectPage", None],
                 "multiProjectPage":
-                [self.trUtf8("Multiproject"),
+                [self.tr("Multiproject"),
                  "preferences-multiproject.png",
                  "MultiProjectPage", "0projectPage", None],
                 
                 "0interfacePage":
-                [self.trUtf8("Interface"), "preferences-interface.png",
+                [self.tr("Interface"), "preferences-interface.png",
                  None, None, None],
                 "interfacePage":
-                [self.trUtf8("Interface"), "preferences-interface.png",
+                [self.tr("Interface"), "preferences-interface.png",
                  "InterfacePage", "0interfacePage", None],
                 "viewmanagerPage":
-                [self.trUtf8("Viewmanager"), "preferences-viewmanager.png",
+                [self.tr("Viewmanager"), "preferences-viewmanager.png",
                  "ViewmanagerPage", "0interfacePage", None],
             }
             
@@ -318,33 +320,33 @@ class ConfigurationWidget(QWidget):
                 # create the configuration page. This must have the method
                 # save to save the settings.
                 "interfacePage":
-                [self.trUtf8("Interface"), "preferences-interface.png",
+                [self.tr("Interface"), "preferences-interface.png",
                  "HelpInterfacePage", None, None],
                 "networkPage":
-                [self.trUtf8("Network"), "preferences-network.png",
+                [self.tr("Network"), "preferences-network.png",
                  "NetworkPage", None, None],
                 "printerPage":
-                [self.trUtf8("Printer"), "preferences-printer.png",
+                [self.tr("Printer"), "preferences-printer.png",
                  "PrinterPage", None, None],
                 "securityPage":
-                [self.trUtf8("Security"), "preferences-security.png",
+                [self.tr("Security"), "preferences-security.png",
                  "SecurityPage", None, None],
                 
                 "0helpPage":
-                [self.trUtf8("Help"), "preferences-help.png",
+                [self.tr("Help"), "preferences-help.png",
                  None, None, None],
                 "helpAppearancePage":
-                [self.trUtf8("Appearance"), "preferences-styles.png",
+                [self.tr("Appearance"), "preferences-styles.png",
                  "HelpAppearancePage", "0helpPage", None],
                 "helpDocumentationPage":
-                [self.trUtf8("Help Documentation"),
+                [self.tr("Help Documentation"),
                  "preferences-helpdocumentation.png",
                  "HelpDocumentationPage", "0helpPage", None],
-                "helpVirusTotalPage":
-                [self.trUtf8("VirusTotal Interface"), "virustotal.png",
-                 "HelpVirusTotalPage", "0helpPage", None],
+##                "helpVirusTotalPage":
+##                [self.tr("VirusTotal Interface"), "virustotal.png",
+##                 "HelpVirusTotalPage", "0helpPage", None],
                 "helpWebBrowserPage":
-                [self.trUtf8("eric5 Web Browser"), "ericWeb.png",
+                [self.tr("eric6 Web Browser"), "ericWeb.png",
                  "HelpWebBrowserPage", "0helpPage", None],
             }
         elif displayMode == ConfigurationWidget.TrayStarterMode:
@@ -356,7 +358,7 @@ class ConfigurationWidget(QWidget):
                 # create the configuration page. This must have the method
                 # save to save the settings.
                 "trayStarterPage":
-                [self.trUtf8("Tray Starter"), "erict.png",
+                [self.tr("Tray Starter"), "erict.png",
                  "TrayStarterPage", None, None],
             }
         else:
@@ -371,6 +373,7 @@ class ConfigurationWidget(QWidget):
                 pitm = self.configList
             self.itmDict[key] = ConfigurationPageItem(pitm, pageData[0], key,
                                                       pageData[1])
+            self.itmDict[key].setData(0, Qt.UserRole, key)
             self.itmDict[key].setExpanded(True)
         self.configList.sortByColumn(0, Qt.AscendingOrder)
         
@@ -418,7 +421,7 @@ class ConfigurationWidget(QWidget):
         self.leftVBoxLayout.setSpacing(0)
         self.leftVBoxLayout.setObjectName("leftVBoxLayout")
         self.configListFilter = E5ClearableLineEdit(
-            self, self.trUtf8("Enter filter text..."))
+            self, self.tr("Enter filter text..."))
         self.configListFilter.setObjectName("configListFilter")
         self.leftVBoxLayout.addWidget(self.configListFilter)
         self.configList = QTreeWidget()
@@ -479,14 +482,14 @@ class ConfigurationWidget(QWidget):
         self.buttonBox.button(QDialogButtonBox.Reset).setEnabled(False)
         self.verticalLayout_2.addWidget(self.buttonBox)
 
-        self.setWindowTitle(self.trUtf8("Preferences"))
+        self.setWindowTitle(self.tr("Preferences"))
         
         self.configList.header().hide()
         self.configList.header().setSortIndicator(0, Qt.AscendingOrder)
         self.configList.setSortingEnabled(True)
         self.textLabel1.setText(
-            self.trUtf8("Please select an entry of the list \n"
-                        "to display the configuration page."))
+            self.tr("Please select an entry of the list \n"
+                    "to display the configuration page."))
         
         QMetaObject.connectSlotsByName(self)
         self.setTabOrder(self.configList, self.configStack)
@@ -516,7 +519,8 @@ class ConfigurationWidget(QWidget):
         for index in range(parent.childCount()):
             itm = parent.child(index)
             if itm.childCount() > 0:
-                visible = self.__filterChildItems(itm, filter)
+                visible = self.__filterChildItems(itm, filter) or \
+                    filter == "" or filter in itm.text(0).lower()
             else:
                 visible = filter == "" or filter in itm.text(0).lower()
             if visible:
@@ -558,9 +562,9 @@ class ConfigurationWidget(QWidget):
         except ImportError:
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Configuration Page Error"),
-                self.trUtf8("""<p>The configuration page <b>{0}</b>"""
-                            """ could not be loaded.</p>""").format(name))
+                self.tr("Configuration Page Error"),
+                self.tr("""<p>The configuration page <b>{0}</b>"""
+                        """ could not be loaded.</p>""").format(name))
             return None
         
     def __showConfigurationPage(self, itm, column):
@@ -603,7 +607,7 @@ class ConfigurationWidget(QWidget):
         @param pageName name of the configuration page to show (string)
         @param setCurrent flag indicating to set the current item (boolean)
         """
-        if pageName == "empty":
+        if pageName == "empty" or pageName not in self.configItems:
             page = self.emptyPage
         else:
             pageData = self.configItems[pageName]
@@ -618,8 +622,9 @@ class ConfigurationWidget(QWidget):
                 items = self.configList.findItems(
                     pageData[0],
                     Qt.MatchFixedString | Qt.MatchRecursive)
-                if items:
-                    self.configList.setCurrentItem(items[0])
+                for item in items:
+                    if item.data(0, Qt.UserRole) == pageName:
+                        self.configList.setCurrentItem(item)
         self.configStack.setCurrentWidget(page)
         ssize = self.scrollArea.size()
         if self.scrollArea.horizontalScrollBar():
@@ -762,14 +767,16 @@ class ConfigurationDialog(QDialog):
         @param name The name of this dialog. string
         @param modal Flag indicating a modal dialog. (boolean)
         @keyparam fromEric flag indicating a dialog generation from within the
-            eric5 ide (boolean)
+            eric6 ide (boolean)
         @keyparam displayMode mode of the configuration dialog
             (DefaultMode, HelpBrowserMode, TrayStarterMode)
         """
-        super().__init__(parent)
+        super(ConfigurationDialog, self).__init__(parent)
         if name:
             self.setObjectName(name)
         self.setModal(modal)
+        self.setWindowFlags(Qt.Window)
+        
         self.layout = QVBoxLayout(self)
         self.layout.setContentsMargins(0, 0, 0, 0)
         self.layout.setSpacing(0)
@@ -781,8 +788,8 @@ class ConfigurationDialog(QDialog):
         self.resize(size)
         self.setWindowTitle(self.cw.windowTitle())
         
-        self.cw.accepted[()].connect(self.accept)
-        self.cw.rejected[()].connect(self.reject)
+        self.cw.accepted.connect(self.accept)
+        self.cw.rejected.connect(self.reject)
         self.cw.preferencesChanged.connect(self.__preferencesChanged)
         self.cw.masterPasswordChanged.connect(self.__masterPasswordChanged)
         
@@ -828,7 +835,7 @@ class ConfigurationDialog(QDialog):
         """
         Public method to accept the dialog.
         """
-        super().accept()
+        super(ConfigurationDialog, self).accept()
 
 
 class ConfigurationWindow(E5MainWindow):
@@ -841,7 +848,7 @@ class ConfigurationWindow(E5MainWindow):
         
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(ConfigurationWindow, self).__init__(parent)
         
         self.cw = ConfigurationWidget(self, fromEric=False)
         size = self.cw.size()
@@ -852,8 +859,8 @@ class ConfigurationWindow(E5MainWindow):
         self.setStyle(Preferences.getUI("Style"),
                       Preferences.getUI("StyleSheet"))
         
-        self.cw.accepted[()].connect(self.accept)
-        self.cw.rejected[()].connect(self.close)
+        self.cw.accepted.connect(self.accept)
+        self.cw.rejected.connect(self.close)
         
     def showConfigurationPageByName(self, pageName):
         """
@@ -865,7 +872,7 @@ class ConfigurationWindow(E5MainWindow):
         
     def accept(self):
         """
-        Protected slot called by the Ok button.
+        Public slot called by the Ok button.
         """
         self.cw.setPreferences()
         Preferences.saveResetLayout()
