@@ -1,12 +1,14 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Application configuration page.
 """
 
+from __future__ import unicode_literals
+
 from .ConfigurationPageBase import ConfigurationPageBase
 from .Ui_ApplicationPage import Ui_ApplicationPage
 
@@ -21,7 +23,7 @@ class ApplicationPage(ConfigurationPageBase, Ui_ApplicationPage):
         """
         Constructor
         """
-        super().__init__()
+        super(ApplicationPage, self).__init__()
         self.setupUi(self)
         self.setObjectName("ApplicationPage")
         
