@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Debugger Python3 configuration page.
 """
 
-from PyQt4.QtCore import pyqtSlot
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSlot
 
 from E5Gui.E5Completers import E5FileCompleter
 from E5Gui import E5FileDialog
@@ -17,6 +19,7 @@ from .Ui_DebuggerPython3Page import Ui_DebuggerPython3Page
 
 import Preferences
 import Utilities
+import UI.PixmapCache
 
 
 class DebuggerPython3Page(ConfigurationPageBase, Ui_DebuggerPython3Page):
@@ -27,16 +30,17 @@ class DebuggerPython3Page(ConfigurationPageBase, Ui_DebuggerPython3Page):
         """
         Constructor
         """
-        super().__init__()
+        super(DebuggerPython3Page, self).__init__()
         self.setupUi(self)
         self.setObjectName("DebuggerPython3Page")
         
+        self.interpreterButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        self.debugClientButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        
         self.interpreterCompleter = E5FileCompleter(self.interpreterEdit)
         self.debugClientCompleter = E5FileCompleter(self.debugClientEdit)
         
         # set initial values
-        self.customPyCheckBox.setChecked(
-            Preferences.getDebugger("CustomPython3Interpreter"))
         self.interpreterEdit.setText(
             Preferences.getDebugger("Python3Interpreter"))
         dct = Preferences.getDebugger("DebugClientType3")
@@ -59,9 +63,6 @@ class DebuggerPython3Page(ConfigurationPageBase, Ui_DebuggerPython3Page):
         """
         Public slot to save the Debugger Python configuration.
         """
-        Preferences.setDebugger(
-            "CustomPython3Interpreter",
-            self.customPyCheckBox.isChecked())
         Preferences.setDebugger(
             "Python3Interpreter",
             self.interpreterEdit.text())
@@ -92,7 +93,7 @@ class DebuggerPython3Page(ConfigurationPageBase, Ui_DebuggerPython3Page):
         """
         file = E5FileDialog.getOpenFileName(
             self,
-            self.trUtf8("Select Python interpreter for Debug Client"),
+            self.tr("Select Python interpreter for Debug Client"),
             self.interpreterEdit.text(),
             "")
             
@@ -107,9 +108,9 @@ class DebuggerPython3Page(ConfigurationPageBase, Ui_DebuggerPython3Page):
         """
         file = E5FileDialog.getOpenFileName(
             None,
-            self.trUtf8("Select Debug Client"),
+            self.tr("Select Debug Client"),
             self.debugClientEdit.text(),
-            self.trUtf8("Python Files (*.py *.py3)"))
+            self.tr("Python Files (*.py *.py3)"))
             
         if file:
             self.debugClientEdit.setText(
