@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Debugger Python configuration page.
 """
 
-from PyQt4.QtCore import pyqtSlot
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSlot
 
 from E5Gui.E5Completers import E5FileCompleter
 from E5Gui import E5FileDialog
@@ -17,6 +19,7 @@ from .Ui_DebuggerPythonPage import Ui_DebuggerPythonPage
 
 import Preferences
 import Utilities
+import UI.PixmapCache
 
 
 class DebuggerPythonPage(ConfigurationPageBase, Ui_DebuggerPythonPage):
@@ -27,10 +30,13 @@ class DebuggerPythonPage(ConfigurationPageBase, Ui_DebuggerPythonPage):
         """
         Constructor
         """
-        super().__init__()
+        super(DebuggerPythonPage, self).__init__()
         self.setupUi(self)
         self.setObjectName("DebuggerPythonPage")
         
+        self.interpreterButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        self.debugClientButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        
         self.interpreterCompleter = E5FileCompleter(self.interpreterEdit)
         self.debugClientCompleter = E5FileCompleter(self.debugClientEdit)
         
@@ -87,7 +93,7 @@ class DebuggerPythonPage(ConfigurationPageBase, Ui_DebuggerPythonPage):
         """
         file = E5FileDialog.getOpenFileName(
             self,
-            self.trUtf8("Select Python interpreter for Debug Client"),
+            self.tr("Select Python interpreter for Debug Client"),
             self.interpreterEdit.text(),
             "")
             
@@ -102,9 +108,9 @@ class DebuggerPythonPage(ConfigurationPageBase, Ui_DebuggerPythonPage):
         """
         file = E5FileDialog.getOpenFileName(
             None,
-            self.trUtf8("Select Debug Client"),
+            self.tr("Select Debug Client"),
             self.debugClientEdit.text(),
-            self.trUtf8("Python Files (*.py *.py2)"))
+            self.tr("Python Files (*.py *.py2)"))
             
         if file:
             self.debugClientEdit.setText(
