@@ -1,12 +1,14 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Editor Autocompletion configuration page.
 """
 
+from __future__ import unicode_literals
+
 from .ConfigurationPageBase import ConfigurationPageBase
 from .Ui_EditorAutocompletionPage import Ui_EditorAutocompletionPage
 
@@ -22,7 +24,7 @@ class EditorAutocompletionPage(ConfigurationPageBase,
         """
         Constructor
         """
-        super().__init__()
+        super(EditorAutocompletionPage, self).__init__()
         self.setupUi(self)
         self.setObjectName("EditorAutocompletionPage")
         
