@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the QScintilla Autocompletion configuration page.
 """
 
-from PyQt4.Qsci import QsciScintilla
+from __future__ import unicode_literals
+
+from PyQt5.Qsci import QsciScintilla
 
 from .ConfigurationPageBase import ConfigurationPageBase
 from .Ui_EditorAutocompletionQScintillaPage import \
@@ -25,7 +27,7 @@ class EditorAutocompletionQScintillaPage(
         """
         Constructor
         """
-        super().__init__()
+        super(EditorAutocompletionQScintillaPage, self).__init__()
         self.setupUi(self)
         self.setObjectName("EditorAutocompletionQScintillaPage")
         
