@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Editor Calltips configuration page.
 """
 
-from PyQt4.Qsci import QsciScintilla
+from __future__ import unicode_literals
+
+from PyQt5.Qsci import QsciScintilla
 
 from QScintilla.QsciScintillaCompat import QSCINTILLA_VERSION
 
@@ -25,16 +27,16 @@ class EditorCalltipsPage(ConfigurationPageBase, Ui_EditorCalltipsPage):
         """
         Constructor
         """
-        super().__init__()
+        super(EditorCalltipsPage, self).__init__()
         self.setupUi(self)
         self.setObjectName("EditorCalltipsPage")
         
         if QSCINTILLA_VERSION() >= 0x020700:
             self.positionComboBox.addItem(
-                self.trUtf8("Below Text"),
+                self.tr("Below Text"),
                 QsciScintilla.CallTipsBelowText)
             self.positionComboBox.addItem(
-                self.trUtf8("Above Text"),
+                self.tr("Above Text"),
                 QsciScintilla.CallTipsAboveText)
         else:
             self.calltipsPositionBox.hide()
