@@ -1,15 +1,17 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Editor File Handling configuration page.
 """
 
-from PyQt4.QtCore import pyqtSlot
-from PyQt4.QtGui import QListWidgetItem, QInputDialog, QLineEdit
-from PyQt4.Qsci import QsciScintilla
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSlot
+from PyQt5.QtWidgets import QListWidgetItem, QInputDialog, QLineEdit
+from PyQt5.Qsci import QsciScintilla
 
 from E5Gui import E5MessageBox
 
@@ -28,7 +30,7 @@ class EditorFilePage(ConfigurationPageBase, Ui_EditorFilePage):
         """
         Constructor
         """
-        super().__init__()
+        super(EditorFilePage, self).__init__()
         self.setupUi(self)
         self.setObjectName("EditorFilePage")
         
@@ -85,6 +87,8 @@ class EditorFilePage(ConfigurationPageBase, Ui_EditorFilePage):
                 Preferences.getEditor("PreviewMarkdownFileNameExtensions")))
         self.previewRestExtensionsEdit.setText(
             " ".join(Preferences.getEditor("PreviewRestFileNameExtensions")))
+        self.previewQssExtensionsEdit.setText(
+            " ".join(Preferences.getEditor("PreviewQssFileNameExtensions")))
         
     def save(self):
         """
@@ -148,6 +152,10 @@ class EditorFilePage(ConfigurationPageBase, Ui_EditorFilePage):
             "PreviewRestFileNameExtensions",
             [ext.strip() for ext in
              self.previewRestExtensionsEdit.text().split()])
+        Preferences.setEditor(
+            "PreviewQssFileNameExtensions",
+            [ext.strip() for ext in
+             self.previewQssExtensionsEdit.text().split()])
     
     def __setDefaultFiltersLists(self, keepSelection=False):
         """
@@ -201,18 +209,18 @@ class EditorFilePage(ConfigurationPageBase, Ui_EditorFilePage):
            filter.count("*") != 1:
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Add File Filter"),
-                self.trUtf8("""A Save File Filter must contain exactly one"""
-                            """ wildcard pattern. Yours contains {0}.""")
+                self.tr("Add File Filter"),
+                self.tr("""A Save File Filter must contain exactly one"""
+                        """ wildcard pattern. Yours contains {0}.""")
                 .format(filter.count("*")))
             return False
         
         if filter.count("*") == 0:
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Add File Filter"),
-                self.trUtf8("""A File Filter must contain at least one"""
-                            """ wildcard pattern."""))
+                self.tr("Add File Filter"),
+                self.tr("""A File Filter must contain at least one"""
+                        """ wildcard pattern."""))
             return False
         
         return True
@@ -224,8 +232,8 @@ class EditorFilePage(ConfigurationPageBase, Ui_EditorFilePage):
         """
         filter, ok = QInputDialog.getText(
             self,
-            self.trUtf8("Add File Filter"),
-            self.trUtf8("Enter the file filter entry:"),
+            self.tr("Add File Filter"),
+            self.tr("Enter the file filter entry:"),
             QLineEdit.Normal)
         if ok and filter:
             if self.__checkFileFilter(filter):
@@ -241,8 +249,8 @@ class EditorFilePage(ConfigurationPageBase, Ui_EditorFilePage):
         filter = self.fileFiltersList.currentItem().text()
         filter, ok = QInputDialog.getText(
             self,
-            self.trUtf8("Add File Filter"),
-            self.trUtf8("Enter the file filter entry:"),
+            self.tr("Add File Filter"),
+            self.tr("Enter the file filter entry:"),
             QLineEdit.Normal,
             filter)
         if ok and filter:
