@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Editor General configuration page.
 """
 
-from PyQt4.Qsci import QsciScintillaBase
+from __future__ import unicode_literals
+
+from PyQt5.Qsci import QsciScintillaBase
 
 from .ConfigurationPageBase import ConfigurationPageBase
 from .Ui_EditorGeneralPage import Ui_EditorGeneralPage
@@ -23,7 +25,7 @@ class EditorGeneralPage(ConfigurationPageBase, Ui_EditorGeneralPage):
         """
         Constructor
         """
-        super().__init__()
+        super(EditorGeneralPage, self).__init__()
         self.setupUi(self)
         self.setObjectName("EditorGeneralPage")
         
