@@ -1,18 +1,20 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Editor Highlighter Associations configuration page.
 """
 
+from __future__ import unicode_literals
+
 import os
 
 from pygments.lexers import get_all_lexers
 
-from PyQt4.QtCore import Qt, pyqtSlot, qVersion
-from PyQt4.QtGui import QHeaderView, QTreeWidgetItem
+from PyQt5.QtCore import Qt, pyqtSlot, qVersion
+from PyQt5.QtWidgets import QHeaderView, QTreeWidgetItem
 
 from .ConfigurationPageBase import ConfigurationPageBase
 from .Ui_EditorHighlightersPage import Ui_EditorHighlightersPage
@@ -30,7 +32,7 @@ class EditorHighlightersPage(ConfigurationPageBase, Ui_EditorHighlightersPage):
         
         @param lexers reference to the lexers dictionary
         """
-        super().__init__()
+        super(EditorHighlightersPage, self).__init__()
         self.setupUi(self)
         self.setObjectName("EditorHighlightersPage")
         
@@ -48,7 +50,7 @@ class EditorHighlightersPage(ConfigurationPageBase, Ui_EditorHighlightersPage):
         except AttributeError:
             self.extsep = "."
         
-        self.extras = ["-----------", self.trUtf8("Alternative")]
+        self.extras = ["-----------", self.tr("Alternative")]
         languages = [''] + sorted(lexers.keys()) + self.extras
         self.editorLexerCombo.addItems(languages)
         
@@ -137,7 +139,7 @@ class EditorHighlightersPage(ConfigurationPageBase, Ui_EditorHighlightersPage):
             if lexer.startswith("Pygments|"):
                 pygmentsLexer = lexer.split("|")[1]
                 pygmentsIndex = self.pygmentsLexerCombo.findText(pygmentsLexer)
-                lexer = self.trUtf8("Alternative")
+                lexer = self.tr("Alternative")
             else:
                 pygmentsIndex = 0
             index = self.editorLexerCombo.findText(lexer)
