@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Editor Spellchecking configuration page.
 """
 
-from PyQt4.QtCore import pyqtSlot
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSlot
 
 from E5Gui.E5Completers import E5FileCompleter
 from E5Gui import E5FileDialog
@@ -17,6 +19,7 @@ from .Ui_EditorSpellCheckingPage import Ui_EditorSpellCheckingPage
 
 import Preferences
 import Utilities
+import UI.PixmapCache
 
 
 class EditorSpellCheckingPage(ConfigurationPageBase,
@@ -28,10 +31,13 @@ class EditorSpellCheckingPage(ConfigurationPageBase,
         """
         Constructor
         """
-        super().__init__()
+        super(EditorSpellCheckingPage, self).__init__()
         self.setupUi(self)
         self.setObjectName("EditorSpellCheckingPage")
         
+        self.pwlButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        self.pelButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        
         from QScintilla.SpellChecker import SpellChecker
         languages = sorted(SpellChecker.getAvailableLanguages())
         self.defaultLanguageCombo.addItems(languages)
@@ -108,9 +114,9 @@ class EditorSpellCheckingPage(ConfigurationPageBase,
         """
         file = E5FileDialog.getOpenFileName(
             self,
-            self.trUtf8("Select personal word list"),
+            self.tr("Select personal word list"),
             self.pwlEdit.text(),
-            self.trUtf8("Dictionary File (*.dic);;All Files (*)"))
+            self.tr("Dictionary File (*.dic);;All Files (*)"))
             
         if file:
             self.pwlEdit.setText(Utilities.toNativeSeparators(file))
@@ -122,9 +128,9 @@ class EditorSpellCheckingPage(ConfigurationPageBase,
         """
         file = E5FileDialog.getOpenFileName(
             self,
-            self.trUtf8("Select personal exclude list"),
+            self.tr("Select personal exclude list"),
             self.pelEdit.text(),
-            self.trUtf8("Dictionary File (*.dic);;All Files (*)"))
+            self.tr("Dictionary File (*.dic);;All Files (*)"))
             
         if file:
             self.pelEdit.setText(Utilities.toNativeSeparators(file))
