@@ -1,15 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Editor Styles configuration page.
 """
 
-from PyQt4.QtCore import pyqtSlot
-from PyQt4.QtGui import QColor, QPalette, QColorDialog
-from PyQt4.Qsci import QsciScintilla
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSlot
+from PyQt5.QtGui import QColor, QPalette
+from PyQt5.QtWidgets import QColorDialog
+from PyQt5.Qsci import QsciScintilla
 
 from .ConfigurationPageBase import ConfigurationPageBase
 from .Ui_EditorStylesPage import Ui_EditorStylesPage
@@ -25,12 +28,12 @@ class EditorStylesPage(ConfigurationPageBase, Ui_EditorStylesPage):
         """
         Constructor
         """
-        super().__init__()
+        super(EditorStylesPage, self).__init__()
         self.setupUi(self)
         self.setObjectName("EditorStylesPage")
         
-        from QScintilla.QsciScintillaCompat import (
-            QsciScintillaCompat, QSCINTILLA_VERSION)
+        from QScintilla.QsciScintillaCompat import QsciScintillaCompat, \
+            QSCINTILLA_VERSION
         self.foldStyles = [
             QsciScintilla.PlainFoldStyle,
             QsciScintilla.CircledFoldStyle,
@@ -48,20 +51,20 @@ class EditorStylesPage(ConfigurationPageBase, Ui_EditorStylesPage):
         ]
         
         self.wrapModeComboBox.addItem(
-            self.trUtf8("Disabled"), QsciScintilla.WrapNone)
+            self.tr("Disabled"), QsciScintilla.WrapNone)
         self.wrapModeComboBox.addItem(
-            self.trUtf8("Word Boundary"), QsciScintilla.WrapWord)
+            self.tr("Word Boundary"), QsciScintilla.WrapWord)
         self.wrapModeComboBox.addItem(
-            self.trUtf8("Character Boundary"), QsciScintilla.WrapCharacter)
+            self.tr("Character Boundary"), QsciScintilla.WrapCharacter)
         self.wrapVisualComboBox.addItem(
-            self.trUtf8("No Indicator"), QsciScintilla.WrapFlagNone)
+            self.tr("No Indicator"), QsciScintilla.WrapFlagNone)
         self.wrapVisualComboBox.addItem(
-            self.trUtf8("Indicator by Text"), QsciScintilla.WrapFlagByText)
+            self.tr("Indicator by Text"), QsciScintilla.WrapFlagByText)
         self.wrapVisualComboBox.addItem(
-            self.trUtf8("Indicator by Margin"), QsciScintilla.WrapFlagByBorder)
+            self.tr("Indicator by Margin"), QsciScintilla.WrapFlagByBorder)
         if QSCINTILLA_VERSION() >= 0x020700:
             self.wrapVisualComboBox.addItem(
-                self.trUtf8("Indicator in Line Number Margin"),
+                self.tr("Indicator in Line Number Margin"),
                 QsciScintilla.WrapFlagInMargin)
         
         if QSCINTILLA_VERSION() < 0x020800:
@@ -211,6 +214,34 @@ class EditorStylesPage(ConfigurationPageBase, Ui_EditorStylesPage):
         self.initColour("OnlineChangeTraceMarkerSaved",
                         self.changeMarkerSavedColorButton,
                         Preferences.getEditorColour)
+        
+        self.initColour("BookmarksMap",
+                        self.bookmarksMapButton,
+                        Preferences.getEditorColour)
+        self.initColour("ErrorsMap",
+                        self.errorsMapButton,
+                        Preferences.getEditorColour)
+        self.initColour("WarningsMap",
+                        self.warningsMapButton,
+                        Preferences.getEditorColour)
+        self.initColour("BreakpointsMap",
+                        self.breakpointsMapButton,
+                        Preferences.getEditorColour)
+        self.initColour("TasksMap",
+                        self.tasksMapButton,
+                        Preferences.getEditorColour)
+        self.initColour("CoverageMap",
+                        self.coverageMapButton,
+                        Preferences.getEditorColour)
+        self.initColour("ChangesMap",
+                        self.changesMapButton,
+                        Preferences.getEditorColour)
+        self.initColour("CurrentMap",
+                        self.currentMapButton,
+                        Preferences.getEditorColour)
+        self.initColour("MarkerMapBackground",
+                        self.markerMapBackgroundButton,
+                        Preferences.getEditorColour)
     
     def save(self):
         """
