@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Editor Typing configuration page.
 """
 
-from PyQt4.QtCore import pyqtSlot
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSlot
 
 from .ConfigurationPageBase import ConfigurationPageBase
 from .Ui_EditorTypingPage import Ui_EditorTypingPage
@@ -23,7 +25,7 @@ class EditorTypingPage(ConfigurationPageBase, Ui_EditorTypingPage):
         """
         Constructor
         """
-        super().__init__()
+        super(EditorTypingPage, self).__init__()
         self.setupUi(self)
         self.setObjectName("EditorTypingPage")
         
