@@ -1,17 +1,20 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Email configuration page.
 """
 
+from __future__ import unicode_literals
+
 import smtplib
 import socket
 
-from PyQt4.QtCore import pyqtSlot,  Qt
-from PyQt4.QtGui import QApplication, QCursor
+from PyQt5.QtCore import pyqtSlot, Qt
+from PyQt5.QtGui import QCursor
+from PyQt5.QtWidgets import QApplication
 
 from E5Gui import E5MessageBox
 
@@ -29,7 +32,7 @@ class EmailPage(ConfigurationPageBase, Ui_EmailPage):
         """
         Constructor
         """
-        super().__init__()
+        super(EmailPage, self).__init__()
         self.setupUi(self)
         self.setObjectName("EmailPage")
         
@@ -133,11 +136,11 @@ class EmailPage(ConfigurationPageBase, Ui_EmailPage):
                 QApplication.restoreOverrideCursor()
                 E5MessageBox.information(
                     self,
-                    self.trUtf8("Login Test"),
-                    self.trUtf8("""The login test succeeded."""))
+                    self.tr("Login Test"),
+                    self.tr("""The login test succeeded."""))
             except (smtplib.SMTPException, socket.error) as e:
                 QApplication.restoreOverrideCursor()
-                if isinstance(e,  smtplib.SMTPResponseException):
+                if isinstance(e, smtplib.SMTPResponseException):
                     errorStr = e.smtp_error.decode()
                 elif isinstance(e, socket.timeout):
                     errorStr = str(e)
@@ -150,14 +153,14 @@ class EmailPage(ConfigurationPageBase, Ui_EmailPage):
                     errorStr = str(e)
                 E5MessageBox.critical(
                     self,
-                    self.trUtf8("Login Test"),
-                    self.trUtf8(
+                    self.tr("Login Test"),
+                    self.tr(
                         """<p>The login test failed.<br>Reason: {0}</p>""")
                     .format(errorStr))
             server.quit()
         except (smtplib.SMTPException, socket.error) as e:
             QApplication.restoreOverrideCursor()
-            if isinstance(e,  smtplib.SMTPResponseException):
+            if isinstance(e, smtplib.SMTPResponseException):
                 errorStr = e.smtp_error.decode()
             elif isinstance(e, socket.timeout):
                 errorStr = str(e)
@@ -170,8 +173,8 @@ class EmailPage(ConfigurationPageBase, Ui_EmailPage):
                 errorStr = str(e)
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Login Test"),
-                self.trUtf8("""<p>The login test failed.<br>Reason: {0}</p>""")
+                self.tr("Login Test"),
+                self.tr("""<p>The login test failed.<br>Reason: {0}</p>""")
                 .format(errorStr))
 
 
