@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Help Viewers configuration page.
 """
 
-from PyQt4.QtCore import pyqtSlot
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSlot
 
 from E5Gui.E5Completers import E5FileCompleter
 from E5Gui import E5FileDialog
@@ -17,6 +19,7 @@ from .Ui_HelpAppearancePage import Ui_HelpAppearancePage
 
 import Preferences
 import Utilities
+import UI.PixmapCache
 
 
 class HelpAppearancePage(ConfigurationPageBase, Ui_HelpAppearancePage):
@@ -27,10 +30,12 @@ class HelpAppearancePage(ConfigurationPageBase, Ui_HelpAppearancePage):
         """
         Constructor
         """
-        super().__init__()
+        super(HelpAppearancePage, self).__init__()
         self.setupUi(self)
         self.setObjectName("HelpAppearancePage")
         
+        self.styleSheetButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        
         self.styleSheetCompleter = E5FileCompleter(self.styleSheetEdit)
         
         self.__displayMode = None
@@ -38,15 +43,15 @@ class HelpAppearancePage(ConfigurationPageBase, Ui_HelpAppearancePage):
         # set initial values
         self.standardFont = Preferences.getHelp("StandardFont")
         self.standardFontSample.setFont(self.standardFont)
-        self.standardFontSample.setText("{0} {1}"
-            .format(self.standardFont.family(),
-                    self.standardFont.pointSize()))
+        self.standardFontSample.setText(
+            "{0} {1}".format(self.standardFont.family(),
+                             self.standardFont.pointSize()))
         
         self.fixedFont = Preferences.getHelp("FixedFont")
         self.fixedFontSample.setFont(self.fixedFont)
-        self.fixedFontSample.setText("{0} {1}"
-            .format(self.fixedFont.family(),
-                    self.fixedFont.pointSize()))
+        self.fixedFontSample.setText(
+            "{0} {1}".format(self.fixedFont.family(),
+                             self.fixedFont.pointSize()))
         
         self.initColour("SaveUrlColor", self.secureURLsColourButton,
                         Preferences.getHelp)
@@ -131,7 +136,7 @@ class HelpAppearancePage(ConfigurationPageBase, Ui_HelpAppearancePage):
         """
         file = E5FileDialog.getOpenFileName(
             self,
-            self.trUtf8("Select Style Sheet"),
+            self.tr("Select Style Sheet"),
             self.styleSheetEdit.text(),
             "")
         
