@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Help Documentation configuration page.
 """
 
-from PyQt4.QtCore import pyqtSlot, QUrl
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSlot, QUrl
 
 from E5Gui.E5Completers import E5FileCompleter
 from E5Gui import E5FileDialog
@@ -17,6 +19,7 @@ from .Ui_HelpDocumentationPage import Ui_HelpDocumentationPage
 
 import Preferences
 import Utilities
+import UI.PixmapCache
 
 
 class HelpDocumentationPage(ConfigurationPageBase, Ui_HelpDocumentationPage):
@@ -27,13 +30,22 @@ class HelpDocumentationPage(ConfigurationPageBase, Ui_HelpDocumentationPage):
         """
         Constructor
         """
-        super().__init__()
+        super(HelpDocumentationPage, self).__init__()
         self.setupUi(self)
         self.setObjectName("HelpDocumentationPage")
         
+        self.python2DocDirButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        self.pythonDocDirButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        self.qt4DocDirButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        self.qt5DocDirButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        self.pyqt4DocDirButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        self.pyqt5DocDirButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        self.pysideDocDirButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        
         self.python2DocDirCompleter = E5FileCompleter(self.python2DocDirEdit)
         self.pythonDocDirCompleter = E5FileCompleter(self.pythonDocDirEdit)
         self.qt4DocDirCompleter = E5FileCompleter(self.qt4DocDirEdit)
+        self.qt5DocDirCompleter = E5FileCompleter(self.qt5DocDirEdit)
         self.pyqt4DocDirCompleter = E5FileCompleter(self.pyqt4DocDirEdit)
         self.pyqt5DocDirCompleter = E5FileCompleter(self.pyqt5DocDirEdit)
         self.pysideDocDirCompleter = E5FileCompleter(self.pysideDocDirEdit)
@@ -98,9 +110,9 @@ class HelpDocumentationPage(ConfigurationPageBase, Ui_HelpDocumentationPage):
         """
         entry = E5FileDialog.getOpenFileName(
             self,
-            self.trUtf8("Select Python 2 documentation entry"),
+            self.tr("Select Python 2 documentation entry"),
             QUrl(self.python2DocDirEdit.text()).path(),
-            self.trUtf8(
+            self.tr(
                 "HTML Files (*.html *.htm);;"
                 "Compressed Help Files (*.chm);;"
                 "All Files (*)"))
@@ -115,9 +127,9 @@ class HelpDocumentationPage(ConfigurationPageBase, Ui_HelpDocumentationPage):
         """
         entry = E5FileDialog.getOpenFileName(
             self,
-            self.trUtf8("Select Python 3 documentation entry"),
+            self.tr("Select Python 3 documentation entry"),
             QUrl(self.pythonDocDirEdit.text()).path(),
-            self.trUtf8(
+            self.tr(
                 "HTML Files (*.html *.htm);;"
                 "Compressed Help Files (*.chm);;"
                 "All Files (*)"))
@@ -132,9 +144,9 @@ class HelpDocumentationPage(ConfigurationPageBase, Ui_HelpDocumentationPage):
         """
         entry = E5FileDialog.getOpenFileName(
             self,
-            self.trUtf8("Select Qt4 documentation entry"),
+            self.tr("Select Qt4 documentation entry"),
             QUrl(self.qt4DocDirEdit.text()).path(),
-            self.trUtf8("HTML Files (*.html *.htm);;All Files (*)"))
+            self.tr("HTML Files (*.html *.htm);;All Files (*)"))
         
         if entry:
             self.qt4DocDirEdit.setText(Utilities.toNativeSeparators(entry))
@@ -146,9 +158,9 @@ class HelpDocumentationPage(ConfigurationPageBase, Ui_HelpDocumentationPage):
         """
         entry = E5FileDialog.getOpenFileName(
             self,
-            self.trUtf8("Select Qt5 documentation entry"),
+            self.tr("Select Qt5 documentation entry"),
             QUrl(self.qt5DocDirEdit.text()).path(),
-            self.trUtf8("HTML Files (*.html *.htm);;All Files (*)"))
+            self.tr("HTML Files (*.html *.htm);;All Files (*)"))
         
         if entry:
             self.qt5DocDirEdit.setText(Utilities.toNativeSeparators(entry))
@@ -156,13 +168,13 @@ class HelpDocumentationPage(ConfigurationPageBase, Ui_HelpDocumentationPage):
     @pyqtSlot()
     def on_pyqt4DocDirButton_clicked(self):
         """
-        Private slot to select the PyQt4 documentation directory.
+        Private slot to select the PyQt5 documentation directory.
         """
         entry = E5FileDialog.getOpenFileName(
             self,
-            self.trUtf8("Select PyQt4 documentation entry"),
+            self.tr("Select PyQt5 documentation entry"),
             QUrl(self.pyqt4DocDirEdit.text()).path(),
-            self.trUtf8("HTML Files (*.html *.htm);;All Files (*)"))
+            self.tr("HTML Files (*.html *.htm);;All Files (*)"))
         
         if entry:
             self.pyqt4DocDirEdit.setText(Utilities.toNativeSeparators(entry))
@@ -174,9 +186,9 @@ class HelpDocumentationPage(ConfigurationPageBase, Ui_HelpDocumentationPage):
         """
         entry = E5FileDialog.getOpenFileName(
             self,
-            self.trUtf8("Select PyQt5 documentation entry"),
+            self.tr("Select PyQt5 documentation entry"),
             QUrl(self.pyqt4DocDirEdit.text()).path(),
-            self.trUtf8("HTML Files (*.html *.htm);;All Files (*)"))
+            self.tr("HTML Files (*.html *.htm);;All Files (*)"))
         
         if entry:
             self.pyqt5DocDirEdit.setText(Utilities.toNativeSeparators(entry))
@@ -188,9 +200,9 @@ class HelpDocumentationPage(ConfigurationPageBase, Ui_HelpDocumentationPage):
         """
         entry = E5FileDialog.getOpenFileName(
             self,
-            self.trUtf8("Select PySide documentation entry"),
+            self.tr("Select PySide documentation entry"),
             QUrl(self.pysideDocDirEdit.text()).path(),
-            self.trUtf8("HTML Files (*.html *.htm);;All Files (*)"))
+            self.tr("HTML Files (*.html *.htm);;All Files (*)"))
         
         if entry:
             self.pysideDocDirEdit.setText(Utilities.toNativeSeparators(entry))
