@@ -1,16 +1,19 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to preview the contents of an icon directory.
 """
 
+from __future__ import unicode_literals
+
 import os.path
 
-from PyQt4.QtGui import QListWidgetItem, QDialog, QIcon
-from PyQt4.QtCore import QDir
+from PyQt5.QtGui import QIcon
+from PyQt5.QtWidgets import QListWidgetItem, QDialog
+from PyQt5.QtCore import QDir
 
 from .Ui_IconsPreviewDialog import Ui_IconsPreviewDialog
 
@@ -26,7 +29,7 @@ class IconsPreviewDialog(QDialog, Ui_IconsPreviewDialog):
         @param parent parent widget (QWidget)
         @param dirName name of directory to show (string)
         """
-        super().__init__(parent)
+        super(IconsPreviewDialog, self).__init__(parent)
         self.setupUi(self)
         
         dir = QDir(dirName)
