@@ -1,17 +1,19 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Interface configuration page.
 """
 
+from __future__ import unicode_literals
+
 import glob
 import os
 
-from PyQt4.QtCore import pyqtSlot, QTranslator
-from PyQt4.QtGui import QStyleFactory
+from PyQt5.QtCore import pyqtSlot, QTranslator
+from PyQt5.QtWidgets import QStyleFactory
 
 from E5Gui.E5Completers import E5FileCompleter
 from E5Gui import E5FileDialog
@@ -21,8 +23,9 @@ from .Ui_InterfacePage import Ui_InterfacePage
 
 import Preferences
 import Utilities
+import UI.PixmapCache
 
-from eric5config import getConfig
+from eric6config import getConfig
 
 
 class InterfacePage(ConfigurationPageBase, Ui_InterfacePage):
@@ -33,10 +36,12 @@ class InterfacePage(ConfigurationPageBase, Ui_InterfacePage):
         """
         Constructor
         """
-        super().__init__()
+        super(InterfacePage, self).__init__()
         self.setupUi(self)
         self.setObjectName("InterfacePage")
         
+        self.styleSheetButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        
         self.styleSheetCompleter = E5FileCompleter(self.styleSheetEdit)
         
         # set initial values
@@ -205,7 +210,7 @@ class InterfacePage(ConfigurationPageBase, Ui_InterfacePage):
         """
         curStyle = Preferences.getUI("Style")
         styles = sorted(list(QStyleFactory.keys()))
-        self.styleComboBox.addItem(self.trUtf8('System'), "System")
+        self.styleComboBox.addItem(self.tr('System'), "System")
         for style in styles:
             self.styleComboBox.addItem(style, style)
         currentIndex = self.styleComboBox.findData(curStyle)
@@ -220,10 +225,10 @@ class InterfacePage(ConfigurationPageBase, Ui_InterfacePage):
         """
         self.languageComboBox.clear()
         
-        fnlist = glob.glob("eric5_*.qm") + \
+        fnlist = glob.glob("eric6_*.qm") + \
             glob.glob(os.path.join(
-                getConfig('ericTranslationsDir'), "eric5_*.qm")) + \
-            glob.glob(os.path.join(Utilities.getConfigDir(), "eric5_*.qm"))
+                getConfig('ericTranslationsDir'), "eric6_*.qm")) + \
+            glob.glob(os.path.join(Utilities.getConfigDir(), "eric6_*.qm"))
         locales = {}
         for fn in fnlist:
             locale = os.path.basename(fn)[6:-3]
@@ -248,7 +253,7 @@ class InterfacePage(ConfigurationPageBase, Ui_InterfacePage):
         self.languageComboBox.clear()
         
         self.languageComboBox.addItem("English (default)", "None")
-        self.languageComboBox.addItem(self.trUtf8('System'), "System")
+        self.languageComboBox.addItem(self.tr('System'), "System")
         for locale in localeList:
             self.languageComboBox.addItem(locales[locale], locale)
         self.languageComboBox.setCurrentIndex(currentIndex)
@@ -260,9 +265,9 @@ class InterfacePage(ConfigurationPageBase, Ui_InterfacePage):
         """
         file = E5FileDialog.getOpenFileName(
             self,
-            self.trUtf8("Select style sheet file"),
+            self.tr("Select style sheet file"),
             self.styleSheetEdit.text(),
-            self.trUtf8(
+            self.tr(
                 "Qt Style Sheets (*.qss);;Cascading Style Sheets (*.css);;"
                 "All files (*)"))
         
