@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Multi Project configuration page.
 """
 
-from PyQt4.QtCore import pyqtSlot
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSlot
 
 from .ConfigurationPageBase import ConfigurationPageBase
 from .Ui_MultiProjectPage import Ui_MultiProjectPage
@@ -16,6 +18,7 @@ from E5Gui import E5FileDialog
 
 import Preferences
 import Utilities
+import UI.PixmapCache
 
 
 class MultiProjectPage(ConfigurationPageBase, Ui_MultiProjectPage):
@@ -26,10 +29,12 @@ class MultiProjectPage(ConfigurationPageBase, Ui_MultiProjectPage):
         """
         Constructor
         """
-        super().__init__()
+        super(MultiProjectPage, self).__init__()
         self.setupUi(self)
         self.setObjectName("MultiProjectPage")
         
+        self.workspaceButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        
         # set initial values
         self.openMasterAutomaticallyCheckBox.setChecked(
             Preferences.getMultiProject("OpenMasterAutomatically"))
@@ -69,7 +74,7 @@ class MultiProjectPage(ConfigurationPageBase, Ui_MultiProjectPage):
             default = Utilities.getHomeDir()
         directory = E5FileDialog.getExistingDirectory(
             self,
-            self.trUtf8("Select Workspace Directory"),
+            self.tr("Select Workspace Directory"),
             default,
             E5FileDialog.Options(0))
         
