@@ -1,15 +1,17 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Plugin Manager configuration page.
 """
 
+from __future__ import unicode_literals
+
 import os
 
-from PyQt4.QtCore import pyqtSlot
+from PyQt5.QtCore import pyqtSlot
 
 from E5Gui.E5Completers import E5DirCompleter
 from E5Gui import E5FileDialog
@@ -19,6 +21,7 @@ from .Ui_PluginManagerPage import Ui_PluginManagerPage
 
 import Preferences
 import Utilities
+import UI.PixmapCache
 
 
 class PluginManagerPage(ConfigurationPageBase, Ui_PluginManagerPage):
@@ -29,10 +32,12 @@ class PluginManagerPage(ConfigurationPageBase, Ui_PluginManagerPage):
         """
         Constructor
         """
-        super().__init__()
+        super(PluginManagerPage, self).__init__()
         self.setupUi(self)
         self.setObjectName("PluginManagerPage")
         
+        self.downloadDirButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        
         self.downloadDirCompleter = E5DirCompleter(self.downloadDirEdit)
         
         # set initial values
@@ -40,6 +45,10 @@ class PluginManagerPage(ConfigurationPageBase, Ui_PluginManagerPage):
             Preferences.getPluginManager("ActivateExternal"))
         self.downloadDirEdit.setText(
             Preferences.getPluginManager("DownloadPath"))
+        self.generationsSpinBox.setValue(
+            Preferences.getPluginManager("KeepGenerations"))
+        self.keepHiddenCheckBox.setChecked(
+            Preferences.getPluginManager("KeepHidden"))
         
         period = Preferences.getPluginManager("UpdatesCheckInterval")
         if period == 0:
@@ -54,7 +63,7 @@ class PluginManagerPage(ConfigurationPageBase, Ui_PluginManagerPage):
         self.downloadedOnlyCheckBox.setChecked(
             Preferences.getPluginManager("CheckInstalledOnly"))
         
-        self.__repositoryUrl = Preferences.getUI("PluginRepositoryUrl5")
+        self.__repositoryUrl = Preferences.getUI("PluginRepositoryUrl6")
         self.repositoryUrlEdit.setText(self.__repositoryUrl)
     
     def save(self):
@@ -67,6 +76,12 @@ class PluginManagerPage(ConfigurationPageBase, Ui_PluginManagerPage):
         Preferences.setPluginManager(
             "DownloadPath",
             self.downloadDirEdit.text())
+        Preferences.setPluginManager(
+            "KeepGenerations",
+            self.generationsSpinBox.value())
+        Preferences.setPluginManager(
+            "KeepHidden",
+            self.keepHiddenCheckBox.isChecked())
         
         if self.noCheckRadioButton.isChecked():
             period = 0
@@ -84,7 +99,7 @@ class PluginManagerPage(ConfigurationPageBase, Ui_PluginManagerPage):
         
         if self.repositoryUrlEdit.text() != self.__repositoryUrl:
             Preferences.setUI(
-                "PluginRepositoryUrl5", self.repositoryUrlEdit.text())
+                "PluginRepositoryUrl6", self.repositoryUrlEdit.text())
     
     @pyqtSlot()
     def on_downloadDirButton_clicked(self):
@@ -93,7 +108,7 @@ class PluginManagerPage(ConfigurationPageBase, Ui_PluginManagerPage):
         """
         directory = E5FileDialog.getExistingDirectory(
             self,
-            self.trUtf8("Select plugins download directory"),
+            self.tr("Select plugins download directory"),
             self.downloadDirEdit.text(),
             E5FileDialog.Options(E5FileDialog.ShowDirsOnly))
             
