@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Printer configuration page.
 """
 
-from PyQt4.QtCore import pyqtSlot
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSlot
 
 from .ConfigurationPageBase import ConfigurationPageBase
 from .Ui_PrinterPage import Ui_PrinterPage
@@ -23,7 +25,7 @@ class PrinterPage(ConfigurationPageBase, Ui_PrinterPage):
         """
         Constructor
         """
-        super().__init__()
+        super(PrinterPage, self).__init__()
         self.setupUi(self)
         self.setObjectName("PrinterPage")
         
