@@ -1,12 +1,14 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the tray starter configuration page.
 """
 
+from __future__ import unicode_literals
+
 from .ConfigurationPageBase import ConfigurationPageBase
 from .Ui_TrayStarterPage import Ui_TrayStarterPage
 
@@ -24,7 +26,7 @@ class TrayStarterPage(ConfigurationPageBase, Ui_TrayStarterPage):
         
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__()
+        super(TrayStarterPage, self).__init__()
         self.setupUi(self)
         self.setObjectName("TrayStarterPage")
         
