@@ -1,14 +1,17 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog for the configuration of a keyboard shortcut.
 """
 
-from PyQt4.QtCore import pyqtSignal, QEvent, Qt
-from PyQt4.QtGui import QKeySequence, QDialog, QDialogButtonBox
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSignal, QEvent, Qt
+from PyQt5.QtGui import QKeySequence
+from PyQt5.QtWidgets import QDialog, QDialogButtonBox
 
 from .Ui_ShortcutDialog import Ui_ShortcutDialog
 
@@ -30,21 +33,22 @@ class ShortcutDialog(QDialog, Ui_ShortcutDialog):
         @param name The name of this dialog. (string)
         @param modal Flag indicating a modal dialog. (boolean)
         """
-        super().__init__(parent)
+        super(ShortcutDialog, self).__init__(parent)
         if name:
             self.setObjectName(name)
         self.setModal(modal)
         self.setupUi(self)
+        self.setWindowFlags(Qt.Window)
         
         self.keyIndex = 0
         self.keys = [0, 0, 0, 0]
         self.noCheck = False
         self.objectType = ""
         
-        self.primaryClearButton.clicked[()].connect(self.__clear)
-        self.alternateClearButton.clicked[()].connect(self.__clear)
-        self.primaryButton.clicked[()].connect(self.__typeChanged)
-        self.alternateButton.clicked[()].connect(self.__typeChanged)
+        self.primaryClearButton.clicked.connect(self.__clear)
+        self.alternateClearButton.clicked.connect(self.__clear)
+        self.primaryButton.clicked.connect(self.__typeChanged)
+        self.alternateButton.clicked.connect(self.__typeChanged)
         
         self.shortcutsGroup.installEventFilter(self)
         self.primaryButton.installEventFilter(self)
@@ -56,8 +60,11 @@ class ShortcutDialog(QDialog, Ui_ShortcutDialog):
         
         self.buttonBox.button(QDialogButtonBox.Ok).installEventFilter(self)
         self.buttonBox.button(QDialogButtonBox.Cancel).installEventFilter(self)
+        
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
 
-    def setKeys(self, key, alternateKey,  noCheck, objectType):
+    def setKeys(self, key, alternateKey, noCheck, objectType):
         """
         Public method to set the key to be configured.
         
@@ -113,7 +120,7 @@ class ShortcutDialog(QDialog, Ui_ShortcutDialog):
         
     def eventFilter(self, watched, event):
         """
-        Method called to filter the event queue.
+        Public method called to filter the event queue.
         
         @param watched the QObject being watched
         @param event the event that occurred
@@ -127,7 +134,7 @@ class ShortcutDialog(QDialog, Ui_ShortcutDialog):
         
     def keyPressEvent(self, evt):
         """
-        Private method to handle a key press event.
+        Protected method to handle a key press event.
         
         @param evt the key event (QKeyEvent)
         """
