@@ -1,22 +1,26 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a configuration dialog for the tools menu.
 """
 
+from __future__ import unicode_literals
+
 import copy
 
-from PyQt4.QtCore import Qt, pyqtSlot
-from PyQt4.QtGui import QDialog
+from PyQt5.QtCore import Qt, pyqtSlot
+from PyQt5.QtWidgets import QDialog
 
 from E5Gui.E5Completers import E5FileCompleter
 from E5Gui import E5MessageBox, E5FileDialog
 
 from .Ui_ToolConfigurationDialog import Ui_ToolConfigurationDialog
+
 import Utilities
+import UI.PixmapCache
 
 
 class ToolConfigurationDialog(QDialog, Ui_ToolConfigurationDialog):
@@ -30,18 +34,21 @@ class ToolConfigurationDialog(QDialog, Ui_ToolConfigurationDialog):
         @param toollist list of configured tools
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(ToolConfigurationDialog, self).__init__(parent)
         self.setupUi(self)
         
+        self.iconButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        self.executableButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        
         self.iconCompleter = E5FileCompleter(self.iconEdit)
         self.executableCompleter = E5FileCompleter(self.executableEdit)
         
         self.redirectionModes = [
-            ("no", self.trUtf8("no redirection")),
-            ("show", self.trUtf8("show output")),
-            ("insert", self.trUtf8("insert into current editor")),
+            ("no", self.tr("no redirection")),
+            ("show", self.tr("show output")),
+            ("insert", self.tr("insert into current editor")),
             ("replaceSelection",
-             self.trUtf8("replace selection of current editor")),
+             self.tr("replace selection of current editor")),
         ]
         
         self.toollist = copy.deepcopy(toollist)
@@ -99,8 +106,8 @@ class ToolConfigurationDialog(QDialog, Ui_ToolConfigurationDialog):
         if not executable:
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Add tool entry"),
-                self.trUtf8(
+                self.tr("Add tool entry"),
+                self.tr(
                     "You have to set an executable to add to the"
                     " Tools-Menu first."))
             return
@@ -108,8 +115,8 @@ class ToolConfigurationDialog(QDialog, Ui_ToolConfigurationDialog):
         if not menutext:
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Add tool entry"),
-                self.trUtf8(
+                self.tr("Add tool entry"),
+                self.tr(
                     "You have to insert a menuentry text to add the"
                     " selected program to the Tools-Menu first."))
             return
@@ -117,8 +124,8 @@ class ToolConfigurationDialog(QDialog, Ui_ToolConfigurationDialog):
         if not Utilities.isinpath(executable):
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Add tool entry"),
-                self.trUtf8(
+                self.tr("Add tool entry"),
+                self.tr(
                     "The selected file could not be found or"
                     " is not an executable."
                     " Please choose an executable filename."))
@@ -128,8 +135,8 @@ class ToolConfigurationDialog(QDialog, Ui_ToolConfigurationDialog):
                 menutext, Qt.MatchFlags(Qt.MatchExactly))):
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Add tool entry"),
-                self.trUtf8("An entry for the menu text {0} already exists.")
+                self.tr("Add tool entry"),
+                self.tr("An entry for the menu text {0} already exists.")
                 .format(menutext))
             return
         
@@ -161,8 +168,8 @@ class ToolConfigurationDialog(QDialog, Ui_ToolConfigurationDialog):
         if not executable:
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Change tool entry"),
-                self.trUtf8(
+                self.tr("Change tool entry"),
+                self.tr(
                     "You have to set an executable to change the"
                     " Tools-Menu entry."))
             return
@@ -170,8 +177,8 @@ class ToolConfigurationDialog(QDialog, Ui_ToolConfigurationDialog):
         if not menutext:
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Change tool entry"),
-                self.trUtf8(
+                self.tr("Change tool entry"),
+                self.tr(
                     "You have to insert a menuentry text to change the"
                     " selected Tools-Menu entry."))
             return
@@ -179,8 +186,8 @@ class ToolConfigurationDialog(QDialog, Ui_ToolConfigurationDialog):
         if not Utilities.isinpath(executable):
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Change tool entry"),
-                self.trUtf8(
+                self.tr("Change tool entry"),
+                self.tr(
                     "The selected file could not be found or"
                     " is not an executable."
                     " Please choose an existing executable filename."))
@@ -266,7 +273,7 @@ class ToolConfigurationDialog(QDialog, Ui_ToolConfigurationDialog):
         """
         execfile = E5FileDialog.getOpenFileName(
             self,
-            self.trUtf8("Select executable"),
+            self.tr("Select executable"),
             self.executableEdit.text(),
             "")
         if execfile:
@@ -274,8 +281,8 @@ class ToolConfigurationDialog(QDialog, Ui_ToolConfigurationDialog):
             if not Utilities.isinpath(execfile):
                 E5MessageBox.critical(
                     self,
-                    self.trUtf8("Select executable"),
-                    self.trUtf8(
+                    self.tr("Select executable"),
+                    self.tr(
                         "The selected file is not an executable."
                         " Please choose an executable filename."))
                 return
@@ -289,9 +296,9 @@ class ToolConfigurationDialog(QDialog, Ui_ToolConfigurationDialog):
         """
         icon = E5FileDialog.getOpenFileName(
             self,
-            self.trUtf8("Select icon file"),
+            self.tr("Select icon file"),
             self.iconEdit.text(),
-            self.trUtf8("Icon files (*.png)"))
+            self.tr("Icon files (*.png)"))
         if icon:
             self.iconEdit.setText(icon)
     
