@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to configure the various view profiles.
 """
 
-from PyQt4.QtGui import QDialog
+from __future__ import unicode_literals
+
+from PyQt5.QtWidgets import QDialog
 
 from .Ui_ViewProfileToolboxesDialog import Ui_ViewProfileToolboxesDialog
 from .Ui_ViewProfileSidebarsDialog import Ui_ViewProfileSidebarsDialog
@@ -30,7 +32,7 @@ class ViewProfileDialog(QDialog):
         @param parent parent widget of this dialog (QWidget)
         @exception ValueError raised to indicate an invalid layout
         """
-        super().__init__(parent)
+        super(ViewProfileDialog, self).__init__(parent)
         
         self.__layout = layout
         if self.__layout == "Toolboxes":
@@ -52,6 +54,9 @@ class ViewProfileDialog(QDialog):
             self.ui.dpltCheckBox.setChecked(debugVisibilities[0])
             self.ui.dphtCheckBox.setChecked(debugVisibilities[1])
             self.ui.dprtCheckBox.setChecked(debugVisibilities[2])
+        
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
     
     def getVisibilities(self):
         """
