@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to show the found files to the user.
 """
 
-from PyQt4.QtCore import pyqtSlot
-from PyQt4.QtGui import QDialog, QDialogButtonBox
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSlot
+from PyQt5.QtWidgets import QDialog, QDialogButtonBox
 
 from .Ui_AddFoundFilesDialog import Ui_AddFoundFilesDialog
 
@@ -30,18 +32,18 @@ class AddFoundFilesDialog(QDialog, Ui_AddFoundFilesDialog):
         @param parent parent widget of this dialog (QWidget)
         @param name name of this dialog (string)
         """
-        super().__init__(parent)
+        super(AddFoundFilesDialog, self).__init__(parent)
         if name:
             self.setObjectName(name)
         self.setupUi(self)
         
         self.addAllButton = self.buttonBox.addButton(
-            self.trUtf8("Add All"), QDialogButtonBox.AcceptRole)
-        self.addAllButton.setToolTip(self.trUtf8("Add all files."))
+            self.tr("Add All"), QDialogButtonBox.AcceptRole)
+        self.addAllButton.setToolTip(self.tr("Add all files."))
         self.addSelectedButton = self.buttonBox.addButton(
-            self.trUtf8("Add Selected"), QDialogButtonBox.AcceptRole)
+            self.tr("Add Selected"), QDialogButtonBox.AcceptRole)
         self.addSelectedButton.setToolTip(
-            self.trUtf8("Add selected files only."))
+            self.tr("Add selected files only."))
         
         self.fileList.addItems(files)
         
