@@ -1,19 +1,23 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to generate code for a Qt4/Qt5 dialog.
 """
 
+from __future__ import unicode_literals
+
 import os
+import xml.etree.ElementTree
+
+from PyQt5.QtCore import QMetaObject, QByteArray, QRegExp, Qt, pyqtSlot, \
+    QMetaMethod, qVersion, QSortFilterProxyModel
+from PyQt5.QtGui import QStandardItemModel, QBrush, QStandardItem
+from PyQt5.QtWidgets import QWidget, QDialog, QDialogButtonBox, QAction
+from PyQt5 import uic
 
-from PyQt4.QtCore import QMetaObject, QByteArray, QRegExp, Qt, pyqtSlot, \
-    QMetaMethod, qVersion
-from PyQt4.QtGui import QWidget, QSortFilterProxyModel, QStandardItemModel, \
-    QDialog, QBrush, QStandardItem, QDialogButtonBox, QAction
-from PyQt4 import uic
 
 from E5Gui.E5Application import e5App
 from E5Gui import E5MessageBox
@@ -21,7 +25,7 @@ from E5Gui import E5MessageBox
 from .Ui_CreateDialogCodeDialog import Ui_CreateDialogCodeDialog
 from .NewDialogClassDialog import NewDialogClassDialog
 
-from eric5config import getConfig
+from eric6config import getConfig
 
 pyqtSignatureRole = Qt.UserRole + 1
 pythonSignatureRole = Qt.UserRole + 2
@@ -47,7 +51,7 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
         @param project reference to the project object
         @param parent parent widget if the dialog (QWidget)
         """
-        super().__init__(parent)
+        super(CreateDialogCodeDialog, self).__init__(parent)
         self.setupUi(self)
         
         self.okButton = self.buttonBox.button(QDialogButtonBox.Ok)
@@ -115,8 +119,8 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
             self.__initError = True
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Create Dialog Code"),
-                self.trUtf8(
+                self.tr("Create Dialog Code"),
+                self.tr(
                     """The file <b>{0}</b> exists but does not contain"""
                     """ any classes.""").format(self.srcFile))
         
@@ -139,13 +143,15 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
         @return object name (string)
         """
         try:
-            dlg = uic.loadUi(self.formFile)
+            dlg = uic.loadUi(
+                self.formFile, package=self.project.getProjectPath())
             return dlg.objectName()
-        except (AttributeError, ImportError) as err:
+        except (AttributeError, ImportError,
+                xml.etree.ElementTree.ParseError) as err:
             E5MessageBox.critical(
                 self,
-                self.trUtf8("uic error"),
-                self.trUtf8(
+                self.tr("uic error"),
+                self.tr(
                     """<p>There was an error loading the form <b>{0}</b>"""
                     """.</p><p>{1}</p>""").format(self.formFile, str(err)))
             return ""
@@ -157,13 +163,15 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
         @return class name (sting)
         """
         try:
-            dlg = uic.loadUi(self.formFile)
+            dlg = uic.loadUi(
+                self.formFile, package=self.project.getProjectPath())
             return dlg.metaObject().className()
-        except (AttributeError, ImportError) as err:
+        except (AttributeError, ImportError,
+                xml.etree.ElementTree.ParseError) as err:
             E5MessageBox.critical(
                 self,
-                self.trUtf8("uic error"),
-                self.trUtf8(
+                self.tr("uic error"),
+                self.tr(
                     """<p>There was an error loading the form <b>{0}</b>"""
                     """.</p><p>{1}</p>""").format(self.formFile, str(err)))
             return ""
@@ -226,7 +234,8 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
         self.filterEdit.clear()
         
         try:
-            dlg = uic.loadUi(self.formFile)
+            dlg = uic.loadUi(
+                self.formFile, package=self.project.getProjectPath())
             objects = dlg.findChildren(QWidget) + dlg.findChildren(QAction)
             
             signatureList = self.__signatures()
@@ -235,7 +244,8 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
             self.slotsModel.setHorizontalHeaderLabels([""])
             for obj in objects:
                 name = obj.objectName()
-                if not name:
+                if not name or name.startswith("qt_"):
+                    # ignore un-named or internal objects
                     continue
                 
                 metaObject = obj.metaObject()
@@ -283,7 +293,8 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
                             for index in range(len(parameterNames)):
                                 if not parameterNames[index]:
                                     parameterNames[index] = \
-                                        QByteArray("p{0:d}".format(index))
+                                        QByteArray("p{0:d}".format(index)
+                                                   .encode("utf-8"))
                         methNamesSig = \
                             ", ".join(
                                 [bytes(n).decode() for n in parameterNames])
@@ -323,11 +334,12 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
                         itm2.setCheckState(Qt.Unchecked)
             
             self.slotsView.sortByColumn(0, Qt.AscendingOrder)
-        except (AttributeError, ImportError) as err:
+        except (AttributeError, ImportError,
+                xml.etree.ElementTree.ParseError) as err:
             E5MessageBox.critical(
                 self,
-                self.trUtf8("uic error"),
-                self.trUtf8(
+                self.tr("uic error"),
+                self.tr(
                     """<p>There was an error loading the form <b>{0}</b>"""
                     """.</p><p>{1}</p>""").format(self.formFile, str(err)))
         
@@ -381,7 +393,8 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
                         tmplName = os.path.join(
                             getConfig('ericCodeTemplatesDir'),
                             "impl_pyside.py.tmpl")
-                    elif self.project.getProjectType() == "PyQt5":
+                    elif self.project.getProjectType() in [
+                            "PyQt5", "E6Plugin"]:
                         tmplName = os.path.join(
                             getConfig('ericCodeTemplatesDir'),
                             "impl_pyqt5.py.tmpl")
@@ -395,8 +408,8 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
             except IOError as why:
                 E5MessageBox.critical(
                     self,
-                    self.trUtf8("Code Generation"),
-                    self.trUtf8(
+                    self.tr("Code Generation"),
+                    self.tr(
                         """<p>Could not open the code template file"""
                         """ "{0}".</p><p>Reason: {1}</p>""")
                     .format(tmplName, str(why)))
@@ -431,8 +444,8 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
             except IOError as why:
                 E5MessageBox.critical(
                     self,
-                    self.trUtf8("Code Generation"),
-                    self.trUtf8(
+                    self.tr("Code Generation"),
+                    self.tr(
                         """<p>Could not open the source file "{0}".</p>"""
                         """<p>Reason: {1}</p>""")
                     .format(self.srcFile, str(why)))
@@ -510,9 +523,9 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
         except IOError as why:
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Code Generation"),
-                self.trUtf8("""<p>Could not write the source file "{0}".</p>"""
-                            """<p>Reason: {1}</p>""")
+                self.tr("Code Generation"),
+                self.tr("""<p>Could not write the source file "{0}".</p>"""
+                        """<p>Reason: {1}</p>""")
                 .format(self.filenameEdit.text(), str(why)))
             return
         
