@@ -1,17 +1,19 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog for entering project specific debugger settings.
 """
 
+from __future__ import unicode_literals
+
 import os
 import sys
 
-from PyQt4.QtCore import pyqtSlot
-from PyQt4.QtGui import QDialog
+from PyQt5.QtCore import pyqtSlot
+from PyQt5.QtWidgets import QDialog
 
 from E5Gui.E5Completers import E5FileCompleter, E5DirCompleter
 from E5Gui import E5FileDialog
@@ -19,8 +21,9 @@ from E5Gui import E5FileDialog
 from .Ui_DebuggerPropertiesDialog import Ui_DebuggerPropertiesDialog
 
 import Utilities
+import UI.PixmapCache
 
-from eric5config import getConfig
+from eric6config import getConfig
 
 
 class DebuggerPropertiesDialog(QDialog, Ui_DebuggerPropertiesDialog):
@@ -36,11 +39,14 @@ class DebuggerPropertiesDialog(QDialog, Ui_DebuggerPropertiesDialog):
         @param parent parent widget of this dialog (QWidget)
         @param name name of this dialog (string)
         """
-        super().__init__(parent)
+        super(DebuggerPropertiesDialog, self).__init__(parent)
         if name:
             self.setObjectName(name)
         self.setupUi(self)
         
+        self.debugClientButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        self.interpreterButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        
         self.debugClientCompleter = E5FileCompleter(self.debugClientEdit)
         self.interpreterCompleter = E5FileCompleter(self.interpreterEdit)
         self.translationLocalCompleter = E5DirCompleter(
@@ -101,6 +107,9 @@ class DebuggerPropertiesDialog(QDialog, Ui_DebuggerPropertiesDialog):
         self.noEncodingCheckBox.setChecked(
             self.project.debugProperties["NOENCODING"])
         
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
+        
     @pyqtSlot()
     def on_interpreterButton_clicked(self):
         """
@@ -108,7 +117,7 @@ class DebuggerPropertiesDialog(QDialog, Ui_DebuggerPropertiesDialog):
         """
         file = E5FileDialog.getOpenFileName(
             self,
-            self.trUtf8("Select interpreter for Debug Client"),
+            self.tr("Select interpreter for Debug Client"),
             self.interpreterEdit.text(),
             "")
             
@@ -122,10 +131,10 @@ class DebuggerPropertiesDialog(QDialog, Ui_DebuggerPropertiesDialog):
         """
         filters = self.project.dbgFilters[
             self.project.pdata["PROGLANGUAGE"][0]]
-        filters += self.trUtf8("All Files (*)")
+        filters += self.tr("All Files (*)")
         file = E5FileDialog.getOpenFileName(
             self,
-            self.trUtf8("Select Debug Client"),
+            self.tr("Select Debug Client"),
             self.debugClientEdit.text(),
             filters)
             
