@@ -1,16 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to enter lexer associations for the project.
 """
 
+from __future__ import unicode_literals
+
 import os
 
-from PyQt4.QtCore import Qt, pyqtSlot, qVersion
-from PyQt4.QtGui import QHeaderView, QTreeWidgetItem, QDialog
+from PyQt5.QtCore import Qt, pyqtSlot, qVersion
+from PyQt5.QtWidgets import QHeaderView, QTreeWidgetItem, QDialog
 
 from .Ui_LexerAssociationDialog import Ui_LexerAssociationDialog
 
@@ -26,7 +28,7 @@ class LexerAssociationDialog(QDialog, Ui_LexerAssociationDialog):
         @param project reference to the project object
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(LexerAssociationDialog, self).__init__(parent)
         self.setupUi(self)
 
         self.editorLexerList.headerItem().setText(
@@ -43,7 +45,7 @@ class LexerAssociationDialog(QDialog, Ui_LexerAssociationDialog):
         except AttributeError:
             self.extsep = "."
         
-        self.extras = ["-----------", self.trUtf8("Alternative")]
+        self.extras = ["-----------", self.tr("Alternative")]
         
         import QScintilla.Lexers
         languages = [''] + \
@@ -126,7 +128,7 @@ class LexerAssociationDialog(QDialog, Ui_LexerAssociationDialog):
             if lexer.startswith("Pygments|"):
                 pygmentsLexer = lexer.split("|")[1]
                 pygmentsIndex = self.pygmentsLexerCombo.findText(pygmentsLexer)
-                lexer = self.trUtf8("Alternative")
+                lexer = self.tr("Alternative")
             else:
                 pygmentsIndex = 0
             index = self.editorLexerCombo.findText(lexer)
