@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to add a new Python package.
 """
 
-from PyQt4.QtGui import QDialog, QDialogButtonBox
-from PyQt4.QtCore import pyqtSlot
+from __future__ import unicode_literals
+
+from PyQt5.QtWidgets import QDialog, QDialogButtonBox
+from PyQt5.QtCore import pyqtSlot
 
 from .Ui_NewPythonPackageDialog import Ui_NewPythonPackageDialog
 
@@ -25,7 +27,7 @@ class NewPythonPackageDialog(QDialog, Ui_NewPythonPackageDialog):
             (string)
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(NewPythonPackageDialog, self).__init__(parent)
         self.setupUi(self)
         
         self.okButton = self.buttonBox.button(QDialogButtonBox.Ok)
@@ -33,6 +35,9 @@ class NewPythonPackageDialog(QDialog, Ui_NewPythonPackageDialog):
         
         rp = relPath.replace("/", ".").replace("\\", ".")
         self.packageEdit.setText(rp)
+        
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
     
     @pyqtSlot(str)
     def on_packageEdit_textChanged(self, txt):
