@@ -1,17 +1,19 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the browser model.
 """
 
+from __future__ import unicode_literals
+
 import os
 import re
 
-from PyQt4.QtCore import QDir, QModelIndex, pyqtSignal, QFileSystemWatcher, Qt
-from PyQt4.QtGui import QColor
+from PyQt5.QtCore import QDir, QModelIndex, pyqtSignal, QFileSystemWatcher, Qt
+from PyQt5.QtGui import QColor
 
 from UI.BrowserModel import BrowserModel, BrowserItem, BrowserDirectoryItem, \
     BrowserFileItem
@@ -150,6 +152,14 @@ class ProjectBrowserSimpleDirectoryItem(BrowserItem, ProjectBrowserItemMixin):
         """
         return self._dirName
     
+    def name(self):
+        """
+        Public method to return the name of the item.
+        
+        @return name of the item (string)
+        """
+        return self._dirName
+    
     def lessThan(self, other, column, order):
         """
         Public method to check, if the item is less than the other one.
@@ -223,11 +233,11 @@ class ProjectBrowserModel(BrowserModel):
         
         @param parent reference to parent object (Project.Project)
         """
-        super().__init__(parent, nopopulate=True)
+        super(ProjectBrowserModel, self).__init__(parent, nopopulate=True)
         
-        rootData = self.trUtf8("Name")
+        rootData = self.tr("Name")
         self.rootItem = BrowserItem(None, rootData)
-        self.rootItem.itemData.append(self.trUtf8("VCS Status"))
+        self.rootItem.itemData.append(self.tr("VCS Status"))
         
         self.progDir = None
         self.project = parent
@@ -335,7 +345,7 @@ class ProjectBrowserModel(BrowserModel):
                                   QDir.Hidden |
                                   QDir.NoDotAndDotDot)
         else:
-            filter = QDir.Filters(QDir.AllEntries | QDir.NoDotAndDotDot)
+            filter = QDir.Filters(QDir.AllEntries | QDir.NoDot | QDir.NoDotDot)
         entryInfoList = qdir.entryInfoList(filter)
         
         if len(entryInfoList) > 0:
@@ -371,7 +381,7 @@ class ProjectBrowserModel(BrowserModel):
                         self.project.clearStatusMonitorCachedState(
                             f.absoluteFilePath())
                     else:
-                        node.addVcsStatus(self.trUtf8("local"))
+                        node.addVcsStatus(self.tr("local"))
                 self._addItem(node, parentItem)
             if repopulate:
                 self.endInsertRows()
@@ -388,7 +398,8 @@ class ProjectBrowserModel(BrowserModel):
             self.watcher.removePaths(watchedDirs)
         
         self.rootItem.removeChildren()
-        self.reset()
+        self.beginResetModel()
+        self.endResetModel()
         
         # reset the module parser cache
         Utilities.ModuleParser.resetParsedModules()
@@ -444,11 +455,12 @@ class ProjectBrowserModel(BrowserModel):
                             self.project.vcs.canBeCommitted:
                         itm.addVcsStatus(self.project.vcs.vcsName())
                     else:
-                        itm.addVcsStatus(self.trUtf8("local"))
+                        itm.addVcsStatus(self.tr("local"))
                 else:
                     itm.addVcsStatus("")
         self.inRefresh = False
-        self.reset()
+        self.beginResetModel()
+        self.endResetModel()
 
     def findParentItemByName(self, type_, name, dontSplit=False):
         """
@@ -661,7 +673,7 @@ class ProjectBrowserModel(BrowserModel):
                                   QDir.Hidden |
                                   QDir.NoDotAndDotDot)
         else:
-            filter = QDir.Filters(QDir.AllEntries | QDir.NoDotAndDotDot)
+            filter = QDir.Filters(QDir.AllEntries | QDir.NoDot | QDir.NoDotDot)
         
         for itm in self.watchedItems[path]:
             oldCnt = itm.childCount()
@@ -704,7 +716,7 @@ class ProjectBrowserModel(BrowserModel):
                     if state == self.project.vcs.canBeCommitted:
                         node.addVcsStatus(self.project.vcs.vcsName())
                     else:
-                        node.addVcsStatus(self.trUtf8("local"))
+                        node.addVcsStatus(self.tr("local"))
                 self.endInsertRows()
             
             # step 2: check for removed entries
@@ -739,7 +751,7 @@ class ProjectBrowserModel(BrowserModel):
             if state == self.project.vcs.canBeCommitted:
                 item.addVcsStatus(self.project.vcs.vcsName())
             else:
-                item.addVcsStatus(self.trUtf8("local"))
+                item.addVcsStatus(self.tr("local"))
         else:
             item.addVcsStatus("")
     
@@ -757,7 +769,7 @@ class ProjectBrowserModel(BrowserModel):
             if state == self.project.vcs.canBeCommitted:
                 item.setVcsStatus(self.project.vcs.vcsName())
             else:
-                item.setVcsStatus(self.trUtf8("local"))
+                item.setVcsStatus(self.tr("local"))
             if recursive:
                 name = os.path.dirname(name)
                 parentItem = item.parent()
@@ -818,10 +830,10 @@ class ProjectBrowserModel(BrowserModel):
                 self.beginRemoveRows(index, 0, itm.childCount() - 1)
                 itm.removeChildren()
                 self.endRemoveRows()
-                Utilities.ModuleParser.resetParsedModule(
-                    os.path.join(self.project.ppath, name))
-                
-                self.populateItem(itm, True)
+            Utilities.ModuleParser.resetParsedModule(
+                os.path.join(self.project.ppath, name))
+            
+            self.populateItem(itm, True)
     
     def projectPropertiesChanged(self):
         """
@@ -873,6 +885,7 @@ class ProjectBrowserModel(BrowserModel):
                     itemCache[name] = itm
             if itm:
                 itm.setVcsState(state)
+                itm.setVcsStatus(self.project.vcs.vcsName())
                 index1 = self.createIndex(itm.row(), 0, itm)
                 index2 = self.createIndex(
                     itm.row(), self.rootItem.columnCount(), itm)
