@@ -1,12 +1,14 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the browser sort filter proxy model.
 """
 
+from __future__ import unicode_literals
+
 from UI.BrowserSortFilterProxyModel import BrowserSortFilterProxyModel
 from .ProjectBrowserModel import ProjectBrowserSourceType
 
@@ -31,7 +33,7 @@ class ProjectBrowserSortFilterProxyModel(BrowserSortFilterProxyModel):
         
     def filterAcceptsRow(self, source_row, source_parent):
         """
-        Protected method to filter rows.
+        Public method to filter rows.
         
         It implements a filter to suppress the display of non public
         classes, methods and attributes.
@@ -46,7 +48,7 @@ class ProjectBrowserSortFilterProxyModel(BrowserSortFilterProxyModel):
             return False
         sitem = self.sourceModel().item(sindex)
         try:
-            if not self.__filterType in sitem.getProjectTypes():
+            if self.__filterType not in sitem.getProjectTypes():
                 return False
             if self.hideGeneratedForms and \
                self.__filterType == ProjectBrowserSourceType and \
@@ -69,4 +71,4 @@ class ProjectBrowserSortFilterProxyModel(BrowserSortFilterProxyModel):
         hideGeneratedForms = Preferences.getProject("HideGeneratedForms")
         if self.hideGeneratedForms != hideGeneratedForms:
             self.hideGeneratedForms = hideGeneratedForms
-            self.filterChanged()
+            self.invalidateFilter()
