@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,12 +8,18 @@ Module implementing a class used to display the translations part of the
 project.
 """
 
+from __future__ import unicode_literals
+try:
+    str = unicode
+except NameError:
+    pass
+
 import os
 import shutil
 import fnmatch
 
-from PyQt4.QtCore import pyqtSignal, QProcess
-from PyQt4.QtGui import QDialog, QMenu
+from PyQt5.QtCore import PYQT_VERSION, pyqtSignal, QProcess
+from PyQt5.QtWidgets import QDialog, QMenu
 
 from E5Gui import E5MessageBox
 from E5Gui.E5Application import e5App
@@ -65,9 +71,9 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         self.selectedItemsFilter = \
             [ProjectBrowserFileItem, ProjectBrowserSimpleDirectoryItem]
         
-        self.setWindowTitle(self.trUtf8('Translations'))
+        self.setWindowTitle(self.tr('Translations'))
 
-        self.setWhatsThis(self.trUtf8(
+        self.setWhatsThis(self.tr(
             """<b>Project Translations Browser</b>"""
             """<p>This allows to easily see all translations contained in"""
             """ the current project. Several actions can be executed via"""
@@ -107,52 +113,52 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         
         self.menu = QMenu(self)
         if self.project.getProjectType() in \
-                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin",
+                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin", "E6Plugin",
                  "PySide", "PySideC"]:
             act = self.menu.addAction(
-                self.trUtf8('Generate translation'), self.__generateSelected)
+                self.tr('Generate translation'), self.__generateSelected)
             self.tsMenuActions.append(act)
             self.tsprocMenuActions.append(act)
             act = self.menu.addAction(
-                self.trUtf8('Generate translation (with obsolete)'),
+                self.tr('Generate translation (with obsolete)'),
                 self.__generateObsoleteSelected)
             self.tsMenuActions.append(act)
             self.tsprocMenuActions.append(act)
             act = self.menu.addAction(
-                self.trUtf8('Generate all translations'), self.__generateAll)
+                self.tr('Generate all translations'), self.__generateAll)
             self.tsprocMenuActions.append(act)
             act = self.menu.addAction(
-                self.trUtf8('Generate all translations (with obsolete)'),
+                self.tr('Generate all translations (with obsolete)'),
                 self.__generateObsoleteAll)
             self.tsprocMenuActions.append(act)
             self.menu.addSeparator()
             act = self.menu.addAction(
-                self.trUtf8('Open in Qt-Linguist'), self._openItem)
+                self.tr('Open in Qt-Linguist'), self._openItem)
             self.tsMenuActions.append(act)
             act = self.menu.addAction(
-                self.trUtf8('Open in Editor'), self.__openFileInEditor)
+                self.tr('Open in Editor'), self.__openFileInEditor)
             self.tsMenuActions.append(act)
             self.menu.addSeparator()
             act = self.menu.addAction(
-                self.trUtf8('Release translation'), self.__releaseSelected)
+                self.tr('Release translation'), self.__releaseSelected)
             self.tsMenuActions.append(act)
             self.qmprocMenuActions.append(act)
             act = self.menu.addAction(
-                self.trUtf8('Release all translations'), self.__releaseAll)
+                self.tr('Release all translations'), self.__releaseAll)
             self.qmprocMenuActions.append(act)
             self.menu.addSeparator()
             act = self.menu.addAction(
-                self.trUtf8('Preview translation'), self.__TRPreview)
+                self.tr('Preview translation'), self.__TRPreview)
             self.qmMenuActions.append(act)
             act = self.menu.addAction(
-                self.trUtf8('Preview all translations'), self.__TRPreviewAll)
+                self.tr('Preview all translations'), self.__TRPreviewAll)
             self.menu.addSeparator()
         else:
             if self.hooks["extractMessages"] is not None:
                 act = self.menu.addAction(
                     self.hooksMenuEntries.get(
                         "extractMessages",
-                        self.trUtf8('Extract messages')),
+                        self.tr('Extract messages')),
                     self.__extractMessages)
                 self.menuActions.append(act)
                 self.menu.addSeparator()
@@ -160,7 +166,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                 act = self.menu.addAction(
                     self.hooksMenuEntries.get(
                         "generateSelected",
-                        self.trUtf8('Generate translation')),
+                        self.tr('Generate translation')),
                     self.__generateSelected)
                 self.tsMenuActions.append(act)
                 self.tsprocMenuActions.append(act)
@@ -168,7 +174,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                 act = self.menu.addAction(
                     self.hooksMenuEntries.get(
                         "generateSelectedWithObsolete",
-                        self.trUtf8('Generate translation (with obsolete)')),
+                        self.tr('Generate translation (with obsolete)')),
                     self.__generateObsoleteSelected)
                 self.tsMenuActions.append(act)
                 self.tsprocMenuActions.append(act)
@@ -176,14 +182,14 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                 act = self.menu.addAction(
                     self.hooksMenuEntries.get(
                         "generateAll",
-                        self.trUtf8('Generate all translations')),
+                        self.tr('Generate all translations')),
                     self.__generateAll)
                 self.tsprocMenuActions.append(act)
             if self.hooks["generateAllWithObsolete"] is not None:
                 act = self.menu.addAction(
                     self.hooksMenuEntries.get(
                         "generateAllWithObsolete",
-                        self.trUtf8(
+                        self.tr(
                             'Generate all translations (with obsolete)')),
                     self.__generateObsoleteAll)
                 self.tsprocMenuActions.append(act)
@@ -191,18 +197,18 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             if self.hooks["open"] is not None:
                 act = self.menu.addAction(
                     self.hooksMenuEntries.get(
-                        "open", self.trUtf8('Open')),
+                        "open", self.tr('Open')),
                     self._openItem)
                 self.tsMenuActions.append(act)
             act = self.menu.addAction(
-                self.trUtf8('Open in Editor'), self.__openFileInEditor)
+                self.tr('Open in Editor'), self.__openFileInEditor)
             self.tsMenuActions.append(act)
             self.menu.addSeparator()
             if self.hooks["releaseSelected"] is not None:
                 act = self.menu.addAction(
                     self.hooksMenuEntries.get(
                         "releaseSelected",
-                        self.trUtf8('Release translation')),
+                        self.tr('Release translation')),
                     self.__releaseSelected)
                 self.tsMenuActions.append(act)
                 self.qmprocMenuActions.append(act)
@@ -210,68 +216,68 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                 act = self.menu.addAction(
                     self.hooksMenuEntries.get(
                         "releaseAll",
-                        self.trUtf8('Release all translations')),
+                        self.tr('Release all translations')),
                     self.__releaseAll)
                 self.qmprocMenuActions.append(act)
             self.menu.addSeparator()
         act = self.menu.addAction(
-            self.trUtf8('Remove from project'), self.__removeLanguageFile)
+            self.tr('Remove from project'), self.__removeLanguageFile)
         self.menuActions.append(act)
         act = self.menu.addAction(
-            self.trUtf8('Delete'), self.__deleteLanguageFile)
+            self.tr('Delete'), self.__deleteLanguageFile)
         self.menuActions.append(act)
         self.menu.addSeparator()
         self.__addTranslationAct = self.menu.addAction(
-            self.trUtf8('Add translation...'), self.project.addLanguage)
+            self.tr('Add translation...'), self.project.addLanguage)
         self.menu.addAction(
-            self.trUtf8('Add translation files...'),
+            self.tr('Add translation files...'),
             self.__addTranslationFiles)
         self.menu.addSeparator()
         self.menu.addAction(
-            self.trUtf8('Copy Path to Clipboard'), self._copyToClipboard)
+            self.tr('Copy Path to Clipboard'), self._copyToClipboard)
         self.menu.addSeparator()
-        self.menu.addAction(self.trUtf8('Configure...'), self._configure)
+        self.menu.addAction(self.tr('Configure...'), self._configure)
         
         self.backMenu = QMenu(self)
         if self.project.getProjectType() in \
-                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin",
+                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin", "E6Plugin",
                  "PySide", "PySideC"]:
             act = self.backMenu.addAction(
-                self.trUtf8('Generate all translations'),
+                self.tr('Generate all translations'),
                 self.__generateAll)
             self.tsprocBackMenuActions.append(act)
             act = self.backMenu.addAction(
-                self.trUtf8('Generate all translations (with obsolete)'),
+                self.tr('Generate all translations (with obsolete)'),
                 self.__generateObsoleteAll)
             self.tsprocBackMenuActions.append(act)
             act = self.backMenu.addAction(
-                self.trUtf8('Release all translations'),
+                self.tr('Release all translations'),
                 self.__releaseAll)
             self.qmprocBackMenuActions.append(act)
             self.backMenu.addSeparator()
             act = self.backMenu.addAction(
-                self.trUtf8('Preview all translations'),
+                self.tr('Preview all translations'),
                 self.__TRPreview)
         else:
             if self.hooks["extractMessages"] is not None:
                 act = self.backMenu.addAction(
                     self.hooksMenuEntries.get(
                         "extractMessages",
-                        self.trUtf8('Extract messages')),
+                        self.tr('Extract messages')),
                     self.__extractMessages)
                 self.backMenu.addSeparator()
             if self.hooks["generateAll"] is not None:
                 act = self.backMenu.addAction(
                     self.hooksMenuEntries.get(
                         "generateAll",
-                        self.trUtf8('Generate all translations')),
+                        self.tr('Generate all translations')),
                     self.__generateAll)
                 self.tsprocBackMenuActions.append(act)
             if self.hooks["generateAllWithObsolete"] is not None:
                 act = self.backMenu.addAction(
                     self.hooksMenuEntries.get(
                         "generateAllWithObsolete",
-                        self.trUtf8(
+                        self.tr(
                             'Generate all translations (with obsolete)')),
                     self.__generateObsoleteAll)
                 self.tsprocBackMenuActions.append(act)
@@ -279,56 +285,56 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                 act = self.backMenu.addAction(
                     self.hooksMenuEntries.get(
                         "releaseAll",
-                        self.trUtf8('Release all translations')),
+                        self.tr('Release all translations')),
                     self.__releaseAll)
                 self.qmprocBackMenuActions.append(act)
         self.backMenu.addSeparator()
         self.__addTranslationBackAct = self.backMenu.addAction(
-            self.trUtf8('Add translation...'), self.project.addLanguage)
+            self.tr('Add translation...'), self.project.addLanguage)
         self.backMenu.addAction(
-            self.trUtf8('Add translation files...'),
+            self.tr('Add translation files...'),
             self.__addTranslationFiles)
         self.backMenu.addSeparator()
-        self.backMenu.addAction(self.trUtf8('Configure...'), self._configure)
+        self.backMenu.addAction(self.tr('Configure...'), self._configure)
         self.backMenu.setEnabled(False)
 
         # create the menu for multiple selected files
         self.multiMenu = QMenu(self)
         if self.project.getProjectType() in \
-                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin",
+                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin", "E6Plugin",
                  "PySide", "PySideC"]:
             act = self.multiMenu.addAction(
-                self.trUtf8('Generate translations'),
+                self.tr('Generate translations'),
                 self.__generateSelected)
             self.tsMultiMenuActions.append(act)
             self.tsprocMultiMenuActions.append(act)
             act = self.multiMenu.addAction(
-                self.trUtf8('Generate translations (with obsolete)'),
+                self.tr('Generate translations (with obsolete)'),
                 self.__generateObsoleteSelected)
             self.tsMultiMenuActions.append(act)
             self.tsprocMultiMenuActions.append(act)
             self.multiMenu.addSeparator()
             act = self.multiMenu.addAction(
-                self.trUtf8('Open in Qt-Linguist'), self._openItem)
+                self.tr('Open in Qt-Linguist'), self._openItem)
             self.tsMultiMenuActions.append(act)
             act = self.multiMenu.addAction(
-                self.trUtf8('Open in Editor'), self.__openFileInEditor)
+                self.tr('Open in Editor'), self.__openFileInEditor)
             self.tsMultiMenuActions.append(act)
             self.multiMenu.addSeparator()
             act = self.multiMenu.addAction(
-                self.trUtf8('Release translations'), self.__releaseSelected)
+                self.tr('Release translations'), self.__releaseSelected)
             self.tsMultiMenuActions.append(act)
             self.qmprocMultiMenuActions.append(act)
             self.multiMenu.addSeparator()
             act = self.multiMenu.addAction(
-                self.trUtf8('Preview translations'), self.__TRPreview)
+                self.tr('Preview translations'), self.__TRPreview)
             self.qmMultiMenuActions.append(act)
         else:
             if self.hooks["extractMessages"] is not None:
                 act = self.multiMenu.addAction(
                     self.hooksMenuEntries.get(
                         "extractMessages",
-                        self.trUtf8('Extract messages')),
+                        self.tr('Extract messages')),
                     self.__extractMessages)
                 self.multiMenuActions.append(act)
                 self.multiMenu.addSeparator()
@@ -336,7 +342,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                 act = self.multiMenu.addAction(
                     self.hooksMenuEntries.get(
                         "generateSelected",
-                        self.trUtf8('Generate translations')),
+                        self.tr('Generate translations')),
                     self.__generateSelected)
                 self.tsMultiMenuActions.append(act)
                 self.tsprocMultiMenuActions.append(act)
@@ -344,7 +350,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                 act = self.multiMenu.addAction(
                     self.hooksMenuEntries.get(
                         "generateSelectedWithObsolete",
-                        self.trUtf8('Generate translations (with obsolete)')),
+                        self.tr('Generate translations (with obsolete)')),
                     self.__generateObsoleteSelected)
                 self.tsMultiMenuActions.append(act)
                 self.tsprocMultiMenuActions.append(act)
@@ -352,57 +358,57 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             if self.hooks["open"] is not None:
                 act = self.multiMenu.addAction(
                     self.hooksMenuEntries.get(
-                        "open", self.trUtf8('Open')),
+                        "open", self.tr('Open')),
                     self._openItem)
                 self.tsMultiMenuActions.append(act)
             act = self.multiMenu.addAction(
-                self.trUtf8('Open in Editor'), self.__openFileInEditor)
+                self.tr('Open in Editor'), self.__openFileInEditor)
             self.tsMultiMenuActions.append(act)
             self.multiMenu.addSeparator()
             if self.hooks["releaseSelected"] is not None:
                 act = self.multiMenu.addAction(
                     self.hooksMenuEntries.get(
                         "releaseSelected",
-                        self.trUtf8('Release translations')),
+                        self.tr('Release translations')),
                     self.__releaseSelected)
                 self.tsMultiMenuActions.append(act)
                 self.qmprocMultiMenuActions.append(act)
         self.multiMenu.addSeparator()
         act = self.multiMenu.addAction(
-            self.trUtf8('Remove from project'), self.__removeLanguageFile)
+            self.tr('Remove from project'), self.__removeLanguageFile)
         self.multiMenuActions.append(act)
         act = self.multiMenu.addAction(
-            self.trUtf8('Delete'), self.__deleteLanguageFile)
+            self.tr('Delete'), self.__deleteLanguageFile)
         self.multiMenuActions.append(act)
         self.multiMenu.addSeparator()
-        self.multiMenu.addAction(self.trUtf8('Configure...'), self._configure)
+        self.multiMenu.addAction(self.tr('Configure...'), self._configure)
 
         self.dirMenu = QMenu(self)
         if self.project.getProjectType() in \
-                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin",
+                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin", "E6Plugin",
                  "PySide", "PySideC"]:
             act = self.dirMenu.addAction(
-                self.trUtf8('Generate all translations'),
+                self.tr('Generate all translations'),
                 self.__generateAll)
             self.tsprocDirMenuActions.append(act)
             act = self.dirMenu.addAction(
-                self.trUtf8('Generate all translations (with obsolete)'),
+                self.tr('Generate all translations (with obsolete)'),
                 self.__generateObsoleteAll)
             self.tsprocDirMenuActions.append(act)
             act = self.dirMenu.addAction(
-                self.trUtf8('Release all translations'),
+                self.tr('Release all translations'),
                 self.__releaseAll)
             self.qmprocDirMenuActions.append(act)
             self.dirMenu.addSeparator()
             act = self.dirMenu.addAction(
-                self.trUtf8('Preview all translations'),
+                self.tr('Preview all translations'),
                 self.__TRPreview)
         else:
             if self.hooks["extractMessages"] is not None:
                 act = self.dirMenu.addAction(
                     self.hooksMenuEntries.get(
                         "extractMessages",
-                        self.trUtf8('Extract messages')),
+                        self.tr('Extract messages')),
                     self.__extractMessages)
                 self.dirMenuActions.append(act)
                 self.dirMenu.addSeparator()
@@ -410,14 +416,14 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                 act = self.dirMenu.addAction(
                     self.hooksMenuEntries.get(
                         "generateAll",
-                        self.trUtf8('Generate all translations')),
+                        self.tr('Generate all translations')),
                     self.__generateAll)
                 self.tsprocDirMenuActions.append(act)
             if self.hooks["generateAllWithObsolete"] is not None:
                 act = self.dirMenu.addAction(
                     self.hooksMenuEntries.get(
                         "generateAllWithObsolete",
-                        self.trUtf8(
+                        self.tr(
                             'Generate all translations (with obsolete)')),
                     self.__generateObsoleteAll)
                 self.tsprocDirMenuActions.append(act)
@@ -425,24 +431,24 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                 act = self.dirMenu.addAction(
                     self.hooksMenuEntries.get(
                         "releaseAll",
-                        self.trUtf8('Release all translations')),
+                        self.tr('Release all translations')),
                     self.__releaseAll)
                 self.qmprocDirMenuActions.append(act)
         self.dirMenu.addSeparator()
         act = self.dirMenu.addAction(
-            self.trUtf8('Delete'), self._deleteDirectory)
+            self.tr('Delete'), self._deleteDirectory)
         self.dirMenuActions.append(act)
         self.dirMenu.addSeparator()
         self.__addTranslationDirAct = self.dirMenu.addAction(
-            self.trUtf8('Add translation...'), self.project.addLanguage)
+            self.tr('Add translation...'), self.project.addLanguage)
         self.dirMenu.addAction(
-            self.trUtf8('Add translation files...'),
+            self.tr('Add translation files...'),
             self.__addTranslationFiles)
         self.dirMenu.addSeparator()
         self.dirMenu.addAction(
-            self.trUtf8('Copy Path to Clipboard'), self._copyToClipboard)
+            self.tr('Copy Path to Clipboard'), self._copyToClipboard)
         self.dirMenu.addSeparator()
-        self.dirMenu.addAction(self.trUtf8('Configure...'), self._configure)
+        self.dirMenu.addAction(self.tr('Configure...'), self._configure)
         
         self.dirMultiMenu = None
         
@@ -497,7 +503,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         Private slot called by the menu aboutToShow signal.
         """
         if self.project.getProjectType() in \
-                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin",
+                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin", "E6Plugin",
                  "PySide", "PySideC"]:
             tsFiles = 0
             qmFiles = 0
@@ -539,7 +545,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         Private slot called by the multiMenu aboutToShow signal.
         """
         if self.project.getProjectType() in \
-                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin",
+                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin", "E6Plugin",
                  "PySide", "PySideC"]:
             tsFiles = 0
             qmFiles = 0
@@ -579,7 +585,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         Private slot called by the dirMenu aboutToShow signal.
         """
         if self.project.getProjectType() in \
-                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin",
+                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin", "E6Plugin",
                  "PySide", "PySideC"]:
             if self.pylupdateProcRunning:
                 for act in self.tsprocDirMenuActions:
@@ -599,7 +605,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         Private slot called by the backMenu aboutToShow signal.
         """
         if self.project.getProjectType() in \
-                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin",
+                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin", "E6Plugin",
                  "PySide", "PySideC"]:
             if self.pylupdateProcRunning:
                 for act in self.tsprocBackMenuActions:
@@ -675,9 +681,9 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             DeleteFilesConfirmationDialog
         dlg = DeleteFilesConfirmationDialog(
             self.parent(),
-            self.trUtf8("Delete translation files"),
-            self.trUtf8("Do you really want to delete these translation files"
-                        " from the project?"),
+            self.tr("Delete translation files"),
+            self.tr("Do you really want to delete these translation files"
+                    " from the project?"),
             translationFiles)
         
         if dlg.exec_() == QDialog.Accepted:
@@ -778,8 +784,8 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         if not langs:
             E5MessageBox.warning(
                 self,
-                self.trUtf8("Write temporary project file"),
-                self.trUtf8("""No translation files (*.ts) selected."""))
+                self.tr("Write temporary project file"),
+                self.tr("""No translation files (*.ts) selected."""))
             return False
         
         # create a prefix relative from the *.ts down to the project path
@@ -804,6 +810,9 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             
             dir, name = os.path.split(pfile)
             outFile = os.path.join(dir, os.path.dirname(langs[0]), name)
+            outDir = os.path.dirname(outFile)
+            if not os.path.exists(outDir):
+                os.makedirs(outDir)
             try:
                 pf = open(outFile, "w", encoding="utf-8")
                 for key, list in sections:
@@ -827,14 +836,14 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             except IOError:
                 E5MessageBox.critical(
                     self,
-                    self.trUtf8("Write temporary project file"),
-                    self.trUtf8(
+                    self.tr("Write temporary project file"),
+                    self.tr(
                         "<p>The temporary project file <b>{0}</b> could not"
                         " be written.</p>").format(outFile))
         
         if len(self.__tmpProjects) == 0:
             return False
-        
+            
         return True
     
     def __readStdoutLupdate(self):
@@ -936,24 +945,28 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             if ui.notificationsEnabled():
                 ui.showNotification(
                     UI.PixmapCache.getPixmap("linguist48.png"),
-                    self.trUtf8("Translation file generation"),
-                    self.trUtf8(
+                    self.tr("Translation file generation"),
+                    self.tr(
                         "The generation of the translation files (*.ts)"
                         " was successful."))
             else:
                 E5MessageBox.information(
                     self,
-                    self.trUtf8("Translation file generation"),
-                    self.trUtf8(
+                    self.tr("Translation file generation"),
+                    self.tr(
                         "The generation of the translation files (*.ts)"
                         " was successful."))
         else:
+            if exitStatus == QProcess.CrashExit:
+                info = self.tr(" The process has crashed.")
+            else:
+                info = ""
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Translation file generation"),
-                self.trUtf8(
+                self.tr("Translation file generation"),
+                self.tr(
                     "The generation of the translation files (*.ts) has"
-                    " failed."))
+                    " failed.{0}").format(info))
         
         proc = self.sender()
         for index in range(len(self.__pylupdateProcesses)):
@@ -1029,6 +1042,13 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             self.pylupdate = 'pylupdate5'
             if Utilities.isWindowsPlatform():
                 self.pylupdate = self.pylupdate + '.exe'
+        elif self.project.getProjectType() in ["E6Plugin"]:
+            if PYQT_VERSION < 0x050000:
+                self.pylupdate = 'pylupdate4'
+            else:
+                self.pylupdate = 'pylupdate5'
+            if Utilities.isWindowsPlatform():
+                self.pylupdate = self.pylupdate + '.exe'
         elif self.project.getProjectType() in ["PySide", "PySideC"]:
             self.pylupdate = Utilities.generatePySideToolPath('pyside-lupdate')
         else:
@@ -1058,12 +1078,11 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             else:
                 E5MessageBox.critical(
                     self,
-                    self.trUtf8('Process Generation Error'),
-                    self.trUtf8(
+                    self.tr('Process Generation Error'),
+                    self.tr(
                         'Could not start {0}.<br>'
                         'Ensure that it is in the search path.'
                     ).format(self.pylupdate))
-                
                 # cleanup
                 try:
                     self.__tmpProjects.remove(tempProjectFile)
@@ -1121,15 +1140,15 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             if ui.notificationsEnabled():
                 ui.showNotification(
                     UI.PixmapCache.getPixmap("linguist48.png"),
-                    self.trUtf8("Translation file release"),
-                    self.trUtf8("The release of the translation files (*.qm)"
-                                " was successful."))
+                    self.tr("Translation file release"),
+                    self.tr("The release of the translation files (*.qm)"
+                            " was successful."))
             else:
                 E5MessageBox.information(
                     self,
-                    self.trUtf8("Translation file release"),
-                    self.trUtf8("The release of the translation files (*.qm)"
-                                " was successful."))
+                    self.tr("Translation file release"),
+                    self.tr("The release of the translation files (*.qm)"
+                            " was successful."))
             if self.project.pdata["TRANSLATIONSBINPATH"] and \
                     self.project.pdata["TRANSLATIONSBINPATH"][0]:
                 target = os.path.join(
@@ -1144,8 +1163,8 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         else:
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Translation file release"),
-                self.trUtf8(
+                self.tr("Translation file release"),
+                self.tr(
                     "The release of the translation files (*.qm) has failed."))
         
         proc = self.sender()
@@ -1199,7 +1218,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             return
         
         if self.project.getProjectType() in \
-                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin",
+                ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E4Plugin", "E6Plugin",
                  "PySide", "PySideC"]:
             lrelease = os.path.join(
                 Utilities.getQtBinariesPath(),
@@ -1230,8 +1249,8 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             else:
                 E5MessageBox.critical(
                     self,
-                    self.trUtf8('Process Generation Error'),
-                    self.trUtf8(
+                    self.tr('Process Generation Error'),
+                    self.tr(
                         '<p>Could not start lrelease.<br>'
                         'Ensure that it is available as <b>{0}</b>.</p>'
                     ).format(lrelease))
