@@ -1,16 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the project properties dialog.
 """
 
+from __future__ import unicode_literals
+
 import os
 
-from PyQt4.QtCore import QDir, pyqtSlot
-from PyQt4.QtGui import QDialog, QDialogButtonBox
+from PyQt5.QtCore import QDir, pyqtSlot
+from PyQt5.QtWidgets import QDialog, QDialogButtonBox
 
 from E5Gui.E5Application import e5App
 from E5Gui.E5Completers import E5FileCompleter, E5DirCompleter
@@ -20,6 +22,7 @@ from .Ui_PropertiesDialog import Ui_PropertiesDialog
 
 import Utilities
 import Preferences
+import UI.PixmapCache
 
 
 class PropertiesDialog(QDialog, Ui_PropertiesDialog):
@@ -35,11 +38,14 @@ class PropertiesDialog(QDialog, Ui_PropertiesDialog):
         @param parent parent widget of this dialog (QWidget)
         @param name name of this dialog (string)
         """
-        super().__init__(parent)
+        super(PropertiesDialog, self).__init__(parent)
         if name:
             self.setObjectName(name)
         self.setupUi(self)
         
+        self.dirButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        self.mainscriptButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        
         self.project = project
         self.newProject = new
         self.transPropertiesDlg = None
@@ -113,20 +119,20 @@ class PropertiesDialog(QDialog, Ui_PropertiesDialog):
                 except KeyError:
                     vcsSystemDisplay = "None"
                 self.vcsLabel.setText(
-                    self.trUtf8(
+                    self.tr(
                         "The project is version controlled by <b>{0}</b>.")
                     .format(vcsSystemDisplay))
                 self.vcsInfoButton.show()
             else:
                 self.vcsLabel.setText(
-                    self.trUtf8("The project is not version controlled."))
+                    self.tr("The project is not version controlled."))
                 self.vcsInfoButton.hide()
             self.vcsCheckBox.hide()
         else:
             self.languageComboBox.setCurrentIndex(
                 self.languageComboBox.findText("Python3"))
             self.projectTypeComboBox.setCurrentIndex(
-                self.projectTypeComboBox.findData("Qt4"))
+                self.projectTypeComboBox.findData("PyQt5"))
             self.dirEdit.setText(self.__initPaths[0])
             self.versionEdit.setText('0.1')
             self.vcsLabel.hide()
@@ -136,7 +142,7 @@ class PropertiesDialog(QDialog, Ui_PropertiesDialog):
         
         self.buttonBox.button(QDialogButtonBox.Ok).setEnabled(
             bool(self.dirEdit.text()) and
-            Utilities.fromNativeSeparators(self.dirEdit.text()) not in 
+            Utilities.fromNativeSeparators(self.dirEdit.text()) not in
             self.__initPaths)
     
     @pyqtSlot(str)
@@ -154,8 +160,10 @@ class PropertiesDialog(QDialog, Ui_PropertiesDialog):
             self.projectTypeComboBox.addItem(
                 projectTypes[projectType], projectType)
         
-        self.projectTypeComboBox.setCurrentIndex(
-            self.projectTypeComboBox.findData(curProjectType))
+        index = self.projectTypeComboBox.findData(curProjectType)
+        if index == -1:
+            index = 0
+        self.projectTypeComboBox.setCurrentIndex(index)
     
     @pyqtSlot(str)
     def on_dirEdit_textChanged(self, txt):
@@ -175,7 +183,7 @@ class PropertiesDialog(QDialog, Ui_PropertiesDialog):
         """
         directory = E5FileDialog.getExistingDirectory(
             self,
-            self.trUtf8("Select project directory"),
+            self.tr("Select project directory"),
             self.dirEdit.text(),
             E5FileDialog.Options(E5FileDialog.ShowDirsOnly))
         
@@ -224,11 +232,11 @@ class PropertiesDialog(QDialog, Ui_PropertiesDialog):
         for pattern, filetype in list(self.project.pdata["FILETYPES"].items()):
             if filetype == "SOURCES":
                 patterns.append(pattern)
-        filters = self.trUtf8("Source Files ({0});;All Files (*)")\
+        filters = self.tr("Source Files ({0});;All Files (*)")\
             .format(" ".join(patterns))
         fn = E5FileDialog.getOpenFileName(
             self,
-            self.trUtf8("Select main script file"),
+            self.tr("Select main script file"),
             dir,
             filters)
         
