@@ -1,16 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Translations Properties dialog.
 """
 
+from __future__ import unicode_literals
+
 import os
 
-from PyQt4.QtCore import pyqtSlot
-from PyQt4.QtGui import QListWidgetItem, QDialog, QDialogButtonBox
+from PyQt5.QtCore import pyqtSlot
+from PyQt5.QtWidgets import QListWidgetItem, QDialog, QDialogButtonBox
 
 from E5Gui.E5Completers import E5FileCompleter, E5DirCompleter
 from E5Gui import E5FileDialog
@@ -18,6 +20,7 @@ from E5Gui import E5FileDialog
 from .Ui_TranslationPropertiesDialog import Ui_TranslationPropertiesDialog
 
 import Utilities
+import UI.PixmapCache
 
 
 class TranslationPropertiesDialog(QDialog, Ui_TranslationPropertiesDialog):
@@ -32,9 +35,12 @@ class TranslationPropertiesDialog(QDialog, Ui_TranslationPropertiesDialog):
         @param new flag indicating the generation of a new project
         @param parent parent widget of this dialog (QWidget)
         """
-        super().__init__(parent)
+        super(TranslationPropertiesDialog, self).__init__(parent)
         self.setupUi(self)
         
+        self.transBinPathButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        self.transPatternButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        
         self.project = project
         self.parent = parent
         
@@ -57,11 +63,11 @@ class TranslationPropertiesDialog(QDialog, Ui_TranslationPropertiesDialog):
         for pattern, filetype in list(self.project.pdata["FILETYPES"].items()):
             if filetype in patterns:
                 patterns[filetype].append(pattern)
-        self.filters = self.trUtf8("Source Files ({0});;")\
+        self.filters = self.tr("Source Files ({0});;")\
             .format(" ".join(patterns["SOURCES"]))
-        self.filters += self.trUtf8("Forms Files ({0});;")\
+        self.filters += self.tr("Forms Files ({0});;")\
             .format(" ".join(patterns["FORMS"]))
-        self.filters += self.trUtf8("All Files (*)")
+        self.filters += self.tr("All Files (*)")
         
     def initDialog(self):
         """
@@ -96,7 +102,7 @@ class TranslationPropertiesDialog(QDialog, Ui_TranslationPropertiesDialog):
                 os.path.join(self.project.ppath, tp))
         tsfile = E5FileDialog.getOpenFileName(
             self,
-            self.trUtf8("Select translation file"),
+            self.tr("Select translation file"),
             tp,
             "")
         
@@ -125,7 +131,7 @@ class TranslationPropertiesDialog(QDialog, Ui_TranslationPropertiesDialog):
                 os.path.join(self.project.ppath, tbp))
         directory = E5FileDialog.getExistingDirectory(
             self,
-            self.trUtf8("Select directory for binary translations"),
+            self.tr("Select directory for binary translations"),
             tbp)
         
         if directory:
@@ -168,7 +174,7 @@ class TranslationPropertiesDialog(QDialog, Ui_TranslationPropertiesDialog):
         """
         texcept = E5FileDialog.getOpenFileName(
             self,
-            self.trUtf8("Exempt file from translation"),
+            self.tr("Exempt file from translation"),
             self.project.ppath,
             self.filters)
         if texcept:
@@ -181,7 +187,7 @@ class TranslationPropertiesDialog(QDialog, Ui_TranslationPropertiesDialog):
         """
         texcept = E5FileDialog.getExistingDirectory(
             self,
-            self.trUtf8("Exempt directory from translation"),
+            self.tr("Exempt directory from translation"),
             self.project.ppath,
             E5FileDialog.Options(E5FileDialog.ShowDirsOnly))
         if texcept:
