@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the user specific project properties dialog.
 """
 
-from PyQt4.QtGui import QDialog
+from __future__ import unicode_literals
+
+from PyQt5.QtWidgets import QDialog
 
 from E5Gui.E5Application import e5App
 
@@ -28,7 +30,7 @@ class UserPropertiesDialog(QDialog, Ui_UserPropertiesDialog):
         @param parent parent widget of this dialog (QWidget)
         @param name name of this dialog (string)
         """
-        super().__init__(parent)
+        super(UserPropertiesDialog, self).__init__(parent)
         if name:
             self.setObjectName(name)
         self.setupUi(self)
@@ -70,6 +72,9 @@ class UserPropertiesDialog(QDialog, Ui_UserPropertiesDialog):
             if index == -1:
                 index = 0
             self.vcsInterfaceCombo.setCurrentIndex(index)
+        
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
 
     def storeData(self):
         """
