@@ -1,21 +1,24 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the UI to the pyunit package.
 """
 
+from __future__ import unicode_literals
+
 import unittest
 import sys
 import time
 import re
 import os
 
-from PyQt4.QtCore import pyqtSignal, QEvent, Qt, pyqtSlot
-from PyQt4.QtGui import QWidget, QColor, QDialog, QApplication, \
-    QDialogButtonBox, QListWidgetItem
+from PyQt5.QtCore import pyqtSignal, QEvent, Qt, pyqtSlot
+from PyQt5.QtGui import QColor
+from PyQt5.QtWidgets import QWidget, QDialog, QApplication, QDialogButtonBox, \
+    QListWidgetItem
 
 from E5Gui.E5Application import e5App
 from E5Gui.E5Completers import E5FileCompleter
@@ -48,37 +51,39 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         
         @param prog filename of the program to open
         @param dbs reference to the debug server object. It is an indication
-            whether we were called from within the eric5 IDE
+            whether we were called from within the eric6 IDE
         @param ui reference to the UI object
         @param fromEric flag indicating an instantiation from within the
             eric IDE (boolean)
         @param parent parent widget of this dialog (QWidget)
         @param name name of this dialog (string)
         """
-        super().__init__(parent)
+        super(UnittestDialog, self).__init__(parent)
         if name:
             self.setObjectName(name)
         self.setupUi(self)
         
+        self.fileDialogButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        
         self.startButton = self.buttonBox.addButton(
-            self.trUtf8("Start"), QDialogButtonBox.ActionRole)
-        self.startButton.setToolTip(self.trUtf8(
+            self.tr("Start"), QDialogButtonBox.ActionRole)
+        self.startButton.setToolTip(self.tr(
             "Start the selected testsuite"))
-        self.startButton.setWhatsThis(self.trUtf8(
+        self.startButton.setWhatsThis(self.tr(
             """<b>Start Test</b>"""
             """<p>This button starts the selected testsuite.</p>"""))
         self.startFailedButton = self.buttonBox.addButton(
-            self.trUtf8("Rerun Failed"), QDialogButtonBox.ActionRole)
+            self.tr("Rerun Failed"), QDialogButtonBox.ActionRole)
         self.startFailedButton.setToolTip(
-            self.trUtf8("Reruns failed tests of the selected testsuite"))
-        self.startFailedButton.setWhatsThis(self.trUtf8(
+            self.tr("Reruns failed tests of the selected testsuite"))
+        self.startFailedButton.setWhatsThis(self.tr(
             """<b>Rerun Failed</b>"""
             """<p>This button reruns all failed tests of the selected"""
             """ testsuite.</p>"""))
         self.stopButton = self.buttonBox.addButton(
-            self.trUtf8("Stop"), QDialogButtonBox.ActionRole)
-        self.stopButton.setToolTip(self.trUtf8("Stop the running unittest"))
-        self.stopButton.setWhatsThis(self.trUtf8(
+            self.tr("Stop"), QDialogButtonBox.ActionRole)
+        self.stopButton.setToolTip(self.tr("Stop the running unittest"))
+        self.stopButton.setWhatsThis(self.tr(
             """<b>Stop Test</b>"""
             """<p>This button stops a running unittest.</p>"""))
         self.stopButton.setEnabled(False)
@@ -92,7 +97,7 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
             self.windowFlags() | Qt.WindowFlags(
                 Qt.WindowContextHelpButtonHint))
         self.setWindowIcon(UI.PixmapCache.getIcon("eric.png"))
-        self.setWindowTitle(self.trUtf8("Unittest"))
+        self.setWindowTitle(self.tr("Unittest"))
         if dbs:
             self.ui = ui
         else:
@@ -112,13 +117,13 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
             self.insertProg(prog)
         
         self.rxPatterns = [
-            self.trUtf8("^Failure: "),
-            self.trUtf8("^Error: "),
+            self.tr("^Failure: "),
+            self.tr("^Error: "),
         ]
         
         self.__failedTests = []
         
-        # now connect the debug server signals if called from the eric5 IDE
+        # now connect the debug server signals if called from the eric6 IDE
         if self.dbs:
             self.dbs.utPrepared.connect(self.__UTPrepared)
             self.dbs.utFinished.connect(self.__setStoppedMode)
@@ -191,11 +196,11 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
             py3Extensions = \
                 ' '.join(["*{0}".format(ext)
                           for ext in self.dbs.getExtensions('Python3')])
-            filter = self.trUtf8(
+            filter = self.tr(
                 "Python3 Files ({1});;Python2 Files ({0});;All Files (*)")\
                 .format(py2Extensions, py3Extensions)
         else:
-            filter = self.trUtf8("Python Files (*.py);;All Files (*)")
+            filter = self.tr("Python Files (*.py);;All Files (*)")
         prog = E5FileDialog.getOpenFileName(
             self,
             "",
@@ -245,7 +250,7 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
     @pyqtSlot()
     def on_startButton_clicked(self, failedOnly=False):
         """
-        Public slot to start the test.
+        Private slot to start the test.
         
         @keyparam failedOnly flag indicating to run only failed tests (boolean)
         """
@@ -256,13 +261,13 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         if not prog:
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Unittest"),
-                self.trUtf8("You must enter a test suite file."))
+                self.tr("Unittest"),
+                self.tr("You must enter a test suite file."))
             return
         
         # prepend the selected file to the testsuite combobox
         self.insertProg(prog)
-        self.sbLabel.setText(self.trUtf8("Preparing Testsuite"))
+        self.sbLabel.setText(self.tr("Preparing Testsuite"))
         QApplication.processEvents()
         
         testFunctionName = self.testComboBox.currentText()
@@ -275,7 +280,7 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         self.testName = os.path.splitext(os.path.basename(prog))[0]
         
         if self.dbs and not self.localCheckBox.isChecked():
-            # we are cooperating with the eric5 IDE
+            # we are cooperating with the eric6 IDE
             project = e5App().getObject("Project")
             if project.isOpen() and project.isProjectSource(prog):
                 mainScript = project.getMainScript(True)
@@ -331,8 +336,8 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
                 exc_type, exc_value, exc_tb = sys.exc_info()
                 E5MessageBox.critical(
                     self,
-                    self.trUtf8("Unittest"),
-                    self.trUtf8(
+                    self.tr("Unittest"),
+                    self.tr(
                         "<p>Unable to run test <b>{0}</b>.<br>"
                         "{1}<br>{2}</p>")
                     .format(self.testName, str(exc_type),
@@ -342,7 +347,7 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
             # now set up the coverage stuff
             if self.coverageCheckBox.isChecked():
                 if self.dbs:
-                    # we are cooperating with the eric5 IDE
+                    # we are cooperating with the eric6 IDE
                     project = e5App().getObject("Project")
                     if project.isOpen() and project.isProjectSource(prog):
                         mainScript = project.getMainScript(True)
@@ -390,8 +395,8 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         if nrTests == 0:
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Unittest"),
-                self.trUtf8(
+                self.tr("Unittest"),
+                self.tr(
                     "<p>Unable to run test <b>{0}</b>.<br>{1}<br>{2}</p>")
                 .format(self.testName, exc_type, exc_value))
             return
@@ -457,7 +462,7 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         self.stopButton.setEnabled(True)
         self.startButton.setEnabled(False)
         self.stopButton.setDefault(True)
-        self.sbLabel.setText(self.trUtf8("Running"))
+        self.sbLabel.setText(self.tr("Running"))
         self.progressLed.on()
         QApplication.processEvents()
         
@@ -481,11 +486,13 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
             self.startFailedButton.setDefault(False)
             self.startButton.setDefault(True)
         if self.runCount == 1:
-            self.sbLabel.setText(self.trUtf8("Ran {0} test in {1:.3f}s")
-                .format(self.runCount, self.timeTaken))
+            self.sbLabel.setText(
+                self.tr("Ran {0} test in {1:.3f}s")
+                    .format(self.runCount, self.timeTaken))
         else:
-            self.sbLabel.setText(self.trUtf8("Ran {0} tests in {1:.3f}s")
-                .format(self.runCount, self.timeTaken))
+            self.sbLabel.setText(
+                self.tr("Ran {0} tests in {1:.3f}s")
+                    .format(self.runCount, self.timeTaken))
         self.progressLed.off()
         
         self.unittestStopped.emit()
@@ -500,7 +507,7 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         """
         self.failCount += 1
         self.progressCounterFailureCount.setText(str(self.failCount))
-        itm = QListWidgetItem(self.trUtf8("Failure: {0}").format(test))
+        itm = QListWidgetItem(self.tr("Failure: {0}").format(test))
         itm.setData(Qt.UserRole, (test, exc))
         self.errorsListWidget.insertItem(0, itm)
         self.__failedTests.append(id)
@@ -515,7 +522,7 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         """
         self.errorCount += 1
         self.progressCounterErrorCount.setText(str(self.errorCount))
-        itm = QListWidgetItem(self.trUtf8("Error: {0}").format(test))
+        itm = QListWidgetItem(self.tr("Error: {0}").format(test))
         itm.setData(Qt.UserRole, (test, exc))
         self.errorsListWidget.insertItem(0, itm)
         self.__failedTests.append(id)
@@ -530,7 +537,7 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         """
         self.skippedCount += 1
         self.progressCounterSkippedCount.setText(str(self.skippedCount))
-        itm = QListWidgetItem(self.trUtf8("    Skipped: {0}").format(reason))
+        itm = QListWidgetItem(self.tr("    Skipped: {0}").format(reason))
         itm.setForeground(Qt.blue)
         self.testsListWidget.insertItem(1, itm)
         
@@ -545,7 +552,7 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         self.expectedFailureCount += 1
         self.progressCounterExpectedFailureCount.setText(
             str(self.expectedFailureCount))
-        itm = QListWidgetItem(self.trUtf8("    Expected Failure"))
+        itm = QListWidgetItem(self.tr("    Expected Failure"))
         itm.setForeground(Qt.blue)
         self.testsListWidget.insertItem(1, itm)
         
@@ -559,7 +566,7 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         self.unexpectedSuccessCount += 1
         self.progressCounterUnexpectedSuccessCount.setText(
             str(self.unexpectedSuccessCount))
-        itm = QListWidgetItem(self.trUtf8("    Unexpected Success"))
+        itm = QListWidgetItem(self.tr("    Unexpected Success"))
         itm.setForeground(Qt.red)
         self.testsListWidget.insertItem(1, itm)
         
@@ -621,7 +628,7 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         self.dlg.traceback = ui.traceback
         
         ui.showButton = ui.buttonBox.addButton(
-            self.trUtf8("Show Source"), QDialogButtonBox.ActionRole)
+            self.tr("Show Source"), QDialogButtonBox.ActionRole)
         ui.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
         
         self.dlg.setWindowTitle(text)
@@ -630,7 +637,7 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         
         # one more button if called from eric
         if self.dbs:
-            ui.showButton.clicked[()].connect(self.__showSource)
+            ui.showButton.clicked.connect(self.__showSource)
         else:
             ui.showButton.hide()
 
@@ -640,7 +647,7 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         
     def __showSource(self):
         """
-        Private slot to show the source of a traceback in an eric5 editor.
+        Private slot to show the source of a traceback in an eric6 editor.
         """
         if not self.dbs:
             return
@@ -678,77 +685,77 @@ class QtTestResult(unittest.TestResult):
         
         @param parent The parent widget.
         """
-        super().__init__()
+        super(QtTestResult, self).__init__()
         self.parent = parent
         
     def addFailure(self, test, err):
         """
-        Method called if a test failed.
+        Public method called if a test failed.
         
         @param test reference to the test object
         @param err error traceback
         """
-        super().addFailure(test, err)
+        super(QtTestResult, self).addFailure(test, err)
         tracebackLines = self._exc_info_to_string(err, test)
         self.parent.testFailed(str(test), tracebackLines, test.id())
         
     def addError(self, test, err):
         """
-        Method called if a test errored.
+        Public method called if a test errored.
         
         @param test reference to the test object
         @param err error traceback
         """
-        super().addError(test, err)
+        super(QtTestResult, self).addError(test, err)
         tracebackLines = self._exc_info_to_string(err, test)
         self.parent.testErrored(str(test), tracebackLines, test.id())
         
     def addSkip(self, test, reason):
         """
-        Method called if a test was skipped.
+        Public method called if a test was skipped.
         
         @param test reference to the test object
         @param reason reason for skipping the test (string)
         """
-        super().addSkip(test, reason)
+        super(QtTestResult, self).addSkip(test, reason)
         self.parent.testSkipped(str(test), reason, test.id())
         
     def addExpectedFailure(self, test, err):
         """
-        Method called if a test failed expected.
+        Public method called if a test failed expected.
         
         @param test reference to the test object
         @param err error traceback
         """
-        super().addExpectedFailure(test, err)
+        super(QtTestResult, self).addExpectedFailure(test, err)
         tracebackLines = self._exc_info_to_string(err, test)
         self.parent.testFailedExpected(str(test), tracebackLines, test.id())
         
     def addUnexpectedSuccess(self, test):
         """
-        Method called if a test succeeded expectedly.
+        Public method called if a test succeeded expectedly.
         
         @param test reference to the test object
         """
-        super().addUnexpectedSuccess(test)
+        super(QtTestResult, self).addUnexpectedSuccess(test)
         self.parent.testSucceededUnexpected(str(test), test.id())
         
     def startTest(self, test):
         """
-        Method called at the start of a test.
+        Public method called at the start of a test.
         
         @param test Reference to the test object
         """
-        super().startTest(test)
+        super(QtTestResult, self).startTest(test)
         self.parent.testStarted(str(test), test.shortDescription())
 
     def stopTest(self, test):
         """
-        Method called at the end of a test.
+        Public method called at the end of a test.
         
         @param test Reference to the test object
         """
-        super().stopTest(test)
+        super(QtTestResult, self).stopTest(test)
         self.parent.testFinished()
 
 
@@ -763,7 +770,7 @@ class UnittestWindow(E5MainWindow):
         @param prog filename of the program to open
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(UnittestWindow, self).__init__(parent)
         self.cw = UnittestDialog(prog=prog, parent=self)
         self.cw.installEventFilter(self)
         size = self.cw.size()
