@@ -1,14 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the exporter base class.
 """
 
-from PyQt4.QtCore import QFileInfo, QObject
-from PyQt4.QtGui import QApplication
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import QFileInfo, QObject, QCoreApplication
 
 from E5Gui import E5MessageBox, E5FileDialog
 
@@ -26,7 +27,7 @@ class ExporterBase(QObject):
         @param editor reference to the editor object (QScintilla.Editor.Editor)
         @param parent parent object of the exporter (QObject)
         """
-        super().__init__(parent)
+        super(ExporterBase, self).__init__(parent)
         self.editor = editor
     
     def _getFileName(self, filter):
@@ -39,10 +40,10 @@ class ExporterBase(QObject):
         """
         filter_ = filter
         filter_ += ";;"
-        filter_ += QApplication.translate('Exporter', "All Files (*)")
+        filter_ += QCoreApplication.translate('Exporter', "All Files (*)")
         fn, selectedFilter = E5FileDialog.getSaveFileNameAndFilter(
             self.editor,
-            self.trUtf8("Export source"),
+            self.tr("Export source"),
             "",
             filter_,
             "",
@@ -57,9 +58,9 @@ class ExporterBase(QObject):
             if QFileInfo(fn).exists():
                 res = E5MessageBox.yesNo(
                     self.editor,
-                    self.trUtf8("Export source"),
-                    self.trUtf8("<p>The file <b>{0}</b> already exists."
-                                " Overwrite it?</p>").format(fn),
+                    self.tr("Export source"),
+                    self.tr("<p>The file <b>{0}</b> already exists."
+                            " Overwrite it?</p>").format(fn),
                     icon=E5MessageBox.Warning)
                 if not res:
                     return ""
