@@ -1,20 +1,23 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing an exporter for TeX.
 """
 
+from __future__ import unicode_literals
+
 # This code is a port of the C++ code found in SciTE 1.74
 # Original code: Copyright 1998-2006 by Neil Hodgson <neilh@scintilla.org>
 
 import os
 
-from PyQt4.QtCore import Qt
-from PyQt4.QtGui import QCursor, QApplication
-from PyQt4.Qsci import QsciScintilla
+from PyQt5.QtCore import Qt
+from PyQt5.QtGui import QCursor
+from PyQt5.QtWidgets import QApplication
+from PyQt5.Qsci import QsciScintilla
 
 from E5Gui import E5MessageBox
 
@@ -109,7 +112,7 @@ class ExporterTEX(ExporterBase):
         """
         Public method performing the export.
         """
-        filename = self._getFileName(self.trUtf8("TeX Files (*.tex)"))
+        filename = self._getFileName(self.tr("TeX Files (*.tex)"))
         if not filename:
             return
         
@@ -269,8 +272,8 @@ class ExporterTEX(ExporterBase):
                 QApplication.restoreOverrideCursor()
                 E5MessageBox.critical(
                     self.editor,
-                    self.trUtf8("Export source"),
-                    self.trUtf8(
+                    self.tr("Export source"),
+                    self.tr(
                         """<p>The source could not be exported to"""
                         """ <b>{0}</b>.</p><p>Reason: {1}</p>""")
                     .format(filename, str(err)))
