@@ -1,12 +1,14 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the lexer mixin class.
 """
 
+from __future__ import unicode_literals
+
 import Preferences
 
 
@@ -224,6 +226,16 @@ class Lexer(object):
         else:
             return self.defaultKeywords(kwSet)
     
+    def maximumKeywordSet(self):
+        """
+        Public method to get the maximum keyword set.
+        
+        Note: A return value of 0 indicates to determine this dynamically.
+        
+        @return maximum keyword set (integer)
+        """
+        return 0
+    
     def lexerName(self):
         """
         Public method to return the lexer name.
