@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a Java lexer with some additional methods.
 """
 
-from PyQt4.Qsci import QsciLexerJava,  QsciScintilla
+from __future__ import unicode_literals
+
+from PyQt5.Qsci import QsciLexerJava, QsciScintilla
 
 from .Lexer import Lexer
 import Preferences
@@ -84,3 +86,11 @@ class LexerJava(Lexer, QsciLexerJava):
         @return string giving the keywords (string) or None
         """
         return QsciLexerJava.keywords(self, kwSet)
+    
+    def maximumKeywordSet(self):
+        """
+        Public method to get the maximum keyword set.
+        
+        @return maximum keyword set (integer)
+        """
+        return 4
