@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a Lua lexer with some additional methods.
 """
 
-from PyQt4.Qsci import QsciLexerLua
+from __future__ import unicode_literals
+
+from PyQt5.Qsci import QsciLexerLua
 
 from .Lexer import Lexer
 import Preferences
@@ -75,3 +77,11 @@ class LexerLua(Lexer, QsciLexerLua):
         @return string giving the keywords (string) or None
         """
         return QsciLexerLua.keywords(self, kwSet)
+    
+    def maximumKeywordSet(self):
+        """
+        Public method to get the maximum keyword set.
+        
+        @return maximum keyword set (integer)
+        """
+        return 8
