@@ -1,18 +1,20 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a custom lexer using pygments.
 """
 
+from __future__ import unicode_literals
+
 from pygments.token import Token
 from pygments.lexers import guess_lexer_for_filename, guess_lexer, \
     find_lexer_class
 from pygments.util import ClassNotFound
 
-from PyQt4.QtGui import QColor, QFont
+from PyQt5.QtGui import QColor, QFont
 
 from QScintilla.Lexers.LexerContainer import LexerContainer
 
@@ -67,70 +69,70 @@ PYGMENTS_PUNCTUATION = 51
 #-----------------------------------------------------------------------------#
 
 TOKEN_MAP = {
-    Token.Comment:                  PYGMENTS_COMMENT,
-    Token.Comment.Preproc:          PYGMENTS_PREPROCESSOR,
-    Token.Comment.Multiline:        PYGMENTS_MULTILINECOMMENT,
-    Token.Comment.Single:           PYGMENTS_COMMENT,
-    Token.Comment.Special:          PYGMENTS_COMMENT,
+    Token.Comment: PYGMENTS_COMMENT,
+    Token.Comment.Preproc: PYGMENTS_PREPROCESSOR,
+    Token.Comment.Multiline: PYGMENTS_MULTILINECOMMENT,
+    Token.Comment.Single: PYGMENTS_COMMENT,
+    Token.Comment.Special: PYGMENTS_COMMENT,
 
-    Token.Keyword:                  PYGMENTS_KEYWORD,
-    Token.Keyword.Pseudo:           PYGMENTS_PSEUDOKEYWORD,
-    Token.Keyword.Type:             PYGMENTS_TYPEKEYWORD,
-    Token.Keyword.Namespace:        PYGMENTS_KEYWORD,
+    Token.Keyword: PYGMENTS_KEYWORD,
+    Token.Keyword.Pseudo: PYGMENTS_PSEUDOKEYWORD,
+    Token.Keyword.Type: PYGMENTS_TYPEKEYWORD,
+    Token.Keyword.Namespace: PYGMENTS_KEYWORD,
 
-    Token.Operator:                 PYGMENTS_OPERATOR,
-    Token.Operator.Word:            PYGMENTS_WORD,
+    Token.Operator: PYGMENTS_OPERATOR,
+    Token.Operator.Word: PYGMENTS_WORD,
 
-    Token.Name:                     PYGMENTS_DEFAULT,
-    Token.Name.Builtin:             PYGMENTS_BUILTIN,
-    Token.Name.Builtin.Pseudo:      PYGMENTS_BUILTIN,
-    Token.Name.Function:            PYGMENTS_FUNCTION,
-    Token.Name.Class:               PYGMENTS_CLASS,
-    Token.Name.Namespace:           PYGMENTS_NAMESPACE,
-    Token.Name.Exception:           PYGMENTS_EXCEPTION,
-    Token.Name.Variable:            PYGMENTS_VARIABLE,
-    Token.Name.Variable.Class:      PYGMENTS_VARIABLE,
-    Token.Name.Variable.Global:     PYGMENTS_VARIABLE,
-    Token.Name.Variable.Instance:   PYGMENTS_VARIABLE,
-    Token.Name.Constant:            PYGMENTS_CONSTANT,
-    Token.Name.Label:               PYGMENTS_LABEL,
-    Token.Name.Entity:              PYGMENTS_ENTITY,
-    Token.Name.Attribute:           PYGMENTS_ATTRIBUTE,
-    Token.Name.Tag:                 PYGMENTS_TAG,
-    Token.Name.Decorator:           PYGMENTS_DECORATOR,
-    Token.Name.Property:            PYGMENTS_PROPERTY,
+    Token.Name: PYGMENTS_DEFAULT,
+    Token.Name.Builtin: PYGMENTS_BUILTIN,
+    Token.Name.Builtin.Pseudo: PYGMENTS_BUILTIN,
+    Token.Name.Function: PYGMENTS_FUNCTION,
+    Token.Name.Class: PYGMENTS_CLASS,
+    Token.Name.Namespace: PYGMENTS_NAMESPACE,
+    Token.Name.Exception: PYGMENTS_EXCEPTION,
+    Token.Name.Variable: PYGMENTS_VARIABLE,
+    Token.Name.Variable.Class: PYGMENTS_VARIABLE,
+    Token.Name.Variable.Global: PYGMENTS_VARIABLE,
+    Token.Name.Variable.Instance: PYGMENTS_VARIABLE,
+    Token.Name.Constant: PYGMENTS_CONSTANT,
+    Token.Name.Label: PYGMENTS_LABEL,
+    Token.Name.Entity: PYGMENTS_ENTITY,
+    Token.Name.Attribute: PYGMENTS_ATTRIBUTE,
+    Token.Name.Tag: PYGMENTS_TAG,
+    Token.Name.Decorator: PYGMENTS_DECORATOR,
+    Token.Name.Property: PYGMENTS_PROPERTY,
 
-    Token.String:                   PYGMENTS_STRING,
-    Token.String.Char:              PYGMENTS_CHAR,
-    Token.String.Doc:               PYGMENTS_DOCSTRING,
-    Token.String.Interpol:          PYGMENTS_SCALAR,
-    Token.String.Escape:            PYGMENTS_ESCAPE,
-    Token.String.Regex:             PYGMENTS_REGEX,
-    Token.String.Symbol:            PYGMENTS_SYMBOL,
-    Token.String.Other:             PYGMENTS_OTHER,
-    Token.String.Heredoc:           PYGMENTS_HEREDOC,
+    Token.String: PYGMENTS_STRING,
+    Token.String.Char: PYGMENTS_CHAR,
+    Token.String.Doc: PYGMENTS_DOCSTRING,
+    Token.String.Interpol: PYGMENTS_SCALAR,
+    Token.String.Escape: PYGMENTS_ESCAPE,
+    Token.String.Regex: PYGMENTS_REGEX,
+    Token.String.Symbol: PYGMENTS_SYMBOL,
+    Token.String.Other: PYGMENTS_OTHER,
+    Token.String.Heredoc: PYGMENTS_HEREDOC,
     
-    Token.Number:                   PYGMENTS_NUMBER,
-    Token.Number.Float:             PYGMENTS_NUMBER,
-    Token.Number.Hex:               PYGMENTS_NUMBER,
-    Token.Number.Integer:           PYGMENTS_NUMBER,
-    Token.Number.Integer.Long:      PYGMENTS_NUMBER,
-    Token.Number.Oct:               PYGMENTS_NUMBER,
+    Token.Number: PYGMENTS_NUMBER,
+    Token.Number.Float: PYGMENTS_NUMBER,
+    Token.Number.Hex: PYGMENTS_NUMBER,
+    Token.Number.Integer: PYGMENTS_NUMBER,
+    Token.Number.Integer.Long: PYGMENTS_NUMBER,
+    Token.Number.Oct: PYGMENTS_NUMBER,
 
-    Token.Punctuation:              PYGMENTS_PUNCTUATION,
+    Token.Punctuation: PYGMENTS_PUNCTUATION,
 
-    Token.Generic.Heading:          PYGMENTS_HEADING,
-    Token.Generic.Subheading:       PYGMENTS_SUBHEADING,
-    Token.Generic.Deleted:          PYGMENTS_DELETED,
-    Token.Generic.Inserted:         PYGMENTS_INSERTED,
-    Token.Generic.Error:            PYGMENTS_GENERIC_ERROR,
-    Token.Generic.Emph:             PYGMENTS_EMPHASIZE,
-    Token.Generic.Strong:           PYGMENTS_STRONG,
-    Token.Generic.Prompt:           PYGMENTS_PROMPT,
-    Token.Generic.Output:           PYGMENTS_OUTPUT,
-    Token.Generic.Traceback:        PYGMENTS_TRACEBACK,
+    Token.Generic.Heading: PYGMENTS_HEADING,
+    Token.Generic.Subheading: PYGMENTS_SUBHEADING,
+    Token.Generic.Deleted: PYGMENTS_DELETED,
+    Token.Generic.Inserted: PYGMENTS_INSERTED,
+    Token.Generic.Error: PYGMENTS_GENERIC_ERROR,
+    Token.Generic.Emph: PYGMENTS_EMPHASIZE,
+    Token.Generic.Strong: PYGMENTS_STRONG,
+    Token.Generic.Prompt: PYGMENTS_PROMPT,
+    Token.Generic.Output: PYGMENTS_OUTPUT,
+    Token.Generic.Traceback: PYGMENTS_TRACEBACK,
 
-    Token.Error:                    PYGMENTS_ERROR,
+    Token.Error: PYGMENTS_ERROR,
 }
 
 #-----------------------------------------------------------------------------#
@@ -152,50 +154,50 @@ class LexerPygments(LexerContainer):
         self.__pygmentsName = name
         
         self.descriptions = {
-            PYGMENTS_DEFAULT: self.trUtf8("Default"),
-            PYGMENTS_COMMENT: self.trUtf8("Comment"),
-            PYGMENTS_PREPROCESSOR: self.trUtf8("Preprocessor"),
-            PYGMENTS_KEYWORD: self.trUtf8("Keyword"),
-            PYGMENTS_PSEUDOKEYWORD: self.trUtf8("Pseudo Keyword"),
-            PYGMENTS_TYPEKEYWORD: self.trUtf8("Type Keyword"),
-            PYGMENTS_OPERATOR: self.trUtf8("Operator"),
-            PYGMENTS_WORD: self.trUtf8("Word"),
-            PYGMENTS_BUILTIN: self.trUtf8("Builtin"),
-            PYGMENTS_FUNCTION: self.trUtf8("Function or method name"),
-            PYGMENTS_CLASS: self.trUtf8("Class name"),
-            PYGMENTS_NAMESPACE: self.trUtf8("Namespace"),
-            PYGMENTS_EXCEPTION: self.trUtf8("Exception"),
-            PYGMENTS_VARIABLE: self.trUtf8("Identifier"),
-            PYGMENTS_CONSTANT: self.trUtf8("Constant"),
-            PYGMENTS_LABEL: self.trUtf8("Label"),
-            PYGMENTS_ENTITY: self.trUtf8("Entity"),
-            PYGMENTS_ATTRIBUTE: self.trUtf8("Attribute"),
-            PYGMENTS_TAG: self.trUtf8("Tag"),
-            PYGMENTS_DECORATOR: self.trUtf8("Decorator"),
-            PYGMENTS_STRING: self.trUtf8("String"),
-            PYGMENTS_DOCSTRING: self.trUtf8("Documentation string"),
-            PYGMENTS_SCALAR: self.trUtf8("Scalar"),
-            PYGMENTS_ESCAPE: self.trUtf8("Escape"),
-            PYGMENTS_REGEX: self.trUtf8("Regular expression"),
-            PYGMENTS_SYMBOL: self.trUtf8("Symbol"),
-            PYGMENTS_OTHER: self.trUtf8("Other string"),
-            PYGMENTS_NUMBER: self.trUtf8("Number"),
-            PYGMENTS_HEADING: self.trUtf8("Heading"),
-            PYGMENTS_SUBHEADING: self.trUtf8("Subheading"),
-            PYGMENTS_DELETED: self.trUtf8("Deleted"),
-            PYGMENTS_INSERTED: self.trUtf8("Inserted"),
-            PYGMENTS_GENERIC_ERROR: self.trUtf8("Generic error"),
-            PYGMENTS_EMPHASIZE: self.trUtf8("Emphasized text"),
-            PYGMENTS_STRONG: self.trUtf8("Strong text"),
-            PYGMENTS_PROMPT: self.trUtf8("Prompt"),
-            PYGMENTS_OUTPUT: self.trUtf8("Output"),
-            PYGMENTS_TRACEBACK: self.trUtf8("Traceback"),
-            PYGMENTS_ERROR: self.trUtf8("Error"),
-            PYGMENTS_MULTILINECOMMENT: self.trUtf8("Comment block"),
-            PYGMENTS_PROPERTY: self.trUtf8("Property"),
-            PYGMENTS_CHAR: self.trUtf8("Character"),
-            PYGMENTS_HEREDOC: self.trUtf8("Here document"),
-            PYGMENTS_PUNCTUATION: self.trUtf8("Punctuation"),
+            PYGMENTS_DEFAULT: self.tr("Default"),
+            PYGMENTS_COMMENT: self.tr("Comment"),
+            PYGMENTS_PREPROCESSOR: self.tr("Preprocessor"),
+            PYGMENTS_KEYWORD: self.tr("Keyword"),
+            PYGMENTS_PSEUDOKEYWORD: self.tr("Pseudo Keyword"),
+            PYGMENTS_TYPEKEYWORD: self.tr("Type Keyword"),
+            PYGMENTS_OPERATOR: self.tr("Operator"),
+            PYGMENTS_WORD: self.tr("Word"),
+            PYGMENTS_BUILTIN: self.tr("Builtin"),
+            PYGMENTS_FUNCTION: self.tr("Function or method name"),
+            PYGMENTS_CLASS: self.tr("Class name"),
+            PYGMENTS_NAMESPACE: self.tr("Namespace"),
+            PYGMENTS_EXCEPTION: self.tr("Exception"),
+            PYGMENTS_VARIABLE: self.tr("Identifier"),
+            PYGMENTS_CONSTANT: self.tr("Constant"),
+            PYGMENTS_LABEL: self.tr("Label"),
+            PYGMENTS_ENTITY: self.tr("Entity"),
+            PYGMENTS_ATTRIBUTE: self.tr("Attribute"),
+            PYGMENTS_TAG: self.tr("Tag"),
+            PYGMENTS_DECORATOR: self.tr("Decorator"),
+            PYGMENTS_STRING: self.tr("String"),
+            PYGMENTS_DOCSTRING: self.tr("Documentation string"),
+            PYGMENTS_SCALAR: self.tr("Scalar"),
+            PYGMENTS_ESCAPE: self.tr("Escape"),
+            PYGMENTS_REGEX: self.tr("Regular expression"),
+            PYGMENTS_SYMBOL: self.tr("Symbol"),
+            PYGMENTS_OTHER: self.tr("Other string"),
+            PYGMENTS_NUMBER: self.tr("Number"),
+            PYGMENTS_HEADING: self.tr("Heading"),
+            PYGMENTS_SUBHEADING: self.tr("Subheading"),
+            PYGMENTS_DELETED: self.tr("Deleted"),
+            PYGMENTS_INSERTED: self.tr("Inserted"),
+            PYGMENTS_GENERIC_ERROR: self.tr("Generic error"),
+            PYGMENTS_EMPHASIZE: self.tr("Emphasized text"),
+            PYGMENTS_STRONG: self.tr("Strong text"),
+            PYGMENTS_PROMPT: self.tr("Prompt"),
+            PYGMENTS_OUTPUT: self.tr("Output"),
+            PYGMENTS_TRACEBACK: self.tr("Traceback"),
+            PYGMENTS_ERROR: self.tr("Error"),
+            PYGMENTS_MULTILINECOMMENT: self.tr("Comment block"),
+            PYGMENTS_PROPERTY: self.tr("Property"),
+            PYGMENTS_CHAR: self.tr("Character"),
+            PYGMENTS_HEREDOC: self.tr("Here document"),
+            PYGMENTS_PUNCTUATION: self.tr("Punctuation"),
         }
         
         self.defaultColors = {
