@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a VHDL lexer with some additional methods.
 """
 
-from PyQt4.Qsci import QsciLexerVHDL
+from __future__ import unicode_literals
+
+from PyQt5.Qsci import QsciLexerVHDL
 
 from .Lexer import Lexer
 import Preferences
@@ -67,3 +69,11 @@ class LexerVHDL(Lexer, QsciLexerVHDL):
         @return string giving the keywords (string) or None
         """
         return QsciLexerVHDL.keywords(self, kwSet)
+    
+    def maximumKeywordSet(self):
+        """
+        Public method to get the maximum keyword set.
+        
+        @return maximum keyword set (integer)
+        """
+        return 7
