@@ -1,15 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a compatability interface class to QsciScintilla.
 """
 
-from PyQt4.QtCore import pyqtSignal, Qt
-from PyQt4.QtGui import QPalette, QColor, QApplication
-from PyQt4.Qsci import QsciScintillaBase, QsciScintilla, \
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSignal, Qt
+from PyQt5.QtGui import QPalette, QColor
+from PyQt5.QtWidgets import QApplication
+from PyQt5.Qsci import QsciScintillaBase, QsciScintilla, \
     QSCINTILLA_VERSION as QSCIQSCINTILLA_VERSION
 
 ###############################################################################
@@ -58,7 +61,7 @@ class QsciScintillaCompat(QsciScintilla):
         
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(QsciScintillaCompat, self).__init__(parent)
         
         self.zoom = 0
         
@@ -96,7 +99,7 @@ class QsciScintillaCompat(QsciScintilla):
         @param m new modification status (boolean)
         """
         self.__modified = m
-        super().setModified(m)
+        super(QsciScintillaCompat, self).setModified(m)
         self.modificationChanged.emit(m)
     
     def setLexer(self, lex=None):
@@ -105,7 +108,7 @@ class QsciScintillaCompat(QsciScintilla):
         
         @param lex the lexer to be set or None to reset it.
         """
-        super().setLexer(lex)
+        super(QsciScintillaCompat, self).setLexer(lex)
         if lex is None:
             self.clearStyles()
     
@@ -139,7 +142,7 @@ class QsciScintillaCompat(QsciScintilla):
         except AttributeError:
             rangeHigh = list(range(40, 128))
         
-        f = font.family().encode()
+        f = font.family().encode("utf-8")
         ps = font.pointSize()
         weight = -font.weight()
         italic = font.italic()
@@ -269,7 +272,15 @@ class QsciScintillaCompat(QsciScintilla):
             while len(ch) < utf8Len:
                 pos += 1
                 ch += self.byteAt(pos)
-            return ch.decode('utf8')
+            try:
+                return ch.decode('utf8')
+            except UnicodeDecodeError:
+                if pos > 0:
+                    # try it one position before; maybe we are in the
+                    # middle of a unicode character
+                    return self.charAt(pos - 1)
+                else:
+                    return ""
         else:
             return ch.decode()
     
@@ -284,10 +295,10 @@ class QsciScintillaCompat(QsciScintilla):
         """
         char = self.SendScintilla(QsciScintilla.SCI_GETCHARAT, pos)
         if char == 0:
-            return b""
+            return bytearray()
         if char < 0:
             char += 256
-        return bytes.fromhex("{0:02x}".format(char))
+        return bytearray((char,))
     
     def foldLevelAt(self, line):
         """
@@ -359,7 +370,7 @@ class QsciScintillaCompat(QsciScintilla):
         
         @param zoom zoom factor increment (integer)
         """
-        super().zoomIn(zoom)
+        super(QsciScintillaCompat, self).zoomIn(zoom)
     
     def zoomOut(self, zoom=1):
         """
@@ -367,7 +378,7 @@ class QsciScintillaCompat(QsciScintilla):
         
         @param zoom zoom factor decrement (integer)
         """
-        super().zoomOut(zoom)
+        super(QsciScintillaCompat, self).zoomOut(zoom)
     
     def zoomTo(self, zoom):
         """
@@ -376,7 +387,7 @@ class QsciScintillaCompat(QsciScintilla):
         @param zoom zoom factor (integer)
         """
         self.zoom = zoom
-        super().zoomTo(zoom)
+        super(QsciScintillaCompat, self).zoomTo(zoom)
         self.zoomValueChanged.emit(self.zoom)
     
     def getZoom(self):
@@ -703,7 +714,7 @@ class QsciScintillaCompat(QsciScintilla):
     
     def setCursorFlashTime(self, time):
         """
-        Public method to get the flash (blink) time of the cursor in
+        Public method to set the flash (blink) time of the cursor in
         milliseconds.
         
         The flash time is the time required to display, invert and restore the
@@ -1109,9 +1120,9 @@ class QsciScintillaCompat(QsciScintilla):
         @param margin margin number (integer)
         """
         if style < self.ArrowFoldStyle:
-            super().setFolding(style, margin)
+            super(QsciScintillaCompat, self).setFolding(style, margin)
         else:
-            super().setFolding(
+            super(QsciScintillaCompat, self).setFolding(
                 QsciScintilla.PlainFoldStyle, margin)
             
             if style == self.ArrowFoldStyle:
@@ -1189,14 +1200,14 @@ class QsciScintillaCompat(QsciScintilla):
     
     def clearKeys(self):
         """
-        Protected method to clear the key commands.
+        Public method to clear the key commands.
         """
         # call into the QsciCommandSet
         self.standardCommands().clearKeys()
         
     def clearAlternateKeys(self):
         """
-        Protected method to clear the alternate key commands.
+        Public method to clear the alternate key commands.
         """
         # call into the QsciCommandSet
         self.standardCommands().clearAlternateKeys()
@@ -1207,7 +1218,7 @@ class QsciScintillaCompat(QsciScintilla):
     
     def focusOutEvent(self, event):
         """
-        Public method called when the editor loses focus.
+        Protected method called when the editor loses focus.
         
         @param event event object (QFocusEvent)
         """
@@ -1227,11 +1238,11 @@ class QsciScintillaCompat(QsciScintilla):
             else:
                 self.SendScintilla(QsciScintilla.SCI_CALLTIPCANCEL)
         
-        super().focusOutEvent(event)
+        super(QsciScintillaCompat, self).focusOutEvent(event)
     
     def event(self, evt):
         """
-        Protected method to handle events.
+        Public method to handle events.
         
         Note: We are not interested in the standard QsciScintilla event
         handling because we do it our self.
@@ -1257,7 +1268,7 @@ class QsciScintillaCompat(QsciScintilla):
         
         def inputMethodQuery(self, query):
             """
-            Protected method to cope with a glitch in some Qscintilla versions
+            Public method to cope with a glitch in some Qscintilla versions
             handling input events.
             
             Note: This simply disables the Qscintilla behavior.
@@ -1291,20 +1302,23 @@ class QsciScintillaCompat(QsciScintilla):
     ## replacements for buggy methods
     ###########################################################################
     
-    def showUserList(self, id, lst):
-        """
-        Public method to show a user supplied list.
-        
-        @param id id of the list (integer)
-        @param lst list to be show (list of strings)
-        """
-        if id <= 0:
-            return
-        
-        self.SendScintilla(QsciScintilla.SCI_AUTOCSETSEPARATOR,
-                           ord(self.UserSeparator))
-        self.SendScintilla(QsciScintilla.SCI_USERLISTSHOW, id,
-                           self._encodeString(self.UserSeparator.join(lst)))
+    if "showUserList" not in QsciScintilla.__dict__:
+        def showUserList(self, id, lst):
+            """
+            Public method to show a user supplied list.
+            
+            @param id id of the list (integer)
+            @param lst list to be show (list of strings)
+            """
+            if id <= 0:
+                return
+            
+            self.SendScintilla(
+                QsciScintilla.SCI_AUTOCSETSEPARATOR,
+                ord(self.UserSeparator))
+            self.SendScintilla(
+                QsciScintilla.SCI_USERLISTSHOW, id,
+                self._encodeString(self.UserSeparator.join(lst)))
     
     ###########################################################################
     ## work-arounds for buggy behavior
