@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the search and replace widget.
 """
 
-from PyQt4.QtCore import pyqtSignal, Qt, pyqtSlot
-from PyQt4.QtGui import QWidget, QHBoxLayout, QToolButton, QScrollArea, \
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSignal, Qt, pyqtSlot, QEvent
+from PyQt5.QtWidgets import QWidget, QHBoxLayout, QToolButton, QScrollArea, \
     QSizePolicy, QFrame
 
 from .Editor import Editor
@@ -39,7 +41,7 @@ class SearchReplaceWidget(QWidget):
         @param sliding flag indicating the widget is embedded in the
             sliding widget (boolean)
         """
-        super().__init__(parent)
+        super(SearchReplaceWidget, self).__init__(parent)
         
         self.viewmanager = vm
         self.replace = replace
@@ -52,7 +54,7 @@ class SearchReplaceWidget(QWidget):
             from .Ui_ReplaceWidget import Ui_ReplaceWidget
             self.replaceHistory = vm.getSRHistory('replace')
             self.ui = Ui_ReplaceWidget()
-            whatsThis = self.trUtf8(
+            whatsThis = self.tr(
 r"""<b>Find and Replace</b>
 <p>This dialog is used to find some text and replace it with another text.
 By checking the various checkboxes, the search can be made more specific.
@@ -63,7 +65,7 @@ special characters interpreted are:</p>
         else:
             from .Ui_SearchWidget import Ui_SearchWidget
             self.ui = Ui_SearchWidget()
-            whatsThis = self.trUtf8(
+            whatsThis = self.tr(
 r"""<b>Find</b>
 <p>This dialog is used to find some text. By checking the various checkboxes,
 the search can be made more specific. The search string might be a regular
@@ -74,7 +76,7 @@ expression. In a regular expression, special characters interpreted are:</p>
         if not replace:
             self.ui.wrapCheckBox.setChecked(True)
         
-        whatsThis += self.trUtf8(
+        whatsThis += self.tr(
 r"""<table border="0">
 <tr><td><code>.</code></td><td>Matches any character</td></tr>
 <tr><td><code>\(</code></td><td>This marks the start of a region for tagging a
@@ -133,34 +135,47 @@ and so on.</td></tr>
             self.ui.replaceAllButton.setIcon(
                 UI.PixmapCache.getIcon("editReplaceAll.png"))
         
+        self.ui.findtextCombo.setCompleter(None)
         self.ui.findtextCombo.lineEdit().returnPressed.connect(
             self.__findByReturnPressed)
         if replace:
+            self.ui.replacetextCombo.setCompleter(None)
             self.ui.replacetextCombo.lineEdit().returnPressed.connect(
                 self.on_replaceButton_clicked)
         
         self.findNextAct = E5Action(
-            self.trUtf8('Find Next'),
-            self.trUtf8('Find Next'),
+            self.tr('Find Next'),
+            self.tr('Find Next'),
             0, 0, self, 'search_widget_find_next')
-        self.findNextAct.triggered[()].connect(self.on_findNextButton_clicked)
+        self.findNextAct.triggered.connect(self.on_findNextButton_clicked)
         self.findNextAct.setEnabled(False)
         self.ui.findtextCombo.addAction(self.findNextAct)
         
         self.findPrevAct = E5Action(
-            self.trUtf8('Find Prev'),
-            self.trUtf8('Find Prev'),
+            self.tr('Find Prev'),
+            self.tr('Find Prev'),
             0, 0, self, 'search_widget_find_prev')
-        self.findPrevAct.triggered[()].connect(self.on_findPrevButton_clicked)
+        self.findPrevAct.triggered.connect(self.on_findPrevButton_clicked)
         self.findPrevAct.setEnabled(False)
         self.ui.findtextCombo.addAction(self.findPrevAct)
         
+        self.adjustSize()
+        
         self.havefound = False
         self.__pos = None
         self.__findBackwards = False
         self.__selections = []
         self.__finding = False
     
+    def changeEvent(self, evt):
+        """
+        Protected method handling state changes.
+        
+        @param evt event containing the state change (QEvent)
+        """
+        if evt.type() == QEvent.FontChange:
+            self.adjustSize()
+    
     def __selectionBoundary(self, selections=None):
         """
         Private method to calculate the current selection boundary.
@@ -245,7 +260,7 @@ and so on.</td></tr>
         else:
             E5MessageBox.information(
                 self, self.windowTitle(),
-                self.trUtf8("'{0}' was not found.").format(txt))
+                self.tr("'{0}' was not found.").format(txt))
 
     @pyqtSlot()
     def on_findPrevButton_clicked(self):
@@ -282,7 +297,7 @@ and so on.</td></tr>
         else:
             E5MessageBox.information(
                 self, self.windowTitle(),
-                self.trUtf8("'{0}' was not found.").format(txt))
+                self.tr("'{0}' was not found.").format(txt))
     
     def __findByReturnPressed(self):
         """
@@ -642,7 +657,7 @@ and so on.</td></tr>
                 self.ui.replaceSearchButton.setEnabled(False)
                 E5MessageBox.information(
                     self, self.windowTitle(),
-                    self.trUtf8("'{0}' was not found.").format(ftxt))
+                    self.tr("'{0}' was not found.").format(ftxt))
         else:
             self.ui.replaceButton.setEnabled(False)
             self.ui.replaceSearchButton.setEnabled(False)
@@ -764,12 +779,12 @@ and so on.</td></tr>
         if found:
             E5MessageBox.information(
                 self, self.windowTitle(),
-                self.trUtf8("Replaced {0} occurrences.")
+                self.tr("Replaced {0} occurrences.")
                 .format(replacements))
         else:
             E5MessageBox.information(
                 self, self.windowTitle(),
-                self.trUtf8("Nothing replaced because '{0}' was not found.")
+                self.tr("Nothing replaced because '{0}' was not found.")
                 .format(ftxt))
         
         aw.setCursorPosition(cline, cindex)
@@ -821,7 +836,7 @@ and so on.</td></tr>
 
     def show(self, text=''):
         """
-        Overridden slot from QWidget.
+        Public slot to show the widget.
         
         @param text text to be shown in the findtext edit (string)
         """
@@ -829,7 +844,7 @@ and so on.</td></tr>
             self.__showReplace(text)
         else:
             self.__showFind(text)
-        super().show()
+        super(SearchReplaceWidget, self).show()
         self.activateWindow()
 
     @pyqtSlot()
@@ -880,11 +895,10 @@ class SearchReplaceSlidingWidget(QWidget):
         @param vm reference to the viewmanager object
         @param parent parent widget of this widget (QWidget)
         """
-        super().__init__(parent)
+        super(SearchReplaceSlidingWidget, self).__init__(parent)
         
         self.__searchReplaceWidget = \
             SearchReplaceWidget(replace, vm, self, True)
-        srHeight = self.__searchReplaceWidget.height()
         
         self.__layout = QHBoxLayout(self)
         self.setLayout(self.__layout)
@@ -901,7 +915,6 @@ class SearchReplaceSlidingWidget(QWidget):
         self.__scroller.setWidget(self.__searchReplaceWidget)
         self.__scroller.setSizePolicy(
             QSizePolicy.Expanding, QSizePolicy.Minimum)
-        self.__scroller.setMaximumHeight(srHeight)
         self.__scroller.setFrameShape(QFrame.NoFrame)
         self.__scroller.setVerticalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
         self.__scroller.setHorizontalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
@@ -917,12 +930,24 @@ class SearchReplaceSlidingWidget(QWidget):
         self.__layout.addWidget(self.__scroller)
         self.__layout.addWidget(self.__rightButton)
         
-        self.setMaximumHeight(srHeight)
+        self.setMaximumHeight(self.__searchReplaceWidget.sizeHint().height())
+        self.adjustSize()
         
         self.__searchReplaceWidget.searchListChanged.connect(
             self.searchListChanged)
-        self.__leftButton.clicked[()].connect(self.__slideLeft)
-        self.__rightButton.clicked[()].connect(self.__slideRight)
+        self.__leftButton.clicked.connect(self.__slideLeft)
+        self.__rightButton.clicked.connect(self.__slideRight)
+    
+    def changeEvent(self, evt):
+        """
+        Protected method handling state changes.
+
+        @param evt event containing the state change (QEvent)
+        """
+        if evt.type() == QEvent.FontChange:
+            self.setMaximumHeight(
+                self.__searchReplaceWidget.sizeHint().height())
+            self.adjustSize()
     
     def findNext(self):
         """
@@ -954,12 +979,12 @@ class SearchReplaceSlidingWidget(QWidget):
 
     def show(self, text=''):
         """
-        Overridden slot from QWidget.
+        Public slot to show the widget.
         
         @param text text to be shown in the findtext edit (string)
         """
         self.__searchReplaceWidget.show(text)
-        super().show()
+        super(SearchReplaceSlidingWidget, self).show()
         self.__enableScrollerButtons()
     
     def __slideLeft(self):
@@ -1010,4 +1035,4 @@ class SearchReplaceSlidingWidget(QWidget):
         """
         self.__enableScrollerButtons()
         
-        super().resizeEvent(evt)
+        super(SearchReplaceSlidingWidget, self).resizeEvent(evt)
