@@ -1,19 +1,22 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a graphical Python shell.
 """
 
+from __future__ import unicode_literals
+
 import sys
 import re
 
-from PyQt4.QtCore import pyqtSignal, QFileInfo, Qt, QEvent
-from PyQt4.QtGui import QDialog, QInputDialog, QApplication, QClipboard, \
-    QMenu, QPalette, QFont, QWidget, QHBoxLayout, QVBoxLayout, QShortcut
-from PyQt4.Qsci import QsciScintilla
+from PyQt5.QtCore import pyqtSignal, QFileInfo, Qt, QEvent, qVersion
+from PyQt5.QtGui import QClipboard, QPalette, QFont
+from PyQt5.QtWidgets import QDialog, QInputDialog, QApplication, QMenu, \
+    QWidget, QHBoxLayout, QVBoxLayout, QShortcut
+from PyQt5.Qsci import QsciScintilla
 
 from E5Gui.E5Application import e5App
 from E5Gui import E5MessageBox
@@ -40,7 +43,7 @@ class ShellAssembly(QWidget):
         @param horizontal flag indicating a horizontal layout (boolean)
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(ShellAssembly, self).__init__(parent)
         
         self.__shell = Shell(dbs, vm, self)
         
@@ -98,7 +101,7 @@ class Shell(QsciScintillaCompat):
         @param vm reference to the viewmanager object
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(Shell, self).__init__(parent)
         self.setUtf8(True)
         
         self.vm = vm
@@ -109,11 +112,11 @@ class Shell(QsciScintillaCompat):
         
         self.passive = Preferences.getDebugger("PassiveDbgEnabled")
         if self.passive:
-            self.setWindowTitle(self.trUtf8('Shell - Passive'))
+            self.setWindowTitle(self.tr('Shell - Passive'))
         else:
-            self.setWindowTitle(self.trUtf8('Shell'))
+            self.setWindowTitle(self.tr('Shell'))
         
-        self.setWhatsThis(self.trUtf8(
+        self.setWhatsThis(self.tr(
             """<b>The Shell Window</b>"""
             """<p>This is simply an interpreter running in a window. The"""
             """ interpreter is the one that is used to run the program"""
@@ -155,8 +158,8 @@ class Shell(QsciScintillaCompat):
         dbs.clientBanner.connect(self.__writeBanner)
         dbs.clientCompletionList.connect(self.__showCompletions)
         dbs.clientCapabilities.connect(self.__clientCapabilities)
-        dbs.clientException.connect(self.__clientError)
-        dbs.clientSyntaxError.connect(self.__clientError)
+        dbs.clientException.connect(self.__clientException)
+        dbs.clientSyntaxError.connect(self.__clientSyntaxError)
         self.dbs = dbs
         
         # Initialize instance variables.
@@ -183,7 +186,7 @@ class Shell(QsciScintillaCompat):
         
         # Make sure we have prompts.
         if self.passive:
-            sys.ps1 = self.trUtf8("Passive >>> ")
+            sys.ps1 = self.tr("Passive >>> ")
         else:
             try:
                 sys.ps1
@@ -198,7 +201,7 @@ class Shell(QsciScintillaCompat):
             self.__getBanner()
         
         # Create a little language context menu
-        self.lmenu = QMenu(self.trUtf8('Start'))
+        self.lmenu = QMenu(self.tr('Start'))
         self.clientLanguages = self.dbs.getSupportedLanguages(shellOnly=True)
         self.clientLanguages.sort()
         for language in self.clientLanguages:
@@ -207,28 +210,28 @@ class Shell(QsciScintillaCompat):
         self.lmenu.triggered.connect(self.__startDebugClient)
         
         # Create the history context menu
-        self.hmenu = QMenu(self.trUtf8('History'))
-        self.hmenu.addAction(self.trUtf8('Select entry'), self.__selectHistory)
-        self.hmenu.addAction(self.trUtf8('Show'), self.__showHistory)
-        self.hmenu.addAction(self.trUtf8('Clear'), self.__clearHistory)
+        self.hmenu = QMenu(self.tr('History'))
+        self.hmenu.addAction(self.tr('Select entry'), self.__selectHistory)
+        self.hmenu.addAction(self.tr('Show'), self.__showHistory)
+        self.hmenu.addAction(self.tr('Clear'), self.__clearHistory)
         
         # Create a little context menu
         self.menu = QMenu(self)
-        self.menu.addAction(self.trUtf8('Cut'), self.cut)
-        self.menu.addAction(self.trUtf8('Copy'), self.copy)
-        self.menu.addAction(self.trUtf8('Paste'), self.paste)
+        self.menu.addAction(self.tr('Cut'), self.cut)
+        self.menu.addAction(self.tr('Copy'), self.copy)
+        self.menu.addAction(self.tr('Paste'), self.paste)
         self.menu.addMenu(self.hmenu)
         self.menu.addSeparator()
-        self.menu.addAction(self.trUtf8('Find'), self.__find)
+        self.menu.addAction(self.tr('Find'), self.__find)
         self.menu.addSeparator()
-        self.menu.addAction(self.trUtf8('Clear'), self.clear)
-        self.menu.addAction(self.trUtf8('Reset'), self.__reset)
+        self.menu.addAction(self.tr('Clear'), self.clear)
+        self.menu.addAction(self.tr('Reset'), self.__reset)
         self.menu.addAction(
-            self.trUtf8('Reset and Clear'), self.__resetAndClear)
+            self.tr('Reset and Clear'), self.__resetAndClear)
         self.menu.addSeparator()
         self.menu.addMenu(self.lmenu)
         self.menu.addSeparator()
-        self.menu.addAction(self.trUtf8("Configure..."), self.__configure)
+        self.menu.addAction(self.tr("Configure..."), self.__configure)
         
         self.__bindLexer()
         self.__setTextDisplay()
@@ -574,9 +577,9 @@ class Shell(QsciScintillaCompat):
         """
         cmd, ok = QInputDialog.getItem(
             self,
-            self.trUtf8("Select History"),
-            self.trUtf8("Select the history entry to execute"
-                        " (most recent shown last)."),
+            self.tr("Select History"),
+            self.tr("Select the history entry to execute"
+                    " (most recent shown last)."),
             self.history,
             0, False)
         if ok:
@@ -621,15 +624,16 @@ class Shell(QsciScintillaCompat):
         @param platform platform of the remote interpreter (string)
         @param dbgclient debug client variant used (string)
         """
-        super().clear()
+        super(Shell, self).clear()
         if self.passive and not self.dbs.isConnected():
-            self.__write(self.trUtf8('Passive Debug Mode'))
-            self.__write(self.trUtf8('\nNot connected'))
+            self.__write(self.tr('Passive Debug Mode'))
+            self.__write(self.tr('\nNot connected'))
         else:
-            version = version.replace("#", self.trUtf8("No."))
+            version = version.replace("#", self.tr("No."))
             if platform != "" and dbgclient != "":
-                self.__write(self.trUtf8('{0} on {1}, {2}')
-                    .format(version, platform, dbgclient))
+                self.__write(
+                    self.tr('{0} on {1}, {2}')
+                        .format(version, platform, dbgclient))
             else:
                 self.__write(version)
         self.__write('\n')
@@ -653,6 +657,59 @@ class Shell(QsciScintillaCompat):
             self.__writePrompt()
         self.inCommandExecution = False
         
+    def __clientException(self, exceptionType, exceptionMessage, stackTrace):
+        """
+        Private method to handle an exception of the client.
+        
+        @param exceptionType type of exception raised (string)
+        @param exceptionMessage message given by the exception (string)
+        @param stackTrace list of stack entries (list of string)
+        """
+        self .__clientError()
+        
+        if Preferences.getDebugger("ShowExceptionInShell"):
+            if exceptionType is not None:
+                if stackTrace:
+                    self.__write(
+                        self.tr('Exception "{0}"\n{1}\nFile: {2}, Line: {3}\n')
+                        .format(
+                            exceptionType,
+                            exceptionMessage,
+                            stackTrace[0][0],
+                            stackTrace[0][1]
+                        )
+                    )
+                else:
+                    self.__write(
+                        self.tr('Exception "{0}"\n{1}\n')
+                        .format(
+                            exceptionType,
+                            exceptionMessage)
+                    )
+        
+    def __clientSyntaxError(self, message, filename, lineNo, characterNo):
+        """
+        Private method to handle a syntax error in the debugged program.
+        
+        @param message message of the syntax error (string)
+        @param filename translated filename of the syntax error position
+            (string)
+        @param lineNo line number of the syntax error position (integer)
+        @param characterNo character number of the syntax error position
+            (integer)
+        """
+        self .__clientError()
+        
+        if Preferences.getDebugger("ShowExceptionInShell"):
+            if message is None:
+                self.__write(self.tr("Unspecified syntax error.\n"))
+            else:
+                self.__write(
+                    self.tr('Syntax error "{1}" in file {0} at line {2},'
+                            ' character {3}.\n')
+                        .format(filename, message, lineNo, characterNo)
+                )
+        
     def __clientError(self):
         """
         Private method to handle an error in the client.
@@ -689,7 +746,7 @@ class Shell(QsciScintillaCompat):
         
         @param s text to be displayed (string)
         """
-        self.__write(self.trUtf8("StdOut: {0}").format(s))
+        self.__write(self.tr("StdOut: {0}").format(s))
         
     def __writeStdErr(self, s):
         """
@@ -697,7 +754,7 @@ class Shell(QsciScintillaCompat):
         
         @param s text to be displayed (string)
         """
-        self.__write(self.trUtf8("StdErr: {0}").format(s))
+        self.__write(self.tr("StdErr: {0}").format(s))
         
     def __raw_input(self, s, echo):
         """
@@ -723,7 +780,7 @@ class Shell(QsciScintillaCompat):
         
     def paste(self):
         """
-        Reimplemented slot to handle the paste action.
+        Public slot to handle the paste action.
         """
         if self.__isCursorOnLastLine():
             line, col = self.getCursorPosition()
@@ -844,7 +901,7 @@ class Shell(QsciScintillaCompat):
         if event.button() == Qt.MidButton:
             self.__middleMouseButton()
         else:
-            super().mousePressEvent(event)
+            super(Shell, self).mousePressEvent(event)
         
     def wheelEvent(self, evt):
         """
@@ -853,18 +910,22 @@ class Shell(QsciScintillaCompat):
         @param evt reference to the wheel event (QWheelEvent)
         """
         if evt.modifiers() & Qt.ControlModifier:
-            if evt.delta() < 0:
+            if qVersion() >= "5.0.0":
+                delta = evt.angleDelta().y()
+            else:
+                delta = evt.delta()
+            if delta < 0:
                 self.zoomOut()
             else:
                 self.zoomIn()
             evt.accept()
             return
         
-        super().wheelEvent(evt)
+        super(Shell, self).wheelEvent(evt)
     
     def event(self, evt):
         """
-        Protected method handling events.
+        Public method handling events.
         
         @param evt reference to the event (QEvent)
         @return flag indicating, if the event was handled (boolean)
@@ -873,7 +934,7 @@ class Shell(QsciScintillaCompat):
             self.gestureEvent(evt)
             return True
         
-        return super().event(evt)
+        return super(Shell, self).event(evt)
     
     def gestureEvent(self, evt):
         """
@@ -921,7 +982,7 @@ class Shell(QsciScintillaCompat):
         
     def keyPressEvent(self, ev):
         """
-        Re-implemented to handle the user input a key at a time.
+        Protected method to handle the user input a key at a time.
         
         @param ev key event (QKeyEvent)
         """
@@ -935,7 +996,7 @@ class Shell(QsciScintillaCompat):
                 self.prline, self.prcol = self.getCursorPosition()
             if self.echoInput:
                 ac = self.isListActive()
-                super().keyPressEvent(ev)
+                super(Shell, self).keyPressEvent(ev)
                 self.incrementalSearchActive = True
                 if ac and \
                    self.racEnabled:
@@ -1287,16 +1348,16 @@ class Shell(QsciScintillaCompat):
                         self.dbs.startClient(False)  # same as reset
                     else:
                         language = cmdList[1]
-                        if not language in self.clientLanguages:
+                        if language not in self.clientLanguages:
                             language = cmdList[1].capitalize()
-                            if not language in self.clientLanguages:
+                            if language not in self.clientLanguages:
                                 language = ""
                         if language:
                             self.dbs.startClient(False, language)
                         else:
                             # language not supported or typo
                             self.__write(
-                                self.trUtf8(
+                                self.tr(
                                     'Shell language "{0}" not supported.\n')
                                 .format(cmdList[1]))
                             self.__clientStatement(False)
@@ -1399,7 +1460,7 @@ class Shell(QsciScintillaCompat):
         
     def focusNextPrevChild(self, next):
         """
-        Reimplemented to stop Tab moving to the next window.
+        Public method to stop Tab moving to the next window.
         
         While the user is entering a multi-line command, the movement to
         the next window by the Tab key being pressed is suppressed.
@@ -1414,7 +1475,7 @@ class Shell(QsciScintillaCompat):
         
     def contextMenuEvent(self, ev):
         """
-        Reimplemented to show our own context menu.
+        Protected method to show our own context menu.
         
         @param ev context menu event (QContextMenuEvent)
         """
@@ -1444,7 +1505,7 @@ class Shell(QsciScintillaCompat):
     def __startDebugClient(self, action):
         """
         Private slot to start a debug client according to the action
-        triggered[()].
+        triggered.
         
         @param action context menu action that was triggered (QAction)
         """
@@ -1541,7 +1602,7 @@ class Shell(QsciScintillaCompat):
         if self.inDragDrop:
             event.acceptProposedAction()
         else:
-            super().dragEnterEvent(event)
+            super(Shell, self).dragEnterEvent(event)
         
     def dragMoveEvent(self, event):
         """
@@ -1552,7 +1613,7 @@ class Shell(QsciScintillaCompat):
         if self.inDragDrop:
             event.accept()
         else:
-            super().dragMoveEvent(event)
+            super(Shell, self).dragMoveEvent(event)
         
     def dragLeaveEvent(self, event):
         """
@@ -1564,7 +1625,7 @@ class Shell(QsciScintillaCompat):
             self.inDragDrop = False
             event.accept()
         else:
-            super().dragLeaveEvent(event)
+            super(Shell, self).dragLeaveEvent(event)
         
     def dropEvent(self, event):
         """
@@ -1581,8 +1642,8 @@ class Shell(QsciScintillaCompat):
                     else:
                         E5MessageBox.information(
                             self,
-                            self.trUtf8("Drop Error"),
-                            self.trUtf8("""<p><b>{0}</b> is not a file.</p>""")
+                            self.tr("Drop Error"),
+                            self.tr("""<p><b>{0}</b> is not a file.</p>""")
                             .format(fname))
             event.acceptProposedAction()
         elif event.mimeData().hasText():
@@ -1592,13 +1653,13 @@ class Shell(QsciScintillaCompat):
                 self.executeLines(s)
             del s
         else:
-            super().dropEvent(event)
+            super(Shell, self).dropEvent(event)
         
         self.inDragDrop = False
         
     def focusInEvent(self, event):
         """
-        Public method called when the shell receives focus.
+        Protected method called when the shell receives focus.
         
         @param event the event object (QFocusEvent)
         """
@@ -1630,11 +1691,11 @@ class Shell(QsciScintillaCompat):
         self.setCaretWidth(self.caretWidth)
         self.setCursorFlashTime(QApplication.cursorFlashTime())
         
-        super().focusInEvent(event)
+        super(Shell, self).focusInEvent(event)
         
     def focusOutEvent(self, event):
         """
-        Public method called when the shell loses focus.
+        Protected method called when the shell loses focus.
         
         @param event the event object (QFocusEvent)
         """
@@ -1646,7 +1707,7 @@ class Shell(QsciScintillaCompat):
         self.__searchNextShortcut.setEnabled(False)
         self.__searchPrevShortcut.setEnabled(False)
         self.setCaretWidth(0)
-        super().focusOutEvent(event)
+        super(Shell, self).focusOutEvent(event)
         
     def insert(self, txt):
         """
