@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2013 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2013 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to enter the sort options for a line sort.
 """
 
-from PyQt4.QtGui import QDialog
+from __future__ import unicode_literals
+
+from PyQt5.QtWidgets import QDialog
 
 from .Ui_SortOptionsDialog import Ui_SortOptionsDialog
 
@@ -22,8 +24,11 @@ class SortOptionsDialog(QDialog, Ui_SortOptionsDialog):
         
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(SortOptionsDialog, self).__init__(parent)
         self.setupUi(self)
+        
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
     
     def getData(self):
         """
