@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,9 +9,12 @@ Module implementing the spell checker for the editor component.
 The spell checker is based on pyenchant.
 """
 
-import os
+from __future__ import unicode_literals
 
-from PyQt4.QtCore import QTimer, QObject
+import os
+import sys
+
+from PyQt5.QtCore import QTimer, QObject
 
 import Preferences
 import Utilities
@@ -43,7 +46,7 @@ class SpellChecker(QObject):
         @keyparam checkRegion reference to a function to check for a valid
             region
         """
-        super().__init__(editor)
+        super(SpellChecker, self).__init__(editor)
         
         self.editor = editor
         self.indicator = indicator
@@ -62,7 +65,7 @@ class SpellChecker(QObject):
     @classmethod
     def getAvailableLanguages(cls):
         """
-        Public classmethod to get all available languages.
+        Class method to get all available languages.
         
         @return list of available languages (list of strings)
         """
@@ -75,14 +78,14 @@ class SpellChecker(QObject):
     @classmethod
     def isAvailable(cls):
         """
-        Public classmethod to check, if spellchecking is available.
+        Class method to check, if spellchecking is available.
         
         @return flag indicating availability (boolean)
         """
         if Preferences.getEditor("SpellCheckingEnabled"):
             try:
                 return len(enchant.list_languages()) > 0
-            except NameError:
+            except (NameError, AttributeError):
                 pass
         return False
     
@@ -157,7 +160,7 @@ class SpellChecker(QObject):
     @classmethod
     def setDefaultLanguage(cls, language):
         """
-        Public classmethod to set the default language.
+        Class method to set the default language.
         
         @param language the language to be used as the default (string).
             The string should be in language locale format (e.g. en_US, de).
@@ -283,7 +286,7 @@ class SpellChecker(QObject):
         @param startPos position to start at (integer)
         @param endPos position to end at (integer)
         """
-        if not self.initCheck(startPos,  endPos):
+        if not self.initCheck(startPos, endPos):
             return
         
         while True:
@@ -340,7 +343,10 @@ class SpellChecker(QObject):
                     line, index = self.editor.lineIndexFromPosition(pos)
                     word = self.editor.getWord(line, index, useWordChars=False)
                     if len(word) >= self.minimumWordSize:
-                        ok = spell.check(word)
+                        try:
+                            ok = spell.check(word)
+                        except enchant.errors.Error:
+                            ok = True
                     else:
                         ok = True
                     start, end = self.editor.getWordBoundaries(
@@ -394,7 +400,7 @@ class SpellChecker(QObject):
     
     def checkSelection(self):
         """
-        Private method to check the current selection.
+        Public method to check the current selection.
         """
         selStartLine, selStartIndex, selEndLine, selEndIndex = \
             self.editor.getSelection()
@@ -405,7 +411,7 @@ class SpellChecker(QObject):
     
     def checkCurrentPage(self):
         """
-        Private method to check the currently visible page.
+        Public method to check the currently visible page.
         """
         startLine = self.editor.firstVisibleLine()
         endLine = startLine + self.editor.linesOnScreen()
@@ -501,7 +507,7 @@ class SpellChecker(QObject):
     
     def __iter__(self):
         """
-        Private method to create an iterator.
+        Special method to create an iterator.
         
         @return self
         """
@@ -509,7 +515,7 @@ class SpellChecker(QObject):
     
     def __next__(self):
         """
-        Public method to advance to the next error.
+        Special method to advance to the next error.
         
         @return self
         @exception StopIteration raised to indicate the end of the iteration
@@ -522,8 +528,12 @@ class SpellChecker(QObject):
                 self.pos = wordEnd
                 if (wordEnd - wordStart) >= self.minimumWordSize and \
                    self.__checkRegion(wordStart):
-                    if spell.check(word):
-                        continue
+                    try:
+                        if spell.check(word):
+                            continue
+                    except enchant.errors.Error:
+                        # ignore these
+                        pass
                     if word in self.__ignoreWords:
                         continue
                     self.word = word
@@ -535,3 +545,12 @@ class SpellChecker(QObject):
                     return self
         
         raise StopIteration
+    
+    if sys.version_info.major == 2:
+        def next(self):
+            """
+            Public method to advance to the next error.
+            
+            @return self
+            """
+            return self.__next__()
