@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -11,7 +11,9 @@ that are performed while the user is typing (e.g. insert ')' when the
 user types '(').
 """
 
-from PyQt4.QtCore import QObject
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import QObject
 
 
 class CompleterBase(QObject):
@@ -29,7 +31,7 @@ class CompleterBase(QObject):
         if parent is None:
             parent = editor
         
-        super().__init__(parent)
+        super(CompleterBase, self).__init__(parent)
         
         self.editor = editor
         self.enabled = False
