@@ -1,16 +1,22 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a typing completer for Python.
 """
 
+from __future__ import unicode_literals
+try:
+    chr = unichr
+except NameError:
+    pass
+
 import re
 
-from PyQt4.QtCore import QRegExp
-from PyQt4.Qsci import QsciLexerPython
+from PyQt5.QtCore import QRegExp
+from PyQt5.Qsci import QsciLexerPython
 
 from .CompleterBase import CompleterBase
 
