@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to select the zoom scale.
 """
 
-from PyQt4.QtGui import QDialog
+from __future__ import unicode_literals
+
+from PyQt5.QtWidgets import QDialog
 
 from .Ui_ZoomDialog import Ui_ZoomDialog
 
@@ -25,7 +27,7 @@ class ZoomDialog(QDialog, Ui_ZoomDialog):
         @param name name of this dialog (string)
         @param modal modal dialog state (boolean)
         """
-        super().__init__(parent)
+        super(ZoomDialog, self).__init__(parent)
         if name:
             self.setObjectName(name)
         self.setupUi(self)
@@ -34,6 +36,9 @@ class ZoomDialog(QDialog, Ui_ZoomDialog):
         self.zoomSpinBox.setValue(zoom)
         self.zoomSpinBox.selectAll()
         
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
+        
     def getZoomSize(self):
         """
         Public method to retrieve the zoom size.
