@@ -1,15 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a grabber widget for a rectangular snapshot region.
 """
 
-from PyQt4.QtCore import pyqtSignal, Qt, QRect, QPoint, QTimer, qVersion
-from PyQt4.QtGui import QWidget, QPixmap, QColor, QRegion, QApplication, \
-    QPainter, QPalette, QToolTip, QPaintEngine, QPen, QBrush
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSignal, Qt, QRect, QPoint, QTimer, qVersion
+from PyQt5.QtGui import QPixmap, QColor, QRegion, QPainter, QPalette, \
+    QPaintEngine, QPen, QBrush
+from PyQt5.QtWidgets import QWidget, QApplication, QToolTip
 
 
 def drawRect(painter, rect, outline, fill=QColor()):
@@ -57,7 +60,7 @@ class SnapshotRegionGrabber(QWidget):
         @param mode region grabber mode (SnapshotRegionGrabber.Rectangle or
             SnapshotRegionGrabber.Ellipse)
         """
-        super().__init__(
+        super(SnapshotRegionGrabber, self).__init__(
             None,
             Qt.X11BypassWindowManagerHint | Qt.WindowStaysOnTopHint |
             Qt.FramelessWindowHint | Qt.Tool)
@@ -92,7 +95,7 @@ class SnapshotRegionGrabber(QWidget):
                           self.__BRHandle, self.__LHandle, self.__THandle,
                           self.__RHandle, self.__BHandle]
         self.__helpTextRect = QRect()
-        self.__helpText = self.trUtf8(
+        self.__helpText = self.tr(
             "Select a region using the mouse. To take the snapshot, press"
             " the Enter key or double click. Press Esc to quit.")
         
