@@ -1,15 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the SQL Browser main window.
 """
 
-from PyQt4.QtCore import QTimer, QUrl
-from PyQt4.QtGui import QKeySequence, qApp
-from PyQt4.QtSql import QSqlError, QSqlDatabase
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import QTimer, QUrl
+from PyQt5.QtGui import QKeySequence
+from PyQt5.QtWidgets import qApp
+from PyQt5.QtSql import QSqlError, QSqlDatabase
 
 from E5Gui.E5Action import E5Action
 from E5Gui import E5MessageBox
@@ -33,10 +36,10 @@ class SqlBrowser(E5MainWindow):
             (list of strings)
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(SqlBrowser, self).__init__(parent)
         self.setObjectName("SqlBrowser")
         
-        self.setWindowTitle(self.trUtf8("SQL Browser"))
+        self.setWindowTitle(self.tr("SQL Browser"))
         self.setWindowIcon(UI.PixmapCache.getIcon("eric.png"))
         
         self.setStyle(Preferences.getUI("Style"),
@@ -60,7 +63,7 @@ class SqlBrowser(E5MainWindow):
             url = QUrl(connection, QUrl.TolerantMode)
             if not url.isValid():
                 self.__warnings.append(
-                    self.trUtf8("Invalid URL: {0}").format(connection))
+                    self.tr("Invalid URL: {0}").format(connection))
                 continue
             
             err = self.__browser.addConnection(url.scheme(), url.path(),
@@ -68,7 +71,7 @@ class SqlBrowser(E5MainWindow):
                                                url.host(), url.port(-1))
             if err.type() != QSqlError.NoError:
                 self.__warnings.append(
-                    self.trUtf8("Unable to open connection: {0}".format(
+                    self.tr("Unable to open connection: {0}".format(
                         err.text())))
         
         QTimer.singleShot(0, self.__uiStartUp)
@@ -81,7 +84,7 @@ class SqlBrowser(E5MainWindow):
         for warning in self.__warnings:
             E5MessageBox.warning(
                 self,
-                self.trUtf8("SQL Browser startup problem"),
+                self.tr("SQL Browser startup problem"),
                 warning)
         
         if len(QSqlDatabase.connectionNames()) == 0:
@@ -95,58 +98,58 @@ class SqlBrowser(E5MainWindow):
         self.__actions = []
         
         self.addConnectionAct = E5Action(
-            self.trUtf8('Add Connection'),
+            self.tr('Add Connection'),
             UI.PixmapCache.getIcon("databaseConnection.png"),
-            self.trUtf8('Add &Connection...'),
+            self.tr('Add &Connection...'),
             0, 0, self, 'sql_file_add_connection')
-        self.addConnectionAct.setStatusTip(self.trUtf8(
+        self.addConnectionAct.setStatusTip(self.tr(
             'Open a dialog to add a new database connection'))
-        self.addConnectionAct.setWhatsThis(self.trUtf8(
+        self.addConnectionAct.setWhatsThis(self.tr(
             """<b>Add Connection</b>"""
             """<p>This opens a dialog to add a new database"""
             """ connection.</p>"""
         ))
-        self.addConnectionAct.triggered[()].connect(
+        self.addConnectionAct.triggered.connect(
             self.__browser.addConnectionByDialog)
         self.__actions.append(self.addConnectionAct)
         
         self.exitAct = E5Action(
-            self.trUtf8('Quit'),
+            self.tr('Quit'),
             UI.PixmapCache.getIcon("exit.png"),
-            self.trUtf8('&Quit'),
-            QKeySequence(self.trUtf8("Ctrl+Q", "File|Quit")),
+            self.tr('&Quit'),
+            QKeySequence(self.tr("Ctrl+Q", "File|Quit")),
             0, self, 'sql_file_quit')
-        self.exitAct.setStatusTip(self.trUtf8('Quit the SQL browser'))
-        self.exitAct.setWhatsThis(self.trUtf8(
+        self.exitAct.setStatusTip(self.tr('Quit the SQL browser'))
+        self.exitAct.setWhatsThis(self.tr(
             """<b>Quit</b>"""
             """<p>Quit the SQL browser.</p>"""
         ))
-        self.exitAct.triggered[()].connect(qApp.closeAllWindows)
+        self.exitAct.triggered.connect(qApp.closeAllWindows)
         
         self.aboutAct = E5Action(
-            self.trUtf8('About'),
-            self.trUtf8('&About'),
+            self.tr('About'),
+            self.tr('&About'),
             0, 0, self, 'sql_help_about')
-        self.aboutAct.setStatusTip(self.trUtf8(
+        self.aboutAct.setStatusTip(self.tr(
             'Display information about this software'))
-        self.aboutAct.setWhatsThis(self.trUtf8(
+        self.aboutAct.setWhatsThis(self.tr(
             """<b>About</b>"""
             """<p>Display some information about this software.</p>"""
         ))
-        self.aboutAct.triggered[()].connect(self.__about)
+        self.aboutAct.triggered.connect(self.__about)
         self.__actions.append(self.aboutAct)
         
         self.aboutQtAct = E5Action(
-            self.trUtf8('About Qt'),
-            self.trUtf8('About &Qt'),
+            self.tr('About Qt'),
+            self.tr('About &Qt'),
             0, 0, self, 'sql_help_about_qt')
         self.aboutQtAct.setStatusTip(
-            self.trUtf8('Display information about the Qt toolkit'))
-        self.aboutQtAct.setWhatsThis(self.trUtf8(
+            self.tr('Display information about the Qt toolkit'))
+        self.aboutQtAct.setWhatsThis(self.tr(
             """<b>About Qt</b>"""
             """<p>Display some information about the Qt toolkit.</p>"""
         ))
-        self.aboutQtAct.triggered[()].connect(self.__aboutQt)
+        self.aboutQtAct.triggered.connect(self.__aboutQt)
         self.__actions.append(self.aboutQtAct)
     
     def __initMenus(self):
@@ -155,7 +158,7 @@ class SqlBrowser(E5MainWindow):
         """
         mb = self.menuBar()
         
-        menu = mb.addMenu(self.trUtf8('&File'))
+        menu = mb.addMenu(self.tr('&File'))
         menu.setTearOffEnabled(True)
         menu.addAction(self.addConnectionAct)
         menu.addSeparator()
@@ -163,7 +166,7 @@ class SqlBrowser(E5MainWindow):
         
         mb.addSeparator()
         
-        menu = mb.addMenu(self.trUtf8('&Help'))
+        menu = mb.addMenu(self.tr('&Help'))
         menu.setTearOffEnabled(True)
         menu.addAction(self.aboutAct)
         menu.addAction(self.aboutQtAct)
@@ -172,7 +175,7 @@ class SqlBrowser(E5MainWindow):
         """
         Private method to create the toolbars.
         """
-        filetb = self.addToolBar(self.trUtf8("File"))
+        filetb = self.addToolBar(self.tr("File"))
         filetb.setObjectName("FileToolBar")
         filetb.setIconSize(UI.Config.ToolBarIconSize)
         filetb.addAction(self.addConnectionAct)
@@ -185,8 +188,8 @@ class SqlBrowser(E5MainWindow):
         """
         E5MessageBox.about(
             self,
-            self.trUtf8("SQL Browser"),
-            self.trUtf8(
+            self.tr("SQL Browser"),
+            self.tr(
                 """<h3>About SQL Browser</h3>"""
                 """<p>The SQL browser window is a little tool to examine """
                 """the data and the schema of a database and to execute """
@@ -198,4 +201,4 @@ class SqlBrowser(E5MainWindow):
         """
         Private slot to show info about Qt.
         """
-        E5MessageBox.aboutQt(self, self.trUtf8("SQL Browser"))
+        E5MessageBox.aboutQt(self, self.tr("SQL Browser"))
