@@ -1,15 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the SQL Browser widget.
 """
 
-from PyQt4.QtCore import pyqtSignal, QVariant, Qt, pyqtSlot
-from PyQt4.QtGui import QWidget, QStandardItemModel, QDialog, QAbstractItemView
-from PyQt4.QtSql import QSqlDatabase, QSqlError, QSqlTableModel, \
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import pyqtSignal, QVariant, Qt, pyqtSlot
+from PyQt5.QtGui import QStandardItemModel
+from PyQt5.QtWidgets import QWidget, QDialog, QAbstractItemView
+from PyQt5.QtSql import QSqlDatabase, QSqlError, QSqlTableModel, \
     QSqlQueryModel, QSqlQuery
 
 from E5Gui import E5MessageBox
@@ -33,7 +36,7 @@ class SqlBrowserWidget(QWidget, Ui_SqlBrowserWidget):
         
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(SqlBrowserWidget, self).__init__(parent)
         self.setupUi(self)
         
         self.table.addAction(self.insertRowAction)
@@ -42,8 +45,8 @@ class SqlBrowserWidget(QWidget, Ui_SqlBrowserWidget):
         if len(QSqlDatabase.drivers()) == 0:
             E5MessageBox.information(
                 self,
-                self.trUtf8("No database drivers found"),
-                self.trUtf8(
+                self.tr("No database drivers found"),
+                self.tr(
                     """This tool requires at least one Qt database driver. """
                     """Please check the Qt documentation how to build the """
                     """Qt SQL plugins."""))
@@ -54,7 +57,7 @@ class SqlBrowserWidget(QWidget, Ui_SqlBrowserWidget):
             self.on_connections_schemaRequested)
         self.connections.cleared.connect(self.on_connections_cleared)
         
-        self.statusMessage.emit(self.trUtf8("Ready"))
+        self.statusMessage.emit(self.tr("Ready"))
     
     @pyqtSlot()
     def on_clearButton_clicked(self):
@@ -159,8 +162,8 @@ class SqlBrowserWidget(QWidget, Ui_SqlBrowserWidget):
             if err.type() != QSqlError.NoError:
                 E5MessageBox.warning(
                     self,
-                    self.trUtf8("Unable to open database"),
-                    self.trUtf8(
+                    self.tr("Unable to open database"),
+                    self.tr(
                         """An error occurred while opening the connection."""))
     
     def showTable(self, table):
@@ -250,7 +253,7 @@ class SqlBrowserWidget(QWidget, Ui_SqlBrowserWidget):
     
     def __insertRow(self):
         """
-        Privat slot to insert a row into the database table.
+        Private slot to insert a row into the database table.
         """
         model = self.table.model()
         if not isinstance(model, QSqlTableModel):
@@ -268,7 +271,7 @@ class SqlBrowserWidget(QWidget, Ui_SqlBrowserWidget):
     
     def __deleteRow(self):
         """
-        Privat slot to delete a row from the database table.
+        Private slot to delete a row from the database table.
         """
         model = self.table.model()
         if not isinstance(model, QSqlTableModel):
@@ -299,10 +302,10 @@ class SqlBrowserWidget(QWidget, Ui_SqlBrowserWidget):
         if model.lastError().type() != QSqlError.NoError:
             self.statusMessage.emit(model.lastError().text())
         elif model.query().isSelect():
-            self.statusMessage.emit(self.trUtf8("Query OK."))
+            self.statusMessage.emit(self.tr("Query OK."))
         else:
             self.statusMessage.emit(
-                self.trUtf8("Query OK, number of affected rows: {0}")
+                self.tr("Query OK, number of affected rows: {0}")
                     .format(model.query().numRowsAffected()))
         
         self.table.resizeColumnsToContents()
