@@ -1,15 +1,17 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the task properties dialog.
 """
 
+from __future__ import unicode_literals
+
 import time
 
-from PyQt4.QtGui import QDialog
+from PyQt5.QtWidgets import QDialog
 
 from E5Gui.E5Completers import E5FileCompleter
 
@@ -28,7 +30,7 @@ class TaskPropertiesDialog(QDialog, Ui_TaskPropertiesDialog):
         @param parent the parent widget (QWidget)
         @param projectOpen flag indicating status of the project (boolean)
         """
-        super().__init__(parent)
+        super(TaskPropertiesDialog, self).__init__(parent)
         self.setupUi(self)
         
         self.filenameCompleter = E5FileCompleter(self.filenameEdit)
