@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog for entering multiple template variables.
 """
 
-from PyQt4.QtCore import QSize, Qt
-from PyQt4.QtGui import QSizePolicy, QSpacerItem, QWidget, QHBoxLayout, \
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import QSize, Qt
+from PyQt5.QtWidgets import QSizePolicy, QSpacerItem, QWidget, QHBoxLayout, \
     QLineEdit, QPushButton, QTextEdit, QDialog, QScrollArea, QFrame, \
     QGridLayout, QVBoxLayout, QLabel
 
@@ -24,7 +26,7 @@ class TemplateMultipleVariablesDialog(QDialog):
         @param variables list of template variable names (list of strings)
         @param parent parent widget of this dialog (QWidget)
         """
-        super().__init__(parent)
+        super(TemplateMultipleVariablesDialog, self).__init__(parent)
 
         self.TemplateMultipleVariablesDialogLayout = QVBoxLayout(self)
         self.TemplateMultipleVariablesDialogLayout.setContentsMargins(
@@ -101,15 +103,15 @@ class TemplateMultipleVariablesDialog(QDialog):
         self.TemplateMultipleVariablesDialogLayout.addLayout(layout1)
 
         # set the texts of the standard widgets
-        self.setWindowTitle(self.trUtf8("Enter Template Variables"))
-        self.okButton.setText(self.trUtf8("&OK"))
-        self.cancelButton.setText(self.trUtf8("&Cancel"))
+        self.setWindowTitle(self.tr("Enter Template Variables"))
+        self.okButton.setText(self.tr("&OK"))
+        self.cancelButton.setText(self.tr("&Cancel"))
 
         # polish up the dialog
         self.resize(QSize(400, 480).expandedTo(self.minimumSizeHint()))
 
-        self.okButton.clicked[()].connect(self.accept)
-        self.cancelButton.clicked[()].connect(self.reject)
+        self.okButton.clicked.connect(self.accept)
+        self.cancelButton.clicked.connect(self.reject)
 
     def getVariables(self):
         """
