@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog for entering a single template variable.
 """
 
-from PyQt4.QtGui import QDialog
+from __future__ import unicode_literals
+
+from PyQt5.QtWidgets import QDialog
 
 from .Ui_TemplateSingleVariableDialog import Ui_TemplateSingleVariableDialog
 
@@ -23,7 +25,7 @@ class TemplateSingleVariableDialog(QDialog, Ui_TemplateSingleVariableDialog):
         @param variable template variable name (string)
         @param parent parent widget of this dialog (QWidget)
         """
-        super().__init__(parent)
+        super(TemplateSingleVariableDialog, self).__init__(parent)
         self.setupUi(self)
         
         self.variableLabel.setText(variable)
