@@ -1,18 +1,20 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a template viewer and associated classes.
 """
 
+from __future__ import unicode_literals
+
 import datetime
 import os
 import re
 
-from PyQt4.QtCore import QFile, QFileInfo, QIODevice, Qt
-from PyQt4.QtGui import QTreeWidget, QDialog, QApplication, QMenu, \
+from PyQt5.QtCore import QFile, QFileInfo, QIODevice, Qt, QCoreApplication
+from PyQt5.QtWidgets import QTreeWidget, QDialog, QApplication, QMenu, \
     QTreeWidgetItem
 
 from E5Gui.E5Application import e5App
@@ -40,7 +42,7 @@ class TemplateGroup(QTreeWidgetItem):
         self.language = language
         self.entries = {}
         
-        super().__init__(parent, [name])
+        super(TemplateGroup, self).__init__(parent, [name])
         
         if Preferences.getTemplates("ShowTooltip"):
             self.setToolTip(0, language)
@@ -93,8 +95,9 @@ class TemplateGroup(QTreeWidgetItem):
             if not quiet:
                 E5MessageBox.critical(
                     None,
-                    QApplication.translate("TemplateGroup", "Add Template"),
-                    QApplication.translate(
+                    QCoreApplication.translate("TemplateGroup",
+                                               "Add Template"),
+                    QCoreApplication.translate(
                         "TemplateGroup",
                         """<p>The group <b>{0}</b> already contains a"""
                         """ template named <b>{1}</b>.</p>""")
@@ -194,7 +197,7 @@ class TemplateEntry(QTreeWidgetItem):
         self.template = templateText
         self.__extractVariables()
         
-        super().__init__(parent, [self.__displayText()])
+        super(TemplateEntry, self).__init__(parent, [self.__displayText()])
         if Preferences.getTemplates("ShowTooltip"):
             self.setToolTip(0, self.template)
 
@@ -361,9 +364,9 @@ class TemplateEntry(QTreeWidgetItem):
         self.variables = []
         self.formatedVariables = []
         for var in variables:
-            if not var in self.variables:
+            if var not in self.variables:
                 self.variables.append(var)
-            if var.find(':') >= 0 and not var in self.formatedVariables:
+            if var.find(':') >= 0 and var not in self.formatedVariables:
                 self.formatedVariables.append(var)
 
 
@@ -378,7 +381,7 @@ class TemplateViewer(QTreeWidget):
         @param parent the parent (QWidget)
         @param viewmanager reference to the viewmanager object
         """
-        super().__init__(parent)
+        super(TemplateViewer, self).__init__(parent)
         
         self.viewmanager = viewmanager
         self.groups = {}
@@ -391,36 +394,36 @@ class TemplateViewer(QTreeWidget):
         
         self.__menu = QMenu(self)
         self.applyAct = self.__menu.addAction(
-            self.trUtf8("Apply"), self.__templateItemActivated)
+            self.tr("Apply"), self.__templateItemActivated)
         self.__menu.addSeparator()
-        self.__menu.addAction(self.trUtf8("Add entry..."), self.__addEntry)
-        self.__menu.addAction(self.trUtf8("Add group..."), self.__addGroup)
-        self.__menu.addAction(self.trUtf8("Edit..."), self.__edit)
-        self.__menu.addAction(self.trUtf8("Remove"), self.__remove)
+        self.__menu.addAction(self.tr("Add entry..."), self.__addEntry)
+        self.__menu.addAction(self.tr("Add group..."), self.__addGroup)
+        self.__menu.addAction(self.tr("Edit..."), self.__edit)
+        self.__menu.addAction(self.tr("Remove"), self.__remove)
         self.__menu.addSeparator()
-        self.__menu.addAction(self.trUtf8("Save"), self.save)
-        self.__menu.addAction(self.trUtf8("Import..."), self.__import)
-        self.__menu.addAction(self.trUtf8("Export..."), self.__export)
-        self.__menu.addAction(self.trUtf8("Reload"), self.__reload)
+        self.__menu.addAction(self.tr("Save"), self.save)
+        self.__menu.addAction(self.tr("Import..."), self.__import)
+        self.__menu.addAction(self.tr("Export..."), self.__export)
+        self.__menu.addAction(self.tr("Reload"), self.__reload)
         self.__menu.addSeparator()
         self.__menu.addAction(
-            self.trUtf8("Help about Templates..."), self.__showHelp)
+            self.tr("Help about Templates..."), self.__showHelp)
         self.__menu.addSeparator()
-        self.__menu.addAction(self.trUtf8("Configure..."), self.__configure)
+        self.__menu.addAction(self.tr("Configure..."), self.__configure)
         
         self.__backMenu = QMenu(self)
-        self.__backMenu.addAction(self.trUtf8("Add group..."), self.__addGroup)
+        self.__backMenu.addAction(self.tr("Add group..."), self.__addGroup)
         self.__backMenu.addSeparator()
-        self.__backMenu.addAction(self.trUtf8("Save"), self.save)
-        self.__backMenu.addAction(self.trUtf8("Import..."), self.__import)
-        self.__backMenu.addAction(self.trUtf8("Export..."), self.__export)
-        self.__backMenu.addAction(self.trUtf8("Reload"), self.__reload)
+        self.__backMenu.addAction(self.tr("Save"), self.save)
+        self.__backMenu.addAction(self.tr("Import..."), self.__import)
+        self.__backMenu.addAction(self.tr("Export..."), self.__export)
+        self.__backMenu.addAction(self.tr("Reload"), self.__reload)
         self.__backMenu.addSeparator()
         self.__backMenu.addAction(
-            self.trUtf8("Help about Templates..."), self.__showHelp)
+            self.tr("Help about Templates..."), self.__showHelp)
         self.__backMenu.addSeparator()
         self.__backMenu.addAction(
-            self.trUtf8("Configure..."), self.__configure)
+            self.tr("Configure..."), self.__configure)
         
         self.__activating = False
         self.__dirty = False
@@ -523,8 +526,8 @@ class TemplateViewer(QTreeWidget):
         itm = self.currentItem()
         res = E5MessageBox.yesNo(
             self,
-            self.trUtf8("Remove Template"),
-            self.trUtf8("""<p>Do you really want to remove <b>{0}</b>?</p>""")
+            self.tr("Remove Template"),
+            self.tr("""<p>Do you really want to remove <b>{0}</b>?</p>""")
             .format(itm.getName()))
         if not res:
             return
@@ -550,9 +553,9 @@ class TemplateViewer(QTreeWidget):
         """
         fn = E5FileDialog.getOpenFileName(
             self,
-            self.trUtf8("Import Templates"),
+            self.tr("Import Templates"),
             "",
-            self.trUtf8("Templates Files (*.e4c);; All Files (*)"))
+            self.tr("Templates Files (*.e4c);; All Files (*)"))
         
         if fn:
             self.readTemplates(fn)
@@ -564,9 +567,9 @@ class TemplateViewer(QTreeWidget):
         """
         fn, selectedFilter = E5FileDialog.getSaveFileNameAndFilter(
             self,
-            self.trUtf8("Export Templates"),
+            self.tr("Export Templates"),
             "",
-            self.trUtf8("Templates Files (*.e4c);; All Files (*)"),
+            self.tr("Templates Files (*.e4c);; All Files (*)"),
             "",
             E5FileDialog.Options(E5FileDialog.DontConfirmOverwrite))
         
@@ -585,8 +588,8 @@ class TemplateViewer(QTreeWidget):
         if self.__dirty:
             res = E5MessageBox.yesNo(
                 self,
-                self.trUtf8("Reload Templates"),
-                self.trUtf8(
+                self.tr("Reload Templates"),
+                self.tr(
                     """The templates contain unsaved changes. Shall these"""
                     """ changes be discarded?"""),
                 icon=E5MessageBox.Warning)
@@ -604,8 +607,8 @@ class TemplateViewer(QTreeWidget):
         """
         E5MessageBox.information(
             self,
-            self.trUtf8("Template Help"),
-            self.trUtf8(
+            self.tr("Template Help"),
+            self.tr(
                 """<p><b>Template groups</b> are a means of grouping"""
                 """ individual templates. Groups have an attribute that"""
                 """ specifies, which programming language they apply for."""
@@ -739,7 +742,7 @@ class TemplateViewer(QTreeWidget):
                 for aline in txt.splitlines():
                     count = aline.find("i_n_s_e_r_t_i_o_n")
                     if count >= 0:
-                        txt = txt.replace("i_n_s_e_r_t_i_o_n",  "")
+                        txt = txt.replace("i_n_s_e_r_t_i_o_n", "")
                         if lines == 1:
                             count += index
                         else:
@@ -756,7 +759,7 @@ class TemplateViewer(QTreeWidget):
                 for aline in txt.splitlines():
                     posa = aline.find("s_e_l_e_c_t_s_t_a_r_t")
                     if posa >= 0:
-                        txt = txt.replace("s_e_l_e_c_t_s_t_a_r_t",  "")
+                        txt = txt.replace("s_e_l_e_c_t_s_t_a_r_t", "")
                         break
                     else:
                         linea += 1
@@ -764,7 +767,7 @@ class TemplateViewer(QTreeWidget):
                 for aline in txt.splitlines():
                     posb = aline.find("s_e_l_e_c_t_e_n_d")
                     if posb >= 0:
-                        txt = txt.replace("s_e_l_e_c_t_e_n_d",  "")
+                        txt = txt.replace("s_e_l_e_c_t_e_n_d", "")
                         break
                     else:
                         lineb += 1
@@ -848,9 +851,9 @@ class TemplateViewer(QTreeWidget):
             if newname in self.groups:
                 E5MessageBox.warning(
                     self,
-                    self.trUtf8("Edit Template Group"),
-                    self.trUtf8("""<p>A template group with the name"""
-                                """ <b>{0}</b> already exists.</p>""")
+                    self.tr("Edit Template Group"),
+                    self.tr("""<p>A template group with the name"""
+                            """ <b>{0}</b> already exists.</p>""")
                     .format(newname))
                 return
             
@@ -936,14 +939,14 @@ class TemplateViewer(QTreeWidget):
         """
         if filename is None:
             filename = os.path.join(
-                Utilities.getConfigDir(), "eric5templates.e4c")
+                Utilities.getConfigDir(), "eric6templates.e4c")
         f = QFile(filename)
         ok = f.open(QIODevice.WriteOnly)
         if not ok:
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Save templates"),
-                self.trUtf8(
+                self.tr("Save templates"),
+                self.tr(
                     "<p>The templates file <b>{0}</b> could not be"
                     " written.</p>")
                 .format(filename))
@@ -963,7 +966,7 @@ class TemplateViewer(QTreeWidget):
         """
         if filename is None:
             filename = os.path.join(
-                Utilities.getConfigDir(), "eric5templates.e4c")
+                Utilities.getConfigDir(), "eric6templates.e4c")
             if not os.path.exists(filename):
                 return
         
@@ -976,8 +979,8 @@ class TemplateViewer(QTreeWidget):
         else:
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Read templates"),
-                self.trUtf8(
+                self.tr("Read templates"),
+                self.tr(
                     "<p>The templates file <b>{0}</b> could not be read.</p>")
                 .format(filename))
     
