@@ -6,10 +6,12 @@
     Module containing filter lookup functions and default
     filters.
 
-    :copyright: Copyright 2006-2012 by the Pygments team, see AUTHORS.
+    :copyright: Copyright 2006-2013 by the Pygments team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
+from __future__ import unicode_literals
+
 import re
 
 from pygments.token import String, Comment, Keyword, Name, Error, Whitespace, \
@@ -117,7 +119,7 @@ class KeywordCaseFilter(Filter):
     def __init__(self, **options):
         Filter.__init__(self, **options)
         case = get_choice_opt(options, 'case', ['lower', 'upper', 'capitalize'], 'lower')
-        self.convert = getattr(unicode, case)
+        self.convert = getattr(str, case)
 
     def filter(self, lexer, stream):
         for ttype, value in stream:
@@ -235,9 +237,9 @@ class VisibleWhitespaceFilter(Filter):
 
     def __init__(self, **options):
         Filter.__init__(self, **options)
-        for name, default in {'spaces': u'·', 'tabs': u'»', 'newlines': u'¶'}.items():
+        for name, default in list({'spaces': '·', 'tabs': '»', 'newlines': '¶'}.items()):
             opt = options.get(name, False)
-            if isinstance(opt, basestring) and len(opt) == 1:
+            if isinstance(opt, str) and len(opt) == 1:
                 setattr(self, name, opt)
             else:
                 setattr(self, name, (opt and default or ''))
@@ -331,7 +333,6 @@ class TokenMergeFilter(Filter):
         Filter.__init__(self, **options)
 
     def filter(self, lexer, stream):
-        output = []
         current_type = None
         current_value = None
         for ttype, value in stream:
