@@ -5,10 +5,12 @@
 
     pygments version of my "fruity" vim theme.
 
-    :copyright: Copyright 2006-2009 by the Pygments team, see AUTHORS.
+    :copyright: Copyright 2006-2013 by the Pygments team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
+from __future__ import unicode_literals
+
 from pygments.style import Style
 from pygments.token import Token, Comment, Name, Keyword, \
     Generic, Number, String, Whitespace
@@ -30,7 +32,6 @@ class FruityStyle(Style):
         Number:             '#0086f7 bold',
         Name.Tag:           '#fb660a bold',
         Name.Variable:      '#fb660a',
-        Name.Constant:      '#fb660a',
         Comment:            '#008800 bg:#0f140f italic',
         Name.Attribute:     '#ff0086 bold',
         String:             '#0086d2',
