@@ -1,20 +1,24 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the TR Previewer main window.
 """
 
+from __future__ import unicode_literals
+
 import os
 
-from PyQt4.QtCore import QDir, QTimer, QFileInfo, pyqtSignal, QEvent, QSize, \
-    QTranslator, QObject, Qt
-from PyQt4.QtGui import QSizePolicy, QSpacerItem, QWidget, QHBoxLayout, \
-    QKeySequence, QWhatsThis, QMdiArea, qApp, QApplication, QComboBox, \
-    QVBoxLayout, QAction, QLabel
-from PyQt4 import uic
+from PyQt5.QtCore import QDir, QTimer, QFileInfo, pyqtSignal, QEvent, QSize, \
+    QTranslator, QObject, Qt, QCoreApplication
+from PyQt5.QtGui import QKeySequence
+from PyQt5.QtWidgets import QSizePolicy, QSpacerItem, QWidget, QHBoxLayout, \
+    QWhatsThis, QMdiArea, qApp, QApplication, QComboBox, QVBoxLayout, \
+    QAction, QLabel
+from PyQt5 import uic
+
 
 from E5Gui import E5MessageBox, E5FileDialog
 from E5Gui.E5MainWindow import E5MainWindow
@@ -25,7 +29,8 @@ import UI.Config
 import Preferences
 
 
-noTranslationName = QApplication.translate("TRPreviewer", "<No translation>")
+noTranslationName = QCoreApplication.translate(
+    "TRPreviewer", "<No translation>")
 
 
 class TRPreviewer(E5MainWindow):
@@ -43,7 +48,7 @@ class TRPreviewer(E5MainWindow):
         self.mainWidget = None
         self.currentFile = QDir.currentPath()
         
-        super().__init__(parent)
+        super(TRPreviewer, self).__init__(parent)
         if not name:
             self.setObjectName("TRPreviewer")
         else:
@@ -53,11 +58,10 @@ class TRPreviewer(E5MainWindow):
                       Preferences.getUI("StyleSheet"))
         
         self.resize(QSize(800, 600).expandedTo(self.minimumSizeHint()))
-        self.setAttribute(Qt.WA_DeleteOnClose)
         self.statusBar()
         
         self.setWindowIcon(UI.PixmapCache.getIcon("eric.png"))
-        self.setWindowTitle(self.trUtf8("Translations Previewer"))
+        self.setWindowTitle(self.tr("Translations Previewer"))
 
         self.cw = QWidget(self)
         self.cw.setObjectName("qt_central_widget")
@@ -73,14 +77,14 @@ class TRPreviewer(E5MainWindow):
         self.languageLayout.setObjectName("languageLayout")
 
         self.languageLabel = QLabel(
-            self.trUtf8("Select language file"), self.cw)
+            self.tr("Select language file"), self.cw)
         self.languageLabel.setObjectName("languageLabel")
         self.languageLayout.addWidget(self.languageLabel)
 
         self.languageCombo = QComboBox(self.cw)
         self.languageCombo.setObjectName("languageCombo")
         self.languageCombo.setEditable(False)
-        self.languageCombo.setToolTip(self.trUtf8("Select language file"))
+        self.languageCombo.setToolTip(self.tr("Select language file"))
         self.languageCombo.setSizePolicy(
             QSizePolicy.Expanding, QSizePolicy.Preferred)
         self.languageLayout.addWidget(self.languageCombo)
@@ -126,7 +130,7 @@ class TRPreviewer(E5MainWindow):
         the main window has been shown. This way, previewing a dialog
         doesn't interfere with showing the main window.
         """
-        super().show()
+        super(TRPreviewer, self).show()
         if self.filesToLoad:
             filenames, self.filesToLoad = (self.filesToLoad[:], [])
             first = True
@@ -142,7 +146,7 @@ class TRPreviewer(E5MainWindow):
         
     def closeEvent(self, event):
         """
-        Private event handler for the close event.
+        Protected event handler for the close event.
         
         @param event close event (QCloseEvent)
         """
@@ -157,54 +161,54 @@ class TRPreviewer(E5MainWindow):
         """
         self.openUIAct = QAction(
             UI.PixmapCache.getIcon("openUI.png"),
-            self.trUtf8('&Open UI Files...'), self)
-        self.openUIAct.setStatusTip(self.trUtf8('Open UI files for display'))
-        self.openUIAct.setWhatsThis(self.trUtf8(
+            self.tr('&Open UI Files...'), self)
+        self.openUIAct.setStatusTip(self.tr('Open UI files for display'))
+        self.openUIAct.setWhatsThis(self.tr(
             """<b>Open UI Files</b>"""
             """<p>This opens some UI files for display.</p>"""
         ))
-        self.openUIAct.triggered[()].connect(self.__openWidget)
+        self.openUIAct.triggered.connect(self.__openWidget)
         
         self.openQMAct = QAction(
             UI.PixmapCache.getIcon("openQM.png"),
-            self.trUtf8('Open &Translation Files...'), self)
-        self.openQMAct.setStatusTip(self.trUtf8(
+            self.tr('Open &Translation Files...'), self)
+        self.openQMAct.setStatusTip(self.tr(
             'Open Translation files for display'))
-        self.openQMAct.setWhatsThis(self.trUtf8(
+        self.openQMAct.setWhatsThis(self.tr(
             """<b>Open Translation Files</b>"""
             """<p>This opens some translation files for display.</p>"""
         ))
-        self.openQMAct.triggered[()].connect(self.__openTranslation)
+        self.openQMAct.triggered.connect(self.__openTranslation)
         
         self.reloadAct = QAction(
             UI.PixmapCache.getIcon("reload.png"),
-            self.trUtf8('&Reload Translations'), self)
-        self.reloadAct.setStatusTip(self.trUtf8(
+            self.tr('&Reload Translations'), self)
+        self.reloadAct.setStatusTip(self.tr(
             'Reload the loaded translations'))
-        self.reloadAct.setWhatsThis(self.trUtf8(
+        self.reloadAct.setWhatsThis(self.tr(
             """<b>Reload Translations</b>"""
             """<p>This reloads the translations for the loaded"""
             """ languages.</p>"""
         ))
-        self.reloadAct.triggered[()].connect(self.translations.reload)
+        self.reloadAct.triggered.connect(self.translations.reload)
         
         self.exitAct = QAction(
-            UI.PixmapCache.getIcon("exit.png"), self.trUtf8('&Quit'), self)
+            UI.PixmapCache.getIcon("exit.png"), self.tr('&Quit'), self)
         self.exitAct.setShortcut(QKeySequence(
-            self.trUtf8("Ctrl+Q", "File|Quit")))
-        self.exitAct.setStatusTip(self.trUtf8('Quit the application'))
-        self.exitAct.setWhatsThis(self.trUtf8(
+            self.tr("Ctrl+Q", "File|Quit")))
+        self.exitAct.setStatusTip(self.tr('Quit the application'))
+        self.exitAct.setWhatsThis(self.tr(
             """<b>Quit</b>"""
             """<p>Quit the application.</p>"""
         ))
-        self.exitAct.triggered[()].connect(qApp.closeAllWindows)
+        self.exitAct.triggered.connect(qApp.closeAllWindows)
         
         self.whatsThisAct = QAction(
             UI.PixmapCache.getIcon("whatsThis.png"),
-            self.trUtf8('&What\'s This?'), self)
-        self.whatsThisAct.setShortcut(QKeySequence(self.trUtf8("Shift+F1")))
-        self.whatsThisAct.setStatusTip(self.trUtf8('Context sensitive help'))
-        self.whatsThisAct.setWhatsThis(self.trUtf8(
+            self.tr('&What\'s This?'), self)
+        self.whatsThisAct.setShortcut(QKeySequence(self.tr("Shift+F1")))
+        self.whatsThisAct.setStatusTip(self.tr('Context sensitive help'))
+        self.whatsThisAct.setWhatsThis(self.tr(
             """<b>Display context sensitive help</b>"""
             """<p>In What's This? mode, the mouse cursor shows an arrow"""
             """ with a question mark, and you can click on the interface"""
@@ -212,62 +216,62 @@ class TRPreviewer(E5MainWindow):
             """ how to use them. In dialogs, this feature can be accessed"""
             """ using the context help button in the titlebar.</p>"""
         ))
-        self.whatsThisAct.triggered[()].connect(self.__whatsThis)
+        self.whatsThisAct.triggered.connect(self.__whatsThis)
 
-        self.aboutAct = QAction(self.trUtf8('&About'), self)
-        self.aboutAct.setStatusTip(self.trUtf8(
+        self.aboutAct = QAction(self.tr('&About'), self)
+        self.aboutAct.setStatusTip(self.tr(
             'Display information about this software'))
-        self.aboutAct.setWhatsThis(self.trUtf8(
+        self.aboutAct.setWhatsThis(self.tr(
             """<b>About</b>"""
             """<p>Display some information about this software.</p>"""
         ))
-        self.aboutAct.triggered[()].connect(self.__about)
+        self.aboutAct.triggered.connect(self.__about)
         
-        self.aboutQtAct = QAction(self.trUtf8('About &Qt'), self)
+        self.aboutQtAct = QAction(self.tr('About &Qt'), self)
         self.aboutQtAct.setStatusTip(
-            self.trUtf8('Display information about the Qt toolkit'))
-        self.aboutQtAct.setWhatsThis(self.trUtf8(
+            self.tr('Display information about the Qt toolkit'))
+        self.aboutQtAct.setWhatsThis(self.tr(
             """<b>About Qt</b>"""
             """<p>Display some information about the Qt toolkit.</p>"""
         ))
-        self.aboutQtAct.triggered[()].connect(self.__aboutQt)
+        self.aboutQtAct.triggered.connect(self.__aboutQt)
         
-        self.tileAct = QAction(self.trUtf8('&Tile'), self)
-        self.tileAct.setStatusTip(self.trUtf8('Tile the windows'))
-        self.tileAct.setWhatsThis(self.trUtf8(
+        self.tileAct = QAction(self.tr('&Tile'), self)
+        self.tileAct.setStatusTip(self.tr('Tile the windows'))
+        self.tileAct.setWhatsThis(self.tr(
             """<b>Tile the windows</b>"""
             """<p>Rearrange and resize the windows so that they are"""
             """ tiled.</p>"""
         ))
-        self.tileAct.triggered[()].connect(self.preview.tileSubWindows)
+        self.tileAct.triggered.connect(self.preview.tileSubWindows)
         
-        self.cascadeAct = QAction(self.trUtf8('&Cascade'), self)
-        self.cascadeAct.setStatusTip(self.trUtf8('Cascade the windows'))
-        self.cascadeAct.setWhatsThis(self.trUtf8(
+        self.cascadeAct = QAction(self.tr('&Cascade'), self)
+        self.cascadeAct.setStatusTip(self.tr('Cascade the windows'))
+        self.cascadeAct.setWhatsThis(self.tr(
             """<b>Cascade the windows</b>"""
             """<p>Rearrange and resize the windows so that they are"""
             """ cascaded.</p>"""
         ))
-        self.cascadeAct.triggered[()].connect(self.preview.cascadeSubWindows)
+        self.cascadeAct.triggered.connect(self.preview.cascadeSubWindows)
         
         self.closeAct = QAction(
-            UI.PixmapCache.getIcon("close.png"), self.trUtf8('&Close'), self)
-        self.closeAct.setShortcut(QKeySequence(self.trUtf8(
+            UI.PixmapCache.getIcon("close.png"), self.tr('&Close'), self)
+        self.closeAct.setShortcut(QKeySequence(self.tr(
             "Ctrl+W", "File|Close")))
-        self.closeAct.setStatusTip(self.trUtf8('Close the current window'))
-        self.closeAct.setWhatsThis(self.trUtf8(
+        self.closeAct.setStatusTip(self.tr('Close the current window'))
+        self.closeAct.setWhatsThis(self.tr(
             """<b>Close Window</b>"""
             """<p>Close the current window.</p>"""
         ))
-        self.closeAct.triggered[()].connect(self.preview.closeWidget)
+        self.closeAct.triggered.connect(self.preview.closeWidget)
         
-        self.closeAllAct = QAction(self.trUtf8('Clos&e All'), self)
-        self.closeAllAct.setStatusTip(self.trUtf8('Close all windows'))
-        self.closeAllAct.setWhatsThis(self.trUtf8(
+        self.closeAllAct = QAction(self.tr('Clos&e All'), self)
+        self.closeAllAct.setStatusTip(self.tr('Close all windows'))
+        self.closeAllAct.setWhatsThis(self.tr(
             """<b>Close All Windows</b>"""
             """<p>Close all windows.</p>"""
         ))
-        self.closeAllAct.triggered[()].connect(self.preview.closeAllWidgets)
+        self.closeAllAct.triggered.connect(self.preview.closeAllWidgets)
 
     def __initMenus(self):
         """
@@ -275,7 +279,7 @@ class TRPreviewer(E5MainWindow):
         """
         mb = self.menuBar()
 
-        menu = mb.addMenu(self.trUtf8('&File'))
+        menu = mb.addMenu(self.tr('&File'))
         menu.setTearOffEnabled(True)
         menu.addAction(self.openUIAct)
         menu.addAction(self.openQMAct)
@@ -286,14 +290,14 @@ class TRPreviewer(E5MainWindow):
         menu.addSeparator()
         menu.addAction(self.exitAct)
         
-        self.windowMenu = mb.addMenu(self.trUtf8('&Window'))
+        self.windowMenu = mb.addMenu(self.tr('&Window'))
         self.windowMenu.setTearOffEnabled(True)
         self.windowMenu.aboutToShow.connect(self.__showWindowMenu)
         self.windowMenu.triggered.connect(self.preview.toggleSelectedWidget)
         
         mb.addSeparator()
         
-        menu = mb.addMenu(self.trUtf8('&Help'))
+        menu = mb.addMenu(self.tr('&Help'))
         menu.setTearOffEnabled(True)
         menu.addAction(self.aboutAct)
         menu.addAction(self.aboutQtAct)
@@ -304,7 +308,7 @@ class TRPreviewer(E5MainWindow):
         """
         Private method to create the toolbars.
         """
-        filetb = self.addToolBar(self.trUtf8("File"))
+        filetb = self.addToolBar(self.tr("File"))
         filetb.setIconSize(UI.Config.ToolBarIconSize)
         filetb.addAction(self.openUIAct)
         filetb.addAction(self.openQMAct)
@@ -314,7 +318,7 @@ class TRPreviewer(E5MainWindow):
         filetb.addSeparator()
         filetb.addAction(self.exitAct)
         
-        helptb = self.addToolBar(self.trUtf8("Help"))
+        helptb = self.addToolBar(self.tr("Help"))
         helptb.setIconSize(UI.Config.ToolBarIconSize)
         helptb.addAction(self.whatsThisAct)
     
@@ -350,8 +354,8 @@ class TRPreviewer(E5MainWindow):
         """
         E5MessageBox.about(
             self,
-            self.trUtf8("TR Previewer"),
-            self.trUtf8(
+            self.tr("TR Previewer"),
+            self.tr(
                 """<h3> About TR Previewer </h3>"""
                 """<p>The TR Previewer loads and displays Qt User-Interface"""
                 """ files and translation files and shows dialogs for a"""
@@ -363,7 +367,7 @@ class TRPreviewer(E5MainWindow):
         """
         Private slot to show info about Qt.
         """
-        E5MessageBox.aboutQt(self, self.trUtf8("TR Previewer"))
+        E5MessageBox.aboutQt(self, self.tr("TR Previewer"))
     
     def __openWidget(self):
         """
@@ -371,9 +375,9 @@ class TRPreviewer(E5MainWindow):
         """
         fileNameList = E5FileDialog.getOpenFileNames(
             None,
-            self.trUtf8("Select UI files"),
+            self.tr("Select UI files"),
             "",
-            self.trUtf8("Qt User-Interface Files (*.ui)"))
+            self.tr("Qt User-Interface Files (*.ui)"))
         
         for fileName in fileNameList:
             self.preview.loadWidget(fileName)
@@ -386,9 +390,9 @@ class TRPreviewer(E5MainWindow):
         """
         fileNameList = E5FileDialog.getOpenFileNames(
             None,
-            self.trUtf8("Select translation files"),
+            self.tr("Select translation files"),
             "",
-            self.trUtf8("Qt Translation Files (*.qm)"))
+            self.tr("Qt Translation Files (*.qm)"))
         
         first = True
         for fileName in fileNameList:
@@ -452,7 +456,7 @@ class TranslationsDict(QObject):
             available languages (QComboBox)
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(TranslationsDict, self).__init__(parent)
         
         self.selector = selector
         self.currentTranslator = None
@@ -477,8 +481,8 @@ class TranslationsDict(QObject):
             if ntr.name is None:
                 E5MessageBox.warning(
                     self.parent(),
-                    self.trUtf8("Set Translator"),
-                    self.trUtf8(
+                    self.tr("Set Translator"),
+                    self.tr(
                         """<p>The translation filename <b>{0}</b>"""
                         """ is invalid.</p>""").format(fileName))
                 return
@@ -507,8 +511,8 @@ class TranslationsDict(QObject):
             if trans is None:
                 E5MessageBox.warning(
                     self.parent(),
-                    self.trUtf8("Set Translator"),
-                    self.trUtf8(
+                    self.tr("Set Translator"),
+                    self.tr(
                         """<p>The translator <b>{0}</b> is not known.</p>""")
                     .format(name))
                 return
@@ -650,9 +654,9 @@ class TranslationsDict(QObject):
         
         E5MessageBox.warning(
             self.parent(),
-            self.trUtf8("Load Translator"),
-            self.trUtf8("""<p>The translation file <b>{0}</b> could"""
-                        """ not be loaded.</p>""").format(transFileName))
+            self.tr("Load Translator"),
+            self.tr("""<p>The translation file <b>{0}</b> could"""
+                    """ not be loaded.</p>""").format(transFileName))
         return None
 
     def hasTranslations(self):
@@ -676,11 +680,10 @@ class WidgetView(QWidget):
         @param parent parent widget (QWidget)
         @param name name of this widget (string)
         """
-        super().__init__(parent)
+        super(WidgetView, self).__init__(parent)
         if name:
             self.setObjectName(name)
             self.setWindowTitle(name)
-        self.setAttribute(Qt.WA_DeleteOnClose)
         
         self.__widget = None
         self.__uiFileName = uiFileName
@@ -724,8 +727,8 @@ class WidgetView(QWidget):
         if not self.__widget:
             E5MessageBox.warning(
                 self,
-                self.trUtf8("Load UI File"),
-                self.trUtf8(
+                self.tr("Load UI File"),
+                self.tr(
                     """<p>The file <b>{0}</b> could not be loaded.</p>""")
                 .format(self.__uiFileName))
             self.__valid = False
@@ -761,7 +764,7 @@ class WidgetArea(QMdiArea):
         
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(WidgetArea, self).__init__(parent)
         
         self.setHorizontalScrollBarPolicy(Qt.ScrollBarAsNeeded)
         self.setVerticalScrollBarPolicy(Qt.ScrollBarAsNeeded)
@@ -780,8 +783,8 @@ class WidgetArea(QMdiArea):
             if not name:
                 E5MessageBox.warning(
                     self,
-                    self.trUtf8("Load UI File"),
-                    self.trUtf8(
+                    self.tr("Load UI File"),
+                    self.tr(
                         """<p>The file <b>{0}</b> could not be loaded.</p>""")
                     .format(uiFileName))
                 return
@@ -809,7 +812,7 @@ class WidgetArea(QMdiArea):
     
     def eventFilter(self, obj, ev):
         """
-        Protected method called to filter an event.
+        Public method called to filter an event.
         
         @param obj object, that generated the event (QObject)
         @param ev the event, that was generated by object (QEvent)
