@@ -1,18 +1,20 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a starter for the system tray.
 """
 
+from __future__ import unicode_literals
+
 import sys
 import os
 
-from PyQt4.QtCore import QProcess, QSettings, QFileInfo
-from PyQt4.QtGui import QSystemTrayIcon, QMenu, qApp, QCursor, QDialog, \
-    QApplication
+from PyQt5.QtCore import QProcess, QSettings, QFileInfo
+from PyQt5.QtGui import QCursor
+from PyQt5.QtWidgets import QSystemTrayIcon, QMenu, qApp, QDialog, QApplication
 
 from E5Gui import E5MessageBox
 
@@ -22,21 +24,25 @@ import UI.PixmapCache
 import Utilities
 import Preferences
 
-from eric5config import getConfig
+from eric6config import getConfig
 
 
 class TrayStarter(QSystemTrayIcon):
     """
     Class implementing a starter for the system tray.
     """
-    def __init__(self):
+    def __init__(self, usePyQt4):
         """
         Constructor
+        
+        @param usePyQt4 flag indicating to use PyQt4 (boolean)
         """
-        super().__init__(
+        super(TrayStarter, self).__init__(
             UI.PixmapCache.getIcon(
                 Preferences.getTrayStarter("TrayStarterIcon")))
         
+        self.usePyQt4 = usePyQt4
+        
         self.maxMenuFilePathLen = 75
         
         self.rsettings = QSettings(
@@ -54,97 +60,97 @@ class TrayStarter(QSystemTrayIcon):
         
         self.activated.connect(self.__activated)
         
-        self.__menu = QMenu(self.trUtf8("Eric5 tray starter"))
+        self.__menu = QMenu(self.tr("Eric6 tray starter"))
         
         self.recentProjectsMenu = QMenu(
-            self.trUtf8('Recent Projects'), self.__menu)
+            self.tr('Recent Projects'), self.__menu)
         self.recentProjectsMenu.aboutToShow.connect(
             self.__showRecentProjectsMenu)
         self.recentProjectsMenu.triggered.connect(self.__openRecent)
         
         self.recentMultiProjectsMenu = \
-            QMenu(self.trUtf8('Recent Multiprojects'), self.__menu)
+            QMenu(self.tr('Recent Multiprojects'), self.__menu)
         self.recentMultiProjectsMenu.aboutToShow.connect(
             self.__showRecentMultiProjectsMenu)
         self.recentMultiProjectsMenu.triggered.connect(self.__openRecent)
         
-        self.recentFilesMenu = QMenu(self.trUtf8('Recent Files'), self.__menu)
+        self.recentFilesMenu = QMenu(self.tr('Recent Files'), self.__menu)
         self.recentFilesMenu.aboutToShow.connect(self.__showRecentFilesMenu)
         self.recentFilesMenu.triggered.connect(self.__openRecent)
         
         act = self.__menu.addAction(
-            self.trUtf8("Eric5 tray starter"), self.__about)
+            self.tr("Eric6 tray starter"), self.__about)
         font = act.font()
         font.setBold(True)
         act.setFont(font)
         self.__menu.addSeparator()
         
         self.__menu.addAction(
-            self.trUtf8("QRegExp editor"), self.__startQRegExp)
+            self.tr("QRegExp editor"), self.__startQRegExp)
         self.__menu.addAction(
-            self.trUtf8("Python re editor"), self.__startPyRe)
+            self.tr("Python re editor"), self.__startPyRe)
         self.__menu.addSeparator()
         
         self.__menu.addAction(
             UI.PixmapCache.getIcon("uiPreviewer.png"),
-            self.trUtf8("UI Previewer"), self.__startUIPreviewer)
+            self.tr("UI Previewer"), self.__startUIPreviewer)
         self.__menu.addAction(
             UI.PixmapCache.getIcon("trPreviewer.png"),
-            self.trUtf8("Translations Previewer"), self.__startTRPreviewer)
+            self.tr("Translations Previewer"), self.__startTRPreviewer)
         self.__menu.addAction(
             UI.PixmapCache.getIcon("unittest.png"),
-            self.trUtf8("Unittest"), self.__startUnittest)
+            self.tr("Unittest"), self.__startUnittest)
         self.__menu.addAction(
             UI.PixmapCache.getIcon("ericWeb.png"),
-            self.trUtf8("eric5 Web Browser"), self.__startHelpViewer)
+            self.tr("eric6 Web Browser"), self.__startHelpViewer)
         self.__menu.addSeparator()
         
         self.__menu.addAction(
             UI.PixmapCache.getIcon("diffFiles.png"),
-            self.trUtf8("Compare Files"), self.__startDiff)
+            self.tr("Compare Files"), self.__startDiff)
         self.__menu.addAction(
             UI.PixmapCache.getIcon("compareFiles.png"),
-            self.trUtf8("Compare Files side by side"), self.__startCompare)
+            self.tr("Compare Files side by side"), self.__startCompare)
         self.__menu.addSeparator()
         
         self.__menu.addAction(
             UI.PixmapCache.getIcon("sqlBrowser.png"),
-            self.trUtf8("SQL Browser"), self.__startSqlBrowser)
+            self.tr("SQL Browser"), self.__startSqlBrowser)
         self.__menu.addSeparator()
         
         self.__menu.addAction(
             UI.PixmapCache.getIcon("ericSnap.png"),
-            self.trUtf8("Snapshot"), self.__startSnapshot)
+            self.tr("Snapshot"), self.__startSnapshot)
         self.__menu.addAction(
             UI.PixmapCache.getIcon("iconEditor.png"),
-            self.trUtf8("Icon Editor"), self.__startIconEditor)
+            self.tr("Icon Editor"), self.__startIconEditor)
         self.__menu.addSeparator()
         
         self.__menu.addAction(
             UI.PixmapCache.getIcon("pluginInstall.png"),
-            self.trUtf8("Install Plugin"), self.__startPluginInstall)
+            self.tr("Install Plugin"), self.__startPluginInstall)
         self.__menu.addAction(
             UI.PixmapCache.getIcon("pluginUninstall.png"),
-            self.trUtf8("Uninstall Plugin"), self.__startPluginUninstall)
+            self.tr("Uninstall Plugin"), self.__startPluginUninstall)
         self.__menu.addAction(
             UI.PixmapCache.getIcon("pluginRepository.png"),
-            self.trUtf8("Plugin Repository"), self.__startPluginRepository)
+            self.tr("Plugin Repository"), self.__startPluginRepository)
         self.__menu.addSeparator()
         
         self.__menu.addAction(
             UI.PixmapCache.getIcon("configure.png"),
-            self.trUtf8('Preferences'), self.__startPreferences)
+            self.tr('Preferences'), self.__startPreferences)
         self.__menu.addAction(
             UI.PixmapCache.getIcon("erict.png"),
-            self.trUtf8("eric5 IDE"), self.__startEric)
+            self.tr("eric6 IDE"), self.__startEric)
         self.__menu.addAction(
             UI.PixmapCache.getIcon("editor.png"),
-            self.trUtf8("eric5 Mini Editor"), self.__startMiniEditor)
+            self.tr("eric6 Mini Editor"), self.__startMiniEditor)
         self.__menu.addSeparator()
         
         self.__menu.addAction(
             UI.PixmapCache.getIcon("configure.png"),
-            self.trUtf8('Configure Tray Starter'), self.__showPreferences)
+            self.tr('Configure Tray Starter'), self.__showPreferences)
         self.__menu.addSeparator()
         
         # recent files
@@ -159,7 +165,7 @@ class TrayStarter(QSystemTrayIcon):
         
         self.__menu.addAction(
             UI.PixmapCache.getIcon("exit.png"),
-            self.trUtf8('Quit'), qApp.quit)
+            self.tr('Quit'), qApp.quit)
     
     def __loadRecentProjects(self):
         """
@@ -222,9 +228,9 @@ class TrayStarter(QSystemTrayIcon):
     
     def __startProc(self, applName, *applArgs):
         """
-        Private method to start an eric5 application.
+        Private method to start an eric6 application.
         
-        @param applName name of the eric5 application script (string)
+        @param applName name of the eric6 application script (string)
         @param *applArgs variable list of application arguments
         """
         proc = QProcess()
@@ -232,6 +238,8 @@ class TrayStarter(QSystemTrayIcon):
         
         args = []
         args.append(applPath)
+        if self.usePyQt4:
+            args.append("--pyqt4")
         for arg in applArgs:
             args.append(arg)
         
@@ -239,130 +247,130 @@ class TrayStarter(QSystemTrayIcon):
                 not proc.startDetached(sys.executable, args):
             E5MessageBox.critical(
                 self,
-                self.trUtf8('Process Generation Error'),
-                self.trUtf8(
+                self.tr('Process Generation Error'),
+                self.tr(
                     '<p>Could not start the process.<br>'
                     'Ensure that it is available as <b>{0}</b>.</p>'
                 ).format(applPath),
-                self.trUtf8('OK'))
+                self.tr('OK'))
     
     def __startMiniEditor(self):
         """
-        Private slot to start the eric5 Mini Editor.
+        Private slot to start the eric6 Mini Editor.
         """
-        self.__startProc("eric5_editor.py", "--config={0}".format(
+        self.__startProc("eric6_editor.py", "--config={0}".format(
             Utilities.getConfigDir()))
     
     def __startEric(self):
         """
-        Private slot to start the eric5 IDE.
+        Private slot to start the eric6 IDE.
         """
-        self.__startProc("eric5.py", "--config={0}".format(
+        self.__startProc("eric6.py", "--config={0}".format(
             Utilities.getConfigDir()))
 
     def __startPreferences(self):
         """
-        Private slot to start the eric5 configuration dialog.
+        Private slot to start the eric6 configuration dialog.
         """
-        self.__startProc("eric5_configure.py", "--config={0}".format(
+        self.__startProc("eric6_configure.py", "--config={0}".format(
             Utilities.getConfigDir()))
 
     def __startPluginInstall(self):
         """
-        Private slot to start the eric5 plugin installation dialog.
+        Private slot to start the eric6 plugin installation dialog.
         """
-        self.__startProc("eric5_plugininstall.py", "--config={0}".format(
+        self.__startProc("eric6_plugininstall.py", "--config={0}".format(
             Utilities.getConfigDir()))
 
     def __startPluginUninstall(self):
         """
-        Private slot to start the eric5 plugin uninstallation dialog.
+        Private slot to start the eric6 plugin uninstallation dialog.
         """
-        self.__startProc("eric5_pluginuninstall.py", "--config={0}".format(
+        self.__startProc("eric6_pluginuninstall.py", "--config={0}".format(
             Utilities.getConfigDir()))
 
     def __startPluginRepository(self):
         """
-        Private slot to start the eric5 plugin repository dialog.
+        Private slot to start the eric6 plugin repository dialog.
         """
-        self.__startProc("eric5_pluginrepository.py", "--config={0}".format(
+        self.__startProc("eric6_pluginrepository.py", "--config={0}".format(
             Utilities.getConfigDir()))
 
     def __startHelpViewer(self):
         """
-        Private slot to start the eric5 web browser.
+        Private slot to start the eric6 web browser.
         """
-        self.__startProc("eric5_webbrowser.py", "--config={0}".format(
+        self.__startProc("eric6_webbrowser.py", "--config={0}".format(
             Utilities.getConfigDir()))
 
     def __startUIPreviewer(self):
         """
-        Private slot to start the eric5 UI previewer.
+        Private slot to start the eric6 UI previewer.
         """
-        self.__startProc("eric5_uipreviewer.py", "--config={0}".format(
+        self.__startProc("eric6_uipreviewer.py", "--config={0}".format(
             Utilities.getConfigDir()))
 
     def __startTRPreviewer(self):
         """
-        Private slot to start the eric5 translations previewer.
+        Private slot to start the eric6 translations previewer.
         """
-        self.__startProc("eric5_trpreviewer.py", "--config={0}".format(
+        self.__startProc("eric6_trpreviewer.py", "--config={0}".format(
             Utilities.getConfigDir()))
 
     def __startUnittest(self):
         """
-        Private slot to start the eric5 unittest dialog.
+        Private slot to start the eric6 unittest dialog.
         """
-        self.__startProc("eric5_unittest.py", "--config={0}".format(
+        self.__startProc("eric6_unittest.py", "--config={0}".format(
             Utilities.getConfigDir()))
 
     def __startDiff(self):
         """
-        Private slot to start the eric5 diff dialog.
+        Private slot to start the eric6 diff dialog.
         """
-        self.__startProc("eric5_diff.py", "--config={0}".format(
+        self.__startProc("eric6_diff.py", "--config={0}".format(
             Utilities.getConfigDir()))
 
     def __startCompare(self):
         """
-        Private slot to start the eric5 compare dialog.
+        Private slot to start the eric6 compare dialog.
         """
-        self.__startProc("eric5_compare.py", "--config={0}".format(
+        self.__startProc("eric6_compare.py", "--config={0}".format(
             Utilities.getConfigDir()))
     
     def __startSqlBrowser(self):
         """
-        Private slot to start the eric5 sql browser dialog.
+        Private slot to start the eric6 sql browser dialog.
         """
-        self.__startProc("eric5_sqlbrowser.py", "--config={0}".format(
+        self.__startProc("eric6_sqlbrowser.py", "--config={0}".format(
             Utilities.getConfigDir()))
 
     def __startIconEditor(self):
         """
-        Private slot to start the eric5 icon editor dialog.
+        Private slot to start the eric6 icon editor dialog.
         """
-        self.__startProc("eric5_iconeditor.py", "--config={0}".format(
+        self.__startProc("eric6_iconeditor.py", "--config={0}".format(
             Utilities.getConfigDir()))
 
     def __startSnapshot(self):
         """
-        Private slot to start the eric5 snapshot dialog.
+        Private slot to start the eric6 snapshot dialog.
         """
-        self.__startProc("eric5_snap.py", "--config={0}".format(
+        self.__startProc("eric6_snap.py", "--config={0}".format(
             Utilities.getConfigDir()))
 
     def __startQRegExp(self):
         """
-        Private slot to start the eric5 QRegExp editor dialog.
+        Private slot to start the eric6 QRegExp editor dialog.
         """
-        self.__startProc("eric5_qregexp.py", "--config={0}".format(
+        self.__startProc("eric6_qregexp.py", "--config={0}".format(
             Utilities.getConfigDir()))
 
     def __startPyRe(self):
         """
-        Private slot to start the eric5 Python re editor dialog.
+        Private slot to start the eric6 Python re editor dialog.
         """
-        self.__startProc("eric5_re.py", "--config={0}".format(
+        self.__startProc("eric6_re.py", "--config={0}".format(
             Utilities.getConfigDir()))
 
     def __showRecentProjectsMenu(self):
@@ -440,7 +448,10 @@ class TrayStarter(QSystemTrayIcon):
         """
         filename = act.data()
         if filename:
-            self.__startProc("eric5.py", filename)
+            self.__startProc(
+                "eric6.py",
+                "--config={0}".format(Utilities.getConfigDir()),
+                filename)
     
     def __showPreferences(self):
         """
