@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the authentication dialog for the help browser.
 """
 
-from PyQt4.QtGui import QDialog, QStyle
+from __future__ import unicode_literals
+
+from PyQt5.QtWidgets import QDialog, QStyle
 
 from .Ui_AuthenticationDialog import Ui_AuthenticationDialog
 
@@ -27,7 +29,7 @@ class AuthenticationDialog(QDialog, Ui_AuthenticationDialog):
         @param saveIt flag indicating the value for the save checkbox (boolean)
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(AuthenticationDialog, self).__init__(parent)
         self.setupUi(self)
         
         self.infoLabel.setText(info)
@@ -39,6 +41,9 @@ class AuthenticationDialog(QDialog, Ui_AuthenticationDialog):
         self.iconLabel.setPixmap(
             self.style().standardIcon(QStyle.SP_MessageBoxQuestion).pixmap(
                 32, 32))
+        
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
     
     def setData(self, username, password):
         """
