@@ -1,19 +1,27 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the browser model.
 """
 
-import sys
-import os
-import fnmatch
+from __future__ import unicode_literals
+try:
+    str = unicode
+except NameError:
+    pass
 
-from PyQt4.QtCore import QDir, QModelIndex, QAbstractItemModel, \
-    QFileSystemWatcher, Qt
-from PyQt4.QtGui import QImageReader, QApplication, QFont
+import os
+import sys
+import fnmatch
+import json
+
+from PyQt5.QtCore import QDir, QModelIndex, QAbstractItemModel, \
+    QFileSystemWatcher, Qt, QProcess, QCoreApplication
+from PyQt5.QtGui import QImageReader, QFont
+from PyQt5.QtWidgets import QApplication
 
 import UI.PixmapCache
 import Preferences
@@ -42,15 +50,18 @@ class BrowserModel(QAbstractItemModel):
         @keyparam nopopulate flag indicating to not populate the model
             (boolean)
         """
-        super().__init__(parent)
+        super(BrowserModel, self).__init__(parent)
         
         self.progDir = None
         self.watchedItems = {}
         self.watcher = QFileSystemWatcher(self)
         self.watcher.directoryChanged.connect(self.directoryChanged)
         
+        self.__sysPathInterpreter = ""
+        self.__sysPathItem = None
+        
         if not nopopulate:
-            rootData = QApplication.translate("BrowserModel", "Name")
+            rootData = QCoreApplication.translate("BrowserModel", "Name")
             self.rootItem = BrowserItem(None, rootData)
             
             self.__populateModel()
@@ -226,8 +237,9 @@ class BrowserModel(QAbstractItemModel):
         """
         Public method to clear the model.
         """
+        self.beginResetModel()
         self.rootItem.removeChildren()
-        self.reset()
+        self.endResetModel()
     
     def item(self, index):
         """
@@ -289,7 +301,7 @@ class BrowserModel(QAbstractItemModel):
             filter = QDir.Filters(
                 QDir.AllEntries | QDir.Hidden | QDir.NoDotAndDotDot)
         else:
-            filter = QDir.Filters(QDir.AllEntries | QDir.NoDotAndDotDot)
+            filter = QDir.Filters(QDir.AllEntries | QDir.NoDot | QDir.NoDotDot)
         
         for itm in self.watchedItems[path]:
             oldCnt = itm.childCount()
@@ -350,8 +362,6 @@ class BrowserModel(QAbstractItemModel):
         """
         Private method to populate the browser model.
         """
-        self._addItem(BrowserSysPathItem(self.rootItem), self.rootItem)
-        
         self.toplevelDirs = []
         tdp = Preferences.Prefs.settings.value('BrowserModel/ToplevelDirs')
         if tdp:
@@ -367,6 +377,41 @@ class BrowserModel(QAbstractItemModel):
             itm = BrowserDirectoryItem(self.rootItem, d)
             self._addItem(itm, self.rootItem)
     
+    def interpreterChanged(self, interpreter):
+        """
+        Public method to handle a change of the debug client's interpreter.
+        
+        @param interpreter interpreter of the debug client (string)
+        """
+        if interpreter and "python" in interpreter.lower():
+            if interpreter.endswith("w.exe"):
+                interpreter = interpreter.replace("w.exe", ".exe")
+            if self.__sysPathInterpreter != interpreter:
+                self.__sysPathInterpreter = interpreter
+                # step 1: remove sys.path entry
+                if self.__sysPathItem is not None:
+                    self.beginRemoveRows(
+                        QModelIndex(), self.__sysPathItem.row(),
+                        self.__sysPathItem.row())
+                    self.rootItem.removeChild(self.__sysPathItem)
+                    self.endRemoveRows()
+                    self.__sysPathItem = None
+                
+                if self.__sysPathInterpreter:
+                    # step 2: add a new one
+                    self.__sysPathItem = BrowserSysPathItem(self.rootItem)
+                    self.addItem(self.__sysPathItem)
+        else:
+            # remove sys.path entry
+            if self.__sysPathItem is not None:
+                self.beginRemoveRows(
+                    QModelIndex(), self.__sysPathItem.row(),
+                    self.__sysPathItem.row())
+                self.rootItem.removeChild(self.__sysPathItem)
+                self.endRemoveRows()
+                self.__sysPathItem = None
+            self.__sysPathInterpreter = ""
+    
     def programChange(self, dirname):
         """
         Public method to change the entry for the directory of file being
@@ -437,7 +482,7 @@ class BrowserModel(QAbstractItemModel):
     
     def addItem(self, itm, parent=QModelIndex()):
         """
-        Puplic slot to add an item.
+        Public slot to add an item.
         
         @param itm item to add (BrowserItem)
         @param parent index of parent item (QModelIndex)
@@ -487,7 +532,7 @@ class BrowserModel(QAbstractItemModel):
             filter = QDir.Filters(
                 QDir.AllEntries | QDir.Hidden | QDir.NoDotAndDotDot)
         else:
-            filter = QDir.Filters(QDir.AllEntries | QDir.NoDotAndDotDot)
+            filter = QDir.Filters(QDir.AllEntries | QDir.NoDot | QDir.NoDotDot)
         entryInfoList = qdir.entryInfoList(filter)
         if len(entryInfoList) > 0:
             if repopulate:
@@ -522,19 +567,31 @@ class BrowserModel(QAbstractItemModel):
         @param parentItem reference to the sys.path item to be populated
         @param repopulate flag indicating a repopulation (boolean)
         """
-        if len(sys.path) > 0:
-            if repopulate:
-                self.beginInsertRows(
-                    self.createIndex(parentItem.row(), 0, parentItem),
-                    0, len(sys.path) - 1)
-            for p in sys.path:
-                if p == '':
-                    p = os.getcwd()
-                
-                node = BrowserDirectoryItem(parentItem, p)
-                self._addItem(node, parentItem)
-            if repopulate:
-                self.endInsertRows()
+        if self.__sysPathInterpreter:
+            script = "import sys, json; print(json.dumps(sys.path))"
+            proc = QProcess()
+            proc.start(self.__sysPathInterpreter, ["-c", script])
+            finished = proc.waitForFinished(3000)
+            if finished:
+                procOutput = str(proc.readAllStandardOutput(),
+                                 Preferences.getSystem("IOEncoding"),
+                                 'replace')
+                syspath = [p for p in json.loads(procOutput) if p]
+                if len(syspath) > 0:
+                    if repopulate:
+                        self.beginInsertRows(
+                            self.createIndex(parentItem.row(), 0, parentItem),
+                            0, len(syspath) - 1)
+                    for p in syspath:
+                        if os.path.isdir(p):
+                            node = BrowserDirectoryItem(parentItem, p)
+                        else:
+                            node = BrowserFileItem(parentItem, p)
+                        self._addItem(node, parentItem)
+                    if repopulate:
+                        self.endInsertRows()
+            else:
+                proc.kill()
 
     def populateFileItem(self, parentItem, repopulate=False):
         """
@@ -573,17 +630,18 @@ class BrowserModel(QAbstractItemModel):
             if "@@Coding@@" in keys:
                 node = BrowserCodingItem(
                     parentItem,
-                    QApplication.translate("BrowserModel", "Coding: {0}")
+                    QCoreApplication.translate("BrowserModel", "Coding: {0}")
                     .format(dict["@@Coding@@"].coding))
                 self._addItem(node, parentItem)
             if "@@Globals@@" in keys:
                 node = BrowserClassAttributesItem(
                     parentItem,
                     dict["@@Globals@@"].globals,
-                    QApplication.translate("BrowserModel", "Globals"))
+                    QCoreApplication.translate("BrowserModel", "Globals"))
                 self._addItem(node, parentItem)
             if repopulate:
                 self.endInsertRows()
+        parentItem._populated = True
 
     def populateClassItem(self, parentItem, repopulate=False):
         """
@@ -623,7 +681,7 @@ class BrowserModel(QAbstractItemModel):
         if len(cl.attributes):
             node = BrowserClassAttributesItem(
                 parentItem, cl.attributes,
-                QApplication.translate("BrowserModel", "Attributes"))
+                QCoreApplication.translate("BrowserModel", "Attributes"))
             if repopulate:
                 self.addItem(
                     node, self.createIndex(parentItem.row(), 0, parentItem))
@@ -633,7 +691,7 @@ class BrowserModel(QAbstractItemModel):
         if len(cl.globals):
             node = BrowserClassAttributesItem(
                 parentItem, cl.globals,
-                QApplication.translate("BrowserModel", "Class Attributes"),
+                QCoreApplication.translate("BrowserModel", "Class Attributes"),
                 True)
             if repopulate:
                 self.addItem(
@@ -709,7 +767,7 @@ class BrowserItem(object):
     """
     def __init__(self, parent, data):
         """
-        Constructor.
+        Constructor
         
         @param parent reference to the parent item
         @param data single data of the item
@@ -964,6 +1022,14 @@ class BrowserSysPathItem(BrowserItem):
         self.icon = UI.PixmapCache.getIcon("filePython.png")
         self._populated = False
         self._lazyPopulation = True
+    
+    def name(self):
+        """
+        Public method to return the name of the item.
+        
+        @return name of the item (string)
+        """
+        return "sys.path"
 
 
 class BrowserFileItem(BrowserItem):
@@ -1035,7 +1101,7 @@ class BrowserFileItem(BrowserItem):
         elif self.isJavaScriptFile():
             pixName = "fileJavascript.png"
             self._populated = False
-            self._lazyPopulation = True
+            self._lazyPopulation = sys.version_info[0] == 3
             self._moduleName = os.path.basename(finfo)
         else:
             pixName = "fileMisc.png"
@@ -1166,7 +1232,7 @@ class BrowserFileItem(BrowserItem):
         
         @return flag indicating an eric project file (boolean)
         """
-        return self.fileext in ['.e4m']
+        return self.fileext in ['.e4m', '.e5m']
     
     def isIdlFile(self):
         """
@@ -1262,7 +1328,7 @@ class BrowserClassItem(BrowserItem):
         BrowserItem.__init__(self, parent, name)
         
         self.type_ = BrowserItemClass
-        self.name = name
+        self._name = name
         self._classObject = cl
         self._filename = filename
         
@@ -1282,6 +1348,9 @@ class BrowserClassItem(BrowserItem):
                 self.icon = UI.PixmapCache.getIcon("method.png")
             self.itemData[0] = "{0}({1})".format(
                 name, ", ".join(self._classObject.parameters))
+            if self._classObject.annotation:
+                self.itemData[0] = "{0} {1}".format(
+                    self.itemData[0], self._classObject.annotation)
             # if no defaults are wanted
             # ....format(name,
             #            ", ".join([e.split('=')[0].strip() \
@@ -1302,6 +1371,14 @@ class BrowserClassItem(BrowserItem):
             self._populated = False
             self._lazyPopulation = True
     
+    def name(self):
+        """
+        Public method to return the name of the item.
+        
+        @return name of the item (string)
+        """
+        return '{0}@@{1}'.format(self._filename, self.lineno())
+    
     def fileName(self):
         """
         Public method returning the filename.
@@ -1382,7 +1459,7 @@ class BrowserMethodItem(BrowserItem):
         
         import Utilities.ClassBrowsers.ClbrBaseClasses
         self.type_ = BrowserItemMethod
-        self.name = name
+        self._name = name
         self._functionObject = fn
         self._filename = filename
         if self._functionObject.modifier == \
@@ -1399,6 +1476,9 @@ class BrowserMethodItem(BrowserItem):
             self.icon = UI.PixmapCache.getIcon("method.png")
         self.itemData[0] = "{0}({1})".format(
             name, ", ".join(self._functionObject.parameters))
+        if self._functionObject.annotation:
+            self.itemData[0] = "{0} {1}".format(
+                self.itemData[0], self._functionObject.annotation)
         # if no defaults are wanted
         # ....format(name,
         #            ", ".join([e.split('=')[0].strip()
@@ -1408,6 +1488,14 @@ class BrowserMethodItem(BrowserItem):
             self._populated = False
             self._lazyPopulation = True
     
+    def name(self):
+        """
+        Public method to return the name of the item.
+        
+        @return name of the item (string)
+        """
+        return '{0}@@{1}'.format(self._filename, self.lineno())
+    
     def fileName(self):
         """
         Public method returning the filename.
@@ -1450,9 +1538,9 @@ class BrowserMethodItem(BrowserItem):
         @return true, if this item is less than other (boolean)
         """
         if issubclass(other.__class__, BrowserMethodItem):
-            if self.name.startswith('__init__'):
+            if self._name.startswith('__init__'):
                 return order == Qt.AscendingOrder
-            if other.name.startswith('__init__'):
+            if other._name.startswith('__init__'):
                 return order == Qt.DescendingOrder
         elif issubclass(other.__class__, BrowserClassAttributesItem):
             return order == Qt.DescendingOrder
@@ -1500,6 +1588,14 @@ class BrowserClassAttributesItem(BrowserItem):
             self.icon = UI.PixmapCache.getIcon("attributes.png")
         self.__isClass = isClass
     
+    def name(self):
+        """
+        Public method to return the name of the item.
+        
+        @return name of the item (string)
+        """
+        return '{0}@@{1}'.format(self.parentItem.name(), self.data(0))
+    
     def attributes(self):
         """
         Public method returning the attribute list.
