@@ -1,14 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the browser sort filter proxy model.
 """
 
-from PyQt4.QtCore import QModelIndex
-from PyQt4.QtGui import QSortFilterProxyModel
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import QModelIndex, QSortFilterProxyModel
 
 import Preferences
 
@@ -23,7 +24,7 @@ class BrowserSortFilterProxyModel(QSortFilterProxyModel):
         
         @param parent reference to the parent object (QObject)
         """
-        super().__init__(parent)
+        super(BrowserSortFilterProxyModel, self).__init__(parent)
         self.hideNonPublic = Preferences.getUI("BrowsersHideNonPublic")
         
     def sort(self, column, order):
@@ -35,11 +36,11 @@ class BrowserSortFilterProxyModel(QSortFilterProxyModel):
         """
         self.__sortColumn = column
         self.__sortOrder = order
-        super().sort(column, order)
+        super(BrowserSortFilterProxyModel, self).sort(column, order)
         
     def lessThan(self, left, right):
         """
-        Protected method used to sort the displayed items.
+        Public method used to sort the displayed items.
         
         It implements a special sorting function that takes into account,
         if folders should be shown first, and that __init__ is always the first
@@ -85,7 +86,7 @@ class BrowserSortFilterProxyModel(QSortFilterProxyModel):
 
     def filterAcceptsRow(self, source_row, source_parent):
         """
-        Protected method to filter rows.
+        Public method to filter rows.
         
         It implements a filter to suppress the display of non public
         classes, methods and attributes.
@@ -108,4 +109,4 @@ class BrowserSortFilterProxyModel(QSortFilterProxyModel):
         hideNonPublic = Preferences.getUI("BrowsersHideNonPublic")
         if self.hideNonPublic != hideNonPublic:
             self.hideNonPublic = hideNonPublic
-            self.filterChanged()
+            self.invalidateFilter()
