@@ -1,20 +1,23 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to send bug reports.
 """
 
+from __future__ import unicode_literals
+
 import os
 import mimetypes
 import smtplib
 import socket
 
-from PyQt4.QtCore import Qt, pyqtSlot, qVersion
-from PyQt4.QtGui import QCursor, QHeaderView, QLineEdit, QDialog, \
-    QInputDialog, QApplication, QDialogButtonBox, QTreeWidgetItem
+from PyQt5.QtCore import Qt, pyqtSlot, qVersion
+from PyQt5.QtGui import QCursor
+from PyQt5.QtWidgets import QHeaderView, QLineEdit, QDialog, QInputDialog, \
+    QApplication, QDialogButtonBox, QTreeWidgetItem
 
 from E5Gui import E5MessageBox, E5FileDialog
 
@@ -53,8 +56,8 @@ def _encode_base64(msg):
     msg.set_payload(encdata)
     msg['Content-Transfer-Encoding'] = 'base64'
 
-encoders.encode_base64 = _encode_base64     # WORK AROUND: implement our
-                                            # corrected encoder
+encoders.encode_base64 = _encode_base64
+# WORK AROUND: implement our corrected encoder
 
 
 class EmailDialog(QDialog, Ui_EmailDialog):
@@ -68,25 +71,26 @@ class EmailDialog(QDialog, Ui_EmailDialog):
         @param mode mode of this dialog (string, "bug" or "feature")
         @param parent parent widget of this dialog (QWidget)
         """
-        super().__init__(parent)
+        super(EmailDialog, self).__init__(parent)
         self.setupUi(self)
+        self.setWindowFlags(Qt.Window)
         
         self.__mode = mode
         if self.__mode == "feature":
-            self.setWindowTitle(self.trUtf8("Send feature request"))
-            self.msgLabel.setText(self.trUtf8(
+            self.setWindowTitle(self.tr("Send feature request"))
+            self.msgLabel.setText(self.tr(
                 "Enter your &feature request below."
                 " Version information is added automatically."))
             self.__toAddress = FeatureAddress
         else:
             # default is bug
-            self.msgLabel.setText(self.trUtf8(
+            self.msgLabel.setText(self.tr(
                 "Enter your &bug description below."
                 " Version information is added automatically."))
             self.__toAddress = BugAddress
         
         self.sendButton = self.buttonBox.addButton(
-            self.trUtf8("Send"), QDialogButtonBox.ActionRole)
+            self.tr("Send"), QDialogButtonBox.ActionRole)
         self.sendButton.setEnabled(False)
         self.sendButton.setDefault(True)
         
@@ -113,15 +117,15 @@ class EmailDialog(QDialog, Ui_EmailDialog):
         
     def keyPressEvent(self, ev):
         """
-        Re-implemented to handle the user pressing the escape key.
+        Protected method to handle the user pressing the escape key.
         
         @param ev key event (QKeyEvent)
         """
         if ev.key() == Qt.Key_Escape:
             res = E5MessageBox.yesNo(
                 self,
-                self.trUtf8("Close dialog"),
-                self.trUtf8("""Do you really want to close the dialog?"""))
+                self.tr("Close dialog"),
+                self.tr("""Do you really want to close the dialog?"""))
             if res:
                 self.reject()
         
@@ -140,8 +144,8 @@ class EmailDialog(QDialog, Ui_EmailDialog):
         """
         res = E5MessageBox.yesNo(
             self,
-            self.trUtf8("Close dialog"),
-            self.trUtf8("""Do you really want to close the dialog?"""))
+            self.tr("Close dialog"),
+            self.tr("""Do you really want to close the dialog?"""))
         if res:
             self.reject()
         
@@ -208,7 +212,7 @@ class EmailDialog(QDialog, Ui_EmailDialog):
         msg = self.__encodedText(msgtext)
         msg['From'] = Preferences.getUser("Email")
         msg['To'] = self.__toAddress
-        subject = '[eric5] {0}'.format(self.subject.text())
+        subject = '[eric6] {0}'.format(self.subject.text())
         msg['Subject'] = self.__encodedHeader(subject)
         
         return msg.as_string()
@@ -233,7 +237,7 @@ class EmailDialog(QDialog, Ui_EmailDialog):
         msg = MIMEMultipart()
         msg['From'] = Preferences.getUser("Email")
         msg['To'] = self.__toAddress
-        subject = '[eric5] {0}'.format(self.subject.text())
+        subject = '[eric6] {0}'.format(self.subject.text())
         msg['Subject'] = self.__encodedHeader(subject)
         msg.preamble = mpPreamble
         msg.epilogue = ''
@@ -287,8 +291,8 @@ class EmailDialog(QDialog, Ui_EmailDialog):
                 if not password:
                     password, ok = QInputDialog.getText(
                         self,
-                        self.trUtf8("Mail Server Password"),
-                        self.trUtf8("Enter your mail server password"),
+                        self.tr("Mail Server Password"),
+                        self.tr("Enter your mail server password"),
                         QLineEdit.Password)
                     if not ok:
                         # abort
@@ -297,7 +301,7 @@ class EmailDialog(QDialog, Ui_EmailDialog):
                     server.login(Preferences.getUser("MailServerUser"),
                                  password)
                 except (smtplib.SMTPException, socket.error) as e:
-                    if isinstance(e,  smtplib.SMTPResponseException):
+                    if isinstance(e, smtplib.SMTPResponseException):
                         errorStr = e.smtp_error.decode()
                     elif isinstance(e, socket.error):
                         errorStr = e[1]
@@ -305,8 +309,8 @@ class EmailDialog(QDialog, Ui_EmailDialog):
                         errorStr = str(e)
                     res = E5MessageBox.retryAbort(
                         self,
-                        self.trUtf8("Send bug report"),
-                        self.trUtf8(
+                        self.tr("Send bug report"),
+                        self.tr(
                             """<p>Authentication failed.<br>Reason: {0}</p>""")
                         .format(errorStr),
                         E5MessageBox.Critical)
@@ -323,7 +327,7 @@ class EmailDialog(QDialog, Ui_EmailDialog):
             QApplication.restoreOverrideCursor()
         except (smtplib.SMTPException, socket.error) as e:
             QApplication.restoreOverrideCursor()
-            if isinstance(e,  smtplib.SMTPResponseException):
+            if isinstance(e, smtplib.SMTPResponseException):
                 errorStr = e.smtp_error.decode()
             elif isinstance(e, socket.error):
                 errorStr = e[1]
@@ -331,8 +335,8 @@ class EmailDialog(QDialog, Ui_EmailDialog):
                 errorStr = str(e)
             res = E5MessageBox.retryAbort(
                 self,
-                self.trUtf8("Send bug report"),
-                self.trUtf8(
+                self.tr("Send bug report"),
+                self.tr(
                     """<p>Message could not be sent.<br>Reason: {0}</p>""")
                 .format(errorStr),
                 E5MessageBox.Critical)
@@ -349,7 +353,7 @@ class EmailDialog(QDialog, Ui_EmailDialog):
         """
         fname = E5FileDialog.getOpenFileName(
             self,
-            self.trUtf8("Attach file"))
+            self.tr("Attach file"))
         if fname:
             self.attachFile(fname, False)
         
