@@ -1,16 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to display an error log.
 """
 
+from __future__ import unicode_literals
+
 import os
 
-from PyQt4.QtCore import pyqtSlot
-from PyQt4.QtGui import QDialog, QStyle
+from PyQt5.QtCore import pyqtSlot, Qt
+from PyQt5.QtWidgets import QDialog, QStyle
 
 from .Ui_ErrorLogDialog import Ui_ErrorLogDialog
 
@@ -28,8 +30,9 @@ class ErrorLogDialog(QDialog, Ui_ErrorLogDialog):
             (boolean)
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(ErrorLogDialog, self).__init__(parent)
         self.setupUi(self)
+        self.setWindowFlags(Qt.Window)
         
         pixmap = self.style().standardIcon(QStyle.SP_MessageBoxQuestion)\
             .pixmap(32, 32)
@@ -38,9 +41,9 @@ class ErrorLogDialog(QDialog, Ui_ErrorLogDialog):
         if showMode:
             self.icon.hide()
             self.label.hide()
-            self.deleteButton.setText(self.trUtf8("Delete"))
-            self.keepButton.setText(self.trUtf8("Close"))
-            self.setWindowTitle(self.trUtf8("Error Log"))
+            self.deleteButton.setText(self.tr("Delete"))
+            self.keepButton.setText(self.tr("Close"))
+            self.setWindowTitle(self.tr("Error Log"))
         
         self.__ui = parent
         self.__logFile = logFile
