@@ -1,18 +1,21 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to search for text in files.
 """
 
+from __future__ import unicode_literals
+
 import os
 import re
 
-from PyQt4.QtCore import pyqtSignal, Qt, pyqtSlot
-from PyQt4.QtGui import QCursor, QDialog, QApplication, QMenu, \
-    QDialogButtonBox, QTreeWidgetItem
+from PyQt5.QtCore import pyqtSignal, Qt, pyqtSlot
+from PyQt5.QtGui import QCursor
+from PyQt5.QtWidgets import QDialog, QApplication, QMenu, QDialogButtonBox, \
+    QTreeWidgetItem
 
 from E5Gui.E5Application import e5App
 from E5Gui import E5MessageBox, E5FileDialog
@@ -21,6 +24,7 @@ from .Ui_FindFileDialog import Ui_FindFileDialog
 
 import Utilities
 import Preferences
+import UI.PixmapCache
 
 
 class FindFileDialog(QDialog, Ui_FindFileDialog):
@@ -52,26 +56,28 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         @param replaceMode flag indicating the replace dialog mode (boolean)
         @param parent parent widget of this dialog (QWidget)
         """
-        super().__init__(parent)
+        super(FindFileDialog, self).__init__(parent)
         self.setupUi(self)
-        self.setWindowFlags(Qt.WindowFlags(Qt.Window))
+        self.setWindowFlags(Qt.Window)
+        
+        self.dirSelectButton.setIcon(UI.PixmapCache.getIcon("open.png"))
         
         self.__replaceMode = replaceMode
         
         self.stopButton = \
-            self.buttonBox.addButton(self.trUtf8("Stop"),
+            self.buttonBox.addButton(self.tr("Stop"),
                                      QDialogButtonBox.ActionRole)
         self.stopButton.setEnabled(False)
         
         self.findButton = \
-            self.buttonBox.addButton(self.trUtf8("Find"),
+            self.buttonBox.addButton(self.tr("Find"),
                                      QDialogButtonBox.ActionRole)
         self.findButton.setEnabled(False)
         self.findButton.setDefault(True)
         
         if self.__replaceMode:
             self.replaceButton.setEnabled(False)
-            self.setWindowTitle(self.trUtf8("Replace in Files"))
+            self.setWindowTitle(self.tr("Replace in Files"))
         else:
             self.replaceLabel.hide()
             self.replacetextCombo.hide()
@@ -79,6 +85,9 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         
         self.findProgressLabel.setMaximumWidth(550)
         
+        self.findtextCombo.setCompleter(None)
+        self.replacetextCombo.setCompleter(None)
+        
         self.searchHistory = Preferences.toList(
             Preferences.Prefs.settings.value(
                 "FindFileDialog/SearchHistory"))
@@ -99,11 +108,7 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         self.__section0Size = self.findList.header().sectionSize(0)
         self.findList.setExpandsOnDoubleClick(False)
         if self.__replaceMode:
-            font = self.findList.font()
-            if Utilities.isWindowsPlatform():
-                font.setFamily("Lucida Console")
-            else:
-                font.setFamily("Monospace")
+            font = Preferences.getEditorOtherFonts("MonospacedFont")
             self.findList.setFont(font)
 
         # Qt Designer form files
@@ -152,7 +157,7 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
             self.__lastFileItem.setData(0, self.md5Role, md5)
         
         itm = QTreeWidgetItem(self.__lastFileItem)
-        itm.setTextAlignment(0,  Qt.AlignRight)
+        itm.setTextAlignment(0, Qt.AlignRight)
         itm.setData(0, Qt.DisplayRole, line)
         itm.setData(1, Qt.DisplayRole, text)
         itm.setData(0, self.lineRole, line)
@@ -166,7 +171,7 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         
     def show(self, txt=""):
         """
-        Overwritten method to enable/disable the project button.
+        Public method to enable/disable the project button.
         
         @param txt text to be shown in the searchtext combo (string)
         """
@@ -184,7 +189,7 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
             self.findList.clear()
             self.replacetextCombo.setEditText("")
         
-        super().show()
+        super(FindFileDialog, self).show()
         
     def on_findtextCombo_editTextChanged(self, text):
         """
@@ -370,9 +375,9 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         except re.error as why:
             E5MessageBox.critical(
                 self,
-                self.trUtf8("Invalid search expression"),
-                self.trUtf8("""<p>The search expression is not valid.</p>"""
-                            """<p>Error: {0}</p>""").format(str(why)))
+                self.tr("Invalid search expression"),
+                self.tr("""<p>The search expression is not valid.</p>"""
+                        """<p>Error: {0}</p>""").format(str(why)))
             self.stopButton.setEnabled(False)
             self.findButton.setEnabled(True)
             self.findButton.setDefault(True)
@@ -419,8 +424,11 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         self.findList.setUpdatesEnabled(False)
         progress = 0
         breakSearch = False
+        occurrences = 0
+        fileOccurrences = 0
         for file in files:
             self.__lastFileItem = None
+            found = False
             if self.__cancelSearch or breakSearch:
                 break
             
@@ -448,6 +456,8 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
                 count += 1
                 contains = search.search(line)
                 if contains:
+                    occurrences += 1
+                    found = True
                     start = contains.start()
                     end = contains.end()
                     if self.__replaceMode:
@@ -474,6 +484,8 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
                 
                 QApplication.processEvents()
             
+            if found:
+                fileOccurrences += 1
             progress += 1
             self.findProgress.setValue(progress)
         
@@ -481,7 +493,10 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
             self.findProgress.setMaximum(1)
             self.findProgress.setValue(1)
         
-        self.findProgressLabel.setPath("")
+        resultFormat = self.tr("{0} / {1}", "occurrences / files")
+        self.findProgressLabel.setPath(resultFormat.format(
+            self.tr("%n occurrence(s)", "", occurrences),
+            self.tr("%n file(s)", "", fileOccurrences)))
         
         self.findList.setUpdatesEnabled(True)
         self.findList.sortItems(self.findList.sortColumn(),
@@ -536,7 +551,7 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         """
         directory = E5FileDialog.getExistingDirectory(
             self,
-            self.trUtf8("Select directory"),
+            self.tr("Select directory"),
             self.dirCombo.currentText(),
             E5FileDialog.Options(E5FileDialog.ShowDirsOnly))
             
@@ -606,8 +621,8 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
                 except (UnicodeError, IOError) as err:
                     E5MessageBox.critical(
                         self,
-                        self.trUtf8("Replace in Files"),
-                        self.trUtf8(
+                        self.tr("Replace in Files"),
+                        self.tr(
                             """<p>Could not read the file <b>{0}</b>."""
                             """ Skipping it.</p><p>Reason: {1}</p>""")
                         .format(fn, str(err))
@@ -621,8 +636,8 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
                 if origHash != hash:
                     E5MessageBox.critical(
                         self,
-                        self.trUtf8("Replace in Files"),
-                        self.trUtf8(
+                        self.tr("Replace in Files"),
+                        self.tr(
                             """<p>The current and the original hash of the"""
                             """ file <b>{0}</b> are different. Skipping it."""
                             """</p><p>Hash 1: {1}</p><p>Hash 2: {2}</p>""")
@@ -647,8 +662,8 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
                 except (IOError, Utilities.CodingError, UnicodeError) as err:
                     E5MessageBox.critical(
                         self,
-                        self.trUtf8("Replace in Files"),
-                        self.trUtf8(
+                        self.tr("Replace in Files"),
+                        self.tr(
                             """<p>Could not save the file <b>{0}</b>."""
                             """ Skipping it.</p><p>Reason: {1}</p>""")
                         .format(fn, str(err))
@@ -672,8 +687,8 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         """
         menu = QMenu(self)
         
-        menu.addAction(self.trUtf8("Open"), self.__openFile)
-        menu.addAction(self.trUtf8("Copy Path to Clipboard"),
+        menu.addAction(self.tr("Open"), self.__openFile)
+        menu.addAction(self.tr("Copy Path to Clipboard"),
                        self.__copyToClipboard)
         
         menu.exec_(QCursor.pos())
