@@ -1,15 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the log viewer widget and the log widget.
 """
 
-from PyQt4.QtCore import Qt, pyqtSignal
-from PyQt4.QtGui import QTextEdit, QBrush, QApplication, QMenu, QTextCursor, \
-    QWidget, QHBoxLayout, QTextDocument
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import Qt, pyqtSignal
+from PyQt5.QtGui import QBrush, QTextCursor, QTextDocument
+from PyQt5.QtWidgets import QTextEdit, QApplication, QMenu, QWidget, \
+    QHBoxLayout
 
 from E5Gui.E5Application import e5App
 
@@ -27,7 +30,7 @@ class LogViewer(QWidget):
         
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(LogViewer, self).__init__(parent)
         
         self.setWindowIcon(UI.PixmapCache.getIcon("eric.png"))
         
@@ -92,7 +95,7 @@ class LogViewerEdit(QTextEdit):
         
         @param parent reference to the parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(LogViewerEdit, self).__init__(parent)
         self.setAcceptRichText(False)
         self.setLineWrapMode(QTextEdit.NoWrap)
         self.setReadOnly(True)
@@ -102,14 +105,14 @@ class LogViewerEdit(QTextEdit):
         
         # create the context menu
         self.__menu = QMenu(self)
-        self.__menu.addAction(self.trUtf8('Clear'), self.clear)
-        self.__menu.addAction(self.trUtf8('Copy'), self.copy)
+        self.__menu.addAction(self.tr('Clear'), self.clear)
+        self.__menu.addAction(self.tr('Copy'), self.copy)
         self.__menu.addSeparator()
-        self.__menu.addAction(self.trUtf8('Find'), self.__find)
+        self.__menu.addAction(self.tr('Find'), self.__find)
         self.__menu.addSeparator()
-        self.__menu.addAction(self.trUtf8('Select All'), self.selectAll)
+        self.__menu.addAction(self.tr('Select All'), self.selectAll)
         self.__menu.addSeparator()
-        self.__menu.addAction(self.trUtf8("Configure..."), self.__configure)
+        self.__menu.addAction(self.tr("Configure..."), self.__configure)
         
         self.setContextMenuPolicy(Qt.CustomContextMenu)
         self.customContextMenuRequested.connect(self.__handleShowContextMenu)
@@ -130,7 +133,7 @@ class LogViewerEdit(QTextEdit):
         
     def __appendText(self, txt, error=False):
         """
-        Public method to append text to the end.
+        Private method to append text to the end.
         
         @param txt text to insert (string)
         @param error flag indicating to insert error text (boolean)
