@@ -1,15 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a pixmap cache for icons.
 """
 
+from __future__ import unicode_literals
+
 import os
 
-from PyQt4.QtGui import QPixmap, QIcon, QPainter
+from PyQt5.QtCore import Qt, QSize
+from PyQt5.QtGui import QPixmap, QIcon, QPainter
 
 
 class PixmapCache(object):
@@ -53,7 +56,7 @@ class PixmapCache(object):
 
         @param path path to add (string)
         """
-        if not path in self.searchPath:
+        if path not in self.searchPath:
             self.searchPath.append(path)
 
 pixCache = PixmapCache()
@@ -97,6 +100,37 @@ def getSymlinkIcon(key, cache=pixCache):
     return QIcon(pix1)
 
 
+def getCombinedIcon(keys, cache=pixCache):
+    """
+    Module function to retrieve a symbolic link icon.
+
+    @param keys list of names of icons (string)
+    @param cache reference to the pixmap cache object (PixmapCache)
+    @return the requested icon (QIcon)
+    """
+    height = width = 0
+    pixmaps = []
+    for key in keys:
+        pix = cache.getPixmap(key)
+        if not pix.isNull():
+            height = max(height, pix.height())
+            width = max(width, pix.width())
+            pixmaps.append(pix)
+    if pixmaps:
+        pix = QPixmap(len(pixmaps) * width, height)
+        pix.fill(Qt.transparent)
+        painter = QPainter(pix)
+        x = 0
+        for pixmap in pixmaps:
+            painter.drawPixmap(x, 0, pixmap.scaled(QSize(width, height)))
+            x += width
+        painter.end()
+        icon = QIcon(pix)
+    else:
+        icon = QIcon()
+    return icon
+
+
 def addSearchPath(path, cache=pixCache):
     """
     Module function to add a path to the search path.
