@@ -1,24 +1,27 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
-Module implementing a splashscreen for eric5.
+Module implementing a splashscreen for eric6.
 """
 
+from __future__ import unicode_literals
+
 import os.path
 import logging
 
-from PyQt4.QtCore import Qt
-from PyQt4.QtGui import QApplication, QPixmap, QSplashScreen, QColor
+from PyQt5.QtCore import Qt
+from PyQt5.QtGui import QPixmap, QColor
+from PyQt5.QtWidgets import QApplication, QSplashScreen
 
-from eric5config import getConfig
+from eric6config import getConfig
 
 
 class SplashScreen(QSplashScreen):
     """
-    Class implementing a splashscreen for eric5.
+    Class implementing a splashscreen for eric6.
     """
     def __init__(self):
         """
@@ -28,7 +31,7 @@ class SplashScreen(QSplashScreen):
             os.path.join(getConfig('ericPixDir'), 'ericSplash.png'))
         self.labelAlignment = Qt.Alignment(
             Qt.AlignBottom | Qt.AlignRight | Qt.AlignAbsolute)
-        super().__init__(ericPic)
+        super(SplashScreen, self).__init__(ericPic)
         self.show()
         QApplication.flush()
         
@@ -39,20 +42,21 @@ class SplashScreen(QSplashScreen):
         @param msg message to be shown (string)
         """
         logging.debug(msg)
-        super().showMessage(msg, self.labelAlignment, QColor(Qt.white))
+        super(SplashScreen, self).showMessage(
+            msg, self.labelAlignment, QColor(Qt.white))
         QApplication.processEvents()
         
     def clearMessage(self):
         """
         Public method to clear the message shown.
         """
-        super().clearMessage()
+        super(SplashScreen, self).clearMessage()
         QApplication.processEvents()
 
 
 class NoneSplashScreen(object):
     """
-    Class implementing a "None" splashscreen for eric5.
+    Class implementing a "None" splashscreen for eric6.
     
     This class implements the same interface as the real splashscreen,
     but simply does nothing.
