@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing an auto saver class.
 """
 
-from PyQt4.QtCore import QObject, QBasicTimer, QTime
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import QObject, QBasicTimer, QTime
 
 
 class AutoSaver(QObject):
@@ -25,7 +27,7 @@ class AutoSaver(QObject):
         @param save slot to be called to perform the save operation
         @exception RuntimeError raised, if no parent is given
         """
-        super().__init__(parent)
+        super(AutoSaver, self).__init__(parent)
         
         if parent is None:
             raise RuntimeError("AutoSaver: parent must not be None.")
@@ -56,7 +58,7 @@ class AutoSaver(QObject):
         if evt.timerId() == self.__timer.timerId():
             self.saveIfNeccessary()
         else:
-            super().timerEvent(evt)
+            super(AutoSaver, self).timerEvent(evt)
     
     def saveIfNeccessary(self):
         """
