@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,6 +8,9 @@ Module implementing base classes used by the various class browsers.
 """
 
 
+from __future__ import unicode_literals
+
+
 class _ClbrBase(object):
     """
     Class implementing the base of all class browser objects.
@@ -252,7 +255,7 @@ class Function(ClbrBase):
     Class = 2
     
     def __init__(self, module, name, file, lineno, signature='', separator=',',
-                 modifierType=General):
+                 modifierType=General, annotation=""):
         """
         Constructor
         
@@ -263,10 +266,12 @@ class Function(ClbrBase):
         @param signature parameterlist of the method
         @param separator string separating the parameters
         @param modifierType type of the function
+        @param annotation return annotation
         """
         ClbrBase.__init__(self, module, name, file, lineno)
         self.parameters = [e.strip() for e in signature.split(separator)]
         self.modifier = modifierType
+        self.annotation = annotation
 
 
 class Coding(ClbrBase):
