@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -13,6 +13,8 @@ This is module is based on pyclbr found in the Python 2.2.2 distribution.
 """
 
 
+from __future__ import unicode_literals
+
 import sys
 import imp
 import re
@@ -67,7 +69,9 @@ r"""
         (?: [ \t]* \[ (?: plain | html ) \] )?
         [ \t]* \(
         (?P<MethodSignature> (?: [^)] | \)[ \t]*,? )*? )
-        \) [ \t]* :
+        \) [ \t]*
+        (?P<MethodReturnAnnotation> (?: -> [ \t]* [^:]+ )? )
+        [ \t]* :
     )
 
 |   (?P<Class>
@@ -117,7 +121,7 @@ class VisibilityMixin(ClbrBaseClasses.ClbrVisibilityMixinBase):
     """
     def __init__(self):
         """
-        Method to initialize the visibility.
+        Constructor
         """
         if self.name.startswith('__'):
             self.setPrivate()
@@ -150,7 +154,7 @@ class Function(ClbrBaseClasses.Function, VisibilityMixin):
     Class to represent a Python function.
     """
     def __init__(self, module, name, file, lineno, signature='', separator=',',
-                 modifierType=ClbrBaseClasses.Function.General):
+                 modifierType=ClbrBaseClasses.Function.General, annotation=""):
         """
         Constructor
         
@@ -161,9 +165,11 @@ class Function(ClbrBaseClasses.Function, VisibilityMixin):
         @param signature parameterlist of the method
         @param separator string separating the parameters
         @param modifierType type of the function
+        @param annotation return annotation
         """
         ClbrBaseClasses.Function.__init__(self, module, name, file, lineno,
-                                          signature, separator, modifierType)
+                                          signature, separator, modifierType,
+                                          annotation)
         VisibilityMixin.__init__(self)
 
 
@@ -295,6 +301,9 @@ def readmodule_ex(module, path=[], inpackage=False, isPyFile=False):
             meth_sig = m.group("MethodSignature")
             meth_sig = meth_sig.replace('\\\n', '')
             meth_sig = _commentsub('', meth_sig)
+            meth_ret = m.group("MethodReturnAnnotation")
+            meth_ret = meth_ret.replace('\\\n', '')
+            meth_ret = _commentsub('', meth_ret)
             lineno = lineno + src.count('\n', last_lineno_pos, start)
             last_lineno_pos = start
             if modifierType and modifierIndent == thisindent:
@@ -311,7 +320,7 @@ def readmodule_ex(module, path=[], inpackage=False, isPyFile=False):
                 if thisindent > conditionalsstack[-1]:
                     if not deltaindentcalculated:
                         deltastack.append(thisindent - conditionalsstack[-1])
-                        deltaindent = reduce(lambda x, y:  x + y, deltastack)
+                        deltaindent = reduce(lambda x, y: x + y, deltastack)
                         deltaindentcalculated = 1
                     thisindent -= deltaindent
                 else:
@@ -334,12 +343,14 @@ def readmodule_ex(module, path=[], inpackage=False, isPyFile=False):
                 if cur_class:
                     # it's a method/nested def
                     f = Function(None, meth_name,
-                                 file, lineno, meth_sig, modifierType=modifier)
+                                 file, lineno, meth_sig, annotation=meth_ret,
+                                 modifierType=modifier)
                     cur_class._addmethod(meth_name, f)
             else:
                 # it's a function
                 f = Function(module, meth_name,
-                             file, lineno, meth_sig, modifierType=modifier)
+                             file, lineno, meth_sig, annotation=meth_ret,
+                             modifierType=modifier)
                 if meth_name in dict_counts:
                     dict_counts[meth_name] += 1
                     meth_name = "{0}_{1:d}".format(
