@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -16,6 +16,8 @@ This module is based on pyclbr.py as of Python 2.2.2
 </ul>
 """
 
+from __future__ import unicode_literals
+
 import sys
 import os
 import imp
@@ -124,7 +126,7 @@ r"""
     )
 
 |   (?P<Method>
-        (^ [ \t]* @ (?: PyQt4 \. )? (?: QtCore \. )?
+        (^ [ \t]* @ (?: PyQt[45] \. )? (?: QtCore \. )?
             (?: pyqtSignature | pyqtSlot )
             [ \t]* \(
                 (?P<MethodPyQtSignature> [^)]* )
@@ -137,7 +139,9 @@ r"""
         (?: [ \t]* \[ (?: plain | html ) \] )?
         [ \t]* \(
         (?P<MethodSignature> (?: [^)] | \)[ \t]*,? )*? )
-        \) [ \t]* :
+        \) [ \t]*
+        (?P<MethodReturnAnnotation> (?: -> [ \t]* [^:]+ )? )
+        [ \t]* :
     )
 
 |   (?P<Class>
@@ -463,14 +467,14 @@ class Module(object):
         @param name name of the global to add (string)
         @param attr Attribute object to be added
         """
-        if not name in self.globals:
+        if name not in self.globals:
             self.globals[name] = attr
         else:
             self.globals[name].addAssignment(attr.lineno)
     
     def addDescription(self, description):
         """
-        Protected method to store the modules docstring.
+        Public method to store the modules docstring.
         
         @param description the docstring to be stored (string)
         """
@@ -536,6 +540,8 @@ class Module(object):
                 meth_name = m.group("MethodName")
                 meth_sig = m.group("MethodSignature")
                 meth_sig = meth_sig.replace('\\\n', '')
+                meth_ret = m.group("MethodReturnAnnotation")
+                meth_ret = meth_ret.replace('\\\n', '')
                 if m.group("MethodPyQtSignature") is not None:
                     meth_pyqtSig = m.group("MethodPyQtSignature")\
                                     .replace('\\\n', '')\
@@ -562,7 +568,7 @@ class Module(object):
                             deltastack.append(
                                 thisindent - conditionalsstack[-1])
                             deltaindent = reduce(
-                                lambda x, y:  x + y, deltastack)
+                                lambda x, y: x + y, deltastack)
                             deltaindentcalculated = 1
                         thisindent -= deltaindent
                     else:
@@ -593,7 +599,8 @@ class Module(object):
                             # it's a class method
                             f = Function(
                                 None, meth_name, None, lineno,
-                                meth_sig, meth_pyqtSig, modifierType=modifier)
+                                meth_sig, meth_pyqtSig, modifierType=modifier,
+                                annotation=meth_ret)
                             self.__py_setVisibility(f)
                             cur_class.addMethod(meth_name, f)
                             break
@@ -601,13 +608,15 @@ class Module(object):
                         # it's a nested function of a module function
                         f = Function(
                             self.name, meth_name, self.file, lineno,
-                            meth_sig, meth_pyqtSig, modifierType=modifier)
+                            meth_sig, meth_pyqtSig, modifierType=modifier,
+                            annotation=meth_ret)
                         self.__py_setVisibility(f)
                         self.addFunction(meth_name, f)
                 else:
                     # it's a module function
                     f = Function(self.name, meth_name, self.file, lineno,
-                                 meth_sig, meth_pyqtSig, modifierType=modifier)
+                                 meth_sig, meth_pyqtSig, modifierType=modifier,
+                                 annotation=meth_ret)
                     self.__py_setVisibility(f)
                     self.addFunction(meth_name, f)
                 if not classstack:
@@ -662,7 +671,7 @@ class Module(object):
                 while classstack and \
                         classstack[-1][1] >= thisindent:
                     if classstack[-1][0] is not None and \
-                       isinstance(classstack[-1][0], (Class,  Function)):
+                       isinstance(classstack[-1][0], (Class, Function)):
                         # record the end line of this class or function
                         classstack[-1][0].setEndLine(lineno - 1)
                     del classstack[-1]
@@ -758,7 +767,7 @@ class Module(object):
                          "".join(m.group("ImportList").splitlines())
                          .replace("\\", "").split(',')]
                 for name in names:
-                    if not name in self.imports:
+                    if name not in self.imports:
                         self.imports.append(name)
             
             elif m.start("ImportFrom") >= 0:
@@ -1271,7 +1280,7 @@ class Class(VisibilityBase):
         @param name name of the attribute to add (string)
         @param attr Attribute object to be added
         """
-        if not name in self.attributes:
+        if name not in self.attributes:
             self.attributes[name] = attr
         else:
             self.attributes[name].addAssignment(attr.lineno)
@@ -1295,7 +1304,7 @@ class Class(VisibilityBase):
         @param name name of the global to add (string)
         @param attr Attribute object to be added
         """
-        if not name in self.globals:
+        if name not in self.globals:
             self.globals[name] = attr
         else:
             self.globals[name].addAssignment(attr.lineno)
@@ -1352,7 +1361,7 @@ class Function(VisibilityBase):
     Class = 2
     
     def __init__(self, module, name, file, lineno, signature='',
-                 pyqtSignature=None, modifierType=General):
+                 pyqtSignature=None, modifierType=General, annotation=""):
         """
         Constructor
         
@@ -1363,6 +1372,7 @@ class Function(VisibilityBase):
         @param signature the functions call signature (string)
         @param pyqtSignature the functions PyQt signature (string)
         @param modifierType type of the function
+        @param annotation return annotation
         """
         self.module = module
         self.name = name
@@ -1374,6 +1384,7 @@ class Function(VisibilityBase):
         self.description = ""
         self.pyqtSignature = pyqtSignature
         self.modifier = modifierType
+        self.annotation = annotation
         self.setPublic()
     
     def addDescription(self, description):
