@@ -1,14 +1,32 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
-Package implementing various functions/classes needed everywhere within eric5.
+Package implementing various functions/classes needed everywhere within eric6.
 """
 
+from __future__ import unicode_literals
+try:
+    str = unicode
+    import urllib
+
+    def quote(url):
+        """
+        Replacement for the urllib.quote function because of unicode problems.
+        
+        @param url text to quote (string)
+        @return quoted url (string)
+        """
+        return urllib.quote(url.encode('utf-8'))
+except NameError:
+    basestring = str
+    from urllib.parse import quote    # __IGNORE_WARNING__
+
 import os
 import sys
+import codecs
 import re
 import fnmatch
 import glob
@@ -38,23 +56,25 @@ warnings.showwarning = __showwarning
 
 from codecs import BOM_UTF8, BOM_UTF16, BOM_UTF32
 
-from PyQt4.QtCore import QRegExp, QDir, QProcess, Qt, QByteArray, \
+from PyQt5.QtCore import QRegExp, QDir, QProcess, Qt, QByteArray, \
     qVersion, PYQT_VERSION_STR, QCoreApplication, QCryptographicHash
-from PyQt4.Qsci import QSCINTILLA_VERSION_STR, QsciScintilla
+from PyQt5.Qsci import QSCINTILLA_VERSION_STR, QsciScintilla
 
-from Globals import isWindowsPlatform, isLinuxPlatform, isMacPlatform  # __IGNORE_WARNING__
-from Globals import getConfigDir, setConfigDir  # __IGNORE_WARNING__
-from Globals import getPythonModulesDirectory, getPyQt4ModulesDirectory  # __IGNORE_WARNING__
-from Globals import getQtBinariesPath  # __IGNORE_WARNING__
 # import these methods into the Utilities namespace
+from Globals import (  # __IGNORE_WARNING__
+    isWindowsPlatform, isLinuxPlatform, isMacPlatform, getConfigDir,
+    setConfigDir, getPythonModulesDirectory, getPyQt5ModulesDirectory,
+    getQtBinariesPath)
 
 from E5Gui.E5Application import e5App
 
 from UI.Info import Program, Version
 
 import Preferences
+from Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheck import (  # __IGNORE_WARNING__
+    normalizeCode)
 
-from eric5config import getConfig
+from eric6config import getConfig
 
 configDir = None
 
@@ -104,7 +124,7 @@ class CodingError(Exception):
         
     def __repr__(self):
         """
-        Private method returning a representation of the exception.
+        Special method returning a representation of the exception.
         
         @return string representing the error message
         """
@@ -112,7 +132,7 @@ class CodingError(Exception):
         
     def __str__(self):
         """
-        Private method returning a string representation of the exception.
+        Special method returning a string representation of the exception.
         
         @return string representing the error message
         """
@@ -250,6 +270,34 @@ def decode(text):
     return str(text, "utf-8", "ignore"), 'utf-8-ignore'
 
 
+def readEncodedFileWithEncoding(filename, encoding):
+    """
+    Function to read a file and decode its contents into proper text.
+    
+    @param filename name of the file to read (string)
+    @keyparam encoding encoding to be used to read the file (string)
+    @return tuple of decoded text and encoding (string, string)
+    """
+    f = open(filename, "rb")
+    text = f.read()
+    f.close()
+    if encoding:
+        try:
+            return str(text, encoding), '{0}-selected'.format(encoding)
+        except (UnicodeError, LookupError):
+            pass
+        # Try default encoding
+        try:
+            codec = Preferences.getEditor("DefaultEncoding")
+            return str(text, codec), '{0}-default'.format(codec)
+        except (UnicodeError, LookupError):
+            pass
+        # Assume UTF-8 loosing information
+        return str(text, "utf-8", "ignore"), 'utf-8-ignore'
+    else:
+        return decode(text)
+
+
 def writeEncodedFile(filename, text, orig_coding):
     """
     Function to write a file with properly encoded text.
@@ -339,7 +387,7 @@ def decodeString(text):
             buf += bytes(qb)
             index += 4
         else:
-            buf += bytes(text[index], encoding="utf-8")
+            buf += codecs.encode(text[index], "utf-8")
             index += 1
     buf = buf.replace(b"\x00", b"")
     return decodeBytes(buf)
@@ -397,7 +445,7 @@ def readStringFromStream(stream):
     data = stream.readString()
     if data is None:
         data = b""
-    return data.decode()
+    return data.decode('utf-8')
 
 
 _escape = re.compile("[&<>\"'\u0080-\uffff]")
@@ -548,13 +596,14 @@ def extractFlags(text):
     @return dictionary of string, boolean, complex, float and int
     """
     flags = {}
-    if isinstance(text, str):
-        lines = text.splitlines()
+    if isinstance(text, basestring):
+        lines = text.rstrip().splitlines()
     else:
         lines = text
     for line in reversed(lines):
-        index = line.find("eflag:")
-        if index == -1:
+        try:
+            index = line.index("eflag:")
+        except ValueError:
             # no flag found, don't look any further
             break
         
@@ -749,7 +798,87 @@ def isinpath(file):
             return True
     
     return False
+
+
+def startswithPath(path, start):
+    """
+    Function to check, if a path starts with a given start path.
     
+    @param path path to be checked (string)
+    @param start start path (string)
+    @return flag indicating that the path starts with the given start
+        path (boolean)
+    """
+    if start:
+        if path == start:
+            return True
+        elif normcasepath(toNativeSeparators(path)).startswith(
+                normcasepath(toNativeSeparators(start + "/"))):
+            return True
+        else:
+            return False
+    else:
+        return False
+
+
+def relativePath(path, start):
+    """
+    Function to convert a file path to a path relative to a start path.
+    
+    @param path file or directory name to convert (string)
+    @param start start path (string)
+    @return relative path or unchanged path, if path does not start with
+        the start path (string)
+    """
+    if startswithPath(path, start):
+        if path == start:
+            return ""
+        else:
+            return path[len(start) + 1:]
+    else:
+        return path
+
+
+def relativeUniversalPath(path, start):
+    """
+    Function to convert a file path to a path relative to a start path
+    with universal separators.
+    
+    @param path file or directory name to convert (string)
+    @param start start path (string)
+    @return relative path or unchanged path, if path does not start with
+        the start path with universal separators (string)
+    """
+    return fromNativeSeparators(relativePath(path, start))
+
+
+def absolutePath(path, start):
+    """
+    Public method to convert a path relative to a start path to an
+    absolute path.
+    
+    @param path file or directory name to convert (string)
+    @param start start path (string)
+    @return absolute path (string)
+    """
+    if not os.path.isabs(path):
+        path = os.path.join(start, path)
+    return path
+
+
+def absoluteUniversalPath(path, start):
+    """
+    Public method to convert a path relative to a start path with
+    universal separators to an absolute path.
+    
+    @param path file or directory name to convert (string)
+    @param start start path (string)
+    @return absolute path with native separators (string)
+    """
+    if not os.path.isabs(path):
+        path = toNativeSeparators(os.path.join(start, path))
+    return path
+
 
 def getExecutablePath(file):
     """
@@ -848,7 +977,26 @@ def samepath(f1, f2):
         return True
     
     return False
+
+
+def samefilepath(f1, f2):
+    """
+    Function to compare two paths. Strips the filename.
     
+    @param f1 first filepath for the compare (string)
+    @param f2 second filepath for the compare (string)
+    @return flag indicating whether the two paths represent the
+        same path on disk.
+    """
+    if f1 is None or f2 is None:
+        return False
+    
+    if (normcaseabspath(os.path.dirname(os.path.realpath(f1))) ==
+            normcaseabspath(os.path.dirname(os.path.realpath(f2)))):
+        return True
+    
+    return False
+
 try:
     EXTSEP = os.extsep
 except AttributeError:
@@ -882,8 +1030,8 @@ def joinext(prefix, ext):
     @return the complete filename (string)
     """
     if ext[0] != ".":
-        ext = ".{0}".format(ext)  # require leading separator to match
-                                  # os.path.splitext
+        ext = ".{0}".format(ext)
+        # require leading separator to match os.path.splitext
     return prefix + EXTSEP + ext[1:]
 
 
@@ -952,7 +1100,7 @@ def direntries(path, filesonly=False, pattern=None, followsymlinks=True,
                          '.svn', '_svn',
                          '.hg', '_hg',
                          '.ropeproject', '_ropeproject',
-                         '.eric5project', '_eric5project',
+                         '.eric6project', '_eric6project',
                          '.issues', '_issues']:
                 continue
             
@@ -1255,164 +1403,76 @@ def getPythonVersion():
     @return An integer representing major and minor version number (integer)
     """
     return sys.hexversion >> 16
-    
 
-def compile(file, codestring=""):
+
+def determinePythonVersion(filename, source, editor=None):
     """
-    Function to compile one Python source file to Python bytecode.
+    Function to determine the python version of a given file.
     
-    @param file source filename (string)
-    @param codestring string containing the code to compile (string)
-    @return A tuple indicating status (True = an error was found), the
-        file name, the line number, the index number, the code string
-        and the error message (boolean, string, string, string, string,
-        string). The values are only valid, if the status is True.
+    @param filename name of the file with extension (str)
+    @param source of the file (str)
+    @keyparam editor reference to the editor, if the file is opened
+        already (Editor object)
+    @return Python version if file is Python2 or Python3 (int)
     """
-    import builtins
-    if not codestring:
-        try:
-            codestring = readEncodedFile(file)[0]
-        except (UnicodeDecodeError, IOError):
-            return (False, None, None, None, None, None)
-
-    codestring = codestring.replace("\r\n", "\n")
-    codestring = codestring.replace("\r", "\n")
-
-    if codestring and codestring[-1] != '\n':
-        codestring = codestring + '\n'
+    pyAssignment = {"Python": 2, "Python2": 2, "Python3": 3}
     
-    try:
-        if file.endswith('.ptl'):
-            try:
-                import quixote.ptl_compile
-            except ImportError:
-                return (False, None, None, None, None, None)
-            template = quixote.ptl_compile.Template(codestring, file)
-            template.compile()
-        else:
-            builtins.compile(codestring, file, 'exec')
-    except SyntaxError as detail:
-        import traceback
-        import re
-        index = "0"
-        code = ""
-        error = ""
-        lines = traceback.format_exception_only(SyntaxError, detail)
-        match = re.match(
-            '\s*File "(.+)", line (\d+)',
-            lines[0].replace('<string>', '{0}'.format(file)))
-        if match is not None:
-            fn, line = match.group(1, 2)
-            if lines[1].startswith('SyntaxError:'):
-                error = re.match('SyntaxError: (.+)', lines[1]).group(1)
-            else:
-                code = re.match('(.+)', lines[1]).group(1)
-                for seLine in lines[2:]:
-                    if seLine.startswith('SyntaxError:'):
-                        error = re.match('SyntaxError: (.+)', seLine).group(1)
-                    elif seLine.rstrip().endswith('^'):
-                        index = len(seLine.rstrip()) - 4
-        else:
-            fn = detail.filename
-            line = detail.lineno and detail.lineno or 1
-            error = detail.msg
-        return (True, fn, line, index, code, error)
-    except ValueError as detail:
-        index = "0"
-        code = ""
-        try:
-            fn = detail.filename
-            line = detail.lineno
-            error = detail.msg
-        except AttributeError:
-            fn = file
-            line = "1"
-            error = str(detail)
-        return (True, fn, line, index, code, error)
-    except Exception as detail:
-        try:
-            fn = detail.filename
-            line = detail.lineno
-            index = "0"
-            code = ""
-            error = detail.msg
-            return (True, fn, line, index, code, error)
-        except:         # this catchall is intentional
-            pass
+    if not editor:
+        viewManager = e5App().getObject('ViewManager')
+        editor = viewManager.getOpenEditor(filename)
     
-    return (False, None, None, None, None, None)
+    # Maybe the user has changed the language
+    if editor and editor.getFileType() in pyAssignment:
+        return pyAssignment[editor.getFileType()]
 
-
-def py2compile(file, checkFlakes=False):
-    """
-    Function to compile one Python 2 source file to Python 2 bytecode.
-    
-    @param file source filename (string)
-    @keyparam checkFlakes flag indicating to do a pyflakes check (boolean)
-    @return A tuple indicating status (True = an error was found), the
-        file name, the line number, the index number, the code string,
-        the error message and a list of tuples of pyflakes warnings indicating
-        file name, line number and message (boolean, string, string, string,
-        string, string, list of (string, string, string)). The syntax error
-        values are only valid, if the status is True. The pyflakes list will
-        be empty, if a syntax error was detected by the syntax checker.
-    """
-    interpreter = Preferences.getDebugger("PythonInterpreter")
-    if interpreter == "" or not isinpath(interpreter):
-        return (False, "", "", "", "", "", [(
-            file, "1",
-            QCoreApplication.translate("Utilities",
-                                       "Python2 interpreter not configured.")
-        )])
-    
-    syntaxChecker = os.path.join(getConfig('ericDir'),
-                                 "UtilitiesPython2", "Py2SyntaxChecker.py")
-    args = [syntaxChecker]
-    if checkFlakes:
-        if Preferences.getFlakes("IgnoreStarImportWarnings"):
-            args.append("-fi")
-        else:
-            args.append("-fs")
-    args.append(file)
-    proc = QProcess()
-    proc.setProcessChannelMode(QProcess.MergedChannels)
-    proc.start(interpreter, args)
-    finished = proc.waitForFinished(30000)
-    if finished:
-        output = \
-            str(proc.readAllStandardOutput(),
-                Preferences.getSystem("IOEncoding"),
-                'replace').splitlines()
+    pyVer = 0
+    if filename:
+        flags = extractFlags(source)
+        ext = os.path.splitext(filename)[1]
+        py2Ext = Preferences.getPython("PythonExtensions")
+        py3Ext = Preferences.getPython("Python3Extensions")
+        project = e5App().getObject('Project')
+        basename = os.path.basename(filename)
         
-        if output:
-            syntaxerror = output[0] == "ERROR"
-            if syntaxerror:
-                fn = output[1]
-                line = output[2]
-                index = output[3]
-                code = output[4]
-                error = output[5]
-                return (True, fn, line, index, code, error, [])
+        if "FileType" in flags:
+            pyVer = pyAssignment.get(flags["FileType"], 0)
+        elif project.isOpen() and project.isProjectFile(filename):
+            language = project.getEditorLexerAssoc(basename)
+            if not language:
+                language = Preferences.getEditorLexerAssoc(basename)
+            if language in ['Python2', 'Python3']:
+                pyVer = pyAssignment[language]
+        
+        if pyVer:
+            # Skip the next tests
+            pass
+        elif (Preferences.getProject("DeterminePyFromProject") and
+              project.isOpen() and
+              project.isProjectFile(filename) and
+              ext in py2Ext + py3Ext):
+                    pyVer = pyAssignment.get(project.getProjectLanguage(), 0)
+        elif ext in py2Ext and ext not in py3Ext:
+            pyVer = 2
+        elif ext in py3Ext and ext not in py2Ext:
+            pyVer = 3
+        elif source:
+            if isinstance(source, basestring):
+                line0 = source.splitlines()[0]
             else:
-                index = 6
-                warnings = []
-                while len(output) - index > 3:
-                    if output[index] == "FLAKES_ERROR":
-                        return (True, output[index + 1], output[index + 2], "",
-                                output[index + 3], [])
-                    else:
-                        warnings.append((output[index + 1], output[index + 2],
-                                         output[index + 3]))
-                    index += 4
-                
-                return (False, None, None, None, None, None, warnings)
-        else:
-            return (False, "", "", "", "", "", [])
+                line0 = source[0]
+            if line0.startswith("#!"):
+                if "python3" in line0:
+                    pyVer = 3
+                elif "python" in line0:
+                    pyVer = 2
+        
+        if pyVer == 0 and ext in py2Ext + py3Ext:
+            pyVer = sys.version_info[0]
+        
+        if editor and pyVer:
+            editor.filetype = "Python{0}".format(pyVer)
     
-    return (True, file, "1", "0", "",
-            QCoreApplication.translate(
-                "Utilities", "Python2 interpreter did not finish within 30s."),
-            [])
+    return pyVer
 
 
 ###############################################################################
@@ -1539,14 +1599,18 @@ def generatePySideToolPath(toolname):
     """
     if isWindowsPlatform():
         try:
-            # step 1: try Python3 variant of PySide
+            # step 1: try internal Python variant of PySide
             import PySide       # __IGNORE_EXCEPTION__
             del PySide
             prefix = sys.prefix
         except ImportError:
-            # step 2: check for a Python2 variant
-            prefix = os.path.dirname(
-                Preferences.getDebugger("PythonInterpreter"))
+            # step 2: check for a external Python variant
+            if sys.version_info[0] == 2:
+                prefix = os.path.dirname(
+                    Preferences.getDebugger("Python3Interpreter"))
+            else:
+                prefix = os.path.dirname(
+                    Preferences.getDebugger("PythonInterpreter"))
         if toolname == "pyside-uic":
             return os.path.join(prefix, "Scripts", toolname + '.exe')
         else:
@@ -1564,21 +1628,24 @@ def checkPyside():
         and PySide for Python3 (boolean, boolean)
     """
     try:
-        # step 1: try Python3 variant of PySide
+        # step 1: try internal Python variant of PySide
         import PySide       # __IGNORE_EXCEPTION__
         del PySide
-        py3 = True
+        int_py = True
     except ImportError:
-        py3 = False
+        int_py = False
     
-    # step 2: check for a Python2 variant
-    interpreter = Preferences.getDebugger("PythonInterpreter")
-    if interpreter == "" or not isinpath(interpreter):
-        py2 = False
+    # step 2: check for a external Python variant
+    if sys.version_info[0] == 2:
+        interpreter = Preferences.getDebugger("Python3Interpreter")
     else:
-        py2 = False
+        interpreter = Preferences.getDebugger("PythonInterpreter")
+    if interpreter == "" or not isinpath(interpreter):
+        ext_py = False
+    else:
+        ext_py = False
         checker = os.path.join(getConfig('ericDir'),
-                               "UtilitiesPython2", "PySideImporter.py")
+                               "Utilities", "PySideImporter.py")
         args = [checker]
         proc = QProcess()
         proc.setProcessChannelMode(QProcess.MergedChannels)
@@ -1586,9 +1653,12 @@ def checkPyside():
         finished = proc.waitForFinished(30000)
         if finished:
             if proc.exitCode() == 0:
-                py2 = True
+                ext_py = True
     
-    return py2, py3
+    if sys.version_info[0] == 2:
+        return int_py, ext_py
+    else:
+        return ext_py, int_py
 
 ###############################################################################
 # Other utility functions below
@@ -1603,19 +1673,19 @@ def generateVersionInfo(linesep='\n'):
     @return string with version infos (string)
     """
     try:
-        import sipconfig
-        sip_version_str = sipconfig.Configuration().sip_version_str
-    except ImportError:
+        import sip
+        sip_version_str = sip.SIP_VERSION_STR
+    except (ImportError, AttributeError):
         sip_version_str = "sip version not available"
     
     info = "Version Numbers:{0}  Python {1}{2}".format(
         linesep, sys.version.split()[0], linesep)
-    info += "  Qt {0}{1}  PyQt4 {2}{3}".format(
+    info += "  Qt {0}{1}  PyQt {2}{3}".format(
         qVersion(), linesep, PYQT_VERSION_STR, linesep)
     info += "  sip {0}{1}  QScintilla {2}{3}".format(
         sip_version_str, linesep, QSCINTILLA_VERSION_STR, linesep)
     try:
-        from PyQt4.QtWebKit import qWebKitVersion
+        from PyQt5.QtWebKit import qWebKitVersion
         info += "  WebKit {0}{1}".format(qWebKitVersion(), linesep)
     except ImportError:
         pass
