@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implemting a dialog to show repository information.
 """
 
-from PyQt4.QtGui import QDialog
+from __future__ import unicode_literals
+
+from PyQt5.QtWidgets import QDialog
 
 from .Ui_RepositoryInfoDialog import Ui_VcsRepositoryInfoDialog
 
@@ -23,6 +25,6 @@ class VcsRepositoryInfoDialog(QDialog, Ui_VcsRepositoryInfoDialog):
         @param parent reference to the parent widget (QWidget)
         @param info info data to show (string)
         """
-        super().__init__(parent)
+        super(VcsRepositoryInfoDialog, self).__init__(parent)
         self.setupUi(self)
         self.infoBrowser.setHtml(info)
