@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,15 +8,18 @@ Module implementing a LED to indicate the status of the VCS status monitor
 thread.
 """
 
-from PyQt4.QtCore import Qt
-from PyQt4.QtGui import QColor, QInputDialog, QMenu
+from __future__ import unicode_literals
 
-from E5Gui.E5Led import E5Led, E5LedRectangular
+from PyQt5.QtCore import Qt
+from PyQt5.QtGui import QColor
+from PyQt5.QtWidgets import QInputDialog, QMenu
+
+from E5Gui.E5Led import E5ClickableLed, E5LedRectangular
 
 import Preferences
 
 
-class StatusMonitorLed(E5Led):
+class StatusMonitorLed(E5ClickableLed):
     """
     Class implementing a LED to indicate the status of the VCS status monitor
     thread.
@@ -28,9 +31,12 @@ class StatusMonitorLed(E5Led):
         @param project reference to the project object (Project.Project)
         @param parent reference to the parent object (QWidget)
         """
-        E5Led.__init__(self, parent, shape=E5LedRectangular, rectRatio=1.0)
+        super(StatusMonitorLed, self).__init__(
+            parent, shape=E5LedRectangular, rectRatio=1.0)
         
+        self.__vcsClean = True
         self.project = project
+        
         self.vcsMonitorLedColors = {
             "off": QColor(Qt.lightGray),
             "ok": QColor(Qt.green),
@@ -42,7 +48,7 @@ class StatusMonitorLed(E5Led):
         }
         self.__on = False
         
-        self.setWhatsThis(self.trUtf8(
+        self.setWhatsThis(self.tr(
             """<p>This LED indicates the operating"""
             """ status of the VCS monitor thread (off = monitoring off,"""
             """ green = monitoring on and ok, red = monitoring on, but"""
@@ -50,21 +56,21 @@ class StatusMonitorLed(E5Led):
             """ is given in the tooltip.</p>"""
         ))
         self.setToolTip(
-            self.trUtf8("Repository status checking is switched off")
+            self.tr("Repository status checking is switched off")
         )
         self.setColor(self.vcsMonitorLedColors["off"])
         
         # define a context menu
         self.__menu = QMenu(self)
         self.__checkAct = self.__menu.addAction(
-            self.trUtf8("Check status"), self.__checkStatus)
+            self.tr("Check status"), self.__checkStatus)
         self.__intervalAct = self.__menu.addAction(
-            self.trUtf8("Set interval..."), self.__setInterval)
+            self.tr("Set interval..."), self.__setInterval)
         self.__menu.addSeparator()
         self.__onAct = self.__menu.addAction(
-            self.trUtf8("Switch on"), self.__switchOn)
+            self.tr("Switch on"), self.__switchOn)
         self.__offAct = self.__menu.addAction(
-            self.trUtf8("Switch off"), self.__switchOff)
+            self.tr("Switch off"), self.__switchOff)
         self.__checkActions()
         
         # connect signals to our slots
@@ -72,6 +78,8 @@ class StatusMonitorLed(E5Led):
         self.customContextMenuRequested.connect(self._showContextMenu)
         self.project.vcsStatusMonitorStatus.connect(
             self.__projectVcsMonitorStatus)
+        self.project.getModel().vcsStateChanged.connect(self.__vcsStateChanged)
+        self.clicked.connect(self.__ledClicked)
     
     def __checkActions(self):
         """
@@ -123,10 +131,10 @@ class StatusMonitorLed(E5Led):
         """
         Private slot to change the status check interval.
         """
-        interval,  ok = QInputDialog.getInt(
+        interval, ok = QInputDialog.getInt(
             None,
-            self.trUtf8("VCS Status Monitor"),
-            self.trUtf8("Enter monitor interval [s]"),
+            self.tr("VCS Status Monitor"),
+            self.tr("Enter monitor interval [s]"),
             self.project.getStatusMonitorInterval(),
             0, 3600, 1)
         if ok:
@@ -143,3 +151,27 @@ class StatusMonitorLed(E5Led):
         Private slot to switch the status monitor thread to Off.
         """
         self.project.stopStatusMonitor()
+    
+    def __vcsStateChanged(self, state):
+        """
+        Private slot to handle a change in the vcs state.
+        
+        @param state new vcs state (string)
+        """
+        self.__vcsClean = state == " "
+    
+    def __ledClicked(self, pos):
+        """
+        Private slot to react upon clicks on the LED.
+        
+        @param pos position of the click (QPoint)
+        """
+        if self.__on:
+            vcs = self.project.getVcs()
+            if vcs:
+                if self.__vcsClean:
+                    # call log browser dialog
+                    vcs.vcsLogBrowser(self.project.getProjectPath())
+                else:
+                    # call status dialog
+                    vcs.vcsStatus(self.project.getProjectPath())
