@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the VCS status monitor thread base class.
 """
 
-from PyQt4.QtCore import QThread, QMutex, QWaitCondition, pyqtSignal
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import QThread, QMutex, QWaitCondition, pyqtSignal
 
 
 class VcsStatusMonitorThread(QThread):
@@ -30,7 +32,7 @@ class VcsStatusMonitorThread(QThread):
         @param vcs reference to the version control object
         @param parent reference to the parent object (QObject)
         """
-        super().__init__(parent)
+        super(VcsStatusMonitorThread, self).__init__(parent)
         self.setObjectName("VcsStatusMonitorThread")
         
         self.setTerminationEnabled(True)
@@ -52,13 +54,13 @@ class VcsStatusMonitorThread(QThread):
     
     def run(self):
         """
-        Protected method implementing the tasks action.
+        Public method implementing the tasks action.
         """
         while not self.__stopIt:
             # perform the checking task
             self.statusList = []
             self.vcsStatusMonitorStatus.emit(
-                "wait", self.trUtf8("Waiting for lock"))
+                "wait", self.tr("Waiting for lock"))
             try:
                 locked = self.vcs.vcsExecutionMutex.tryLock(5000)
             except TypeError:
@@ -66,7 +68,7 @@ class VcsStatusMonitorThread(QThread):
             if locked:
                 try:
                     self.vcsStatusMonitorStatus.emit(
-                        "op", self.trUtf8("Checking repository status"))
+                        "op", self.tr("Checking repository status"))
                     res, statusMsg = self._performMonitor()
                 finally:
                     self.vcs.vcsExecutionMutex.unlock()
@@ -75,12 +77,12 @@ class VcsStatusMonitorThread(QThread):
                 else:
                     status = "nok"
                 self.vcsStatusMonitorStatus.emit(
-                    "send", self.trUtf8("Sending data"))
+                    "send", self.tr("Sending data"))
                 self.vcsStatusMonitorData.emit(self.statusList)
                 self.vcsStatusMonitorStatus.emit(status, statusMsg)
             else:
                 self.vcsStatusMonitorStatus.emit(
-                    "timeout", self.trUtf8("Timed out waiting for lock"))
+                    "timeout", self.tr("Timed out waiting for lock"))
             
             if self.autoUpdate and self.shouldUpdate:
                 self.vcs.vcsUpdate(self.projectDir, True)
