@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,11 +8,13 @@ Module implementing an abstract base class to be subclassed by all specific
 VCS interfaces.
 """
 
+from __future__ import unicode_literals
+
 import os
 
-from PyQt4.QtCore import QObject, QThread, QMutex, QProcess, \
+from PyQt5.QtCore import QObject, QThread, QMutex, QProcess, \
     Qt, pyqtSignal
-from PyQt4.QtGui import QApplication
+from PyQt5.QtWidgets import QApplication
 
 from E5Gui import E5MessageBox
 
@@ -47,7 +49,7 @@ class VersionControl(QObject):
         @param parent parent widget (QWidget)
         @param name name of this object (string)
         """
-        super().__init__(parent)
+        super(VersionControl, self).__init__(parent)
         if name:
             self.setObjectName(name)
         self.defaultOptions = {
@@ -253,6 +255,19 @@ class VersionControl(QObject):
         """
         raise RuntimeError('Not implemented')
         
+    def vcsLogBrowser(self, name, isFile=False):
+        """
+        Public method used to view the log of a file/directory in the vcs
+        with a log browser dialog.
+        
+        @param name file/directory name to show the log for (string)
+        @keyparam isFile flag indicating log for a file is to be shown
+            (boolean)
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
+        """
+        raise RuntimeError('Not implemented')
+        
     def vcsDiff(self, name):
         """
         Public method used to view the diff of a file/directory in the vcs.
@@ -580,8 +595,8 @@ class VersionControl(QObject):
         if not procStarted:
             E5MessageBox.critical(
                 None,
-                self.trUtf8('Process Generation Error'),
-                self.trUtf8(
+                self.tr('Process Generation Error'),
+                self.tr(
                     'The process {0} could not be started. '
                     'Ensure, that it is in the search path.'
                 ).format(program))
@@ -628,7 +643,7 @@ class VersionControl(QObject):
 
     def addArguments(self, args, argslist):
         """
-        Protected method to add an argument list to the already present
+        Public method to add an argument list to the already present
         arguments.
         
         @param args current arguments list (list of strings)
@@ -711,7 +726,7 @@ class VersionControl(QObject):
             self.statusMonitorThread = None
             self.__statusMonitorStatus(
                 "off",
-                self.trUtf8("Repository status checking is switched off"))
+                self.tr("Repository status checking is switched off"))
     
     def setStatusMonitorInterval(self, interval, project):
         """
