@@ -1,14 +1,17 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a configuration dialog for the bookmarked files menu.
 """
 
-from PyQt4.QtCore import QFileInfo, Qt, pyqtSlot
-from PyQt4.QtGui import QListWidgetItem, QColor, QDialog
+from __future__ import unicode_literals
+
+from PyQt5.QtCore import QFileInfo, Qt, pyqtSlot
+from PyQt5.QtGui import QColor
+from PyQt5.QtWidgets import QListWidgetItem, QDialog
 
 from E5Gui.E5Completers import E5FileCompleter
 from E5Gui import E5FileDialog
@@ -16,6 +19,7 @@ from E5Gui import E5FileDialog
 from .Ui_BookmarkedFilesDialog import Ui_BookmarkedFilesDialog
 
 import Utilities
+import UI.PixmapCache
 
 
 class BookmarkedFilesDialog(QDialog, Ui_BookmarkedFilesDialog):
@@ -29,16 +33,18 @@ class BookmarkedFilesDialog(QDialog, Ui_BookmarkedFilesDialog):
         @param bookmarks list of bookmarked files (list of strings)
         @param parent parent widget (QWidget)
         """
-        super().__init__(parent)
+        super(BookmarkedFilesDialog, self).__init__(parent)
         self.setupUi(self)
         
+        self.fileButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        
         self.fileCompleter = E5FileCompleter(self.fileEdit)
         
         self.bookmarks = bookmarks[:]
         for bookmark in self.bookmarks:
             itm = QListWidgetItem(bookmark, self.filesList)
             if not QFileInfo(bookmark).exists():
-                itm.setBackgroundColor(QColor(Qt.red))
+                itm.setBackground(QColor(Qt.red))
             
         if len(self.bookmarks):
             self.filesList.setCurrentRow(0)
@@ -86,7 +92,7 @@ class BookmarkedFilesDialog(QDialog, Ui_BookmarkedFilesDialog):
             bookmark = Utilities.toNativeSeparators(bookmark)
             itm = QListWidgetItem(bookmark, self.filesList)
             if not QFileInfo(bookmark).exists():
-                itm.setBackgroundColor(QColor(Qt.red))
+                itm.setBackground(QColor(Qt.red))
             self.fileEdit.clear()
             self.bookmarks.append(bookmark)
         row = self.filesList.currentRow()
@@ -104,9 +110,9 @@ class BookmarkedFilesDialog(QDialog, Ui_BookmarkedFilesDialog):
         itm = self.filesList.item(row)
         itm.setText(bookmark)
         if not QFileInfo(bookmark).exists():
-            itm.setBackgroundColor(QColor(Qt.red))
+            itm.setBackground(QColor(Qt.red))
         else:
-            itm.setBackgroundColor(QColor())
+            itm.setBackground(QColor())
         
     @pyqtSlot()
     def on_deleteButton_clicked(self):
