@@ -1,13 +1,16 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
-Script for eric5 to compile all .ui files to Python source.
+Script for eric6 to compile all .ui files to Python source.
 """
 
+from __future__ import unicode_literals
+from __future__ import print_function
+
 import sys
 import os
 
@@ -16,10 +19,25 @@ def compileUiFiles():
     """
     Compile the .ui files to Python sources.
     """                                                 # __IGNORE_WARNING__
+    # step 1: determine PyQt variant, preferring PyQt5
     try:
-        from PyQt4.uic import compileUiDir
+        import PyQt5        # __IGNORE_WARNING__
+        pyqtVariant = "PyQt5"
     except ImportError:
-        from PyQt4.uic import compileUi
+        import PyQt4    # __IGNORE_WARNING__
+        pyqtVariant = "PyQt4"
+    
+    # step 2: compile the UI files
+    try:
+        if pyqtVariant == "PyQt4":
+            from PyQt4.uic import compileUiDir
+        else:
+            from PyQt5.uic import compileUiDir
+    except ImportError:
+        if pyqtVariant == "PyQt4":
+            from PyQt4.uic import compileUi
+        else:
+            from PyQt5.uic import compileUi
         
         def compileUiDir(dir, recurse=False,            # __IGNORE_WARNING__
                          map=None, **compileUi_args):
@@ -28,7 +46,7 @@ def compileUiFiles():
             directory tree.
             
             Note: This function is a modified version of the one found in
-            PyQt4.
+            PyQt5.
 
             @param dir Name of the directory to scan for files whose name ends
                 with '.ui'. By default the generated Python module is created
@@ -122,5 +140,5 @@ if __name__ == "__main__":
         print(
             "\nAn internal error occured.  Please report all the output of the"
             " program, \nincluding the following traceback, to"
-            " eric5-bugs@eric-ide.python-projects.org.\n")
+            " eric-bugs@eric-ide.python-projects.org.\n")
         raise
